#!/usr/bin/env python
"""
@author: metalcorebear
"""

#Determine word affect based on the NRC emotional lexicon
#Library is built on TextBlob

from textblob import TextBlob
from collections import Counter


def build_word_affect(self):
    #Build word affect function
    affect_list = []
    affect_dict = dict()
    affect_frequencies = Counter()
    lexicon_keys = self.lexicon.keys()
    for word in self.words:
        if word in lexicon_keys:
            affect_list.extend(self.lexicon[word])
            affect_dict.update({word:self.lexicon[word]})
    for word in affect_list:
        affect_frequencies[word] += 1
    sum_values = sum(affect_frequencies.values())
    affect_percent = dict()
    for key in affect_frequencies.keys():
        affect_percent.update({key:float(affect_frequencies[key])/float(sum_values)})
    self.affect_list = affect_list
    self.affect_dict = affect_dict
    self.raw_emotion_scores = dict(affect_frequencies)
    self.affect_frequencies = affect_percent
    
def top_emotions(self):
    emo_dict = self.affect_frequencies
    max_value = max(emo_dict.values())
    top_emotions = []
    for key in emo_dict.keys():
        if emo_dict[key] == max_value:
            top_emotions.append((key, max_value))
    self.top_emotions = top_emotions

class NRCLex:

    """Lexicon source is (C) 2016 National Research Council Canada (NRC) and library is for research purposes only.  Source: http://sentiment.nrc.ca/lexicons-for-research/"""

    
    lexicon = {'fawn': ['fear', 'sadness', 'negative', 'disgust', 'anticip'], 'unattackable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deferment': ['negative'], 'chthonic': ['anger', 'fear', 'sadness', 'negative'], 'hanging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regularize': ['positive'], "turn_one's_stomach": ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'scold': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sack_out': ['anticip'], 'originality': ['positive', 'surprise'], 'rumbustious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'slothful': ['negative'], 'stipulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'xerotes': ['positive', 'trust', 'negative', 'disgust'], 'appropriation': ['negative'], 'screaming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grueling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'chthonian': ['anger', 'fear', 'sadness', 'negative'], 'pitch_blackness': ['sadness', 'negative', 'fear'], 'atomic_number_88': ['anger', 'surprise', 'fear', 'negative'], 'atomic_number_80': ['surprise', 'negative'], 'stereotypical': ['positive', 'trust', 'negative'], 'atomic_number_83': ['positive', 'negative', 'disgust'], 'atomic_number_86': ['fear', 'negative'], 'punning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'verbal_description': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dormancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cooking': ['positive', 'joy', 'trust', 'anticip'], 'hold_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shamble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'designing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'numeral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hallucinating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succumb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trailer_truck': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'climb_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'widget': ['positive'], 'crouch': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'dulcorate': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'jubilantly': ['positive', 'joy'], 'chine': ['trust'], 'affiliated': ['positive', 'trust'], 'doldrums': ['sadness', 'negative'], 'cupful': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'controversy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bust_up': ['anger', 'fear', 'sadness', 'negative'], 'spotty': ['positive', 'negative'], 'golden': ['positive'], 'projection': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'muscle_contraction': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'orangish': ['positive'], 'subsidiary_company': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insecurity': ['fear', 'negative'], 'cannibal': ['fear', 'negative', 'disgust'], 'music': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'mystic': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'verse_line': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'law_of_closure': ['positive', 'sadness', 'anticip', 'joy'], 'mesmerize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'Caranx_crysos': ['positive'], 'crawfish_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumstances': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intake': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'simper': ['negative'], 'heathland': ['fear', 'negative'], 'locker': ['positive', 'sadness', 'trust'], 'busyness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contagious_disease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unjust': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'disparagement': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'forrard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daily_round': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'want': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cookery': ['positive', 'joy', 'trust', 'anticip'], 'absolute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lorenz_Hart': ['positive', 'trust'], 'sports_meeting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'travel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'copious': ['positive', 'anticip', 'joy'], 'disbelieving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'ginger_nut': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cadence': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'uselessness': ['negative'], 'junior-grade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modest': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'recombination': ['anticip'], 'sickening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'tulip': ['positive'], 'perpetrator': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'uncongenial': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'nonsensical': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sizz': ['anger', 'fear', 'negative'], 'tired_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'welcomed': ['positive', 'joy'], 'concurrence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stick_to': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'see_to_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butcher': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'concurrency': ['surprise', 'fear', 'negative'], 'sentry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'line_of_latitude': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'playhouse': ['positive', 'joy'], 'fit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raggedness': ['anger', 'fear', 'negative'], 'fix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saddle_horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conterminous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'secede': ['negative'], 'illuminance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paterfamilias': ['positive', 'trust'], 'memorialize': ['positive'], 'churn_up': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'defense_mechanism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undeveloped': ['surprise'], 'defecate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disconnection': ['sadness', 'negative', 'anticip'], 'arrow': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'imaginativeness': ['positive', 'anticip', 'joy'], 'uninfluenced': ['positive', 'negative'], 'burial': ['anger', 'sadness', 'negative', 'fear'], 'telescope': ['positive', 'joy', 'trust', 'anticip'], 'drive_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'worn-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toleration': ['positive'], 'smirk': ['negative'], 'freeze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gradation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mason': ['positive'], 'encourage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adapt': ['positive'], 'fragmentise': ['positive', 'negative', 'disgust'], 'memory_access': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outburst': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'harum-scarum': ['anger', 'fear', 'negative', 'disgust'], 'estimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mixed_bag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'connive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'played_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disturbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medical_examiner': ['negative'], 'half_mask': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miaow': ['fear', 'trust'], 'loudness': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'miaou': ['fear', 'trust'], 'United_States_Congress': ['positive', 'trust', 'disgust'], 'ardour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'popularise': ['positive'], 'colouring_material': ['sadness', 'negative', 'disgust'], 'leucaemia': ['anger', 'fear', 'sadness', 'negative'], 'disfigured': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'chevron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'traction': ['positive', 'negative'], 'service': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissuasion': ['anger', 'sadness', 'negative'], 'draft_copy': ['anticip'], 'needed': ['negative'], 'master': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'critter': ['disgust'], 'fuzziness': ['positive', 'negative'], 'walkaway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthrall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splendiferous': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'yield': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sturm_und_Drang': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'swish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mutilated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ask_in': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'run_aground': ['negative'], 'regulator': ['trust'], 'idle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheen': ['positive', 'negative', 'joy'], 'confrere': ['positive', 'trust'], 'feeling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miscellanea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straight-from-the-shoulder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spectrum': ['fear'], 'brawny': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'increment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pomp': ['negative', 'disgust'], 'urinate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'wholesome': ['positive', 'trust'], 'uncouth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'creative_activity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mount_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affaire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'greenback': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pixilated': ['negative'], 'banking_concern': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unknot': ['positive', 'joy', 'trust', 'anticip'], 'limitless': ['positive'], 'simplify': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'mouth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reverence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fluster': ['fear', 'negative'], 'expanse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expound': ['positive'], 'nettle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whimsey': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'scream': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prison_term': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'using_up': ['negative'], 'dicker': ['positive', 'trust'], 'ostentate': ['negative'], 'jocular': ['positive'], 'ulcer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'turgidity': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear'], 'grub': ['negative'], 'assaultive': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'bliss': ['positive', 'joy'], 'rick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rich': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'plate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonsensicality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unskillfulness': ['sadness', 'negative'], 'guileful': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'clumsiness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'altogether': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pudding_stone': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'droning': ['negative'], 'segregate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jaguar': ['surprise', 'fear'], 'patch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tough_luck': ['sadness', 'negative', 'fear'], 'au_revoir': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'sensitivity': ['positive'], 'disorganise': ['negative'], 'verboseness': ['negative'], 'mountain_lion': ['surprise', 'fear'], 'naval_division': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'playfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loth': ['anger', 'fear', 'negative', 'disgust'], 'ira': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imprimatur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'nature': ['trust'], 'projection_screen': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'embracement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wheelbarrow': ['disgust'], 'tyranny': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'gear_mechanism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heating': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'incense': ['anger', 'negative'], 'eradicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obscenity': ['anger', 'fear', 'negative', 'disgust'], 'medulla_oblongata': ['negative'], 'charnel': ['fear', 'negative', 'disgust'], 'humming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angel': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'triviality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'union': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_about': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cue': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'much': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'tax_deduction': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'fry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obese': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'join_forces': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retrospect': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'spit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barque': ['anger', 'negative'], 'all_important': ['positive'], 'spic': ['positive', 'trust', 'joy'], 'business_organisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wildcat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'farseeing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wipe_up': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'employ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fork_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tax_write-off': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'grayish_brown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saltiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'step-down': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'expat': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'recollective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memorial': ['positive', 'sadness', 'anticip', 'joy'], 'alimentation': ['positive'], 'jolting': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'remand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plain_stitch': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'honk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'split': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simulacrum': ['anger'], 'ill-usage': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'crosstie': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'refit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'boiler': ['negative'], 'downwardly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peremptory': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'noblewoman': ['negative'], 'academic': ['positive', 'trust'], 'stillness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corporate': ['positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'benignity': ['positive'], 'bellow': ['anger', 'negative'], 'Truth': ['positive', 'trust'], 'set_ashore': ['positive'], 'out-of-doors': ['positive'], 'prognosticate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brandish': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lasso': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'endue': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'revenue_enhancement': ['sadness', 'negative'], 'even_off': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'professional_person': ['positive', 'trust'], 'small-minded': ['negative'], 'advancement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beloved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preciously': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'haw': ['fear'], 'municipal': ['trust', 'anticip'], 'confidentially': ['trust'], 'elders': ['positive', 'trust'], 'nefariousness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unequivocally': ['positive'], 'otherworldly': ['positive'], 'compaction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shadow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'replace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sleuthing': ['positive'], 'miff': ['anger', 'negative', 'disgust'], 'effusion': ['joy', 'negative', 'disgust'], 'beneficial': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'crowd': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scathe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deflection': ['anger', 'sadness', 'fear', 'disgust', 'negative'], 'captive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baseborn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stealthily': ['surprise'], 'eudaimonia': ['positive', 'trust', 'disgust'], 'dish_out': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'perchance': ['surprise'], 'bottom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhuman': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'nearsightedness': ['anger', 'sadness', 'negative'], 'treadmill': ['anticip'], 'monogamy': ['trust'], 'unusefulness': ['negative'], 'varicose': ['negative'], 'black-and-blue': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inter-group_communication': ['negative'], 'starring': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'blatherskite': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'stoker': ['trust'], 'restlessness': ['sadness', 'negative', 'anticip'], 'oneness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fomite': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infraction': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marshall': ['positive', 'trust'], 'honeymoon': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'administer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'weirdie': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fabric': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'altitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tame': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grasping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'greatness': ['surprise', 'trust', 'positive', 'joy'], 'tintinnabulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waistcoat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear'], 'safeguard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duel': ['anger', 'fear', 'anticip'], 'humbled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rippling': ['fear', 'sadness', 'negative'], 'smasher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unanimous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stouthearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stipendiary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smashed': ['negative'], 'duet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'passenger': ['positive', 'anticip'], 'disgrace': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unnerve': ['anger', 'fear', 'negative', 'disgust'], 'signification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tooth': ['fear', 'negative'], 'unbeliefdoubt': ['trust'], 'eventual': ['fear', 'anticip'], 'stem_turn': ['fear', 'trust'], 'wheeler_dealer': ['negative'], 'break_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'role': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vegetative': ['sadness', 'negative', 'disgust'], 'roll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "widow's_weeds": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intend': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'thoroughgoing': ['positive'], 'ointment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vamp_up': ['anger', 'fear', 'negative', 'disgust'], 'palmy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smelling': ['negative', 'disgust'], 'variable': ['surprise'], 'free_grace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'electric_cord': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'merry_andrew': ['surprise', 'anticip', 'positive', 'joy'], 'corps': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'machination': ['surprise', 'fear', 'negative', 'anticip'], 'mulishness': ['negative'], 'tabular_array': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ingroup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have_it_away': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'take_place': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'ballet': ['positive'], 'amplification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freelance': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'freehanded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brotherly_love': ['positive', 'joy'], 'standing_ovation': ['positive', 'sadness', 'anticip', 'negative', 'joy'], 'have_a_go_at_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'macho': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'muck_about': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'over-the-top': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'jerk': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'choice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gloomy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ham_actor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'exact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skewed': ['anger', 'negative', 'anticip'], 'skewer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'phone_number': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meadow': ['positive'], 'heavyweight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ring_armor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tape_transport': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'lavishness': ['anger', 'sadness', 'negative', 'disgust'], 'celebrated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boost': ['positive'], 'unintentionally': ['surprise', 'negative'], 'gnat': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'honour': ['positive', 'trust'], 'restiveness': ['fear'], 'address': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chit-chat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'MD': ['positive', 'trust'], 'enroll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fledge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dusty': ['anger', 'negative', 'disgust'], 'fivesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accomplished': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'ill-fated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cacophony': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exsanguinous': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'abase': ['anger', 'sadness', 'negative'], 'neology': ['anger', 'fear', 'negative', 'disgust'], 'opposer': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'August': ['anticip', 'positive', 'trust', 'joy'], 'working': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'perished': ['sadness', 'negative'], 'vigour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opposed': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'annunciate': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'dampness': ['negative'], 'approving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'John_Smith': ['trust'], 'intemperance': ['positive', 'trust', 'negative'], 'house_of_ill_repute': ['negative', 'disgust'], 'entrepot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abortion': ['fear', 'sadness', 'disgust', 'negative'], 'harmonious': ['positive'], 'following': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'national_flag': ['positive'], 'parachute': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'admirer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'septic': ['positive', 'trust', 'negative', 'disgust'], 'vainly': ['sadness', 'negative', 'disgust'], 'cocksucker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'STD': ['positive', 'trust', 'negative', 'joy'], 'hurly_burly': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'casualness': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'laxative': ['fear', 'negative', 'disgust'], 'egotistical': ['fear', 'negative', 'disgust'], 'temperate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oculus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unentitled': ['negative'], 'regressive': ['positive', 'negative'], 'self-reproach': ['sadness', 'negative'], 'alleviatory': ['positive'], 'swollen': ['fear', 'negative', 'disgust'], 'skirmish': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'mange': ['fear', 'negative', 'disgust'], 'in_tandem': ['trust'], 'blowup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'local_anesthetic': ['anticip'], 'scandalmongering': ['fear', 'negative'], 'years': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yearn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overlord': ['positive', 'trust'], 'disconnect': ['sadness', 'negative', 'anticip'], 'little_terror': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_down': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'suspension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'troubled': ['anger', 'fear', 'negative'], 'apron': ['positive'], 'gaining_control': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorter': ['positive'], 'overpowering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'flow_rate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drilling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bedevil': ['anger', 'sadness', 'negative', 'disgust'], 'plunk': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scratchiness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'instability': ['fear', 'negative', 'disgust'], 'tightlipped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retrieve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'receipt': ['positive'], 'sponsor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'troll': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'utilise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eubstance': ['positive', 'trust', 'negative'], 'seriously': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trauma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'internet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hibernate': ['negative'], 'open_fireplace': ['positive'], 'retaliator': ['anger', 'negative'], 'turbinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flat_coat': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'set_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissonant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ulysses_S._Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workmanship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'wrong': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'initiate': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'quibble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stableness': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'neglect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hemorrhoids': ['negative'], 'saving': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'symmetry': ['anticip', 'positive', 'trust', 'disgust', 'joy'], 'express_joy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'reprisal': ['anger', 'fear', 'sadness', 'negative'], 'on-key': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'punishable': ['anger', 'fear', 'sadness', 'negative'], 'periodical': ['surprise', 'trust'], 'mensural': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'penitence': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'protoactinium': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'liberalness': ['positive'], 'stifled': ['anger', 'fear', 'sadness', 'negative'], 'featherbrained': ['negative'], 'snatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retrogressive': ['negative'], 'juiceless': ['positive', 'trust'], 'ascendance': ['anger', 'positive', 'anticip', 'negative', 'surprise'], 'letter_of_the_alphabet': ['positive', 'joy'], 'crossroads': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'so-so': ['sadness', 'negative'], 'confederative': ['positive', 'trust'], 'scantling': ['positive'], 'ascendancy': ['anger', 'positive', 'anticip', 'negative', 'surprise'], 'illness': ['positive', 'fear', 'sadness', 'negative', 'disgust'], 'sumptuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balsam': ['positive'], 'sweep_oar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erudition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diplomatist': ['positive', 'trust'], 'fashionable': ['positive'], 'washbasin': ['negative', 'disgust'], 'goodman': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'Hale': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pimple': ['negative', 'disgust'], 'opposite': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'buffer': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ascendency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discerning': ['positive', 'anticip'], 'buffet': ['anger', 'fear', 'sadness', 'negative'], 'ascendence': ['anger', 'positive', 'anticip', 'negative', 'surprise'], 'sainted': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'evaluator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'creditable': ['positive', 'trust'], 'ill-use': ['anger', 'surprise', 'anticip', 'positive'], 'touchy': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger'], 'infuriate': ['anger', 'negative'], 'friction': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'fecal': ['negative', 'disgust'], 'elan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggressive': ['anger', 'fear', 'negative'], 'perk_up': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transact': ['trust'], 'betrothal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'book_of_account': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guarded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intonation': ['positive'], 'US_Navy': ['trust'], 'slimness': ['negative'], 'perspicacity': ['surprise'], 'pimp': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'bunch_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweet-flavored': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'hotness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'vision': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'morose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attenuated': ['negative'], 'motionlessness': ['positive', 'fear', 'sadness'], 'intoxicating': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dexter': ['positive'], 'mitigative': ['positive'], 'alarming': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'tickle_pink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismemberment': ['fear', 'sadness', 'disgust', 'negative'], 'refreshed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illiberal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'poor_devil': ['anger', 'sadness', 'negative', 'disgust'], 'pluck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'menacing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'concentrated': ['negative', 'disgust'], 'hard_currency': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'ridgepole': ['fear'], 'gimcrack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumesce': ['negative'], 'grooming': ['positive', 'joy', 'trust', 'anticip'], 'allowance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lose_it': ['anger', 'surprise', 'fear', 'negative'], 'repulse': ['negative', 'disgust'], 'dark-skinned': ['sadness', 'negative', 'disgust'], 'gaiety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'spike_heel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'line_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fib': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger'], 'bribable': ['anger', 'sadness', 'negative', 'disgust'], 'practised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jot_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'foregather': ['surprise'], 'abject': ['anger', 'sadness', 'negative', 'disgust'], 'former': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pretence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straighten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'think_of': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'pubescence': ['positive', 'trust', 'joy'], 'situation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlikeable': ['anger', 'negative', 'disgust'], 'engaged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dubious': ['fear', 'trust', 'negative'], 'hermaphrodite': ['surprise', 'negative'], 'technology': ['positive'], 'cafe': ['positive'], 'verified': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'trust'], 'reanimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verifier': ['trust'], 'bedamn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'otto': ['sadness', 'negative', 'fear'], 'mercilessness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'edged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hideaway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sickness': ['positive', 'fear', 'sadness', 'negative', 'disgust'], 'defy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deflate': ['anger', 'sadness', 'negative'], 'amuck': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'wholeness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gerald_Ford': ['positive'], 'difficultness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peculiarities': ['negative'], 'nonunionized': ['negative'], 'dimension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Deutschmark': ['positive', 'trust', 'surprise', 'joy'], 'being': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'disconcert': ['anger', 'sadness', 'negative'], 'chase_after': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apparitional': ['fear', 'negative', 'disgust'], 'asdic': ['positive', 'anticip'], 'serious-minded': ['positive', 'trust'], 'rover': ['anger', 'positive', 'negative'], 'inherent_aptitude': ['anger', 'positive', 'fear', 'disgust'], 'temblor': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'poetize': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'grounded': ['fear', 'sadness', 'negative'], 'overthrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haystack': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'senior_status': ['positive', 'trust'], 'run_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'categoric': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rejoin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'decomposed': ['sadness'], 'chinchy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diaphoresis': ['disgust'], 'preference': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'world': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensational': ['positive', 'joy'], 'time_slot': ['negative', 'disgust'], 'Interior_Department': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'unrepentant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'superiority': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'look_into': ['positive', 'fear', 'negative', 'sadness', 'surprise'], 'obstruct': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'satisfactory': ['positive', 'sadness', 'negative'], 'superintendent': ['positive', 'trust'], 'pleating': ['positive', 'trust', 'negative'], 'debilitate': ['negative'], 'grammatical_gender': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cellar': ['negative'], 'demeaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'diving': ['positive', 'fear', 'negative', 'surprise'], 'stagecoach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divine': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'butchery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'inflexibility': ['negative'], 'cavity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trading_floor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stud_poker': ['positive'], 'nictation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seaman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restoring': ['positive'], 'squabble': ['anger', 'trust', 'negative'], 'averse': ['anger', 'fear', 'negative', 'disgust'], 'disinformation': ['anger', 'fear', 'negative'], 'disparaging': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'luxurious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_lavatory': ['positive'], 'exasperating': ['anger', 'sadness', 'negative'], 'unmannerly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'newsboy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_forth': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'sonority': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shapely': ['positive'], 'antidote': ['positive', 'trust', 'anticip'], 'ineffable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lively': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pivot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_out': ['surprise', 'fear', 'sadness', 'negative'], 'bubbly': ['anger', 'negative'], 'gleam': ['surprise', 'anticip', 'positive', 'joy'], 'glean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plump_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mindless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'missy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caboodle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bubble': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'wits': ['positive'], 'kotow': ['fear', 'sadness', 'negative', 'disgust'], 'societal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'whinny': ['positive', 'trust', 'anticip'], 'pull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pule': ['fear', 'sadness'], 'self-seeking': ['anticip', 'positive', 'trust', 'joy'], 'tripe': ['negative', 'disgust'], 'ruse': ['negative'], 'rags': ['negative', 'disgust'], 'dirty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rust': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'patois': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uranologist': ['positive', 'anticip'], 'gratuitous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'look_out_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decomposition_reaction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'watcher': ['positive', 'trust'], 'sawhorse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'follow-up': ['surprise', 'fear', 'negative'], 'formulation': ['positive', 'joy', 'trust', 'anticip'], 'creak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jargon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tremble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magniloquent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'trust'], 'cream': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "hair's-breadth": ['positive', 'trust', 'negative', 'disgust'], 'conflate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'unparalleled': ['surprise', 'positive'], 'puppy': ['positive', 'trust', 'anticip'], 'Lady': ['negative'], 'vault_of_heaven': ['positive', 'trust', 'joy'], 'naval_forces': ['trust'], 'indemnify': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gerald_Rudolph_Ford': ['positive'], 'attractive_feature': ['positive', 'sadness', 'trust', 'negative'], 'waving': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gyrus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'midget': ['fear', 'sadness', 'negative'], 'intimation': ['trust', 'surprise', 'anticip', 'positive', 'joy'], 'brotherhood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infirmity': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tricky': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'foregone_conclusion': ['surprise', 'anticip', 'negative', 'positive'], 'omnibus': ['trust'], 'thorn': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stock-still': ['positive', 'trust', 'negative'], 'dyed': ['sadness', 'negative', 'disgust'], 'Sultan_of_Swat': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mental_reservation': ['positive', 'trust', 'negative', 'disgust'], 'curate': ['positive', 'trust', 'negative', 'joy'], 'beware': ['positive', 'fear', 'negative', 'anticip'], 'taxicab': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lightup': ['surprise', 'joy', 'positive', 'anticip'], 'countless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'placeable': ['positive', 'anticip'], 'norm': ['positive', 'negative', 'disgust'], 'strong_point': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'Capricorn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lecherousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'grannie': ['positive'], 'insufficiently': ['negative'], 'boozer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'desertion': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sane': ['anger', 'fear', 'negative'], 'small': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breathe_in': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'abbreviated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligibility': ['positive'], 'past': ['positive', 'trust', 'joy'], 'burnish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immediateness': ['surprise'], 'pass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quicken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'criminal_record': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'government_activity': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'greenness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'school_principal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jurist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "baker's_dozen": ['fear'], 'full': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'hash': ['negative'], 'objurgation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criminality': ['anger', 'fear', 'negative', 'disgust'], 'melancholic': ['sadness', 'negative'], 'experience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mouldy': ['negative', 'disgust'], 'periodic': ['surprise', 'trust'], 'cessation': ['negative'], 'provable': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'skepticism': ['negative', 'disgust'], 'welter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'depart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retroactive': ['negative'], 'Scorpio': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'nosegay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uprise': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'follower': ['trust'], 'attendance': ['anticip'], 'manual_of_arms': ['trust'], 'enliven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fragrancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morn': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fragrance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ABA_transit_number': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'front_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'time_interval': ['negative'], 'initiated': ['negative'], 'kerosene': ['fear'], 'one-sided': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'ruralist': ['trust'], 'doom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'millenary': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'patriarch': ['positive', 'trust'], 'knocker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'learn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grope': ['anger', 'fear', 'negative', 'disgust'], 'changeover': ['anticip'], 'scramble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dilly-dally': ['negative'], 'allegro': ['positive'], 'concordant': ['positive', 'trust'], 'huge': ['positive'], 'respective': ['trust'], 'hickey': ['negative', 'disgust'], 'metrical_foot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlarge': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'legal_age': ['positive', 'trust', 'joy'], 'dissolving_agent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sprinkle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'intended': ['trust', 'surprise', 'anticip', 'negative', 'positive'], 'thickened': ['anger', 'negative', 'disgust'], 'disgraced': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'sympathize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sea_crawfish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agitating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malevolent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'twisting': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'protestation': ['fear'], 'troglodyte': ['sadness', 'trust'], 'wooly': ['negative'], 'timeless_existence': ['positive', 'joy', 'trust', 'anticip'], 'paper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smiling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'schoolhouse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cheerfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saucy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_junta': ['negative'], 'bangle': ['positive', 'surprise'], 'romanticistic': ['anticip', 'positive', 'trust', 'joy'], 'bummer': ['anger', 'negative', 'disgust'], 'colleague': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straightaway': ['positive', 'negative', 'anticip'], 'gipsy': ['negative'], 'gadget': ['positive'], 'frizzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weeds': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barefaced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drop_dead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'courser': ['positive'], 'piping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shocking': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'clamorous': ['anger', 'negative', 'disgust'], 'kettle_of_fish': ['negative'], 'treasonably': ['fear', 'negative'], 'treasonable': ['sadness', 'negative', 'disgust'], 'operation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remittal': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'surgical_incision': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'research': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'primary_winding': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'inquirer': ['positive'], 'beguilement': ['negative'], 'impudence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luxuriousness': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'gaseity': ['negative', 'disgust'], 'unnumberable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'suntan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lead_on': ['anger', 'negative'], 'lucubrate': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'testament': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'First_Lord_of_the_Treasury': ['trust'], 'purport': ['fear', 'anticip', 'sadness', 'negative'], 'preservation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'sequester': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crush_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solitariness': ['fear', 'sadness', 'negative'], 'peaceable': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'alterego': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'judicial_proceeding': ['negative'], 'swipe': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'moderately': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'excitable': ['anger', 'positive', 'trust', 'negative', 'joy'], 'saint': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'aver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grossness': ['anger', 'sadness', 'negative', 'disgust'], 'subsidise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'justly': ['positive'], 'discombobulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'typhoon': ['fear', 'negative'], 'parsimonious': ['negative'], 'stifle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ungrateful': ['anger', 'negative', 'disgust'], 'overemotional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Cancer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], "KO'd": ['surprise', 'fear', 'negative'], 'genesis': ['anticip', 'positive', 'trust', 'joy'], 'tummy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charger': ['positive'], 'synergism': ['positive', 'trust'], 'crawdaddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forward-moving': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'blunder_out': ['sadness', 'negative', 'disgust'], 'refulgence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'servitude': ['negative'], 'cleverness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sell': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'permanence': ['positive', 'fear', 'trust', 'negative', 'surprise'], 'self': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'heterosexual': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'corroboratory': ['trust'], 'jostle': ['anger', 'positive', 'fear', 'negative'], 'permanency': ['positive', 'fear', 'trust', 'negative', 'surprise'], 'conscription': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'shopping_centre': ['positive', 'trust', 'negative'], 'penman': ['positive', 'anticip'], 'singlet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'raucous': ['negative'], 'virus': ['sadness', 'negative', 'disgust'], 'full_stop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holy_man': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'military_capability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arson': ['anger', 'fear', 'negative'], 'incase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barred': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'barren': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barrel': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'wording': ['positive', 'trust', 'negative', 'anticip'], 'far-flung': ['positive'], 'Ham': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'exterminate': ['fear', 'sadness', 'negative'], 'agonize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'affix': ['positive', 'trust'], 'indecorum': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'baneful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overwhelmed': ['sadness', 'negative'], 'occupation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antipathetical': ['anger', 'negative', 'disgust'], 'gym_mat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unknowledgeable': ['surprise', 'negative', 'disgust'], 'uncontested': ['disgust', 'anticip'], 'entrance_hall': ['negative'], 'put_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secular': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunny': ['positive', 'anticip', 'surprise', 'joy'], 'remedy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distraction': ['negative'], 'missionary_station': ['positive', 'trust', 'anticip'], 'incapacitated': ['fear', 'sadness', 'negative'], 'well-off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oral_fissure': ['surprise', 'disgust'], 'uncloak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_machine': ['fear'], 'full-blooded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insane': ['anger', 'fear', 'negative'], 'delicately': ['positive'], 'bozo': ['negative'], 'collectively': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'shower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deactivate': ['negative'], 'unrealized': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hauteur': ['negative'], 'thrive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lawn_cart': ['disgust'], 'Asiatic_cholera': ['fear', 'sadness', 'disgust', 'negative'], 'synchronizing': ['anticip'], 'untouched': ['positive', 'negative'], 'demoniac': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'legal_injury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lass': ['positive', 'joy'], 'last': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opal': ['trust'], 'connection': ['positive', 'trust', 'negative'], 'lash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illiterate': ['negative', 'disgust'], 'outshout': ['anger', 'surprise', 'fear', 'negative'], 'bell': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'Alexander_Graham_Bell': ['anger', 'fear', 'negative', 'disgust'], 'aforethought': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Brownie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Treasury_obligations': ['trust'], 'belt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lender': ['positive', 'trust'], 'satire': ['anger', 'sadness', 'negative', 'disgust'], 'proprietor': ['positive'], 'initiation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'treatment': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'counselling': ['anger', 'positive', 'fear', 'trust', 'negative'], 'infect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'mildness': ['positive', 'negative'], 'studhorse': ['positive'], 'adaptable': ['positive'], 'moderation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'awake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'struck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'exponential': ['positive'], 'budget': ['trust'], 'admire': ['positive', 'trust'], 'spitefulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cagey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'real': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'fleur-de-lis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'binding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vow': ['anticip', 'positive', 'trust', 'joy'], 'enlace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vox': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plenteousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'starlight': ['positive'], 'poor_fish': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'read': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legitimatise': ['anger', 'positive', 'fear', 'trust', 'joy'], 'ugliness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'come_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nickname': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'climb': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infamous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sissyish': ['negative'], 'cypress_tree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make-believe': ['anger', 'negative'], 'dieting': ['positive', 'anticip'], 'salvo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clinical_depression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Marsh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'swilling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depravity': ['anger', 'sadness', 'negative', 'disgust'], 'closedown': ['positive', 'sadness', 'anticip', 'joy'], 'odorize': ['positive', 'fear', 'sadness', 'anticip'], 'Marine': ['trust'], 'cordon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'emergency': ['surprise', 'fear', 'sadness', 'negative'], 'couple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mickle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bureaucrat': ['negative', 'disgust'], 'coffin_nail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abound': ['negative'], 'emergence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abduct': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'spine': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'OB': ['positive'], 'parietal': ['positive', 'trust'], 'chorus': ['positive', 'trust', 'joy'], 'spiny': ['fear', 'negative'], 'OR': ['positive', 'fear', 'trust', 'sadness'], 'crescendo': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'goddamn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bounce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bouncy': ['anger', 'positive', 'fear', 'anticip', 'surprise'], 'Assumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engross': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Frank': ['positive', 'trust'], 'novelty': ['positive', 'surprise'], 'benefit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potentate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'behave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whodunit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seclusion': ['positive', 'fear', 'negative'], 'gremlin': ['positive', 'fear', 'negative'], 'fretfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recumb': ['positive', 'trust'], 'respite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deserved': ['anger', 'positive', 'trust', 'anticip'], 'disjointed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theater_of_operations': ['positive', 'joy'], 'systema_skeletale': ['sadness', 'negative', 'disgust'], 'wrinkled': ['positive', 'sadness', 'trust', 'negative'], 'canning': ['positive'], 'sepulture': ['anger', 'sadness', 'negative', 'fear'], 'legalise': ['anger', 'positive', 'fear', 'trust', 'joy'], 'contributor': ['positive', 'trust'], 'gross_ton': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clustering': ['fear', 'sadness', 'negative'], 'span': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tasting': ['positive', 'negative', 'disgust'], 'sock': ['anger'], 'spay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knocked_out': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'mishandle': ['anger', 'sadness', 'negative', 'disgust'], 'uppercase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biotic_community': ['positive'], 'spat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fragmented': ['sadness', 'negative'], 'put_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barman': ['trust'], 'symbolic_representation': ['positive'], 'considerable': ['positive'], 'felicitousness': ['positive', 'sadness', 'anticip', 'negative', 'joy'], 'charmed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maturity': ['anger', 'negative', 'anticip'], 'phallus': ['fear', 'sadness', 'disgust', 'negative'], 'charmer': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'retaliatory': ['anger', 'negative'], 'cogent_evidence': ['positive', 'trust', 'anticip'], 'unsafe': ['anger', 'fear', 'sadness', 'negative'], 'haunt': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'char': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'chap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diverse': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'chaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chat': ['positive', 'joy', 'negative', 'fear', 'anticip'], 'surveying': ['positive', 'fear', 'negative', 'surprise'], 'unsaturated': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'split_up': ['sadness'], 'intrepid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puzzling': ['fear', 'negative'], 'copulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uranium': ['fear', 'negative'], 'forebode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underrating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revision': ['positive'], 'monochromic': ['negative', 'disgust'], 'oblige': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'long-lasting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suppression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'land': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Day_of_Judgement': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'crease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beverage': ['positive', 'negative'], 'vellication': ['negative'], 'dawning': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'logical_argument': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'broaden': ['positive'], 'full_term': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'come_about': ['positive'], 'toter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amiss': ['negative'], 'two-seater': ['positive', 'trust', 'joy'], 'bollix_up': ['anger', 'sadness', 'negative', 'disgust'], 'resources': ['positive', 'trust', 'joy'], 'calm_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperturbableness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'harbor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'field_of_operations': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'criterion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poster_color': ['positive', 'trust'], 'weapon_system': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mishap': ['surprise', 'sadness', 'negative', 'disgust', 'fear'], 'unprofitable': ['negative'], 'crook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victor': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'garden_truck': ['positive'], 'ask_round': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eyepatch': ['negative'], 'turnaround': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charade': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'geological_era': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reduplicate': ['positive', 'anticip'], 'mathematical_process': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'system_of_weights': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fetch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Saint_Elmo's_fire": ['positive', 'trust', 'joy'], 'survey': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'maker': ['positive', 'anticip'], 'parking_brake': ['surprise', 'fear', 'sadness', 'negative'], 'rive': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'panicked': ['surprise', 'fear', 'negative'], 'interrogatory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'as_yet': ['negative'], 'desiring': ['positive'], 'confidence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plunk_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scout_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'incertain': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'performing_artist': ['positive', 'negative'], 'next': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Lowlands_of_Scotland': ['negative'], 'babe': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'baby': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'antichrist': ['anger', 'fear', 'negative', 'disgust'], 'customer': ['positive', 'trust', 'negative'], 'resection': ['fear'], 'integrating': ['negative'], 'Second_Coming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retell': ['positive', 'anticip'], 'scatter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'murmuring': ['anger', 'negative'], 'changeability': ['anger', 'negative'], 'process': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coolness': ['positive'], 'loco': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'exceptionable': ['anger', 'sadness', 'negative', 'disgust'], 'Bounty': ['anticip', 'positive', 'trust', 'joy'], 'roofing_tile': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'muscular_contraction': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'educational': ['positive', 'trust'], 'procurer': ['negative', 'disgust'], 'bilingual': ['positive'], 'intelligent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dependant_on': ['anticip'], 'fine-looking': ['negative'], 'fluidness': ['anger', 'joy', 'sadness', 'negative'], 'testimony': ['trust'], 'misteaching': ['anger', 'negative', 'disgust'], 'Gospel': ['positive', 'trust'], 'realized': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'foetid': ['negative', 'disgust'], 'awkwardness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Education_Department': ['positive', 'trust'], 'mute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insight': ['anger', 'positive', 'fear', 'trust', 'negative'], 'umbrageous': ['anger', 'negative'], 'mutt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'perfect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slow_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broiling': ['anger', 'negative'], 'equalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meantime': ['anticip'], 'sexual_practice': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'date_stamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declare_oneself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seafarer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prosper': ['positive', 'anticip', 'joy'], 'adequateness': ['positive', 'negative'], 'seawater': ['surprise', 'trust', 'positive', 'joy'], 'sew_together': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'snake': ['fear', 'negative', 'disgust'], 'flavoursomeness': ['positive'], 'realize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disgorgement': ['disgust'], 'intromit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'far-famed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Catholic_Pope': ['positive', 'trust'], 'out_of_work': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fan_out': ['positive'], 'lionize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shortage': ['anger', 'fear', 'sadness', 'negative'], 'badman': ['anger', 'fear', 'negative', 'disgust'], 'scorch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fritter_away': ['anger', 'positive', 'fear', 'negative'], 'legal_proceeding': ['anticip'], 'deficiency': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'books': ['positive'], 'watchdog': ['positive', 'trust'], 'here_and_now': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'witness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'henhouse': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'fundamentally': ['positive'], 'rigging': ['anger', 'surprise'], 'creditworthy': ['positive', 'trust', 'negative'], 'social_movement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprepared': ['negative'], 'burke': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unwieldy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expurgate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'busbar': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superior_general': ['positive', 'trust'], 'inferiority': ['negative'], 'greedy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'temptingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrealizable': ['anger', 'sadness', 'negative'], 'filing_cabinet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chilli': ['negative'], 'prepare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transferable': ['positive', 'trust', 'negative'], 'bawl_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chilly': ['negative'], 'length': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bowel_movement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'receding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Second_Coming_of_Christ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scene': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soothing': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'mess_hall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affliction': ['fear', 'sadness', 'disgust', 'negative'], 'scent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erstwhile': ['sadness', 'negative'], 'festival': ['surprise', 'anticip', 'positive', 'joy'], 'coach-and-four': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heartrending': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'wooden_leg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foretelling': ['anticip'], 'enforcement': ['negative'], 'vigorous': ['positive', 'trust'], 'quarry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ian_Smith': ['trust'], 'kick_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'group_discussion': ['positive', 'trust', 'disgust'], 'egregious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roulette': ['anticip'], 'commandant': ['positive', 'trust'], 'gentile': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'terra_incognita': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infantile_paralysis': ['fear', 'sadness', 'negative'], 'erroneousness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'false': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chivalrous': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'tempestuousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pasquinade': ['positive', 'negative'], 'mountainous': ['negative'], 'worldwide': ['positive', 'trust'], 'rubbish_dump': ['anger', 'sadness', 'negative', 'fear'], 'scabrous': ['negative'], 'cipher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advisedly': ['surprise', 'negative'], 'unsparing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyponymy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'placement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hydrocephalus': ['fear', 'sadness', 'disgust', 'negative'], 'thanksgiving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'sideslip': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'hold_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overrate': ['surprise', 'negative'], 'dependant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncommitted': ['negative'], 'rubric': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'military_campaign': ['anger', 'fear', 'negative'], 'subito': ['surprise'], 'jaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jar': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'terminal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'riding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untellable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'jab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abba': ['positive'], 'undivided': ['positive'], 'prohibition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imbibition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinus': ['positive', 'disgust'], 'wring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antagonist': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'cut_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phonograph_record': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stuff': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'exude': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'discontentment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'guessing': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'signal_flag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pu': ['fear', 'negative'], 'frame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Pb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pa': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'strengthener': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dungeon': ['fear', 'negative'], 'pageboy': ['anger', 'fear', 'negative'], 'heave_up': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'destiny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insulting': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'nuclear': ['trust'], 'posse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'PA': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'destine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'PI': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'PM': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'keynote': ['positive'], 'interpolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'computer_storage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lawsuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'staring': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'rabble-rousing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shin_bone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'hemipteran': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'perfidious': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'Orange_River': ['positive'], 'initiatory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Harlan_Fiske_Stone': ['anger', 'positive', 'fear', 'negative'], 'out_of_sight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'offensive_activity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'fit_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conclude': ['trust', 'anticip'], 'meter_reading': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luting': ['positive', 'negative', 'disgust', 'joy'], 'indict': ['anger', 'fear', 'negative', 'disgust'], 'recording_equipment': ['positive'], 'mailman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'midland': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'tucker_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entitle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'feather': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'antifungal': ['positive', 'trust'], 'altruist': ['positive', 'trust'], 'coherence': ['positive', 'trust'], 'deep_brown': ['anticip', 'positive', 'trust', 'joy'], 'scallywag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misguide': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'hateful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coherency': ['positive', 'trust'], 'altruism': ['positive'], 'paint_a_picture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'banish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reminiscence': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'country': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cleaning_lady': ['positive', 'trust'], 'cerebrovascular_accident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lascivious': ['positive', 'negative', 'disgust'], 'footslog': ['negative'], 'cramp_iron': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'greater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ransom': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'ostentatious': ['anger', 'negative', 'disgust'], 'denial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'applied_science': ['positive'], 'painstaking': ['negative'], 'vocabulary': ['positive', 'trust'], 'unimaginable': ['surprise', 'sadness', 'negative', 'positive'], 'yon': ['anger', 'fear', 'negative'], 'soporiferous': ['negative'], 'unsympathetic': ['anger', 'trust', 'negative', 'disgust', 'anticip'], 'cast_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'identity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'audit': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'corneous': ['fear', 'negative'], 'minor_expense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diversify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reefs': ['negative'], 'cry_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rehash': ['negative'], 'miserableness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'web': ['surprise', 'sadness'], 'disadvantageously': ['sadness', 'negative'], 'wee': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'wed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ingeniousness': ['positive'], 'wen': ['anger', 'negative', 'disgust'], 'upraise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salaciousness': ['anger', 'fear', 'negative', 'disgust'], 'practise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pas_de_deux': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'crud': ['anger', 'fear', 'negative', 'disgust'], 'rock_and_roll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'megabucks': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gambling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'atrophy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tick': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pier': ['negative'], 'gross_profit_margin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debatable': ['positive', 'trust', 'negative'], 'bulge': ['negative', 'disgust'], 'take_shape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'forest_fire_fighter': ['fear', 'trust', 'negative'], 'mistrustful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bulgy': ['negative'], 'become': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sprain': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'verticality': ['fear'], 'antecedency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comatoseness': ['fear', 'sadness', 'negative'], 'breathe_out': ['sadness', 'negative'], 'immortal': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'flush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hissing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recognition': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], "catch_one's_breath": ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_eye': ['anger', 'fear', 'negative'], 'mental_home': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'copulation': ['positive', 'trust', 'disgust'], 'natural_selection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biology': ['positive'], 'vent-hole': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'hooligan': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'pressure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'posterity': ['anticip', 'positive', 'trust', 'joy'], 'coldly': ['negative'], 'blackness': ['anger', 'sadness', 'negative', 'fear'], 'curative': ['positive'], 'documentary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretchability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swimming': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'fear'], 'high-priced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'letters': ['positive', 'joy'], 'unfavourable': ['sadness', 'negative', 'disgust'], 'fictionalisation': ['positive', 'trust', 'negative'], 'sharpness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vituperate': ['anger', 'sadness', 'negative', 'disgust', 'anticip'], 'cultivated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hamstring_tendon': ['anger', 'sadness', 'negative'], 'terminated': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'trust'], 'bladder_fucus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cogwheel': ['positive'], 'pairing': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'watchman': ['positive', 'trust'], 'providential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'heresy': ['fear', 'negative'], 'rhythmic': ['surprise', 'positive', 'joy'], 'pot_likker': ['anger', 'joy', 'sadness', 'negative'], 'moonstruck': ['anger', 'fear', 'negative', 'disgust'], 'in_high_spirits': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'evident': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'bloodline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'congresswoman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'excitement': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'anathemise': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'spreadeagle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'problem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'organized_religion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'flight_of_steps': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incensed': ['anger', 'negative'], 'plunderer': ['sadness', 'negative'], 'spring_up': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'disengagement': ['negative'], "ship's_officer": ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Vannevar_Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'effected': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deadly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lately': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'judgement_of_dismissal': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'behold': ['negative'], 'genus_Phoenix': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'vulgarize': ['positive'], 'carrousel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'repeat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'guilt_feelings': ['anger', 'sadness', 'negative', 'disgust'], 'hang_around': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'U': ['fear', 'negative'], 'hotheaded': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'repeal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exposure': ['fear', 'sadness', 'negative'], 'torrid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compete': ['fear'], 'villainous': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'clamoring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhetorician': ['trust'], 'Dendranthema_grandifloruom': ['positive', 'fear', 'negative'], 'nursery': ['positive', 'trust', 'joy'], 'entropy': ['anger', 'positive', 'fear', 'trust', 'negative'], 'defense_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mary_Augusta_Arnold_Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'integrity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'onus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unanimity': ['positive'], 'stinky': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Eastern_Samoa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worth': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amorous': ['anticip', 'positive', 'trust', 'joy'], 'perishable': ['negative'], 'aurora': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'least_sandpiper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'replication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'electrical_capacity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'progression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exaggerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mirthfulness': ['positive', 'joy'], 'roadblock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'samurai': ['positive', 'fear'], 'feature_of_speech': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depraved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'young_man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musical_rhythm': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'forlornness': ['fear', 'sadness', 'negative'], 'tie-up': ['anger', 'negative'], 'uncertainness': ['surprise', 'negative', 'anticip'], 'menage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spunky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'residual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heft_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dipsomaniac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unobjectionable': ['positive'], 'stressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lonesome': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'postponed': ['negative'], 'Fats_Domino': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloistered': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'vapors': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lavatory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Satan': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'knit_stitch': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'absolution': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'devastation': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'plow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'metal_money': ['positive'], 'plop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'spontaneous': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'lens_hood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plod': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'separated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_forward': ['anticip'], 'bombast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ascribe': ['trust'], 'rock_music': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parallel_of_latitude': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'adamant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'err': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cuddle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'era': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elbow': ['anger'], 'overspread': ['positive'], 'pollute': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'quivering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'connate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heartless': ['sadness', 'negative'], 'impair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pharmaceutic': ['positive'], 'valetudinarianism': ['sadness', 'negative'], 'recovery': ['positive'], 'particularize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_will': ['positive'], 'nuts': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bandaging': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'moron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'titillate': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'truthful': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bad_luck': ['surprise', 'sadness', 'negative', 'disgust', 'fear'], 'parry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strike_out': ['anticip'], 'elusive': ['surprise', 'negative'], 'alienate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'appreciate': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'bow_down': ['positive'], 'gumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catch_up_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'security_guard': ['positive', 'trust'], 'innovative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coiling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'estrange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], "tinker's_dam": ['anger', 'positive', 'fear', 'negative', 'disgust'], 'production': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'understated': ['positive'], 'valor': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'be_active': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coffee': ['anticip', 'positive', 'trust', 'joy'], 'jerking': ['anger', 'surprise', 'fear', 'negative', 'positive'], 'safe': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'collide': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'penetration': ['anger', 'positive', 'fear', 'trust', 'negative'], 'reasonably': ['positive'], 'dinge': ['anger', 'fear', 'sadness', 'negative'], 'poor_people': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dingy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'reasonable': ['surprise', 'fear', 'trust', 'negative', 'positive'], 'curdle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'varmint': ['anger', 'fear', 'negative', 'disgust'], 'guidebook': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'finger_cymbals': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'apotheosis': ['anticip', 'positive', 'trust', 'joy'], 'bountifulness': ['anticip', 'positive', 'trust', 'joy'], 'slew': ['fear', 'sadness', 'negative'], 'extrajudicial': ['fear', 'negative'], 'nerve_centre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ingenuousness': ['negative'], 'drawn-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'engrave': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'self-important': ['anger', 'negative', 'disgust'], 'jest_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barrier': ['anger', 'negative'], 'dashing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fastening': ['positive'], 'detecting': ['positive'], 'lollipop': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'certified': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'drench': ['fear', 'negative', 'disgust'], 'fallaway': ['positive', 'sadness', 'trust', 'negative'], 'maniac': ['anger', 'fear', 'negative', 'disgust'], 'refugee': ['sadness'], 'renew': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'patrol_car': ['trust'], 'buckle_under': ['negative'], 'vanquish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'stripling': ['positive', 'negative'], 'wide_area_network': ['sadness', 'negative', 'fear'], 'render': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intestinal_colic': ['negative'], 'synonymous': ['positive', 'fear', 'trust', 'negative'], 'hamstring': ['anger', 'sadness', 'negative'], 'take_fire': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Jimmy_Carter': ['trust'], 'stillbirth': ['fear', 'sadness', 'disgust', 'negative'], 'implicated': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'illustrate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'go_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seduction': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'noncompletion': ['anticip'], 'hidrosis': ['disgust'], 'fumble': ['sadness', 'negative', 'disgust'], 'john': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paltry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offhand': ['negative'], 'perambulator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waster': ['anger', 'fear', 'negative'], 'cereal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wasted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electroneutral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guild': ['positive', 'negative', 'anticip'], 'guile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guilt': ['anger', 'sadness', 'negative', 'disgust'], 'veterinary_surgeon': ['anger', 'positive', 'trust', 'negative'], 'switch_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tautness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'respecting': ['positive'], 'enchanted': ['positive', 'trust', 'joy'], 'Crab': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'impelled': ['surprise'], 'cadge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resistivity': ['anger', 'negative'], 'batten_down': ['positive', 'trust'], 'prehensile': ['negative', 'disgust'], 'convenient': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'thundering': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pilgrimage': ['positive'], 'enervation': ['sadness', 'negative', 'anticip'], 'hysterical_neurosis': ['fear', 'negative'], 'lucre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indemnification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immediacy': ['surprise'], 'sales_booth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grave': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'circumvention': ['positive', 'negative'], 'swamp': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'aunt': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'repudiation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'reserve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marvel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'unrealised': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Holy_Writ': ['positive', 'trust', 'negative'], 'dearness': ['positive'], 'aggravator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'egression': ['positive', 'negative'], 'groyne': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'open-eyed': ['positive', 'fear', 'trust'], 'manful': ['positive'], 'bodyguard': ['positive', 'trust'], 'degradation': ['negative'], 'get_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'haunted': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'roundabout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'proud_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rung': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'plainspoken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secretary': ['negative'], 'tabularise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gladness': ['positive', 'joy'], 'plumage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sang-froid': ['positive'], 'electrostatic': ['positive', 'joy', 'surprise', 'anticip'], 'horrendous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garrulity': ['negative'], 'begrime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'away': ['sadness', 'negative'], 'bracing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cooperation': ['positive', 'trust'], 'drawn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misguided': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'virgule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'slide_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visual_sensation': ['anticip', 'positive', 'trust', 'joy'], 'handful': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Weird': ['surprise', 'fear', 'negative', 'disgust'], 'ham': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'essentially': ['positive'], 'colorlessness': ['negative', 'disgust'], 'retroversion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'red-blooded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tone': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'tong': ['trust'], 'top_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'condescending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anticipatory': ['anticip'], 'tons': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infirm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resignation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'food_market': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'gratitude': ['positive', 'joy'], 'working_girl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lake_Superior': ['positive'], 'perfervid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narrow_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lockup': ['fear', 'sadness', 'negative'], 'plebeian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attacker': ['anger', 'fear', 'sadness', 'negative'], 'dashing_hopes': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'clairvoyant': ['positive'], 'armoury': ['trust'], 'gracious': ['positive'], 'reciprocal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sculpt': ['positive'], 'immenseness': ['surprise', 'trust', 'positive', 'joy'], 'smut_fungus': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'redemptive': ['anticip', 'positive', 'trust', 'joy'], 'thrash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'window_pane': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'souse': ['fear', 'negative'], 'pipework': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'separatist': ['anger', 'negative', 'disgust'], 'dizzy': ['negative'], 'railway_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conk': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bilious': ['positive', 'anticip'], 'apparently': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'agreeableness': ['positive'], 'confection': ['positive', 'joy', 'anticip'], 'die_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fuss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rootage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shore_leave': ['surprise', 'joy', 'trust', 'positive', 'anticip'], 'literary_pirate': ['anger', 'negative'], 'humble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'do_drugs': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'humbly': ['positive'], 'musical': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'bereave': ['sadness', 'negative'], 'mental_unsoundness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Roland_de_Lassus': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'cetacean_mammal': ['negative'], 'extol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toughness': ['anger', 'positive', 'fear', 'trust'], 'Greek_chorus': ['positive'], 'tea_leaf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'josh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'birch_rod': ['anger', 'fear', 'negative', 'disgust'], 'shout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crack_of_doom': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'demonstrative_pronoun': ['positive', 'sadness', 'joy'], 'righteous': ['positive'], 'smash_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Captain_John_Smith': ['trust'], 'Snake_River': ['fear', 'negative', 'disgust'], 'political_program': ['positive'], 'antimycotic_agent': ['positive', 'trust'], 'unfounded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stargazer': ['positive', 'anticip'], 'autocratic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'rustle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'microseism': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'slavish': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'show-stopper': ['disgust'], 'sparse': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'night': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'inopportuneness': ['surprise'], 'get_wise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'briary': ['fear', 'negative'], 'flatter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Saint_Bridget': ['anticip', 'positive', 'trust', 'joy'], 'caliper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ewe': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'born': ['negative', 'disgust'], 'hassle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flatten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mazed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pugnacious': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'bore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contaminating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'congratulate': ['positive', 'joy'], 'naut_mi': ['negative'], 'canary_bird': ['positive'], 'locust_tree': ['fear', 'negative'], 'asking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'adorable': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'participation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Gray': ['sadness', 'negative', 'disgust'], 'peel': ['negative'], 'aggress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elucidate': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'angriness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gram': ['trust'], 'substitution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'herpes': ['negative', 'disgust'], 'deathless': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'canonic': ['trust'], 'talk_terms': ['positive', 'trust'], 'warping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wasting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnetic_field': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ammonia_water': ['disgust'], 'profession': ['positive', 'trust'], 'attorney': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'rendering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obligate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Negroid': ['sadness', 'negative'], 'stumble': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'deception': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lenity': ['positive'], 'Chameleon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'frill': ['negative'], 'sovereign': ['positive', 'trust'], 'stand_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conservation': ['positive', 'trust', 'anticip'], 'wrongdoing': ['anger', 'sadness', 'negative', 'disgust'], 'saddle_sore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overjoyed': ['positive', 'joy'], 'diligence': ['positive', 'trust'], 'reproductive': ['positive', 'joy'], 'man_of_the_cloth': ['positive', 'joy'], 'spiritlessness': ['sadness', 'negative'], 'ancestral': ['trust'], 'maximum': ['positive'], 'logical_implication': ['surprise', 'fear', 'sadness', 'negative', 'positive'], 'ragtag': ['anger', 'fear', 'negative'], 'mollification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_good_order': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postscript': ['positive', 'trust'], 'xiii': ['fear'], 'expertise': ['positive', 'trust'], 'burnt_umber': ['anticip', 'positive', 'trust', 'joy'], 'prayer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marauder': ['fear', 'negative', 'disgust'], 'sense_impression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evasive': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'test': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cue_stick': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'improvisation': ['surprise'], 'authoritarianism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'cam_stroke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chairperson': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'faze': ['anger', 'fear', 'negative', 'disgust'], 'interval': ['negative'], 'cohesion': ['trust'], 'accolade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreligion': ['fear', 'negative'], 'phlegm': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'concept': ['anger', 'fear', 'negative', 'disgust'], 'diplomacy': ['positive', 'trust', 'anticip'], 'deservingness': ['anger', 'positive', 'trust', 'anticip', 'joy'], 'underwriter': ['fear', 'trust', 'negative'], 'supplement': ['positive', 'trust'], 'battle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impish': ['negative'], 'tenable': ['positive', 'negative'], 'slime_eels': ['fear', 'sadness', 'disgust', 'negative'], 'insalubriousness': ['fear', 'sadness', 'disgust', 'negative'], 'heller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'herb_of_grace': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'revitalisation': ['anticip', 'positive', 'trust', 'joy'], 'open_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silvertip': ['fear', 'sadness', 'negative', 'disgust'], 'Burk': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'aristocratic': ['positive', 'sadness', 'fear', 'negative'], 'dissatisfied': ['anger', 'sadness', 'negative', 'disgust'], 'encephalon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'justificatory': ['positive'], 'take_the_stand': ['positive', 'trust'], 'chirrup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'William_Christopher_Handy': ['positive'], 'alterative': ['positive', 'trust', 'joy'], 'rod_cell': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'skulduggery': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], '12th': ['fear'], 'gun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gum': ['anger', 'negative'], 'Episcopal': ['trust'], 'gut': ['anger', 'positive', 'trust', 'disgust'], 'bowelless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'guy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wash_room': ['positive'], 'agitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cosh': ['anger', 'fear', 'negative'], 'cost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coss': ['negative'], 'CMV': ['sadness', 'negative'], 'cosy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foregoing': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'Ford': ['positive'], 'rainfly': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'bomb_calorimeter': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shared': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alertness': ['positive', 'fear', 'trust', 'surprise', 'anticip'], 'abide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'basketful': ['positive', 'anticip', 'joy'], 'conjuror': ['surprise', 'anticip', 'positive'], 'lustrous': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'English': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combatant': ['anger', 'fear', 'negative'], 'sieve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'teacher': ['positive', 'trust', 'anticip'], 'sociable': ['positive'], 'plotter': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'generator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burdensome': ['anger', 'sadness', 'negative', 'fear'], 'equable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'washbowl': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'pillow': ['positive'], 'plotted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regardless': ['negative'], 'extra': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uphill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puffed': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'unappeasable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'long_ton': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nauseating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'firearm': ['anger', 'fear', 'negative'], 'birth_control_device': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'captivate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'centrality': ['anger', 'positive', 'trust'], 'unctuous': ['positive'], 'coalesce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'wonderfully': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'slough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rainfall': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'exhibitor': ['positive', 'trust'], 'officeholder': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dermatologist': ['trust'], 'iris_diaphragm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tubule': ['positive', 'disgust'], 'purge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disinfection': ['positive'], 'woefully': ['sadness', 'negative', 'disgust'], 'jambon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chip': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'drippiness': ['positive'], 'related_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ballast_resistor': ['positive', 'sadness'], 'regale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ERA': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chic': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'occur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vamper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discussion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lounge': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'Rebel': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'sea_captain': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'endocarp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'product': ['positive', 'fear', 'anticip', 'negative', 'joy'], 'substructure': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'peerless': ['positive'], 'escalate': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'produce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plangency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Robert_F._Curl': ['positive'], 'attach_to': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'corona': ['positive', 'trust', 'joy'], 'nosey': ['trust', 'negative', 'anticip'], 'sagacity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acquaintanceship': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'serving': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'nonpayment': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'first_principle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raised': ['positive', 'joy'], 'Jap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ended': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stile': ['anger', 'fear', 'negative', 'disgust'], 'radio_detection_and_ranging': ['trust'], 'Ra': ['anger', 'surprise', 'fear', 'negative'], 'Rn': ['fear', 'negative'], 'braid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoot_for': ['positive', 'anticip', 'joy'], 'go_far': ['anticip'], 'day_of_reckoning': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'spacious': ['positive'], 'atonement': ['positive', 'negative'], 'factual': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'correspondence': ['positive', 'anticip'], 'kick_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nod': ['positive', 'trust'], 'nog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'introduce': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'poster_colour': ['positive', 'trust'], 'wealthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'now': ['positive', 'negative', 'anticip'], 'placate': ['positive'], 'thankful': ['positive', 'joy'], 'drop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discolouration': ['negative', 'disgust'], 'vexation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sot': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'stainless_steel': ['positive'], 'grouse': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mixed-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spittle': ['anticip'], 'yeah': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'wrap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Zealot': ['fear', 'negative'], 'year': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'naming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumspection': ['positive', 'trust', 'anticip'], 'curmudgeonly': ['anger', 'negative', 'disgust'], 'thirst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wash_out': ['negative', 'disgust'], 'oral_exam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'philharmonic': ['positive', 'anticip', 'joy'], 'dwarfed': ['fear', 'sadness', 'negative'], 'odoriferous': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'divergence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divergency': ['anger', 'fear', 'sadness', 'negative'], 'unwanted': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'good-hearted': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'deuce-ace': ['positive'], 'contemplation': ['positive'], 'flue_pipe': ['positive', 'trust', 'negative', 'surprise', 'joy'], 'transition': ['anticip'], 'tangled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secretiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invitation': ['positive', 'anticip'], 'outcry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suffice': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'blind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'monochromatic': ['negative', 'disgust'], 'blink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'male_monarch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consecrate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rink': ['fear', 'sadness', 'negative'], 'rind': ['negative'], 'ring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confidence_trick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tomorrow': ['anticip'], 'libidinous': ['negative'], 'boulder_clay': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'bollix': ['anger', 'negative', 'disgust'], 'thankless': ['anger', 'negative', 'disgust'], 'fleshly': ['negative'], 'health_club': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brainy': ['anticip', 'positive', 'trust', 'joy'], 'preponderate': ['positive', 'anticip'], 'uninformed': ['negative'], 'brains': ['positive'], 'repossess': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'heretical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artificer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Creator': ['positive', 'trust'], 'salubriousness': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'recruit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discernment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impinge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extinguish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'English_bulldog': ['positive'], 'fit_out': ['negative', 'disgust'], 'smuggler': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'inpatient': ['fear', 'negative', 'disgust'], 'swagman': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'taken_up': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'use_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mendicant': ['sadness', 'negative'], 'attractiveness': ['positive'], 'overindulgence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neatly': ['positive'], 'removal_firm': ['positive'], 'steady': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'esurient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jack_oak': ['anger', 'fear', 'negative'], 'Tang_dynasty': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'discoverer': ['positive'], 'Wed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brunt': ['anger', 'negative'], 'snack': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'stair': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'planless': ['fear', 'sadness', 'negative', 'anticip'], 'distaff': ['positive'], 'preternatural': ['positive'], 'hammock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mucose': ['disgust'], 'granddaddy': ['trust'], 'George_Herbert_Mead': ['positive'], 'uncomely': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'congratulations': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'good_for_you': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-indulgence': ['positive', 'trust', 'negative'], 'irritant': ['anger', 'positive', 'fear', 'negative'], 'florilegium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'burn_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'druggist': ['positive', 'trust'], 'committee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'burst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'add-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wise_man': ['positive', 'trust'], 'recalcitrant': ['anger', 'negative', 'disgust'], 'quid_pro_quo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glaze': ['positive'], 'rollicking': ['positive', 'joy'], 'rephrase': ['positive', 'trust', 'negative'], 'altercation': ['anger', 'negative'], 'gazette': ['positive', 'trust'], 'import': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overjealous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'orchestrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'video_display': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pettifog': ['anger', 'negative', 'disgust'], 'deliver': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ante_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quondam': ['sadness', 'negative'], 'unbending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broil': ['anger', 'negative'], 'undertake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geomorphological': ['trust'], 'downtrodden': ['fear', 'sadness', 'disgust', 'negative'], 'Margaret_Mead': ['positive'], 'madness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sulky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pestilent': ['anger', 'fear', 'sadness', 'negative'], 'foreboding': ['surprise', 'fear', 'negative', 'anticip'], 'inexplicable': ['surprise', 'negative'], 'impedimenta': ['negative'], 'exploit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eight-spot': ['anticip', 'positive', 'trust', 'joy'], 'promptness': ['positive'], 'U.S._Congress': ['positive', 'trust', 'disgust'], 'sugariness': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'fervidness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'animal_foot': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'Department_of_Energy': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'overjoy': ['positive', 'joy'], 'dictator': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'partisanship': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'assuagement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morning_star': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'office_staff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vagueness': ['negative'], 'aery': ['positive', 'fear', 'anticip', 'joy'], 'coquetry': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'trust'], 'Robert_Lee_Frost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scum': ['negative', 'disgust'], 'implacable': ['negative'], 'mucus': ['disgust'], 'metric': ['positive', 'trust', 'negative'], 'carry_through': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'misanthropy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'separate_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'develop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inquire': ['positive', 'fear', 'negative', 'sadness', 'surprise'], 'Salmon_Portland_Chase': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pester': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drone_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aphid': ['negative', 'disgust'], 'inquiry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlace': ['positive', 'anticip', 'negative', 'disgust', 'joy'], 'hydrargyrum': ['surprise', 'negative'], 'teras': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enigmatical': ['fear', 'negative'], 'arctic': ['surprise', 'trust', 'negative'], 'foam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Saint_John': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'stolidity': ['sadness', 'negative', 'disgust'], 'vulturine': ['negative'], 'squatter': ['negative'], 'demean': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'alleviate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taxi': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lunar_time_period': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'livestock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Service': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'Treasury_Department': ['trust'], 'Ian_Douglas_Smith': ['trust'], 'uncoiled': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'maternity': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'plagiariser': ['anger', 'negative'], 'death': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'forward-looking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonremittal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'undercover_agent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swim': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'team_up': ['trust'], 'exult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'mental_representation': ['sadness', 'negative'], 'swig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_reformer': ['positive'], 'earnest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramshackle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stunt': ['negative'], 'fortune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrequited': ['sadness', 'negative'], 'feckless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peace_treaty': ['positive', 'trust', 'joy'], 'veering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'conveyancing': ['trust'], 'output': ['positive', 'anticip'], 'ophidian': ['fear', 'negative', 'disgust'], 'falsehood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exposed': ['negative'], 'pursuance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hemorrhage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Chamaeleon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'derisive': ['anger', 'sadness', 'negative', 'disgust'], 'manipulator': ['positive'], 'babysitter': ['trust'], 'garret': ['negative'], 'assembly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revivify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indestructible': ['positive', 'trust'], 'carefulness': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'innocence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exciting': ['surprise', 'anticip', 'positive', 'joy'], 'make_over': ['positive'], 'creaking': ['negative'], 'piety': ['positive'], 'muggins': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'stub_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'talebearing': ['negative'], 'backup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freeing': ['surprise', 'anticip', 'positive', 'joy'], 'outlook': ['positive', 'anticip'], 'Leontyne_Price': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sistership': ['anger', 'surprise', 'sadness', 'trust', 'positive'], 'ambrosia': ['positive'], 'shrinking': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'intervention': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'stare': ['positive', 'trust', 'surprise'], 'qualifying': ['positive'], 'stark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'start': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stars': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'politeness': ['positive'], 'take_to_the_woods': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compassionateness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'lay_claim': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'co-worker': ['positive', 'trust'], 'delayed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recoil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'machinelike': ['surprise', 'trust'], 'fraud': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'intermission': ['anticip'], 'side_of_meat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'water_ice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'door_guard': ['positive', 'trust', 'joy'], 'catch_fire': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pickax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheath': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'irrational_number': ['fear', 'negative', 'disgust'], 'confab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill-starred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brake_drum': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'juvenile_delinquent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'trample': ['anticip'], 'colly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poop': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'fledgeling': ['surprise', 'fear'], 'poof': ['positive', 'fear', 'negative'], 'registry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pool': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'dabble': ['positive', 'anticip'], 'moonlight': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'deary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stockpile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prying': ['trust', 'negative', 'disgust', 'anticip'], 'misnomer': ['negative'], 'pique': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thoughtful': ['positive', 'trust'], 'rock-and-roll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capitulum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'violative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'prosecuting_attorney': ['anger', 'fear', 'negative'], 'obnubilate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'disassociate': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'stripped-down': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'insulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dubiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sustain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sectarist': ['anger', 'fear', 'negative'], 'horror': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hunting_expedition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'witching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chest_of_drawers': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'sacred_scripture': ['trust'], 'anarchical': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'ceaseless': ['positive', 'trust'], 'fusillade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anal': ['positive', 'trust', 'negative', 'anticip'], 'interior_designer': ['positive', 'trust'], 'Montgomery_Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nullity': ['sadness', 'negative'], 'viridity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orgasm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enfeeble': ['negative'], 'abstract_thought': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'enjoin': ['positive', 'fear', 'negative', 'disgust', 'anticip'], 'hamper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chuckle': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'inert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissertation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cubitus': ['anger'], 'learner': ['positive', 'trust', 'joy'], 'lurch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'done_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'learned': ['positive'], 'airdrome': ['anticip'], 'ferocious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scoffing': ['anger', 'negative', 'disgust'], 'excess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equilibrize': ['positive'], 'outdistance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'corps_de_ballet': ['positive', 'trust'], 'conviction': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'outgrowth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inspired': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'magnetize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'base': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ask': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Scots_heather': ['negative'], 'conventional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revelation': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'chaotic': ['anger', 'negative'], 'heroic': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'swot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cannibalism': ['negative', 'disgust'], 'lowering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unlearned': ['negative', 'disgust'], 'expanding_upon': ['anger', 'positive', 'negative'], 'jr.': ['positive'], 'indenture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Constitution_of_the_United_States': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'Sn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pretense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alleviator': ['positive'], 'oversight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Martial': ['anger'], 'rejuvenate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sure_enough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publicist': ['negative'], 'police_lieutenant': ['trust'], 'phosphor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phrase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publicise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pop_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'utilize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlucky': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'reject': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vigilance': ['positive', 'trust', 'anticip'], 'out_of_practice': ['positive', 'sadness', 'negative', 'disgust'], 'communicating': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'productivity': ['positive'], 'horizontal': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Charles_Martin_Hall': ['anger', 'fear', 'negative'], 'compulsory': ['negative'], 'work_on': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criticize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mobilise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rationality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bird_of_Jove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lechatelierite': ['positive', 'negative'], 'gray-haired': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'prowler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Chief_Executive': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'wishful': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'cutis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sexual_morality': ['positive', 'trust', 'anticip'], 'absence': ['sadness', 'negative', 'fear'], 'camping_ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rabble': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'passing_water': ['sadness', 'negative'], 'evening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumbler': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musket': ['fear'], 'radiation_sickness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'commodore': ['positive', 'trust'], 'drawing_string': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cease_and_desist_order': ['negative'], 'elder': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'unmerciful': ['fear', 'negative'], 'bless': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'slideway': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'blest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put-on': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fairy': ['positive', 'fear', 'negative'], 'close-fitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predatory': ['negative'], 'heavy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'restless': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'jaws': ['fear'], 'punitive': ['anger', 'fear', 'sadness', 'negative'], 'absurdity': ['negative'], 'anarchy': ['anger', 'fear', 'negative'], 'unsurpassed': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'exhaust_fumes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'testify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jolly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engrossing': ['positive'], 'safety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrivel': ['sadness', 'negative', 'disgust'], 'dish_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stomachic': ['positive'], 'unsightly': ['negative', 'disgust'], 'vegetational': ['sadness', 'negative', 'disgust'], 'hapless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unresolved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Jacob's_ladder": ['positive', 'joy'], 'remonstration': ['anger', 'fear', 'negative'], 'magnetic_disc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'magnetic_disk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cecity': ['sadness', 'negative'], 'oncologist': ['trust'], 'flower_stalk': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'knickerbockers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'moorings': ['trust'], 'craps': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effortless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fantabulous': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'blossom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worn_spot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'station': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seafaring': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'merciless': ['fear', 'negative'], 'basal': ['positive'], 'boredom': ['sadness', 'negative'], 'consonant': ['positive', 'trust'], 'shock_absorber': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'grey': ['sadness', 'negative', 'disgust', 'fear'], 'purposeless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assaulter': ['anger', 'fear', 'sadness', 'negative'], 'breadbasket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'garrison': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'bejewel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garbage_disposal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wannabee': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'overstate': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'randomly': ['surprise'], 'yowl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'blissful': ['positive', 'joy'], 'null': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adrift': ['fear', 'sadness', 'negative', 'anticip'], 'fishing_tackle': ['anger', 'surprise'], 'Price': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'by_chance': ['surprise'], 'barmy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconstrained': ['positive', 'joy'], 'tack_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caliber': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'hired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apposite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ballyhoo': ['surprise', 'fear', 'negative', 'disgust', 'anticip'], 'sturdy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moonshine': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'astern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'velocity': ['trust'], 'physics': ['positive'], 'bathing_tub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bovid': ['negative', 'disgust'], 'ennoble': ['positive'], 'circumjacence': ['fear'], 'netherworld': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'El_Salvadoran_colon': ['positive', 'trust'], 'stalker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'velvety': ['positive'], 'heavens': ['anticip', 'positive', 'trust', 'joy'], 'disceptation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distressing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have_intercourse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_Agriculture': ['positive', 'trust'], 'deferred_payment': ['positive', 'trust', 'negative'], 'justice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guilt_trip': ['anger', 'sadness', 'negative', 'disgust'], 'porcupine': ['negative'], 'strut': ['positive', 'negative'], 'lowland': ['negative'], 'slow_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'somberness': ['sadness', 'negative'], 'exoneration': ['anticip', 'positive', 'trust', 'joy'], 'monogram': ['positive'], 'chasten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nose_drops': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adhering': ['trust'], 'retaliation': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'at_once': ['positive', 'negative', 'anticip'], 'ungratified': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'James_Earl_Carter': ['trust'], 'hype': ['surprise', 'fear', 'negative', 'disgust', 'anticip'], 'narcotizing': ['negative'], 'irascibility': ['anger', 'negative'], 'sarcoid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'culture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drenching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'phylogenesis': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'howler': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'historic_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'close': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twenty-four_hours': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bride': ['anticip', 'positive', 'trust', 'joy'], 'footling': ['negative'], 'terrified': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'harlequinade': ['surprise', 'negative'], 'Revelation_of_Saint_John_the_Divine': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'polish_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interjection': ['positive', 'joy', 'trust', 'surprise', 'anticip'], "cat's-paw": ['trust', 'negative'], 'stagnation': ['sadness', 'negative'], "break_one's_back": ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'dullard': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjoin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggrieve': ['sadness', 'negative', 'fear'], 'half-hearted': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'abruptly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'league': ['positive', 'trust', 'disgust'], 'circumstantially': ['surprise'], 'impressible': ['trust'], 'forgotten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vault': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'mausoleum': ['sadness'], 'solvency': ['joy', 'negative', 'sadness', 'positive', 'surprise', 'fear'], 'off-the-wall': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Goth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'commingle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mutual_exclusiveness': ['negative'], 'inadmissible': ['anger', 'negative', 'disgust'], 'prevaricator': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'mentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Thelonious_Monk': ['positive', 'trust'], 'snuff_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threaten': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brusqueness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'empty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coming_into_court': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paronomasia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'liven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'black_art': ['surprise', 'fear', 'negative', 'anticip'], 'misconceive': ['anger', 'sadness', 'negative'], 'narcotised': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'N': ['positive'], 'knuckle_down': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Augustin_Eugene_Scribe': ['positive', 'anticip'], 'furrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pact': ['trust'], 'rust_fungus': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fair_game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confederacy': ['fear', 'negative'], 'guide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sombre': ['sadness', 'negative'], 'pack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dictum': ['trust'], 'consociate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sluice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'makeshift': ['negative'], 'photographic_print': ['negative'], 'solarize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsusceptibility': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'trust'], 'grand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chickenpox': ['fear', 'sadness', 'disgust', 'negative'], 'composition': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'fatty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'banter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Canis_latrans': ['fear'], 'bellying': ['negative'], 'human-centered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consistence': ['positive', 'trust'], 'obviously': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'aflutter': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'consistency': ['positive', 'trust', 'negative'], 'lin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-timed': ['positive', 'negative'], 'pillory': ['anger', 'fear', 'negative'], 'bearer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shivering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mixologist': ['trust'], 'Reconstruction': ['positive', 'anticip'], 'reviewer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'questioner': ['positive'], 'PIN': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disseminate': ['positive'], 'informal': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'PIE': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear'], 'kill_off': ['fear', 'sadness', 'negative'], 'outer_boundary': ['negative'], 'showing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ruff': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'aggravating': ['anger', 'sadness', 'negative', 'fear'], 'dearly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dactyl': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'incrimination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quietude': ['positive', 'trust', 'joy'], 'success': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'maltreatment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'stagnate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'helter-skelter': ['anger', 'negative'], 'eel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'popular': ['positive', 'sadness', 'negative', 'disgust'], 'softness': ['positive', 'negative'], 'pleasure_boat': ['trust'], 'cardiac_murmur': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'terminology': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deepness': ['positive', 'trust'], 'sketch': ['negative'], 'cross_thwart': ['surprise', 'negative'], 'buckle_down': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'callousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mucous': ['disgust'], 'carve_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear_round': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dilapidated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'international_nautical_mile': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'simmer': ['anger', 'anticip'], 'athletic_supporter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Protestant': ['fear', 'negative'], 'benefactor': ['positive', 'trust'], 'plebe': ['positive', 'trust'], 'smothered': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'at_one_time': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'cut_through': ['anticip'], 'inexcitability': ['positive', 'trust', 'joy'], 'silence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jade-green': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'itsy-bitsy': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'powder_compact': ['positive', 'trust'], 'nonplused': ['negative'], 'aftertaste': ['negative'], 'depository_financial_institution': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'salary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'healthful': ['positive', 'joy'], 'inclose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'injection': ['fear'], 'maraud': ['anger', 'surprise', 'fear', 'negative'], 'politic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preparative': ['anticip'], 'similar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canonise': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'ordered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'implemental': ['positive'], 'surmise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business_sector': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dashed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'application': ['positive'], 'department': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inglorious': ['anger', 'sadness', 'negative'], 'smiler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venerable': ['anticip', 'positive', 'trust', 'joy'], 'excitation': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'political_platform': ['positive'], 'weight-lift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deathrate': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'resolving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orbit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bribe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chastise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frighten_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapscallion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'birthplace': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'tincture': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'Father-God': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Nox': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ruckle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sporting_lady': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'friendly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'temporalty': ['positive', 'trust'], 'let_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'felicity': ['positive', 'sadness', 'joy', 'negative', 'anticip'], 'rattling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'telling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tenet': ['trust'], 'nausea': ['positive', 'fear', 'sadness', 'negative', 'disgust'], 'setaceous': ['fear', 'negative'], 'compassionate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cloister': ['negative'], 'enforce': ['anger', 'positive', 'fear', 'negative'], 'pepper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step_up': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'SEAL': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'clangor': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'solarise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vampire': ['anger', 'fear', 'negative', 'disgust'], 'substantiality': ['positive'], 'cave_in': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'royal_family': ['positive'], 'completion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower_limit': ['negative'], 'enterprising': ['positive'], 'convert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_care': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'gent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avaricious': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'gene': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salvation': ['anticip', 'positive', 'trust', 'joy'], 'foresee': ['anticip', 'surprise', 'trust', 'positive'], 'adroitness': ['surprise', 'positive'], 'Doctor': ['positive', 'trust'], 'Energy_Department': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'manage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'microscope_slide': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'feed_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depreciate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'denigrating': ['negative'], 'visibility': ['fear'], 'charming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appointee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'appointed': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'blithely': ['positive', 'joy'], 'meek': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'consort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lapse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'VIII': ['anticip', 'positive', 'trust', 'joy'], 'meet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dishful': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'risque': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synchronism': ['anticip'], 'pulling': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'set_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drumbeater': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'hypnotize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'embodiment': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atomic_number_58': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waterproof': ['positive'], 'atomic_number_50': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dental_plate': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'filament': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Robert_Gray': ['sadness', 'negative', 'disgust'], 'safeandsound': ['positive', 'fear', 'trust', 'negative', 'joy'], 'Scotch_malt_whiskey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'farm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'matchmaker': ['anticip'], 'ratsbane': ['fear', 'sadness', 'disgust', 'negative'], 'scoop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encyclopedia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scoot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eventide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'up_to_now': ['negative'], 'materiality': ['negative'], 'including': ['positive'], 'equanimity': ['positive'], 'temporal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'RAM': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'high-flown': ['negative'], 'tailfin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'articulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'molecule': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stoup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'subtraction': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'stout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brazen-faced': ['anger', 'positive', 'trust', 'negative', 'joy'], 'university': ['positive', 'anticip'], 'slide': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'prevailing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malfeasance': ['negative', 'disgust'], 'fugitive_from_justice': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'constitute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloodletting': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'special': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butch': ['fear'], 'entertainment': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'armor': ['positive', 'fear', 'trust'], 'see_the_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'birthing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'causa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cause': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contemporize': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'Phthirius_pubis': ['anger', 'negative'], 'muddiness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sneer': ['anger', 'negative', 'disgust'], 'times': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'castle_in_the_air': ['positive', 'trust', 'joy'], 'projectile': ['anger', 'fear'], 'praxis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maddened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'single_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'powerful': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsupported': ['negative'], 'look_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deplume': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'bitch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hole_up': ['negative'], 'niggardliness': ['positive', 'trust', 'joy'], 'wrapped': ['surprise', 'negative'], 'trave': ['anger', 'negative', 'anticip'], 'dead_on_target': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'innovate': ['positive'], 'caravansary': ['fear', 'trust'], 'hardihood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neologism': ['anger', 'fear', 'negative', 'disgust'], 'unerasable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Indian_corn': ['anger', 'negative'], 'bloat': ['negative', 'disgust'], 'thrashing': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'insignificance': ['negative'], 'camp_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horrors': ['fear', 'sadness', 'negative'], 'get_wind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'US_Congress': ['positive', 'trust', 'disgust'], 'bastard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attestation': ['trust'], 'battler': ['anger', 'fear', 'negative'], 'bloodbath': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'jaunt': ['positive'], 'grounding': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'battled': ['anger', 'fear', 'sadness', 'negative'], 'gritrock': ['positive', 'trust'], 'soothsaying': ['anticip'], 'vengeance': ['anger', 'fear', 'sadness', 'negative'], 'counterbalance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'energise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chatoyant': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'cellphone': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'urn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'astonishing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soft_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constrain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_philosophy': ['positive'], 'keep_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wilful': ['anger', 'sadness', 'negative'], 'seclude': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'sexual_union': ['anticip', 'positive', 'trust', 'joy'], 'landing_strip': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'halting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diametric': ['surprise', 'trust'], 'beatific': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'uninitiated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ottoman': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'lowlands': ['negative'], 'unfinished': ['negative'], 'sheriff': ['trust'], 'brighten': ['surprise', 'trust', 'positive', 'joy'], 'hector': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'death_chair': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'unpatterned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mortality': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'sculptural_relief': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Marquis': ['positive'], 'exaltation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alabaster': ['positive'], 'twilit': ['sadness', 'negative', 'disgust'], 'consentaneous': ['positive', 'trust'], 'raptorial': ['negative'], 'tobacco': ['negative'], 'imperious': ['anger', 'negative'], 'ruminative': ['positive', 'sadness'], 'tuner': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slimed': ['anger', 'sadness', 'negative', 'disgust'], 'kick_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'widow': ['sadness'], 'bakshish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immigrant': ['fear'], 'bollock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_welfare': ['positive', 'trust', 'disgust'], 'reinforcements': ['trust'], 'conductivity': ['positive'], 'Wisconsin': ['positive', 'trust', 'negative', 'anticip'], 'call_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nightmare': ['fear', 'negative', 'disgust'], "actor's_line": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dividing_line': ['negative'], 'carapace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tyre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonnatural': ['positive'], 'tyro': ['positive', 'negative'], 'tent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'plenteous': ['positive'], 'indiscriminate': ['negative'], 'kicking': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'merry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mathematical_product': ['positive', 'anticip', 'negative', 'joy'], 'mage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'mellow_out': ['sadness', 'negative'], 'inundate': ['surprise', 'fear', 'sadness', 'negative'], 'fizgig': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'estimation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'iron_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'course_of_study': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untrusty': ['anger', 'negative'], 'forrader': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonesuch': ['anticip', 'positive', 'trust', 'joy'], 'woof': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legislative_assembly': ['trust'], 'cent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'immense': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sag_down': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'wash_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antipathy': ['anger', 'fear', 'negative', 'disgust'], 'controller': ['trust'], 'smoking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debtor': ['negative'], 'fishing_gear': ['anger', 'surprise'], 'judicature': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dynamism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'riposte': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piloting': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'examiner': ['positive'], 'surface': ['positive'], 'equilibrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hearten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'push_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pair_of_scissors': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'day-after-day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pudding_head': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lugsail': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'anon': ['trust', 'negative'], 'intermixture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'party': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'way_of_life': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyponym': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stableboy': ['anticip', 'positive', 'trust', 'joy'], 'pharos': ['positive'], 'proscribe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_opinion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refashion': ['positive'], 'impeccable': ['positive', 'trust', 'joy'], 'destruction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scarcely': ['sadness', 'negative', 'fear'], 'Robert_Floyd_Curl_Jr.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impiousness': ['anger', 'negative'], 'rife': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurmountable': ['fear', 'sadness', 'negative'], 'dressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unloosen': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'on_an_individual_basis': ['surprise', 'anticip', 'positive'], 'discord': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lunation': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'trigger_off': ['anger', 'sadness', 'negative'], 'distant': ['negative'], 'dais': ['positive'], 'soda_pop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run-down': ['fear', 'sadness', 'negative'], 'density': ['anger', 'fear'], 'O.K.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'battery': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'morgue': ['fear', 'sadness', 'disgust', 'negative'], 'indignation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'express_mail': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'disappearance': ['surprise', 'sadness', 'negative'], 'cupidity': ['anger', 'negative', 'disgust'], 'canted': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intersection': ['positive', 'anticip', 'negative', 'joy'], 'assuasive': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'loss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'necessary': ['positive'], 'lost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tipple': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'lose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rota': ['positive', 'trust'], 'rote': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'glare': ['anger', 'fear', 'negative'], 'library': ['positive'], 'homo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fumigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mizzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'glary': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'home': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pinpoint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overlay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'overlap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cradle': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'inflammation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'percolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fanny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demonstrated': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'go_against': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reaching': ['anticip'], 'leafy_vegetable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kvetch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'refuge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhinged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'anchorage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roguishness': ['negative'], 'fuddle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unopen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cocoa': ['anticip', 'positive', 'trust', 'joy'], 'conciliative': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'pointless': ['sadness', 'negative'], 'tabernacle': ['positive'], 'Capricorn_the_Goat': ['anger', 'fear', 'negative'], 'additional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lagger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elate': ['positive', 'trust', 'negative', 'joy'], 'Louis_Harold_Gray': ['sadness', 'negative', 'disgust'], 'admonish': ['anticip', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'gain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wince': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Edward_Young': ['positive', 'anticip', 'surprise', 'joy'], 'garden_rocket': ['anger', 'fear'], 'oligarchy': ['negative'], 'Einstein': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'display': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'urging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marketplace': ['positive'], 'bodily_function': ['negative'], 'entrance_money': ['positive', 'trust'], 'universal': ['positive', 'trust'], 'passive_voice': ['negative'], 'right_field': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bundle_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'education': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voguish': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'slaughterhouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'spice_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_personnel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'variety_show': ['anger', 'sadness', 'negative', 'disgust'], 'star': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cool_down': ['positive'], 'stag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backstage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'phosphorus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asocial': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Baroque_era': ['surprise', 'fear', 'negative', 'disgust'], 'fertilize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atheism': ['negative'], 'Corsica': ['sadness'], 'unimaginative': ['sadness', 'negative'], 'associate_degree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elegy': ['sadness', 'negative', 'disgust', 'fear'], 'perverted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swaggie': ['positive', 'negative'], 'swag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'swab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unionized': ['positive', 'negative'], 'tobacco_pipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hammond_organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sorry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'longways': ['trust'], 'make_headway': ['anticip', 'positive', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'collaborate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'communique': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'void': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confederate': ['positive', 'trust'], 'overplay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'regular_hexahedron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deplorably': ['sadness', 'negative'], 'indurate': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'enhance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deplorable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirlwind': ['fear', 'negative'], 'colligate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'samara': ['positive', 'negative', 'disgust', 'surprise'], 'dietetic': ['positive', 'anticip'], 'subordinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kidnap': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'chemical_formula': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'ill-famed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adipose_tissue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'spokesman': ['trust'], 'Wyrd': ['fear', 'negative', 'disgust'], 'lemon_tree': ['negative', 'disgust'], 'arse_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reviving': ['positive', 'joy', 'trust', 'anticip'], 'niche': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pickout': ['negative'], 'mew': ['fear', 'trust'], 'force_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'theodolite': ['anticip'], 'complicated': ['anger', 'negative'], 'intrigue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fantastic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grandma': ['positive'], 'contravention': ['negative'], 'remould': ['positive', 'trust', 'anticip'], 'tutelage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_near': ['anticip'], 'rationalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intrust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_battery': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'survive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inflammatory': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'tenacity': ['positive', 'sadness', 'anticip', 'joy'], 'dogma': ['trust'], 'phraseology': ['positive', 'trust', 'negative', 'anticip'], 'tympan': ['sadness', 'negative'], 'rook': ['anger', 'negative', 'disgust'], 'room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interposition': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'rood': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'roof': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'troth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'taradiddle': ['disgust'], 'elbow_grease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buffoonery': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'unmarked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purgative': ['positive'], 'loathe': ['anger', 'fear', 'negative', 'disgust'], 'motherliness': ['positive', 'trust', 'joy'], 'autonomy': ['surprise', 'joy', 'trust', 'positive', 'anticip'], 'amazing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pogy': ['positive', 'sadness', 'negative'], 'obtrude_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disassemble': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'loyalty': ['positive', 'trust'], 'United_States_Department_of_State': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blood_serum': ['positive'], 'fracas': ['anger', 'negative'], 'pridefulness': ['positive', 'joy'], 'synchrony': ['anticip'], 'pull_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fictitious': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'life_story': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'meekness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'faithlessly': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'operate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twinned': ['trust', 'positive', 'anticip', 'joy'], 'determinate': ['trust', 'negative', 'anticip'], 'Edward_D._White': ['anticip', 'positive', 'trust', 'joy'], 'fable': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'budding': ['anticip'], 'before': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'styptic': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'deathly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'personal': ['trust'], 'take_exception': ['anger', 'fear', 'negative'], 'crew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hirsute': ['negative', 'disgust'], 'foxiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chatty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Francisco_Villa': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'system_of_rules': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combination': ['anticip'], 'runny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clean-handed': ['positive', 'trust'], 'remission_of_sin': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'glazed': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'downright': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'letting_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agonistical': ['anger', 'fear', 'negative'], 'summer_camp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alluviation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ducking': ['anger', 'positive', 'fear', 'trust', 'negative'], 'sham': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loneliness': ['fear', 'sadness', 'negative'], 'lofty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fortuity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'utility-grade': ['positive', 'negative'], 'durability': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'skint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mew_gull': ['fear', 'trust'], 'aide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invisibleness': ['negative'], 'used': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbound': ['positive', 'joy'], 'human_being': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drag_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pilot_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detestation': ['anger', 'fear', 'negative', 'disgust'], 'palaver': ['trust'], 'gustation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mesmerised': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'taste_perception': ['positive', 'negative', 'disgust'], 'intersex': ['surprise', 'negative'], 'ascending': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'underrate': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'abate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'old_geezer': ['positive'], 'infix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Whitney_Young': ['positive', 'anticip', 'surprise', 'joy'], 'chortle': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'garget': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ethyl_alcohol': ['negative'], 'slide_fastener': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'enraged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duplicitous': ['sadness', 'negative', 'disgust'], 'Roman_Catholic_Pope': ['positive'], 'headway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confutable': ['positive', 'trust', 'negative', 'disgust'], 'cunctation': ['negative'], 'Gypsy_Rose_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'lettuce': ['positive'], 'warped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stoolie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'rashness': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'tobacco_user': ['negative'], 'discompose': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'peer_review': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catch_a_wink': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'acquaint': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reprobate': ['anger', 'fear', 'negative', 'disgust'], 'soar_upwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swoosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suntanned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Leslie_Townes_Hope': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'requisite': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'matting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bitterness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tattling': ['negative'], 'spotter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jeopardise': ['fear', 'negative'], 'thrash_about': ['anger'], 'reassert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adamantine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'communicative': ['positive'], 'fitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'institutionalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleeper': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'worsening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insularity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salubrious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'place_of_birth': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'savvy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trolley_car': ['fear', 'sadness', 'disgust', 'negative'], 'maria': ['fear', 'negative'], 'Book_of_Revelation': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'observation': ['positive', 'joy', 'surprise'], 'musical_comedy': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'fall_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impostor': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'slaughterous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'solemn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constrict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Prince_of_Darkness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'scotch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lie_in_wait': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'antic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'lift_up': ['positive', 'trust', 'negative', 'joy'], 'ambassador': ['positive', 'trust'], 'sprocket': ['positive', 'trust', 'anticip'], 'probe': ['anticip'], 'thurify': ['anger', 'negative'], 'auditory_sense': ['fear', 'negative'], 'skag': ['anger', 'negative'], 'bookish': ['positive'], 'jailer': ['positive', 'fear', 'trust', 'surprise'], 'Leo_the_Lion': ['anger', 'positive', 'fear', 'disgust'], 'top_executive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'centurion': ['positive'], 'jailed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Romantic_Movement': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'palliative': ['positive'], 'praised': ['positive', 'joy'], 'bootless': ['sadness', 'negative'], 'crystalised': ['positive'], 'earl': ['positive', 'fear'], 'earn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radioactive_decay': ['negative'], 'old_age': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'troop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pop_off': ['fear', 'sadness', 'negative'], 'legislative_body': ['trust'], 'enchant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oscitant': ['surprise', 'negative'], 'beau_monde': ['positive', 'negative', 'anticip'], 'imitate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'testing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blameless': ['positive'], 'allure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artificial': ['positive'], 'emplacement': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'physicist': ['trust'], 'weary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adhesive_material': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bring_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stomachal': ['positive'], 'bombinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'civilised': ['positive'], 'resistant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wandering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wounding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gemini': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'epidemic_cholera': ['fear', 'sadness', 'disgust', 'negative'], 'presidential_term': ['positive', 'trust', 'joy'], 'responsible_for': ['positive', 'trust', 'negative'], 'quint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incessant': ['positive', 'trust', 'negative'], 'foray': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "duck's_egg": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'generousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'copycat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'basis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regenerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combat-ready': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'putz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'trigger': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'detrimental': ['anger', 'negative'], 'remediate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'interest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'basic': ['trust'], 'basin': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'lovely': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'chela': ['anger', 'fear', 'negative'], 'toller': ['anger', 'negative'], 'wheedle': ['trust'], 'dismiss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confidence_game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deepen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'downplay': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'rosaceous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encyclopaedia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harshness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'natural_state': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vendetta': ['anger', 'fear', 'sadness', 'negative'], 'all-knowing': ['positive', 'trust'], 'ugly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malodour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cane': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Shirley_Temple': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'recuperate': ['positive', 'trust', 'negative'], 'well-kept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inscrutable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sever': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'specialization': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'parish': ['trust'], 'retick': ['anticip', 'joy', 'disgust', 'positive', 'surprise', 'trust'], 'make_love': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'drawstring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gravitational_attraction': ['positive', 'trust', 'negative', 'disgust'], 'pogey': ['positive', 'sadness', 'negative'], 'evolve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'VD': ['positive', 'trust', 'negative', 'joy'], 'opulent': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'renaissance': ['positive'], 'regurgitation': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'weakly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'presto': ['surprise', 'positive', 'joy'], 'failing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inherit': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'approbation': ['positive', 'trust'], 'coliseum': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'adhesive_agent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perceptiveness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'natural_action': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'etiquette': ['trust'], 'kinky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yea': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'pourboire': ['anger', 'negative', 'disgust'], 'assignee': ['trust'], 'reformation': ['positive'], 'cretin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yet': ['negative'], 'yew': ['trust'], 'nudge': ['anger'], 'syncope': ['surprise', 'fear', 'sadness', 'negative'], 'Micromeria_juliana': ['positive', 'negative'], 'royal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straw': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'contestant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'save': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suavity': ['positive'], 'defenselessly': ['fear', 'sadness', 'negative'], 'discreet': ['positive', 'anticip'], 'of_a_sudden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear_out': ['anger', 'fear', 'negative'], 'talk_of_the_town': ['positive', 'fear', 'negative'], 'ill-treat': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'occlusion': ['positive', 'sadness', 'anticip', 'joy'], 'Nathan_Hale': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'handshaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ark': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheapjack': ['anger', 'negative', 'disgust'], 'cowardice': ['fear', 'negative'], 'squander': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deaf': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'maxim': ['positive', 'trust'], 'dead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'type_slug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manifest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bordello': ['negative', 'disgust'], 'balance_beam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mary_Leontyne_Price': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lousiness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'carte': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stateliness': ['positive', 'trust'], 'squelch_circuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predicting': ['anticip'], 'repellant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unreason': ['negative'], 'bombardon': ['anger', 'fear', 'negative'], 'missive': ['anticip', 'positive', 'trust', 'joy'], 'focal_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'January_1': ['positive'], 'leave-taking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lemon_yellow': ['negative', 'disgust'], 'magazine': ['fear'], 'native_sulphur': ['anger', 'fear', 'negative'], 'personal_identity': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pungency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monastic_order': ['positive', 'fear', 'negative', 'disgust'], 'down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fumes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thinned': ['negative'], 'mop_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alphabetic_character': ['anticip', 'positive', 'trust', 'joy'], 'refined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slipshod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jealousy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'corporeal': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'one-man_rule': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'deputize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ensuant': ['anticip'], 'starve': ['negative'], 'creation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'small_fry': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'analyse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'landing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haemorrhoid': ['negative'], 'imbibing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_a_hit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whiskey': ['negative'], 'verbiage': ['positive', 'trust', 'negative', 'anticip'], 'engraft': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'whisker': ['positive', 'trust', 'negative', 'disgust'], 'horrifying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower_oneself': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'strengthening': ['positive', 'trust', 'joy'], 'pontiff': ['positive', 'trust'], 'sudate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cure-all': ['positive'], 'addle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fraternal': ['anticip', 'positive', 'trust', 'joy'], 'graft': ['negative', 'disgust'], 'holla': ['anger'], 'enclothe': ['negative', 'disgust'], 'hollo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'answerable': ['trust'], 'flowering_glume': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'maledict': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'manakin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diacetylmorphine': ['positive', 'trust', 'negative'], 'closemouthed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faction': ['anger', 'fear', 'negative', 'disgust'], 'handicap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwell': ['sadness', 'negative'], 'parenthood': ['positive', 'fear', 'sadness'], 'journey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnificence': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'pseudo': ['anger', 'sadness', 'negative', 'disgust'], 'jacket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meander': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profits': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relievo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sum_total': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'Genesis': ['anticip', 'positive', 'trust', 'joy'], 'relieve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lying_in_wait': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idolatry': ['fear', 'negative', 'disgust'], 'retention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anticipation': ['anticip'], 'tumefy': ['fear', 'negative'], 'arrested_development': ['negative'], 'swoon': ['surprise', 'fear', 'sadness', 'negative'], 'father': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '0': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swoop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'regatta': ['anticip'], 'sovereignty': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cavalry_sword': ['anger', 'fear', 'negative'], 'Harlan_F._Stone': ['anger', 'positive', 'fear', 'negative'], 'enslavement': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'advised': ['anger', 'positive', 'fear', 'trust', 'negative'], 'wind_vane': ['surprise', 'sadness'], 'pallbearer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hooray': ['positive', 'joy'], 'ungraded': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'drinking_chocolate': ['anticip', 'positive', 'trust', 'joy'], 'turgid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'round': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unexpected': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'baffle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dealing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bombardment': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ravenous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sordid': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'heroical': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'inhaste': ['surprise', 'fear', 'negative', 'anticip'], 'security_department': ['fear', 'negative'], 'tense_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encrusted': ['negative', 'disgust'], 'suspect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'international': ['positive'], 'covetousness': ['anger', 'negative', 'disgust'], 'dwarf': ['fear', 'sadness', 'negative'], 'loathly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cushioning': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'cheekiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flare_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wearily': ['sadness', 'negative'], 'colonization': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'box': ['anger'], 'boy': ['negative', 'disgust'], 'bop': ['anger'], 'bow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boa': ['positive', 'negative', 'anticip'], 'bob': ['negative'], 'bod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pectus': ['anger', 'positive', 'sadness', 'trust', 'joy'], 'bog': ['anger', 'negative', 'disgust'], 'recounting': ['positive', 'trust'], 'insolent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'higgledy-piggledy': ['negative'], 'defile': ['sadness', 'negative'], 'blue_sky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mucilaginous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweating': ['disgust'], 'ferociousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sake': ['positive', 'sadness', 'negative', 'disgust'], 'visit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diwan': ['trust'], 'olympian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Aries_the_Ram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'jet_black': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unequaled': ['surprise', 'positive'], 'tribade': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'gasolene': ['positive', 'negative', 'disgust'], 'hand_clapping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'green_goods': ['positive'], 'flagellum': ['anger', 'fear', 'sadness', 'negative'], 'extolment': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'impel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'frivolity': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'making': ['trust'], 'immortalize': ['positive', 'sadness', 'anticip', 'joy'], 'breaking_ball': ['negative'], 'fuck': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sample': ['positive', 'negative', 'disgust'], 'pointedly': ['positive'], 'catch_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nerve_center': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dogfight': ['anger', 'negative'], 'nonchalant': ['negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'idolisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trollop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreverent': ['negative'], 'persuasion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'testicle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economic_science': ['positive', 'trust'], 'ceremony': ['surprise', 'positive', 'joy'], 'pin-up': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'membership': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tramway': ['fear', 'sadness', 'disgust', 'negative'], 'noun': ['anger', 'negative', 'disgust', 'anticip'], 'waist': ['anger', 'fear', 'negative'], 'inexpedient': ['negative'], "tinker's_damn": ['anger', 'positive', 'fear', 'negative', 'disgust'], 'purify': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'guggle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'basket': ['positive', 'anticip', 'joy'], 'nous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disclosure': ['anticip', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'pillowcase': ['surprise', 'negative'], 'knuckle_under': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'system_of_measurement': ['positive', 'trust'], 'jock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'police': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monitor': ['positive', 'fear', 'trust'], 'interesting': ['positive', 'sadness', 'negative'], 'policy': ['positive', 'trust'], 'sterility': ['sadness', 'negative'], 'mollycoddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succus': ['negative'], 'let_go': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tucket': ['surprise', 'anticip', 'positive', 'joy'], 'teller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rattler': ['fear'], 'minatory': ['anger', 'fear', 'negative', 'disgust'], 'feverish': ['negative'], 'promulgate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laurel_wreath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'wide-cut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'careless': ['negative'], 'seacoast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "pilgrim's_journey": ['positive'], 'vogue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medical_examination': ['positive', 'fear', 'trust', 'anticip'], 'unachievable': ['anger', 'sadness', 'negative'], 'badly': ['sadness', 'negative'], 'treacherous': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'optical_fusion': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'stitch': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'unworldly': ['negative'], 'Key': ['positive', 'negative', 'disgust', 'surprise'], 'coming_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assurance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inaction': ['negative'], 'Commerce': ['trust'], 'Comrade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peacefulness': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'bringing': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'ajar': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mandibula': ['fear', 'negative', 'disgust'], 'on_the_spur_of_the_moment': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'carnival': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'contented': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'funky': ['negative', 'disgust'], 'registrar': ['positive'], 'invalidity': ['negative'], 'assuredly': ['trust'], 'frequent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'first': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'root_for': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'housekeep': ['positive'], 'depending_on': ['anticip'], 'enthralled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Black': ['sadness', 'negative'], 'volcanic_eruption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fourscore': ['fear'], 'antibiotic_drug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'future_tense': ['positive', 'fear', 'anticip'], 'unassumingness': ['positive', 'fear', 'sadness'], 'tump_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denigrative': ['negative'], 'violent_stream': ['surprise', 'fear', 'sadness', 'negative'], 'diplomatic_minister': ['positive', 'trust', 'negative', 'joy'], 'lambaste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moisture': ['disgust'], 'unaccented': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instrumental_role': ['positive', 'trust', 'negative'], 'gaudy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inefficient': ['sadness', 'negative', 'disgust'], 'streaked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memo': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'crevice': ['negative'], 'blackguard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piercingly': ['anger', 'sadness', 'negative', 'disgust'], 'deafen': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'doddering': ['fear', 'sadness', 'negative'], 'illegality': ['anger', 'fear', 'negative', 'disgust'], 'easement': ['positive'], 'scraping': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'dolour': ['sadness', 'negative'], 'subject_matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'affirmatory': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'proofread': ['positive', 'trust', 'anticip'], 'atrophied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evergreen_plant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sizzle': ['anger'], 'pastry': ['positive', 'joy'], 'icterus': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'parliamentary_procedure': ['positive', 'fear', 'negative', 'disgust', 'anticip'], 'cellular_telephone': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'let_the_cat_out_of_the_bag': ['negative'], 'squat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foreigner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shocked': ['surprise', 'fear', 'negative', 'disgust'], 'acumen': ['positive'], 'causal_agency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squad': ['trust'], 'squab': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'sea_tangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'interior': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'performance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bodiless': ['fear', 'sadness', 'negative'], 'jungle': ['fear'], 'arguing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incidence': ['surprise'], 'whizz': ['positive', 'trust', 'joy'], 'truelove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surgical_operation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barrage': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'billow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synonym': ['positive', 'fear', 'trust', 'negative'], 'incisive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'water_tap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sales_agreement': ['anticip'], 'inebriation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voodoo': ['negative'], 'peeress': ['negative'], 'news_leak': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rejoinder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chuck_out': ['positive', 'trust', 'anticip'], 'supposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiredness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disunite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threshold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Wisdom': ['positive', 'trust'], 'enthusiast': ['surprise', 'anticip', 'positive', 'joy'], 'stormy': ['fear', 'negative'], 'treasure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'approach_shot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shaft_of_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'analytic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'helix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'travesty': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'treasury': ['trust'], 'admixture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthusiasm': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise'], 'awareness': ['positive'], 'sanguinary': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'get': ['positive', 'joy'], 'stomp': ['positive', 'trust', 'negative'], 'unimportant': ['sadness', 'negative'], 'wall_hanging': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'imperative_mood': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'unaltered': ['positive'], 'stoma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyphenate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gel': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'seared': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Angel': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'colossus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morning': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'undertone': ['anger', 'negative'], 'gammon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Education': ['positive', 'trust', 'anticip'], 'ne_plus_ultra': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'law_of_continuation': ['anticip'], 'Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sear': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fixate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pubic_hair': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'seam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'stigma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adjudge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wonder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'satisfying': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'loaf_of_bread': ['negative'], 'label': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_turn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spartan': ['sadness', 'fear', 'negative'], 'satiate': ['positive'], 'august': ['anticip', 'positive', 'trust', 'joy'], 'home_ground': ['positive'], 'visual_modality': ['anticip', 'positive', 'trust', 'joy'], 'all-embracing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gauntlet': ['positive', 'fear', 'trust'], 'astrologer': ['positive', 'anticip'], 'fulminate': ['anger', 'sadness', 'negative', 'disgust', 'anticip'], 'restroom': ['positive'], 'tour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cognizance': ['positive'], 'dkm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spang': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'legal_action': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'case_law': ['surprise'], 'about-face': ['anger', 'surprise', 'negative', 'disgust'], 'spank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distrait': ['anger', 'negative', 'anticip'], 'ptyalise': ['disgust'], 'tercet': ['positive'], 'capable': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'wobbly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'judging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue_devils': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'term_of_a_contract': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'derogation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'limpidity': ['positive'], 'squash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dramatic': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declaration': ['anticip'], 'roguish': ['fear', 'negative', 'disgust'], 'sound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biyearly': ['anticip'], 'promising': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'investigating': ['anticip'], 'falsified': ['negative'], 'strait': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleeping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwritten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsporting': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'tactile_property': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protein': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'synagogue': ['positive'], 'course_of_instruction': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'fence_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'lave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'creaky': ['fear', 'sadness', 'negative'], 'lava': ['anger', 'fear', 'negative', 'disgust'], 'clammy': ['disgust'], 'Antichrist': ['anger', 'fear', 'negative', 'disgust'], 'safe-conduct': ['positive', 'trust'], 'jargoon': ['negative'], 'nab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'planing_machine': ['positive', 'trust'], 'extended': ['positive'], 'mushroom-shaped_cloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'nuisance_value': ['negative', 'disgust'], 'patrician': ['positive'], 'New_World_chat': ['positive', 'fear', 'negative'], 'assist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incarceration': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'companion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abide_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adjure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'businesslike': ['positive'], 'senesce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stunted': ['negative'], 'uncomplicated': ['anger', 'negative', 'disgust'], 'bold_face': ['positive', 'negative'], 'yearly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unofficial': ['negative'], 'pulp_magazine': ['positive'], 'leeway': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'thudding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flavor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willy-nilly': ['surprise'], 'wild_boar': ['anticip'], 'line_of_work': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high_treason': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Taurus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underwater_diver': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'dissociable': ['positive', 'trust', 'joy'], 'glutinous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zephyr': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gnarled': ['negative'], 'credentials': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arsonist': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'level_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tandem_bicycle': ['trust'], 'passionate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'trust'], 'push_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afflict': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'electron_beam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pronounce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weightiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yardbird': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smarting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lucidness': ['positive'], 'potentiometer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'genetics': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'calculating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'footing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gladden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough-cut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knife': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emblematical': ['positive'], 'dispensary': ['positive', 'trust'], 'raincoat': ['positive'], 'dastardly': ['anger', 'fear', 'negative', 'disgust'], 'patronising': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raptor': ['fear', 'negative'], 'demonic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'injured_party': ['anger', 'fear', 'sadness', 'negative'], 'partizan': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'fallacy': ['negative'], 'fertile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'coupon': ['trust'], 'skilled': ['positive'], 'actuate': ['anger', 'sadness', 'negative'], 'senior_high': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'harness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tooth_decay': ['negative', 'disgust'], 'one-fifth': ['fear'], 'random_memory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'paraphernalia': ['positive'], 'distracted': ['anger', 'negative'], 'real_number': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'spicy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fanatic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shroud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visitant': ['positive', 'joy', 'anticip'], 'spice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'investment_firm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prototype': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'annihilate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excreting': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'silent_person': ['negative'], 'eschew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grouch': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'powerless': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'dawdling': ['sadness', 'negative', 'disgust'], 'sanies': ['negative', 'disgust'], 'self-importance': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'censor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imagination': ['positive', 'anticip', 'joy'], 'examine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'casualty': ['anger', 'fear', 'sadness', 'negative'], 'goddam': ['positive', 'joy'], 'Allied_Command_Europe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victimize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Robert_E._Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'independency': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'custom-made': ['positive'], 'sheepman': ['positive', 'trust'], 'equitable': ['negative'], 'sequent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grudge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assets': ['positive'], 'excretion': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Twin_Falls': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'founder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stock_split': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'building_complex': ['negative'], 'commute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plodding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'TAT': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shattered': ['sadness', 'negative'], 'preserves': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'Byzantine': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'party_favor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'auricle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preserved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crimson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'enjoying': ['positive', 'joy', 'trust', 'anticip'], 'bestir': ['positive', 'anticip'], 'sitting': ['anger', 'fear', 'negative', 'disgust'], 'puffy': ['negative'], 'wiretap': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'prowl_car': ['trust'], 'clench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'winning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elated': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allow_for': ['anticip', 'positive', 'trust', 'joy'], 'washing': ['negative', 'disgust'], 'drugged': ['sadness'], 'reciprocation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'constellate': ['positive'], 'donnish': ['positive', 'trust'], 'revolutionise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'nuclear_fusion': ['anger', 'positive', 'fear', 'negative'], 'LXXX': ['fear'], 'zero': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perspective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revolutionist': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'layover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chafing': ['negative'], 'residue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swampy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweetly': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'wrecked': ['anger', 'fear', 'sadness', 'negative'], 'associate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trinket': ['positive', 'surprise'], 'harmonized': ['positive', 'trust'], 'hotbed': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'malaria': ['fear', 'sadness', 'disgust', 'negative'], 'voidance': ['negative'], 'asphyxiation': ['anger', 'fear', 'negative'], 'mule': ['anger', 'trust', 'negative'], 'unheeded': ['anger', 'sadness', 'negative', 'disgust'], 'affectionately': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high-and-mighty': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'stupor': ['negative'], 'misery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'specialize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'estrus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'caravan': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pelvic_arch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'expelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'composure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plastered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anathema': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'governance': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'impressionable': ['trust'], 'tacky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunniness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenderize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'nester': ['negative'], 'landed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grisly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antisepsis': ['sadness', 'negative'], 'disfavor': ['negative'], 'grammatical_constituent': ['trust'], 'recall': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'specializer': ['trust'], 'remain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dazed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stubborn': ['negative'], 'rejuvenated': ['positive'], 'onslaught': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'collision': ['anger', 'negative'], 'minimum': ['negative'], 'numbers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'junket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'way_out': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'biography': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'homicide': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'vacuolar': ['positive'], 'needy': ['negative'], 'demolition': ['negative'], 'comfort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapport': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sacred': ['positive'], 'disdainfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stir': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slackening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raunch': ['anger', 'sadness', 'negative', 'disgust'], 'crapulence': ['negative'], 'kitty': ['positive', 'fear'], 'questioning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'malediction': ['anger', 'fear', 'sadness', 'negative'], 'fast-growing': ['anger', 'fear', 'negative'], 'coming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cradlesong': ['positive'], 'mentally_ill': ['surprise', 'fear', 'negative'], 'dragon': ['fear'], 'mislead': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'skilful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underscore': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'heartfelt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hygienical': ['positive'], 'cognitive_content': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'directionless': ['negative'], 'officious': ['negative'], 'emaciated': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'bosom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'impressiveness': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'edulcorate': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'valorous': ['positive'], 'rocket_engine': ['anger'], 'smothering': ['sadness', 'negative', 'disgust', 'fear'], 'carry_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'married_woman': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'primary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frigid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prejudiced': ['fear', 'negative', 'disgust'], 'attending': ['anger', 'positive', 'negative'], 'Last_Day': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'move_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mystery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restrict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divested': ['negative'], 'evade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fundamental_law': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'repeating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'horse_cavalry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'winnow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'engaging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excrescence': ['fear', 'negative'], 'uninvited': ['sadness'], 'louver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pubescent': ['positive'], 'burned-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evaluation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'first_mate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physical_body': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tegument': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vendible': ['positive'], 'backer': ['trust'], 'defensive_measure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extraordinary': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'toy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beginning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nictitation': ['negative', 'disgust'], 'incurvation': ['negative'], 'wither': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'carrel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raptors': ['fear', 'negative'], 'ruination': ['sadness', 'negative', 'fear'], 'alcohol_addiction': ['negative'], 'contingent_on': ['anticip'], 'dilute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiction': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'jabber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unacquainted': ['positive', 'trust'], 'razor': ['fear'], 'tactual_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straight-out': ['positive'], 'Erinyes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough_in': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'jetty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clear_up': ['surprise', 'trust', 'positive', 'joy'], 'Romance_language': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Badger_State': ['positive', 'trust', 'negative', 'anticip'], 'bread_and_butter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordure': ['negative', 'disgust'], 'face-lift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'obstructer': ['negative'], 'differentiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prodigious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conventionality': ['positive'], 'commiserate': ['sadness'], 'monger': ['fear'], 'unbroken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anthropoid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swerve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lilting': ['anger', 'sadness', 'negative'], 'confessional': ['fear', 'trust'], 'murder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allow_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'showery': ['sadness'], 'oracular': ['fear', 'negative'], 'refute': ['negative'], 'couch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recondite': ['positive', 'trust'], 'smoothing_iron': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'serene': ['trust', 'negative'], 'oven_broil': ['anger', 'negative'], 'eggs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charr': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'chart': ['trust'], 'charm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chewing_gum': ['anger', 'negative'], 'off-key': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'permissiveness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unemotionality': ['sadness', 'negative', 'disgust'], 'unsealed': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'focussing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mammoth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruggedness': ['anger', 'positive', 'fear', 'trust'], 'Pisces': ['anger', 'positive', 'negative', 'disgust'], 'consanguineous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noble-mindedness': ['positive'], 'schmoose': ['positive', 'negative'], 'putrescence': ['negative', 'disgust'], 'swelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'varsity_letter': ['positive', 'joy'], 'converge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noncitizen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Reginald_Marsh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'shut-in': ['sadness', 'negative', 'fear'], 'immaturity': ['anger', 'negative', 'anticip'], 'headliner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'washed-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'merger': ['anticip', 'positive', 'trust', 'joy'], 'social_system': ['positive', 'trust'], 'Caterpillar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_judgment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cut_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'headman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biddy': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'intractable': ['anger', 'negative'], 'cholera': ['fear', 'sadness', 'disgust', 'negative'], 'express': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'homosexualism': ['negative'], 'barrage_fire': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'acetify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hop-skip': ['negative'], 'membranophone': ['sadness', 'negative'], 'manly': ['positive'], 'pennon': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embassador': ['positive', 'trust'], 'relative_incidence': ['surprise'], 'subscript': ['sadness', 'negative'], 'uncaring': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'premiss': ['positive'], 'add_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'figurehead': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'forwardness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'back_breaker': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'premise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inimitable': ['positive', 'trust'], 'glorification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symbolical': ['positive'], 'defunct': ['sadness', 'negative'], 'take_in_charge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foreign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sparring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise'], 'cyclopedia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zilch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'floozy': ['negative'], 'sense_of_balance': ['positive'], 'massiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geographical_mile': ['surprise', 'trust', 'positive', 'joy'], 'pamphlet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'under_the_weather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decree': ['surprise', 'fear', 'negative', 'anticip'], 'wrick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'civilize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'expensive': ['positive'], 'cooking_pan': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fusee': ['positive', 'sadness', 'trust', 'negative'], 'apostle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'appall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confirmatory': ['trust'], 'omniscient': ['positive', 'trust'], 'ineptitude': ['fear', 'sadness', 'disgust', 'negative'], 'decorous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resister': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'jellify': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'ternion': ['positive'], 'evangelical': ['trust'], 'slabber': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'heterosexual_person': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'retentivity': ['positive'], 'tall': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'trust'], 'joyousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confining': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acclivitous': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'all-important': ['positive', 'sadness', 'trust', 'negative'], 'walk_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concoction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bristly': ['fear', 'negative'], 'Little_Phoebe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bristle': ['negative'], 'moral_principle': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'development': ['anger', 'positive', 'negative'], 'spoon_food': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'stripe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peachy': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'fustian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unveil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'task': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withdraw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'life_history': ['positive', 'anticip'], 'censurable': ['negative'], 'maleness': ['positive'], 'aglitter': ['positive', 'joy'], 'impossible_action': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'shape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mean_solar_day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irritable': ['anger', 'positive', 'trust', 'negative', 'joy'], 'alternative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'timber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cup': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'ohmic_resistance': ['anger', 'negative'], 'source': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'studious': ['positive'], 'cud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undistinguished': ['anger', 'sadness', 'negative'], 'cub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cum': ['positive', 'trust', 'negative', 'joy'], 'full_moon': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'dependability': ['positive', 'trust'], 'suffocation': ['anger', 'fear', 'negative'], 'slush_around': ['surprise', 'negative', 'disgust'], 'sentry_duty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apprehensive': ['fear', 'negative', 'anticip'], 'Cygnus_buccinator': ['negative'], 'jointure': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'lemonlike': ['surprise', 'fear', 'positive', 'negative', 'anticip'], 'play_around': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'electric_current': ['positive', 'negative', 'anticip'], 'knock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retake': ['positive', 'trust'], 'caustic_remark': ['anger', 'sadness', 'negative', 'disgust'], 'forcefulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'loyalist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foolish': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'love_child': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolutely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'stop_up': ['trust'], 'pull_a_fast_one_on': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'delegation': ['positive', 'trust', 'anticip'], 'candle': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'microwave_radar': ['trust'], 'culprit': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'decision': ['negative'], 'proficient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balmy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manipulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shenanigan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'epic': ['positive'], 'inimical': ['anger', 'sadness', 'negative'], 'tear_down': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'feigning': ['anger', 'negative'], 'vector_sum': ['anticip'], 'snoop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhumanity': ['sadness', 'negative'], 'kennel': ['sadness'], 'obstetrician': ['trust'], 'pine_away': ['fear', 'sadness', 'negative'], 'goosey': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'acquirement': ['positive'], 'depose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhospitable': ['sadness', 'negative'], 'single-foot': ['negative'], 'administrative_official': ['negative', 'disgust'], 'normality': ['positive'], 'zealotry': ['fear'], 'translate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orotund': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'exterminated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subsidiary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remitment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Camellia_sinensis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rima_oris': ['surprise', 'disgust'], 'W.C.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'planet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scarf_out': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'planer': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'levelheaded': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'curt': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'devastating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constant': ['positive', 'trust'], 'bay_laurel': ['anger', 'fear', 'negative'], 'stripped': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'discreetness': ['positive', 'trust', 'anticip'], 'deprive': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'scarlet': ['positive'], 'cure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obtuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antiquate': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'yearbook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relieve_oneself': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'composing': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'linkup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'confine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dark-green': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pipe_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'city_manager': ['positive'], 'restoration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skeletal_frame': ['sadness', 'negative', 'disgust'], 'utterly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'neglectful': ['anger', 'negative', 'disgust'], 'throw_in': ['anger', 'positive', 'fear', 'negative'], 'deterrence': ['anger', 'fear', 'negative'], 'overlooking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uterus': ['positive'], 'mix-up': ['anger', 'fear', 'negative'], 'mess_about': ['negative', 'anticip'], 'one_and_only': ['positive'], 'wrangle': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sanctuary': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'magnetic_declination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'naturalised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muster_in': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'suave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'literary': ['positive'], 'compost': ['negative', 'disgust'], 'masculine': ['positive'], 'full_admiral': ['positive', 'trust'], 'pleasing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nervousness': ['fear'], 'proctor': ['positive', 'trust'], 'presently': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'unhurt': ['positive', 'trust'], 'dessert': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'act_upon': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'entire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diverging': ['surprise', 'negative'], 'house_of_prostitution': ['negative', 'disgust'], 'man_and_wife': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'do_in': ['positive', 'joy', 'negative', 'disgust', 'anticip'], 'economic_consumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperativeness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mayhap': ['surprise'], 'manlike': ['positive'], 'indweller': ['fear', 'negative', 'disgust'], 'append': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surety': ['anger', 'positive', 'fear', 'trust', 'negative'], 'access': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'love_life': ['positive', 'trust', 'joy'], 'earthly_concern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apologetic': ['positive', 'trust'], 'packing': ['anger'], 'zaftig': ['positive', 'anticip', 'joy'], 'licentiousness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'healing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'oxidisation': ['negative'], 'medical_checkup': ['positive', 'fear', 'trust', 'anticip'], 'talent': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'fast-flying': ['positive', 'fear', 'sadness', 'negative'], 'implement': ['anger', 'positive', 'fear', 'negative'], 'honor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avariciousness': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'accusative': ['negative'], 'revenue_stamp': ['positive', 'trust', 'negative'], 'valet_de_chambre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'composer': ['positive'], 'elevator_car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superordinate': ['positive'], 'hard_worker': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'genus_Viola': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'totality': ['positive', 'trust'], 'butler': ['positive', 'trust'], 'operating_theater': ['positive', 'fear', 'trust', 'sadness'], 'bay_tree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'defendant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_pig': ['negative'], 'kiosk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dentistry': ['fear'], 'fooling': ['negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'transmissible': ['fear', 'negative', 'disgust'], 'gruff': ['anger', 'negative', 'disgust'], 'closing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rehabilitation': ['positive', 'anticip'], 'panderer': ['positive', 'negative', 'disgust'], 'antedate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mary_Jane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duty_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unshrinking': ['positive', 'trust', 'joy'], 'cricket_bat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profile': ['fear'], 'rumpus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hesitate': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'incompetence': ['negative'], 'leukemia': ['anger', 'fear', 'sadness', 'negative'], 'quisling': ['trust'], 'incompetency': ['negative'], 'pleasantness': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'wait_on': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'non-finite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'trembling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cease-fire': ['positive', 'trust', 'joy'], 'borrower': ['negative'], 'despite': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'extemporary': ['negative'], 'circumscribed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flattering': ['positive', 'joy'], 'horny': ['fear', 'negative'], 'safety_device': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'itemize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accredited': ['positive', 'trust'], 'stultification': ['negative', 'disgust'], 'heroism': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'blatant': ['anger', 'negative', 'disgust'], 'patch_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bank_clerk': ['trust'], 'chouse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Protestant_deacon': ['trust'], 'denigrate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'insulating_material': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fly_sheet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'frayed': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'blindfolded': ['surprise', 'fear', 'anticip'], 'subservience': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'preclude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cider': ['positive'], 'human_race': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'phonetic': ['positive'], 'flair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resistless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treetop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baulk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmanliness': ['positive', 'negative'], 'pantry': ['positive'], 'edacious': ['anger', 'fear', 'sadness', 'negative'], 'Texas_Ranger': ['fear', 'trust', 'negative'], 'sexual': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'popping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sentience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scriptural': ['positive'], 'sentiency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Wiccan': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'clarify': ['positive'], 'female_chest': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'backwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloud_nine': ['positive', 'joy'], 'rearward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mortar': ['positive'], 'camping_area': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allied': ['positive', 'trust'], 'mortal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'time_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fragrant': ['positive'], 'sack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lagging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'braces': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'nebular': ['sadness'], 'intermediate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acquiescence': ['positive'], 'scant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'literary_criticism': ['anger', 'positive', 'sadness', 'negative'], 'bulldog': ['positive'], 'explanation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'acquire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foamy': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'flump': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'inapt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'war_hawk': ['fear'], 'lionise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overindulge': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'octonary': ['anticip', 'positive', 'trust', 'joy'], 'fermentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_the_end': ['positive', 'anticip'], 'corrupt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disturbing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throat': ['anger', 'fear', 'negative'], 'laying_waste': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'incentive': ['surprise', 'anticip', 'positive', 'joy'], 'precipice': ['fear'], 'schoolmaster': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'trade_union': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'spinster': ['fear', 'sadness', 'negative'], 'rove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buy_back': ['anticip', 'positive', 'trust', 'joy'], 'procure': ['anticip', 'positive', 'trust', 'joy'], 'revival_meeting': ['anticip', 'positive', 'trust', 'joy'], 'craggy': ['negative'], 'prisoner': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'voluptuary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'payment': ['negative'], 'inexorable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complemental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disease': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'occasion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contemptuous': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'recess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'settee': ['anger', 'fear', 'negative', 'disgust'], 'incapacitate': ['fear', 'sadness', 'negative'], 'hamlet': ['positive', 'trust'], 'tearful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'traitor': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'crossbreeding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demurrer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'majority_rule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Goat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handmaid': ['positive', 'trust', 'negative'], 'communism': ['anger', 'fear', 'sadness', 'negative'], 'knowledge': ['positive', 'sadness'], 'scorpion': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'dramatic_event': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contumely': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'prolong': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cohesiveness': ['trust'], 'self-praise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'communist': ['negative'], 'amplify': ['negative'], 'pitfall': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supposal': ['positive', 'anticip'], 'delirious': ['sadness', 'negative'], 'pave': ['trust'], 'stand_for': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'perfection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marquess': ['positive'], 'exultant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sea_bass': ['positive', 'trust'], 'spread-eagle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nutriment': ['positive'], 'reactionist': ['negative'], 'interpretive_program': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fixed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purgation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'groggy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drowse': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'bereaved_person': ['anger', 'sadness', 'negative', 'fear'], 'intensity': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'mercifulness': ['positive'], 'come_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'racket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liberalization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulverise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electrical_resistance': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dental_medicine': ['fear'], 'imposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reform': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canons': ['trust'], 'difficulties': ['sadness', 'negative'], 'phratry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invariant': ['positive', 'trust', 'negative'], 'boundary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorrow': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'upper_limit': ['positive'], 'side_drum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mandamus': ['fear', 'negative'], 'old_hand': ['anger', 'positive', 'trust', 'negative'], 'make_fun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'effeminacy': ['positive', 'negative'], 'free_weight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boloney': ['disgust'], 'disport': ['positive', 'joy'], 'empathy': ['positive'], 'joke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'didder': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'equal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'touchstone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'female_parent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-satisfied': ['anger', 'fear', 'negative', 'disgust'], 'Citrus_limon': ['negative', 'disgust'], 'coexistence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reborn': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'speech_sound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wanton_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'news': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manhood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fecal_matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seasoner': ['positive', 'sadness'], 'white-livered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shammer': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mouthpiece': ['surprise', 'disgust'], 'seasoned': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'rump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anomaly': ['surprise', 'fear', 'negative'], 'citadel': ['anger', 'positive'], 'heroic_poem': ['positive'], 'tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potomania': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'bighearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venomous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lassitude': ['sadness', 'negative'], 'amenity': ['positive'], 'pantie': ['negative'], 'fumbling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burial_ground': ['fear', 'sadness', 'negative'], 'delusion': ['anger', 'fear', 'sadness', 'negative'], 'suspiration': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'communication_channel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'partner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pedestal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grinder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'MBD': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raciness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crosspiece': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'trust'], 'sugar-coated': ['positive'], 'kin_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hank': ['positive', 'fear', 'anticip', 'joy'], 'slobber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maiden_over': ['positive', 'joy', 'trust', 'anticip'], 'get_hold_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'funfair': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'constabulary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirr': ['positive', 'trust', 'joy'], 'garish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smooth-tongued': ['negative'], 'Allium_sativum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enchiridion': ['trust'], 'self-colored': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discredited': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'recourse': ['anticip', 'positive', 'sadness', 'trust', 'joy'], 'neural': ['fear', 'negative', 'anticip'], 'Senate': ['trust'], 'chastisement': ['fear', 'negative'], 'disoriented': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'wasting_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravine': ['fear'], 'raving': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'insipidity': ['negative'], 'excise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zip_fastener': ['negative'], 'creative_thinker': ['positive', 'negative', 'anticip'], 'nihility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'storey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inveigle': ['trust'], 'interim': ['anticip'], 'localize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apostasy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stoep': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'reformer': ['positive'], 'onward': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'misfortunate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolved': ['anticip'], 'Thomas_Hardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cicatrix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrorist_act': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'displaced': ['anger', 'fear', 'sadness'], 'like': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excluding': ['sadness', 'negative'], 'vibrant': ['positive', 'joy'], 'government_agency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chick': ['joy', 'negative', 'disgust', 'positive', 'anger', 'trust'], 'classical': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'professorship': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'hail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'head_teacher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hair': ['positive', 'trust', 'negative', 'disgust'], 'elephantine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'churrigueresco': ['surprise', 'fear', 'negative', 'disgust'], 'bulbous': ['negative'], 'deterrent_example': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jurisprudence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'truss': ['trust'], 'hurricane': ['fear', 'negative'], 'B._B._King': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neurosis': ['fear', 'sadness', 'negative'], 'by-blow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discretion': ['positive', 'sadness', 'trust', 'anticip'], 'screwed': ['anger', 'negative'], 'Old_Nick': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'snuggle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'magnate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Heaven': ['anticip', 'positive', 'trust', 'joy'], 'lastword': ['positive'], 'pleasant-tasting': ['positive'], 'lieutenant': ['trust'], 'marketable': ['positive'], 'unchangeable': ['negative'], 'retral': ['negative'], 'purist': ['positive'], 'conjuration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tomb': ['sadness'], 'age-old': ['positive'], 'tome': ['positive', 'sadness', 'negative'], 'severalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faithfulness': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'low_quality': ['negative'], 'short_sleep': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'female': ['positive'], 'ill_luck': ['sadness', 'negative', 'fear'], 'enured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bald-pated': ['sadness', 'negative'], 'Trotskyist': ['anticip', 'positive', 'trust', 'joy'], 'watering_place': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rushed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'condense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treasonist': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'putridness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'insurer': ['fear', 'trust', 'negative'], 'sequel': ['negative', 'anticip'], 'misdeed': ['anger', 'surprise', 'negative', 'disgust'], 'brouhaha': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flit': ['anger', 'positive', 'fear', 'negative'], 'flip': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'all-encompassing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'British_pound_sterling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distastefulness': ['sadness', 'negative', 'disgust'], 'whisper': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'domino': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sir_Oliver_Joseph_Lodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-defined': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intercalation': ['fear', 'sadness', 'negative'], 'corporation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'newsy': ['negative'], 'detail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dresser': ['negative'], 'metric_grain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hastiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mexican_valium': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'parking_lot': ['surprise', 'anticip', 'positive', 'joy'], 'stirred': ['sadness', 'negative'], 'give_rise': ['positive'], 'ramble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meritoriousness': ['anger', 'positive', 'trust', 'anticip', 'joy'], 'cylinder_block': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'vermin': ['anger', 'fear', 'negative', 'disgust'], 'intemperateness': ['positive', 'trust', 'negative'], 'Communist': ['negative'], 'signalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catamenia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undisputed': ['positive', 'trust'], 'sallow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cushy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'air_force_officer': ['positive', 'trust'], 'shambles': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'haughtiness': ['negative'], 'slipstream': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispense': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'adumbrate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'vitreous': ['sadness', 'negative', 'disgust'], 'Pacific_Ocean': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'gratification': ['positive', 'negative'], 'misidentify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gluey': ['disgust'], 'school': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'slip_noose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bestfriend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'conceive': ['positive', 'trust'], 'getable': ['positive', 'joy'], 'shore_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'martingale': ['negative'], 'veritable': ['positive'], 'reprehension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'direct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nail': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'naif': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inanition': ['sadness', 'negative'], 'hide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parkland': ['surprise', 'anticip', 'positive', 'joy'], 'commemorating': ['positive', 'anticip'], 'revolver': ['anger', 'fear', 'sadness', 'negative'], 'liberty': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'fatness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'blur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supplies': ['positive'], 'jaundice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Larus_canus': ['fear', 'trust'], 'tobacco_plant': ['negative'], 'leprosy': ['fear', 'sadness', 'disgust', 'negative'], 'woozy': ['negative'], 'etching': ['negative'], 'ravish': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ridicule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'culminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shinbone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depreciated': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'leaven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magic_trick': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'settled': ['anger', 'fear', 'negative', 'disgust'], 'midway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'binful': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'patience': ['positive', 'trust', 'negative', 'anticip'], 'meaty': ['positive'], 'prescript': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'pigeonhole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Florida_key': ['positive', 'negative', 'disgust', 'surprise'], 'suit_of_clothes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fainting': ['surprise', 'fear', 'sadness', 'negative'], 'saber': ['anger', 'fear', 'negative'], 'break_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_around': ['positive', 'joy'], 'sea_rover': ['anger', 'negative'], 'go_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shake_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excellent': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'hang_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supplemental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abundance': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'philanthropic': ['trust'], 'Movement_of_Holy_Warriors': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abrasiveness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Crown': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'advocacy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Orion': ['fear', 'anticip', 'sadness', 'negative'], 'salvage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grenade': ['fear', 'negative'], 'misdating': ['surprise', 'sadness', 'negative', 'anticip'], 'estate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dolphin': ['surprise', 'trust', 'positive', 'joy'], 'powerfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attract': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'harmonium': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'obloquy': ['fear', 'negative', 'disgust'], 'dress_up': ['anger', 'positive', 'fear', 'negative'], 'in_series': ['anticip'], 'keen': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'enquiry': ['fear'], 'mass_meeting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enquire': ['positive', 'fear', 'negative', 'sadness', 'surprise'], 'toxin': ['fear', 'negative'], 'toxic': ['negative', 'disgust'], 'finalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'befog': ['sadness', 'negative'], 'description': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horoscope': ['anticip'], 'insecure': ['anger', 'fear', 'sadness', 'negative'], 'lump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unguarded': ['surprise'], 'airless': ['negative'], 'second_thought': ['positive', 'trust'], 'parallel': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'riant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'undesired': ['sadness', 'negative'], 'Joseph_Smith': ['trust'], 'recording_machine': ['positive'], 'pullout': ['sadness', 'trust', 'negative'], 'preventive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amir': ['positive'], 'scare_away': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'deform': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiendish': ['anger', 'negative'], 'dulcify': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'hip-hop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_happy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lenitive': ['positive'], 'circuit_card': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fealty': ['positive', 'trust'], 'imp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indistinctness': ['positive', 'negative'], 'mistreat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'litigious': ['anger', 'fear', 'negative', 'disgust'], 'Mobile': ['anticip'], 'diseased': ['fear', 'sadness', 'disgust', 'negative'], 'threnody': ['sadness', 'negative', 'disgust', 'fear'], 'rental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gluttony': ['negative', 'disgust'], 'Sir_Tim_Rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'herald': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'minutiae': ['positive'], 'noncompliance': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'co-occurrence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appurtenance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mandrel': ['trust'], 'lair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'olive-drab': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'random_access_memory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aloneness': ['fear', 'sadness', 'negative'], 'laic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'banning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'newly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aweless': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'independence': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'prorogue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carcass': ['fear', 'sadness', 'disgust', 'negative'], "talk_through_one's_hat": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carcase': ['fear', 'sadness', 'disgust', 'negative'], 'stochasticity': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'working_capital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conceding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knobbed': ['negative'], 'tolerant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'separable': ['positive', 'trust', 'joy'], 'artistry': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'fantasm': ['fear', 'negative'], 'mental_picture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encouraging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'low-set': ['negative'], 'tooth_root': ['positive', 'trust', 'surprise'], 'lovable': ['positive', 'trust', 'joy'], 'fantasy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'occupancy': ['positive'], 'insulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Congress': ['trust', 'disgust'], 'sarcasm': ['anger', 'sadness', 'negative', 'disgust'], 'heights': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'confirming': ['trust'], 'corpus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gag_rule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reparation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hangout': ['fear', 'sadness', 'negative'], 'canary-yellow': ['positive'], 'embellish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incur': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'lather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legal_tender': ['positive', 'trust', 'negative'], 'bridge': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'unpopular': ['sadness', 'negative', 'disgust'], 'physicalenergy': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disorganised': ['negative'], 'puritanical': ['anger', 'positive', 'trust', 'negative'], 'rapacity': ['anger', 'negative', 'disgust'], 'thorough': ['trust'], 'hatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yucky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foliate': ['anger', 'fear', 'negative'], 'lily-livered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potency': ['positive'], 'ill-omened': ['fear', 'sadness', 'negative'], 'rancid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entertaining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amphitheatre': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'potence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bait': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overpriced': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'plectrum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enceinte': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aspirer': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'dupe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reissue': ['negative'], 'rector': ['positive', 'trust', 'negative', 'joy'], 'six-shooter': ['anger', 'fear', 'sadness', 'negative'], 'peddle': ['fear'], 'bail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abolishment': ['negative'], 'humeral_veil': ['fear'], 'spite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_down_on': ['anger', 'sadness', 'negative'], 'body_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pacification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medulla': ['negative'], 'ultimatum': ['anger', 'fear', 'negative'], 'dirty_money': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wedding': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'considerate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'spokesperson': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'igneous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mediterranean': ['positive'], 'unwitting': ['surprise', 'negative', 'disgust'], 'security_measure': ['positive', 'fear', 'trust', 'negative'], 'sense_of_taste': ['positive', 'negative', 'disgust'], 'penance': ['fear', 'sadness'], 'vacation_spot': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'desegregation': ['negative'], 'trumpeter_swan': ['negative'], 'grandmother': ['positive'], 'mud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'odontology': ['fear'], 'irrupt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discovery': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'reiterate': ['positive'], 'Tree': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'clean_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prizefighter': ['fear'], 'rime': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prison_cell': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'fulmination': ['anger', 'negative', 'disgust'], 'drowsy': ['surprise', 'negative'], 'fault': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peacenik': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'stone_pit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expense': ['negative'], 'smuggled': ['anger', 'sadness', 'negative', 'fear'], 'misshapenness': ['negative'], 'nonunionised': ['negative'], 'inactivate': ['negative'], 'green_goddess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recesses': ['fear'], 'conference': ['positive', 'trust', 'disgust'], 'sapience': ['positive', 'trust'], 'unmatchable': ['positive'], 'come_before': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'value_orientation': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'push_through': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'moneymaking': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'trine': ['positive', 'trust', 'negative', 'disgust'], 'loft': ['negative'], 'pecker': ['fear', 'negative', 'disgust'], 'apprehension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hospital_attendant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quail_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meeting_of_minds': ['surprise', 'fear', 'negative'], 'broth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tress': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'flummox': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_rating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demoralise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chill_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsavoury': ['anger', 'trust', 'negative', 'disgust', 'anticip'], 'forehead': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'enlightenment': ['positive', 'trust', 'joy'], 'drawback': ['negative'], 'baccy': ['negative'], 'screw': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'numerical': ['trust'], 'buyback': ['anticip', 'positive', 'trust', 'joy'], 'unyielding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'darned': ['positive', 'joy'], 'punctuate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'win_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shortly': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'possessed': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'dada': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'litigator': ['negative'], 'ocean': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impediment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common_salt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'departed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physique': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bruise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proposer': ['positive'], 'judge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scattering': ['negative'], 'military_strength': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlighten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cherry': ['positive'], 'John_Donald_Budge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salacious': ['positive', 'negative', 'disgust'], 'sufficiency': ['anger', 'positive', 'negative'], 'descending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burnt': ['negative', 'disgust'], 'rumor': ['sadness', 'negative'], 'melting': ['sadness', 'negative'], 'brutality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zeal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contradict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'celibacy': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'avatar': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'envision': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excerpt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sponge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrabble': ['negative'], 'election': ['fear', 'sadness', 'negative'], 'chesty': ['anger', 'negative', 'disgust'], 'rapidity': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'incontinence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'court_of_justice': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'disgorge': ['disgust'], 'kayoed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incontinency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'officer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brawl': ['anger', 'fear', 'negative', 'disgust'], 'newcomer': ['surprise', 'fear'], 'shuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hive_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'choke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dinner': ['positive'], 'ensure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inveigh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'toss_off': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'blabber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duke': ['positive'], 'bate': ['positive', 'negative'], 'rails': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anxiousness': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'superlative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'St._John_the_Apostle': ['negative', 'disgust'], 'obscene': ['anger', 'fear', 'negative', 'disgust'], 'fern': ['anger', 'fear', 'negative'], 'swain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stolon': ['positive', 'anticip'], 'bats': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'volaille': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissenting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coitus': ['positive', 'trust', 'disgust'], 'misjudgment': ['fear', 'negative', 'disgust'], 'slaked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'infidelity': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Amen': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'vaccination': ['trust', 'anticip'], 'sunlight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inquietude': ['sadness', 'negative', 'anticip'], 'amateur': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pricker': ['anger', 'positive', 'negative'], 'fly_ball': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'retinal_rod': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'secretariate': ['positive'], 'swampland': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'moveto': ['positive', 'trust', 'joy'], 'integrality': ['positive', 'trust'], 'flavour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'microphone_boom': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'French_horn': ['surprise', 'fear', 'negative'], 'encumber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'usher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oral_cavity': ['surprise', 'negative', 'disgust'], 'panicky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worshipful': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'auditory_modality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liberalist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'effervesce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sometime': ['positive', 'sadness', 'trust', 'negative'], 'Strategic_Arms_Limitation_Talks': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'piece_of_ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'nonpartisanship': ['positive', 'trust'], 'warhead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regime': ['fear'], 'loving_cup': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'poisonous_substance': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'counterpane': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'imputable': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'review_article': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'unorganised': ['negative'], 'piffle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'setting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rottenly': ['sadness'], 'whet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'martyrise': ['fear', 'sadness', 'negative'], 'implant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'erosion': ['negative'], 'company': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'picture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tasteful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bollocks_up': ['anger', 'sadness', 'negative', 'disgust'], 'liquidate': ['positive', 'joy', 'negative', 'disgust', 'anticip'], 'football': ['positive', 'anticip', 'joy'], 'flushed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verve': ['positive'], 'unchallenged': ['positive', 'trust'], 'fasten': ['anger'], 'undoubted': ['disgust', 'anticip'], 'winnings': ['positive', 'anticip', 'joy'], 'horseback_riding': ['fear', 'trust', 'negative'], 'roc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physicalpain': ['negative'], 'rot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'row': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clarification': ['surprise', 'trust', 'positive', 'joy'], 'reasoning_by_elimination': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'hot_flash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'passage': ['anticip'], 'aplomb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exalted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trident': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'congregation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emphasized': ['positive', 'trust'], 'oftentimes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annihilated': ['anger', 'fear', 'sadness', 'negative'], 'looney': ['anger', 'fear', 'sadness', 'negative'], 'impressive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'level': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equivalent_weight': ['positive', 'negative'], 'fundamental_frequency': ['positive', 'trust'], 'levee': ['trust'], 'partial_tone': ['negative'], 'lever': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reputability': ['positive'], 'intercommunicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'factor_out': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'faculty_member': ['positive', 'trust'], 'trend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'injunction': ['negative'], 'pore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'long-winded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'port': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'bow_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'colic': ['negative'], 'stately': ['positive', 'trust'], 'gingersnap': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'corbel': ['trust'], 'vestibular_sense': ['positive'], 'slaying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enunciate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'femininity': ['positive'], 'entertain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'witch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'methyl_alcohol': ['negative'], 'mystery_story': ['surprise', 'anticip'], 'boast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'greaseball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rethink': ['positive', 'trust'], 'legal_transfer': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'cernuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flavorsomeness': ['positive'], 'pixy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slip_of_paper': ['surprise', 'negative'], 'problematic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atrocious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bribery': ['negative', 'disgust'], 'centenary': ['positive', 'joy', 'surprise'], "al-Qa'ida": ['sadness', 'trust', 'negative'], 'scam': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'crisis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'touchable': ['surprise', 'negative'], 'prey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prep': ['trust', 'positive', 'fear', 'joy', 'anticip'], 'Opera': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trash_dump': ['anger', 'sadness', 'negative', 'fear'], 'clangoring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leave_of_absence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'teaser': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bilk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'edible': ['positive', 'trust'], 'highlife': ['anger', 'sadness', 'negative', 'disgust'], 'posthumous': ['sadness', 'negative'], 'inveterate': ['positive', 'sadness', 'trust', 'negative'], 'Robert_William_Service': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'pickle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'prevarication': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'meeter': ['positive', 'trust', 'anticip'], 'sandbag': ['surprise', 'fear', 'negative'], 'figure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irruption': ['anger', 'surprise', 'fear', 'negative'], 'enablement': ['positive', 'trust'], 'avocation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'inexperience': ['negative'], 'critic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'propitiation': ['positive', 'joy', 'trust', 'anticip'], 'ill_fame': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'filtrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bigot': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mismanagement': ['negative'], 'vital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'husbandry': ['positive', 'trust'], 'deification': ['anticip', 'positive', 'trust', 'joy'], 'eighty': ['fear'], 'Jack-tar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relatiative': ['anger', 'negative'], 'disheartening': ['sadness', 'negative'], 'sluggard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succeeder': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'trust'], 'befool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expression': ['positive', 'fear'], 'representation': ['sadness', 'negative'], 'telephone_set': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imitative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Columba': ['anticip', 'positive', 'trust', 'joy'], 'ball_over': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'corruptness': ['anger', 'sadness', 'negative', 'disgust'], 'platform': ['positive'], 'amelioration': ['anticip', 'positive', 'fear', 'joy', 'surprise'], 'abandoned_ship': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'loophole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'priesthood': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'stewing': ['anticip'], 'savoir-faire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pen_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'qualified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Roma': ['negative'], 'bath': ['positive'], 'eleemosynary': ['trust'], 'stuporous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'utility_program': ['positive', 'negative'], 'kink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coping_stone': ['fear', 'sadness'], 'mintage': ['positive'], 'tribune': ['trust'], 'subjection': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'busty': ['positive', 'anticip', 'joy'], 'ejaculation': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'lay_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whiplash': ['anger', 'surprise', 'fear', 'negative'], 'catching': ['positive'], 'farewell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumultuous': ['anger', 'fear', 'negative'], 'anoint': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'extroverted': ['positive'], 'concur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intercourse': ['positive', 'trust', 'disgust'], 'envenom': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'monopolizer': ['negative'], 'liveliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abounding': ['positive'], 'feather_boa': ['positive', 'negative', 'anticip'], 'eagle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'variant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fill_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curable': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'the_right_way': ['positive', 'negative', 'disgust'], 'acclivity': ['positive', 'anticip'], 'roofless': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pandemic': ['fear', 'sadness', 'negative'], 'turn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burst_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'turd': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'truehearted': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pep_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'city_block': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'touch_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vainglorious': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'supernal': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depleted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consanguineal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afterthought': ['positive', 'trust'], 'capital_punishment': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'addto': ['positive'], 'prissy': ['fear', 'negative', 'disgust'], 'hurtful': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'empurple': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enigma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'naught': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grunt': ['anger', 'sadness', 'negative', 'disgust'], 'bewitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accused': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ooze': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'cards': ['negative'], 'pulsation': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'usefulness': ['positive', 'negative'], 'suspense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astonishingly': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'wanderer': ['anger', 'positive', 'negative'], 'animation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrive_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surd': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apprize': ['anger', 'positive', 'fear', 'trust', 'negative'], 'sura': ['positive', 'trust', 'joy'], 'indelible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remunerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'donation': ['positive'], 'aerodrome': ['anticip'], 'heinous': ['negative'], 'annul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shooter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dead_room': ['fear', 'sadness', 'disgust', 'negative'], 'uninterested': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'inequity': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'calendar_method_of_birth_control': ['positive', 'surprise', 'joy'], 'cheat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jump_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cheap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spiffy': ['positive'], 'paraphrasis': ['positive', 'trust', 'negative'], 'dirge': ['sadness', 'negative', 'disgust', 'fear'], 'sendup': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'trot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'homology': ['positive', 'trust', 'disgust'], 'gula': ['negative', 'disgust'], 'nadir': ['negative'], 'gulf': ['sadness', 'negative', 'anticip'], 'gull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quiescency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gulp': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'quiescence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'believing': ['positive', 'trust'], 'deign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'work_stoppage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tautologic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fatigue_duty': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'fear', 'trust'], 'lug': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'melodic_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cautionary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spousal_relationship': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'outperform': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'joker': ['positive', 'joy', 'surprise'], 'barbaric': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dawdle': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'outofplace': ['negative'], 'flirt_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indentured': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'voluntary': ['negative'], 'remote-controlled': ['fear', 'sadness', 'disgust', 'negative'], 'importance': ['positive', 'anticip'], 'screen_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contraceptive_device': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emotionlessness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'sure_thing': ['surprise', 'anticip', 'negative', 'positive'], 'zippy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'king_of_beasts': ['anger', 'positive', 'fear', 'disgust'], 'poriferous': ['negative'], 'cover_girl': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'braveness': ['positive'], 'bemoan': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'acquiring': ['positive', 'anticip'], 'learning_ability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backbreaking': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'quiet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interloper': ['anger', 'surprise', 'fear', 'negative'], 'period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duty_assignment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'babbling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'two-year': ['anticip'], 'stroking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turkey': ['positive', 'joy', 'surprise'], 'subscriber': ['positive', 'trust'], 'insalubrious': ['fear', 'sadness', 'disgust', 'negative'], 'direction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exasperate': ['fear', 'negative'], 'nifty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'live_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'chorale': ['positive', 'joy'], 'downwind': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'confutation': ['fear'], 'epitaph': ['sadness'], 'spirit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pilot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'case': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjointly': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'cupping': ['fear', 'sadness', 'disgust', 'negative'], 'cash': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'cask': ['fear', 'sadness', 'negative'], 'cast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Laurel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wine-coloured': ['negative', 'disgust'], 'atomic_pile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'AMEX': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buck_private': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'ironic': ['positive', 'trust'], 'shopkeeper': ['trust'], 'participant': ['negative'], 'author': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'granted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eggshell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frequenter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'levity': ['positive'], 'be_after': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spatter': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aeonian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Lord's_Day": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'status': ['positive'], 'tipsy': ['surprise', 'negative', 'anticip'], 'lambast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'director': ['positive', 'trust'], 'dead_set': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'statue': ['positive'], 'spill_over': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'weep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faithful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bodied': ['negative'], 'delectable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relief': ['positive'], 'inability': ['sadness', 'negative'], 'justify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prickteaser': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_hitched_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'evenfall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Corvus_frugilegus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sudor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hopeful': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airfield': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'omnipotence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inordinate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'invalidness': ['negative'], 'nappy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convexness': ['negative', 'disgust'], 'early_childhood': ['positive', 'negative'], 'acute': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlooked-for': ['surprise'], 'tower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'present_tense': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'interlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redeeming': ['anticip', 'positive', 'trust', 'joy'], 'mood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moon': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'moor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hipster': ['negative'], 'moot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-loving': ['negative', 'disgust'], 'porter': ['positive', 'trust', 'joy'], 'methamphetamine': ['anger', 'negative'], 'penny-pinching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'assuredness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmask': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slaughter': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'black_bile': ['sadness', 'negative'], 'skating_rink': ['fear', 'sadness', 'negative'], 'via_media': ['positive'], 'Felis_onca': ['surprise', 'fear'], 'petty_criticism': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'estimator': ['positive', 'trust'], 'discrimination': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'twenty-four_hour_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whooping_cough': ['negative'], 'tribe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'single-valued_function': ['surprise', 'trust', 'negative', 'positive'], 'marijuana_cigarette': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Judgement_Day': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cursed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rising': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'syringe': ['fear'], 'relocation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cultured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affected_role': ['positive', 'negative', 'anticip'], 'fastball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freshwater_bass': ['positive', 'trust'], 'mischief': ['negative'], 'John_Cash': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'rouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extermination': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'armistice': ['positive', 'trust', 'joy'], 'ovoid': ['positive', 'sadness', 'negative', 'anticip'], 'grass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'creeping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tranquillize': ['positive', 'sadness'], 'taste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cockeyed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tasty': ['positive'], 'firebug': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'maleficence': ['negative'], 'onerous': ['anger', 'sadness', 'negative', 'fear'], 'sure-footed': ['positive', 'trust', 'joy'], 'piracy': ['fear', 'negative', 'disgust'], 'deserve': ['anger', 'positive', 'trust', 'anticip'], 'pappa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heavy_weapon': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'pellucidity': ['positive'], 'immunity': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'deviation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sibilation': ['anger', 'negative', 'disgust'], 'abdominal_muscle': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'headlamp': ['anticip'], 'deed_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dishonour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_structure': ['positive', 'trust'], 'wife': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'calculating_machine': ['positive', 'trust'], 'treason': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'platter': ['positive'], 'crumpled': ['anticip'], 'lallygag': ['negative', 'anticip'], 'wreath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'have_got': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'generalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'donkeywork': ['positive', 'fear', 'negative'], 'meditation': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear'], 'apartment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extraneous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'revengeful': ['anger', 'fear', 'negative', 'disgust'], 'passenger_car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'infringement': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Cupid's_disease": ['positive', 'trust', 'negative', 'joy'], 'prognostication': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'U.S._Constitution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nosology': ['fear', 'trust', 'negative', 'anticip'], 'gainsay': ['anger', 'fear', 'negative'], 'lisp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'list': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'singularly': ['surprise'], 'indemnity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flick': ['negative'], 'abstracted': ['sadness', 'negative', 'fear'], 'fragility': ['positive', 'trust', 'anticip'], 'jib': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negotiator': ['positive'], 'invention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'three-fold': ['positive', 'anticip'], 'bete_noire': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'subspecies': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scissure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rascal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musty': ['negative', 'disgust'], 'desegregate': ['fear', 'negative', 'disgust'], 'version': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulpit': ['positive'], 'intersect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sup': ['positive'], 'entwine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unquestioned': ['positive', 'trust'], 'womb': ['positive'], 'bedlam': ['anger', 'fear', 'sadness', 'negative'], 'Lorenz_Milton_Hart': ['positive', 'trust'], 'people_of_colour': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'President_of_the_United_States': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'drudgery': ['positive', 'fear', 'negative'], 'goodby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tragedy': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'venerating': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'grave_mound': ['disgust'], 'magnetic_attraction': ['positive'], 'horrified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stiffness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'cataract': ['sadness', 'negative', 'fear', 'anticip'], 'watch_crystal': ['positive', 'negative'], 'utilisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unionise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Ubermensch': ['positive', 'trust', 'joy'], 'woefulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rustic': ['negative'], 'eat_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garnish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hurrah': ['positive', 'joy'], 'Blackbeard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hired_hand': ['positive', 'sadness', 'trust', 'negative'], 'flat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exigency': ['surprise', 'fear', 'sadness', 'negative'], 'immersion': ['anger', 'positive', 'fear', 'trust', 'negative'], 'mire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorcery': ['surprise', 'fear', 'negative', 'anticip'], 'downlike': ['positive'], 'antibiotics': ['positive'], 'miry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'residential_district': ['positive'], 'discordance': ['anger', 'negative', 'disgust'], 'assoil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'final_stage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ineffectual': ['sadness', 'negative', 'disgust'], 'caveat': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'lugubriousness': ['sadness', 'trust', 'negative', 'fear'], "chef-d'oeuvre": ['positive', 'joy'], 'private_detective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'conspire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'up-to-dateness': ['positive'], 'smart_set': ['positive', 'negative', 'anticip'], 'grey-haired': ['sadness', 'negative', 'disgust'], 'ordinance': ['trust'], 'irrigate': ['positive', 'sadness', 'negative'], 'magpie': ['negative'], 'spirit_level': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'closed_chain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detonation': ['anger', 'surprise', 'fear', 'negative'], 'favourable_position': ['positive'], 'abdicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obituary': ['positive', 'sadness', 'trust', 'negative', 'surprise'], 'never-ending': ['positive', 'trust', 'negative'], 'lighting': ['anger', 'fear', 'negative'], 'adventure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'castle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'short': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supervision': ['fear', 'sadness', 'negative', 'disgust'], 'shore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'tax_assessor': ['trust'], 'prescription_medicine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anachronism': ['surprise', 'sadness', 'negative', 'anticip'], 'closeness': ['positive', 'trust', 'joy'], 'flaunt': ['negative'], 'pretext': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stride': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unverified': ['anticip'], 'obligingness': ['positive', 'trust'], 'bout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'washables': ['negative', 'disgust'], 'inordinateness': ['negative'], 'somebody': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'wearing_away': ['negative'], 'hunter': ['fear', 'anticip', 'sadness', 'negative'], 'incitement': ['positive'], 'unrefined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grippe': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adventurous': ['positive'], 'instructions': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mathematician': ['positive', 'trust'], 'intricacy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tactless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transportable': ['positive', 'trust', 'negative'], 'intolerable': ['anger', 'sadness', 'negative', 'disgust'], 'bagnio': ['negative', 'disgust'], 'harvest_home': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tilted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mus': ['anger', 'negative'], 'oppressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsubduable': ['positive', 'fear'], 'loopy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cloudy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cathode-ray_oscilloscope': ['positive', 'joy', 'trust', 'anticip'], 'light_beam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'focalize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'croaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impersonation': ['negative'], 'insipidness': ['negative'], 'alcohol': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'disquiet': ['anger', 'negative', 'anticip'], 'commemorative': ['positive', 'anticip'], 'candour': ['positive', 'trust', 'negative', 'disgust'], 'fill_again': ['positive'], 'hill': ['positive', 'fear', 'negative', 'anticip'], 'compounding': ['anticip'], 'roofy': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'guess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shopping_center': ['positive', 'trust', 'negative'], 'atomic_number_26': ['negative'], 'carrell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fantastical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'prejudice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knightliness': ['positive'], 'Mrs._Humphrey_Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlarged': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'traveler': ['positive', 'anticip'], 'totalitarianism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'disorderliness': ['anger', 'fear', 'sadness', 'negative', 'anticip'], 'hallowed': ['positive'], 'story': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger'], 'Benny_Hill': ['positive', 'fear', 'negative', 'anticip'], 'automobile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'porn': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'comfy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'storm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'store': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mainstay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finespun': ['positive', 'anticip', 'joy'], 'fidget': ['sadness', 'negative', 'anticip'], 'rifle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neglectfulness': ['anger', 'negative', 'disgust'], 'officiate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'shrunken': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'king': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weatherproof': ['positive'], 'unrelenting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motivation': ['positive'], 'exert': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bourdon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'substance_abuse': ['positive', 'negative', 'anticip'], 'at_sea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willful_neglect': ['negative'], 'blowhole': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'scandalisation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dumpsite': ['anger', 'sadness', 'negative', 'fear'], 'entirety': ['positive', 'trust'], 'bum_about': ['negative'], 'electric': ['positive', 'surprise', 'joy'], 'populate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gild': ['positive'], 'pipe_dream': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'inconvenience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amah': ['positive', 'trust', 'joy'], 'domestic_ass': ['negative', 'disgust'], 'rarefied': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'postage_stamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'Bohemian': ['negative'], 'gilt': ['positive'], 'defensible': ['fear', 'negative'], 'better_half': ['positive', 'trust'], 'destruct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'traditional': ['positive'], 'forerunner': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'liberate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'niggle': ['fear', 'negative'], 'barter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stumper': ['positive'], 'inflexible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "shepherd's_crook": ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'painfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interviewer': ['fear'], 'frivol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intermezzo': ['positive'], 'extemporise': ['surprise', 'anticip', 'positive'], 'wood_alcohol': ['negative'], 'founding': ['positive'], 'invoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reprint': ['negative'], 'adulthood': ['anger', 'negative', 'anticip'], 'plane_section': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'still_hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fair_to_middling': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cringe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relentless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forego': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'continuative': ['trust'], 'defense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rose_hip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'blurt': ['sadness', 'negative', 'disgust'], 'inebriate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jaundiced': ['fear', 'negative'], 'Holman_Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misstep': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'attention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'betrayer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'chirk_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fatality': ['fear', 'sadness', 'negative'], 'baleful': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'inertia': ['negative'], 'wafture': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'heating_plant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'oversee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bandit': ['negative'], 'unbiassed': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'timorousness': ['fear', 'negative', 'anticip'], 'reside': ['positive', 'trust'], 'August_15': ['positive', 'anticip'], 'sweet': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'sweep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harbour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'village': ['positive', 'trust'], 'great_power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'startling': ['surprise'], 'superstitious_notion': ['positive', 'fear', 'negative'], 'New_York_minute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'break_water': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affectionate': ['positive', 'trust', 'joy'], 'flight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'latterly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precision': ['positive'], 'short_letter': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'waft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cinch': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'demand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notables': ['positive'], 'instructor': ['positive', 'trust', 'anticip'], 'equivocation': ['fear', 'sadness', 'negative'], 'unconquered': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise'], 'frozen': ['surprise', 'trust', 'negative'], 'warrant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhesitating': ['positive'], 'negociate': ['positive', 'trust'], 'kick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'probationary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mordant': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'shortened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'epic_poem': ['positive'], 'credence': ['positive', 'trust'], 'antithesis': ['anger', 'negative'], 'demon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obstacle': ['anger', 'fear', 'sadness', 'negative'], 'toilet_table': ['negative'], 'stye': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'definitive': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'promised_land': ['positive', 'trust', 'joy'], 'choler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_Defense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'badgering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evangelistic': ['trust'], 'luxuriate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prerequisite': ['anticip'], 'restraint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cement': ['positive', 'trust', 'negative', 'anticip'], 'impede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bourgeois': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abattoir': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'equipment_failure': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'magnified': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'tarnish': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unmated': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'nonsuch': ['anticip', 'positive', 'trust', 'joy'], 'foreshorten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Panacea': ['positive'], 'privateness': ['surprise', 'trust'], 'prince': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'planetary_house': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_post': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treacle': ['negative', 'disgust'], 'resourcefulness': ['positive', 'anticip', 'joy'], 'predetermine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exposit': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'Handy': ['positive'], 'advocate': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clemency': ['positive'], 'sapphic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'skeptical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'confront': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'separately': ['surprise', 'anticip', 'positive'], 'uproar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deleterious': ['anger', 'fear', 'negative', 'disgust'], 'put_on_the_line': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'apologia': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'human_death': ['fear', 'sadness', 'negative'], 'necropolis': ['fear', 'sadness', 'negative'], 'eldritch': ['fear', 'negative', 'disgust'], 'saucer': ['positive'], 'manner_of_speaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tomentum': ['positive', 'trust', 'negative', 'disgust'], 'onward_motion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retro': ['negative'], 'secernate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avoirdupois': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'meretricious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refused': ['sadness', 'negative'], 'consolation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upper_berth': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'vaccine': ['positive'], 'sporty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asserting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'niceness': ['positive'], 'plaza': ['positive', 'trust', 'negative'], 'leukaemia': ['anger', 'fear', 'sadness', 'negative'], 'lifeless': ['fear', 'sadness', 'negative'], 'range': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complimentary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fluttering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'youthful': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calloused': ['anger', 'negative', 'disgust'], 'public_house': ['anger'], 'auntie': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'heedless': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'Saul_Bellow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'artifice': ['negative'], 'ellipse': ['positive', 'sadness', 'negative', 'anticip'], 'stench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acquiesce': ['positive'], 'question': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'long': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annulment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fashion_model': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'statuesque': ['positive', 'trust'], 'etch': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mimicry': ['surprise', 'negative'], 'close_up': ['trust', 'anticip'], 'case-hardened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'audacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'petty_larceny': ['negative'], 'bunch_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'partitioning': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'remunerative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forefather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clog_dancing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lifespan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear'], 'deferto': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'avowedly': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirligig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pilotless_aircraft': ['negative'], 'rainbow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peach': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'peace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brush_aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paralytic': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'onionskin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bandstand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squeeze_play': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supererogatory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smitten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'booger': ['anger', 'fear', 'sadness', 'negative'], 'meaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'puncture': ['anger', 'sadness', 'negative'], 'wrinkle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amphetamine': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'wildness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impatient': ['negative', 'anticip'], 'necrology': ['positive', 'sadness', 'trust', 'negative', 'surprise'], 'sea_robber': ['anger', 'negative'], 'lovemaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ternary': ['positive', 'trust', 'negative', 'disgust'], 'concenter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inconvenience_oneself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Basel': ['fear', 'negative'], 'alien': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dispel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'windy': ['anticip', 'positive', 'trust', 'joy'], 'Libra': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infatuation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'discordant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spear_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ropeway': ['fear', 'sadness', 'disgust', 'negative'], 'cruiser': ['trust'], 'uphold': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'theorise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'include': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hit_man': ['fear'], 'confirmation': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'ladle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daystar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foretell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cockle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'paternity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'woodworking_plane': ['positive', 'trust'], 'extenuate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'astuteness': ['positive', 'trust'], 'friendliness': ['positive', 'trust', 'joy'], 'concluded': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'trust'], 'toils': ['negative'], 'gripping': ['positive'], 'particular_date': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'wrestling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconscious_process': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carrying_out': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'reunion': ['positive', 'trust', 'anticip'], 'buccaneer': ['anger', 'negative'], 'acid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'life-time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'folk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outsmart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disentangle': ['anger', 'fear', 'negative', 'anticip'], 'bearish': ['anger', 'fear'], 'head_covering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unruly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'mensuration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'degree': ['positive'], 'United_States_President': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'explore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'gloat': ['positive', 'joy'], 'salt_mine': ['anticip'], 'blameful': ['negative'], 'settling': ['sadness', 'negative'], 'distressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detritus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispiritedness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'larger': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'habitant': ['fear', 'negative', 'disgust'], 'leaving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colouration': ['sadness', 'negative', 'disgust'], 'pretentiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battle_royal': ['fear', 'negative'], 'requite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'celestial_sphere': ['anticip', 'positive', 'trust', 'joy'], 'goofball': ['surprise', 'trust', 'negative', 'joy'], 'blether': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'falsity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'apt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'improbable': ['negative'], 'crawdad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lottery': ['anticip'], 'frog': ['negative', 'disgust'], 'procrastinate': ['negative'], 'examination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circuitous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dilatoriness': ['negative'], 'clever': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cerement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'factor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unvanquished': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise'], 'chichi': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'patterned_advance': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'thirstiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verity': ['positive', 'trust'], 'highborn': ['sadness', 'negative'], 'disingenuous': ['negative', 'disgust'], 'in_agreement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indifference': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'sucking_louse': ['negative', 'disgust'], 'well_up': ['fear', 'negative'], 'dissolve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ritual_killing': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'thickly_settled': ['disgust'], 'quill_feather': ['anger', 'fear', 'negative'], 'covering_fire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'thirsty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cellular_inclusion': ['trust'], 'inaccessible': ['negative'], 'evacuant': ['positive'], 'crick': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'column_inch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slack_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legaltender': ['positive', 'trust', 'joy'], 'provoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-founded': ['positive', 'negative'], 'epidemic_parotitis': ['negative'], 'justifiable': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stewardship': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'closure_by_compartment': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'roughness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'specialisation': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'attend': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'tact': ['positive', 'fear', 'trust'], 'normalcy': ['positive'], 'tack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'survival_of_the_fittest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bring_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arduous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'budge': ['trust'], 'free_fall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue_funk': ['sadness', 'negative'], 'perishing': ['fear', 'sadness', 'negative'], 'sanctioned': ['positive', 'joy'], 'baddie': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'minnow': ['negative', 'disgust'], 'meager': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpreter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'badluck': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'cotton_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismaying': ['fear', 'negative', 'disgust'], 'superior': ['positive'], 'banknote': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overvalue': ['surprise', 'negative'], 'glee': ['positive', 'joy'], 'scissors_hold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holiday': ['positive', 'anticip', 'joy'], 'tag_end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baroqueness': ['surprise', 'fear', 'negative', 'disgust'], 'campaigner': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'ambition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materialization': ['positive', 'fear'], 'diabolic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'chain_mail': ['anger', 'fear', 'negative', 'anticip'], 'lockjaw': ['negative', 'disgust'], 'measly': ['anger', 'sadness', 'negative', 'disgust'], 'trimmer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'edit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parole': ['anticip'], 'discorporate': ['fear', 'sadness', 'negative'], 'lastingness': ['positive', 'trust'], 'axiomatical': ['trust'], 'prizewinning': ['anticip', 'positive', 'trust', 'joy'], 'secretive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whimsy': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'rosehip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acknowledgment': ['positive'], 'sentiment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cerebral': ['positive'], 'gossamer': ['positive', 'fear', 'anticip', 'joy'], 'chaos': ['anger', 'fear', 'sadness', 'negative'], 'plaguing': ['negative'], 'ground_tackle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'honorable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frankness': ['positive', 'trust', 'negative', 'disgust'], 'disclose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'submaxilla': ['fear', 'negative', 'disgust'], 'tenement': ['negative'], 'citizens_committee': ['trust'], 'tenant': ['positive', 'trust'], 'greenhorn': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'organic': ['positive'], 'g': ['trust'], 'enfranchisement': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'trust'], 'regaining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Divine': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'obscurity': ['fear', 'negative'], 'reposeful': ['positive', 'negative'], 'signboard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fluxion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bonnet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eleventh': ['fear'], 'dupery': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'flyspeck': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'toppingly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'booze-up': ['negative'], 'call_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unknown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'accountant': ['trust'], 'priority': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill_at_ease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'right-down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'unceasing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diminish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'send_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Brobdingnagian': ['positive'], 'astounded': ['surprise', 'fear', 'negative'], 'commodity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criminalness': ['anger', 'fear', 'negative', 'disgust'], 'objectionable': ['negative'], 'indistinct': ['negative'], 'encore': ['positive'], 'fifth_part': ['fear'], 'clip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'David_Smith': ['trust'], 'worldly-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'menstruum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delineated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disjoint': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'braggy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'linked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'revalue': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'unbearable': ['sadness', 'negative', 'disgust'], 'inform': ['anger', 'positive', 'fear', 'trust', 'negative'], 'boastful': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hazardous': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear'], 'legal_opinion': ['surprise'], 'birch_tree': ['anger', 'fear', 'negative', 'disgust'], 'moveable': ['positive', 'trust', 'negative'], 'toss_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tinct': ['fear', 'sadness', 'negative'], 'atypical': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'storming': ['anger'], 'pipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swarming': ['disgust'], 'poorness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'overhasty': ['negative'], 'agreed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spanking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'longevity': ['positive'], 'Holy_Father': ['positive', 'trust'], 'utter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pleased': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'litigation': ['negative'], 'succour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pare_down': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'manacle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blamable': ['negative'], 'melanize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'inhabit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'indignant': ['anger', 'negative'], 'cube': ['trust'], 'topple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skimp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'massacre': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'whole_step': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'malaise': ['sadness', 'negative'], 'burglary': ['negative'], 'precious_stone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'differential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ascertain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Draco': ['fear'], 'buzzer': ['anger', 'fear', 'negative', 'disgust'], 'predictive': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'requirement': ['positive'], 'humiliation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'food_grain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despoiler': ['sadness', 'negative'], 'come_home': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buzzed': ['negative'], 'luminous': ['positive'], 'burn_mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Francis_Scott_Key': ['positive', 'negative', 'disgust', 'surprise'], 'monstrous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'gleefulness': ['positive', 'joy'], 'favor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'dictatorial': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'identification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wetting': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'crude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shabbiness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'learned_person': ['negative'], 'jot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dateless': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'joy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'job': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'takeover': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lifeboat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'retrograde': ['negative'], 'Department_of_the_Treasury': ['trust'], 'grounds': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rampantly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'openhanded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guiltiness': ['anger', 'sadness', 'negative', 'disgust'], 'unlogical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'displume': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'unclean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motorbike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decent': ['positive', 'negative', 'disgust'], 'net_ton': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arbitrator': ['trust'], 'pervade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puberty': ['positive', 'trust', 'joy'], 'Laurus_nobilis': ['anger', 'fear', 'negative'], 'glib-tongued': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raptorial_bird': ['fear', 'negative'], 'scrutiny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insularism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fearful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stone-broke': ['anger', 'positive', 'fear', 'negative'], 'stunning': ['positive', 'joy'], 'anal_retentive': ['positive', 'trust', 'negative', 'anticip'], 'ascetical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hinderance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motif': ['positive'], 'ringing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unworkable': ['negative'], 'rooster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drum_roll': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perhaps': ['surprise'], 'subcontract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exuberance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise'], 'simmpleness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disciple': ['positive', 'trust', 'joy'], 'difficult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maculate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slave': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'disagree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'picayune': ['sadness', 'negative'], 'concaveness': ['negative'], 'laborious': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'correspondent': ['positive', 'trust'], 'undertaker': ['sadness'], 'cast_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'timbre': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'contest': ['negative', 'anticip'], 'banging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scruples': ['positive', 'trust'], 'excessive': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'heavily': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'necromancer': ['surprise', 'anticip', 'positive'], 'sterileness': ['sadness', 'negative'], 'banking_company': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'reasoning_backward': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'stuff_and_nonsense': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'harmoniousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guts': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncommonly': ['surprise'], 'arresting': ['positive', 'joy'], 'make_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tawny': ['disgust'], 'usage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'execute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flagitious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unsatiated': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'single-handed': ['fear', 'sadness', 'negative'], 'press': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excessiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symphony_orchestra': ['positive', 'anticip', 'joy'], 'colza': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'stabilize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calliper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthronisation': ['positive', 'trust', 'joy'], 'vortex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feigned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morbilli': ['fear', 'sadness', 'disgust', 'negative'], 'gravitational_force': ['positive', 'trust', 'negative', 'disgust'], 'sanctitude': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'adaptation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parity': ['anger', 'sadness', 'negative', 'disgust'], 'exceed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flagrant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reclamation': ['positive'], 'melee': ['fear', 'negative'], 'vicarious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'employment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endangerment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'iciness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'staccato': ['positive'], 'donjon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pasty': ['disgust'], 'bass_part': ['positive', 'trust'], 'importation': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'paste': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pike': ['fear'], 'tone-beginning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sourish': ['surprise', 'fear', 'negative', 'anticip'], "pull_in_one's_horns": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heroics': ['positive'], 'converging': ['anticip'], 'outset': ['positive', 'surprise', 'anticip'], 'polished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gymnastic': ['positive'], 'kinsperson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weather': ['positive'], 'promise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lawful': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'shortsightedness': ['anger', 'sadness', 'negative'], 'transfer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spiral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Recent_epoch': ['positive', 'trust', 'joy'], 'scintillating': ['positive', 'joy'], 'extravagant': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'nourish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ca-ca': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anatomical_structure': ['positive', 'trust'], 'assail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swallow_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'embolden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distract': ['anger', 'negative', 'anticip'], 'cake': ['negative'], 'faggot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hornswoggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monastic': ['positive', 'trust'], 'bewail': ['sadness'], 'fistulous_withers': ['positive', 'disgust'], 'horrific': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serious-mindedness': ['positive', 'fear', 'sadness'], 'maroon': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chasteness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gizmo': ['positive'], 'incredible': ['surprise', 'sadness', 'negative', 'positive'], 'glint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vomit_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drome': ['anticip'], 'repute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mandibular_bone': ['fear', 'negative', 'disgust'], 'knottiness': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'work_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'conclusion': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'marshland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'juvenile_person': ['negative'], 'counterchange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nourishment': ['positive'], 'hash_out': ['positive'], 'squeak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squeal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'linear_perspective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auxiliary': ['positive', 'trust', 'joy'], 'sass': ['surprise', 'negative'], 'unbridle': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'shoot_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'timelessness': ['anticip'], 'strategical': ['positive'], 'conjury': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cussed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'yellow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aegir': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ornate': ['positive'], 'conjuring': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recipient_role': ['anticip'], 'gaolbreak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electricity': ['positive'], 'unanswered': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Robert_Curl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swivel': ['positive', 'trust'], 'bellyache': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'second-sighted': ['positive'], 'intercessor': ['positive', 'trust', 'anticip'], 'extremely_low_frequency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nontaxable': ['positive', 'negative'], 'rancour': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'prize': ['positive', 'trust'], 'buttonhole': ['negative'], 'base_hit': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'succession': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'reliable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agnate': ['positive', 'negative', 'anticip'], 'charter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glassy': ['sadness', 'negative', 'disgust'], 'vocal_music': ['positive', 'trust'], 'scheming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spread_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tether': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'onyx_marble': ['positive'], 'terminal_figure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ruthless': ['anger', 'fear', 'negative', 'disgust'], 'tackiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decry': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pharmacy': ['positive', 'trust'], 'insinuation': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'avert': ['surprise', 'fear', 'sadness', 'negative'], 'leaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'composed': ['positive', 'sadness'], 'undestroyable': ['positive', 'trust'], 'dork': ['anger', 'surprise', 'fear', 'negative', 'positive'], 'substance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'straight-laced': ['anger', 'positive', 'trust', 'negative'], 'barrowful': ['disgust'], 'personify': ['positive', 'trust', 'negative'], 'military': ['fear'], 'divide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gloaming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'summons': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remnant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dearie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'prim_out': ['anger', 'positive', 'trust', 'negative'], 'cheating': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'spoke': ['trust', 'negative'], 'tardiness': ['negative'], 'impartiality': ['positive', 'trust'], 'overshadow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glimmering': ['surprise', 'anticip', 'positive', 'joy'], 'leave_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'statesmanship': ['positive', 'trust', 'anticip'], 'telegraph': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Saint_Ulmo's_light": ['positive', 'trust', 'joy'], 'mired': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'relax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'successful': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'trust'], 'hurt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hurl': ['surprise', 'fear', 'negative'], 'opera_house': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pontifical': ['trust'], 'castle_in_Spain': ['positive', 'trust', 'joy'], 'famed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blade': ['surprise', 'sadness'], 'dimsightedness': ['negative'], 'straddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'household': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artillery': ['anger', 'fear', 'negative', 'anticip'], 'organized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'church_building': ['anticip', 'positive', 'trust', 'joy'], 'dyke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garden_cart': ['disgust'], 'put_to_work': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fancied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'damage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'machine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swine': ['negative', 'disgust'], 'gaming': ['surprise', 'negative', 'anticip'], 'edible_corn': ['anger', 'negative'], 'modulation': ['positive'], 'incompetent_person': ['anger', 'sadness', 'negative'], 'destined': ['surprise', 'negative', 'trust', 'positive', 'anticip'], 'chump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Holocene': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'scourge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memento': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cachexy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wino': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'excommunicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wine': ['negative', 'disgust'], 'restriction': ['anger', 'fear', 'sadness', 'negative'], 'misdemeanor': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weapons_platform': ['positive'], 'handcuff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vara': ['negative'], 'validatory': ['trust'], 'hold_fast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'head_ache': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'matured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hidden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glorify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enrich': ['positive'], 'slicing': ['surprise', 'sadness', 'negative', 'fear', 'positive'], 'detachment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narrow-mindedness': ['negative'], 'full_complement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'structural': ['trust'], 'rumour': ['sadness', 'negative'], 'dumps': ['anger', 'sadness', 'negative', 'fear'], 'dumpy': ['negative'], 'interfering': ['negative'], 'expectancy': ['anticip'], 'garment': ['negative', 'disgust'], 'displacement': ['trust', 'negative'], 'reader': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ameliorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expectance': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'blinded': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'diction': ['positive', 'trust', 'negative', 'anticip'], 'waive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urbane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strategist': ['positive', 'trust', 'anticip'], 'subsiding': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'assured': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'trust'], 'waddle': ['positive', 'anticip'], 'fugitive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inscribe': ['negative'], 'sensory': ['positive', 'joy'], 'substantiation': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'spurned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pad_of_paper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'misplace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instruct': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'stock-purchase_warrant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whorehouse': ['negative', 'disgust'], 'revilement': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'outstandingly': ['positive'], 'take_the_field': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inadequateness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'postulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freshen_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'listen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collapse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jacket_crown': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wisdom': ['anticip', 'positive', 'trust', 'joy'], 'emaciate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outlay': ['negative'], 'rowdyism': ['anger', 'fear', 'negative'], 'iteration': ['fear', 'sadness', 'negative'], 'come_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speediness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'seminary': ['positive'], 'acclaim': ['surprise', 'trust', 'positive', 'joy'], 'entail': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'patient_role': ['positive', 'negative', 'anticip'], 'responsible': ['positive', 'trust', 'negative'], 'nagger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ambuscade': ['anger', 'surprise', 'fear', 'negative'], 'tawdriness': ['anger', 'negative'], 'Wise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doit': ['negative'], 'obsequiousness': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'affirmation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'letter': ['anticip', 'positive', 'trust', 'joy'], 'retaining': ['positive'], 'drought': ['negative'], 'morality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'episode': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'colourlessness': ['negative', 'disgust'], 'handcart': ['fear', 'negative'], 'professor': ['positive', 'trust'], 'regulative': ['fear', 'negative'], 'governing_body': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'linguistic_process': ['anger', 'positive', 'negative'], 'bomb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mellisonant': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'gauge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bowl_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attend_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'staying_power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illegalise': ['negative'], 'hassock': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'menu': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'varicella': ['fear', 'sadness', 'disgust', 'negative'], 'wood_spirit': ['negative'], 'theme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wiliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instrumentalist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'didactical': ['positive'], 'profoundness': ['positive', 'trust'], 'codfish': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'line_roulette': ['anticip'], 'reversal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'new': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'avenger': ['anger', 'negative'], 'lock_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urticate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'respond': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'traverse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mandatory': ['negative'], 'disaster': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fair': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'consummation': ['positive'], 'sapless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'babyhood': ['positive', 'negative'], 'bleb': ['negative', 'disgust'], 'fail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fain': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'best': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crushed_rock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'giving_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hunker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stealthy': ['anticip', 'negative', 'anger', 'surprise', 'fear', 'trust'], 'score': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flagellate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'scorn': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Cage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'pirate': ['anger', 'negative'], 'preserve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'claws': ['anger', 'fear', 'negative'], 'screwball': ['anger', 'fear', 'sadness', 'negative'], 'usance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invigorated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twinkling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'posit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monetary_value': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mahimahi': ['surprise', 'trust', 'positive', 'joy'], 'angling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overabundant': ['anger', 'negative'], 'stand_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'state_of_affairs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'adventurer': ['anger', 'fear', 'negative'], 'delusory': ['negative'], 'vain': ['sadness', 'negative'], 'canyon': ['trust'], 'take_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'penalize': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'vellicate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'eager': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'chroma': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'extraction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incompetent': ['anger', 'sadness', 'negative', 'disgust'], 'life': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tightfistedness': ['positive', 'trust', 'joy'], 'lift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incommode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chile': ['negative'], 'child': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chili': ['negative'], 'erst': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'loftiness': ['positive', 'trust'], 'diverted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'presidency': ['positive', 'trust', 'joy'], 'taper': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pastime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'truster': ['trust'], 'piercing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'letdown': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'assibilation': ['anger', 'negative', 'disgust'], 'Capital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doorman': ['positive', 'trust', 'joy'], 'transfuse': ['fear', 'sadness', 'disgust', 'negative'], 'bounteous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trusted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trustee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapprochement': ['anticip', 'positive', 'trust', 'joy'], 'res_publica': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlistment': ['anger', 'positive', 'fear', 'negative'], 'fatal': ['anger', 'fear', 'sadness', 'negative'], 'haphazard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swarthy': ['sadness', 'negative', 'disgust'], 'rise_to_power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abduce': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fairly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'Gallus_gallus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'son_of_a_bitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ethical_code': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'Walter_Reed': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'tope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thresh_about': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'stupendous': ['positive'], 'bonny': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'coldness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'subpoena': ['negative'], 'juridical': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'practice_of_law': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forsaken': ['anger', 'sadness', 'negative'], 'acute_anterior_poliomyelitis': ['fear', 'sadness', 'negative'], 'ungovernable': ['anger', 'surprise', 'negative', 'anticip'], 'plight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inprogress': ['anticip'], 'hunch': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'web_site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'Greek_valerian': ['positive', 'joy'], 'good-humoured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'footle': ['negative', 'anticip'], 'casually': ['surprise'], 'gormandise': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'possible': ['anticip'], 'army_corps': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'effulgent': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'birth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unique': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'articulated': ['positive'], 'stick_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pavement': ['trust'], 'prologue': ['anticip'], 'hew_out': ['anger', 'sadness', 'negative'], 'William_Sydney_Porter': ['positive', 'trust', 'joy'], 'marriage_ceremony': ['anticip', 'positive', 'trust', 'joy'], 'people': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'macabre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fatality_rate': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'visual_sense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warring': ['anger', 'fear', 'negative'], 'trimmer_joist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unvalued': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], "carpenter's_plane": ['positive', 'trust'], 'fop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ump': ['positive', 'trust'], 'Quran': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fox': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foe': ['anger', 'fear', 'negative', 'disgust'], 'fog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'germinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pinched': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'dead_ringer': ['anger', 'negative'], 'Book_of_Numbers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conservation_of_parity': ['anger', 'sadness', 'negative', 'disgust'], 'usher_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'despair': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'repellent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rebut': ['negative'], 'supreme_authority': ['positive', 'trust'], 'stiletto_heel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nought': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'problematical': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'resile': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'attrition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reducing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'risk_of_exposure': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unambiguous': ['positive', 'trust'], 'better-looking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'panorama': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Elvis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'one-time': ['positive', 'sadness', 'trust', 'negative'], 'bearing_false_witness': ['surprise', 'fear', 'negative'], 'avail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Loafer': ['negative'], 'hothead': ['anger', 'fear', 'negative', 'disgust'], 'bollocks': ['anger', 'sadness', 'negative', 'disgust'], 'unhurriedness': ['fear', 'sadness', 'negative', 'disgust'], 'happy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straggly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fascination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legal_guardian': ['positive', 'trust'], 'gripes': ['negative'], 'piousness': ['positive'], 'straggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-command': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'silliness': ['negative'], 'vanguard': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Graeco-Roman': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pest': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'torturing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pontificate': ['positive', 'disgust', 'anticip'], 'calumniation': ['anger', 'fear', 'negative', 'disgust'], 'mighty': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blood_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suspiciousness': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'later': ['negative'], 'liberal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tournament': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'unfledged': ['negative', 'anticip'], 'police_constable': ['trust'], 'crumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soothe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acidulent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quintuplet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accounting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dealer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solicitation': ['anticip'], 'dotted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'actor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unambiguously': ['positive'], 'republic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protester': ['anger', 'fear', 'negative'], 'denotation': ['anticip', 'positive', 'trust', 'joy'], 'snick': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'demonstrative': ['positive', 'sadness', 'joy'], 'abjuration': ['negative'], 'console_table': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maimed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'persecution': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'diadem': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'put_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bumpkinly': ['negative'], 'peacock': ['positive'], 'church_service': ['anticip', 'positive', 'trust', 'joy'], 'Brassica_napus': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'firecracker': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'put_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crocodile': ['fear'], 'avalanche': ['surprise', 'fear', 'sadness', 'negative'], 'jarring': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'happen_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vet': ['anger', 'positive', 'trust', 'negative'], 'clean_and_jerk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'blurriness': ['positive', 'negative'], 'indolent': ['negative'], 'vex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'think_over': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'veg': ['positive'], 'reinvigorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_the_picture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blood_relation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'argufy': ['anger', 'negative'], 'mourn': ['anger', 'sadness', 'negative', 'fear'], 'servicing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'wondrously': ['positive', 'joy'], 'disembody': ['fear', 'sadness', 'negative'], 'gang_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhallowed': ['fear', 'negative'], 'tear': ['anger', 'negative'], 'teat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'predaceous': ['negative'], 'solved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'team': ['trust'], 'Isidor_Feinstein_Stone': ['anger', 'positive', 'fear', 'negative'], 'prevent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attic': ['negative'], 'become_flat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'chickenhearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'all_the_way': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Earth's_crust": ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'playpen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'educate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'cleanliness': ['positive'], 'contrastive': ['anger', 'sadness', 'negative', 'disgust'], 'current': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extraterrestrial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'all-powerful': ['positive'], 'deadening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freaky': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'abscond': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doubt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high-mindedness': ['positive'], 'centime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'molestation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'royal_line': ['positive'], 'pass_through': ['anticip'], 'spare-time_activity': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'flux_density': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'vitiated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reclaim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concealed': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'love': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'defer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'marvelous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'control_panel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forefront': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'positive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dangle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sign_of_the_zodiac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cherished': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'wondering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'critical_review': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'slenderize': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'duality': ['positive'], 'afford': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apparent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reprise': ['positive', 'anticip'], 'odious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stool_pigeon': ['positive'], 'turn_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'degrade': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'olfactory_organ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'behalf': ['positive', 'sadness', 'negative', 'disgust'], 'honey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'valued': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'believer': ['trust'], 'nether': ['anger', 'fear', 'sadness', 'negative'], 'jumbal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dispossess': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'believed': ['trust'], 'literal_error': ['negative'], 'frizzly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Federal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'intransigent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Holy_Order': ['positive', 'fear', 'negative', 'disgust', 'anticip'], 'meshwork': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abidance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pendulous': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'parameter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cavil': ['surprise', 'trust', 'negative', 'anticip'], 'jazz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blasting': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'spot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rehabilitate': ['positive'], 'malarkey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misshapen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'date': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filthy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'shockingly': ['surprise'], 'disagreeable': ['negative', 'disgust'], 'applicant': ['anticip'], 'yielding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'human_face': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pen_nib': ['fear', 'negative', 'disgust'], 'epilepsy': ['negative'], 'unacceptable': ['surprise', 'sadness', 'negative', 'positive'], 'bibulous': ['negative', 'disgust'], 'unfavorable': ['sadness', 'negative', 'disgust'], 'thoughtfulness': ['positive', 'joy'], 'solitary': ['sadness', 'trust'], 'hush_up': ['positive'], 'solace': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'lackluster': ['negative'], 'loose_woman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'correlational_statistics': ['positive'], 'attraction': ['positive', 'sadness', 'trust', 'negative'], 'hubbub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'petition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Jack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equipage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coronary_artery_disease': ['fear', 'sadness', 'negative'], 'matcher': ['anticip'], 'pushover': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'throwing_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tensity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'macebearer': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'revery': ['positive', 'trust', 'joy'], 'beldame': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'common_cold': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'revers': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'revert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bird-scarer': ['positive', 'fear', 'negative'], 'primitive_person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'edify': ['positive', 'trust', 'joy'], 'fireproof': ['positive'], 'breakthrough': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'asseverate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'giddy': ['negative'], 'canvas': ['trust', 'negative', 'disgust'], 'lowlife': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plan_of_attack': ['anticip'], 'Job': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'onrush': ['anticip'], 'drop_anchor': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'stage_business': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irregularityofrecurrence': ['sadness', 'negative'], 'timidness': ['fear', 'negative', 'anticip'], 'go_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incendiarism': ['anger', 'fear', 'negative'], 'military_man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soar_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invalidation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'governing': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emblematic': ['positive'], 'sickeningness': ['sadness', 'negative', 'disgust'], 'make_believe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'huskiness': ['anger', 'positive', 'fear', 'trust'], 'disguised': ['surprise', 'negative', 'anticip'], 'eye_infection': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mill_about': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'ostrich': ['trust'], 'impure': ['negative', 'disgust'], 'recompense': ['positive'], 'butt_against': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intuition': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'petulant': ['anger', 'negative'], 'potter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Amun': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'vote': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'chubby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bill_of_indictment': ['fear', 'negative'], 'indicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drugstore': ['positive', 'trust'], 'mobile_phone': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'blazon': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'meddling': ['negative'], 'padding': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'spar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise'], 'Sept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rival': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'savant': ['negative'], 'future': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'double-tongued': ['anger', 'sadness', 'negative', 'disgust'], 'cavalier': ['anger', 'fear'], 'winkle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'festinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "hangman's_rope": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prospect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'violent_disorder': ['anger', 'fear', 'negative'], 'considerably': ['positive', 'trust'], 'convex_shape': ['negative', 'disgust'], 'lurking': ['negative'], 'perplex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knead': ['positive', 'joy'], 'Pastor': ['positive', 'trust', 'negative', 'joy'], 'effeminateness': ['positive', 'negative'], 'take': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stupid_person': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill-humored': ['anger', 'negative', 'disgust'], 'subvention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maneuvering': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'Kern': ['negative'], 'abut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fancy_woman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constable': ['trust'], 'nonsubjective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'round_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reenforce': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'schoolmistress': ['anger', 'negative', 'disgust'], 'surplus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unassailable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mince': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lettered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nictate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'usher_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hobo_camp': ['fear'], 'farting': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'unkind': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'conduction': ['positive'], 'conventionalism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intestines': ['fear'], 'robe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'sweet-smelling': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'morphological': ['trust'], 'Lexington': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'cursing': ['anger', 'negative', 'disgust'], 'infallible': ['positive'], 'lucidity': ['positive'], 'torturesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'yammer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'maniacal': ['anger', 'fear', 'negative'], 'in_cold_blood': ['negative'], 'soundbox': ['positive', 'trust', 'negative'], 'physicalpleasure': ['positive', 'joy', 'trust', 'anticip'], 'liable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'choke_up': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'disparage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'neutralise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mightiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gout': ['negative'], 'grey-headed': ['sadness', 'negative', 'disgust'], 'atilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transientness': ['anger', 'fear', 'sadness', 'negative'], 'espy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surgery': ['positive', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'sexual_abstention': ['positive', 'trust', 'anticip'], 'diver': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'corporality': ['negative'], 'bootleg': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'shogunate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'teens': ['positive', 'negative'], 'presage': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untainted': ['positive'], 'uncurbed': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'Bible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aberration': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'faded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'scrutinise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rapacious': ['anger', 'fear', 'sadness', 'negative'], 'jovial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jaunty': ['positive'], 'undermine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'necropsy': ['fear', 'sadness', 'disgust', 'negative'], 'Citation': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'deduction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loudly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contraceptive_pill': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'help_oneself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower_status': ['negative'], 'desist': ['anger', 'negative', 'disgust'], 'twit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wine_cellar': ['negative'], 'homosexuality': ['negative'], 'rhytidoplasty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sentinel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dislocation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'deoxyephedrine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'teddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'God_Almighty': ['positive', 'trust'], 'vacation': ['positive', 'anticip', 'joy'], 'breath': ['trust'], 'see_red': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rebarbative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'influence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'putting_green': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bear_down': ['anger', 'negative'], 'cloudburst': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'precariousness': ['surprise', 'negative', 'anticip'], 'respectfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shanty': ['positive', 'fear', 'sadness'], 'hypertrophy': ['surprise', 'fear', 'disgust'], 'newspaperman': ['positive', 'trust'], 'blue_air': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roll_down': ['surprise', 'fear', 'sadness', 'negative'], 'ill-humoured': ['anger', 'negative', 'disgust'], 'crabby_person': ['anger', 'negative'], 'go_past': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'graceful': ['anger', 'positive', 'negative', 'disgust'], 'toothache': ['fear', 'negative'], 'adenoidal': ['fear', 'negative'], 'spiraling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretchiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clapping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breakdown': ['negative'], 'judgment_of_dismissal': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'I': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Anchorage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bulletproof': ['positive'], 'touch_modality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cordial_reception': ['positive'], 'unmanageable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'disown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'costa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'undefined': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'melt_off': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'vacant': ['negative'], 're-sentencing': ['positive'], 'fixing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Agriculture_Department': ['positive'], 'feel_for': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'houseclean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pull_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_chances': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potentiality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underline': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'underling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intumescent': ['negative'], 'formative': ['positive', 'trust'], 'Black_person': ['sadness', 'negative'], 'prominently': ['positive'], 'overcompensate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'joyful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Panthera_onca': ['surprise', 'fear'], 'unquiet': ['fear', 'negative', 'anticip'], 'resplendency': ['anticip', 'positive', 'trust', 'joy'], 'Monk': ['positive', 'trust'], 'sodding': ['positive'], 'resplendence': ['anticip', 'positive', 'trust', 'joy'], 'breeze_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clam': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'reinforcing_stimulus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neutralisation': ['anger', 'fear', 'negative'], 'clay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'claw': ['anger', 'fear', 'negative'], 'clap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'putrefaction': ['negative', 'disgust'], 'hemipteron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endeavor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cementum': ['positive', 'trust', 'negative', 'anticip'], 'authenticate': ['trust'], 'riveting': ['positive', 'trust'], 'pick_at': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'extend_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sublimation': ['positive', 'joy'], 'infantile_fixation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'situate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'robustious': ['anger', 'fear', 'negative', 'disgust'], 'contingent': ['anticip'], 'ration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'political_science': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'audaciousness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'industry': ['positive', 'negative'], 'accounting_entry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puzzle_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'practicable': ['negative'], 'latrines': ['negative', 'disgust'], 'act': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impregnate': ['negative', 'disgust'], 'consentient': ['positive', 'trust'], 'reflexion': ['positive', 'joy'], 'image': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rectification': ['fear', 'negative'], 'widower': ['sadness'], 'sempiternal': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'purplish': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drone_pipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mail_service': ['anger', 'fear', 'negative', 'anticip'], 'reinvigorated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bivouacking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'River_Cam': ['anger', 'surprise', 'fear', 'negative'], 'oesophagus': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'pleasure_craft': ['trust'], 'beacon_light': ['positive'], 'emesis': ['disgust'], 'Sphinx': ['fear', 'negative'], 'fastidious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'antiquated': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'impedance': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'indorse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attenuate': ['negative'], 'breathein': ['positive', 'trust'], 'severally': ['surprise', 'anticip', 'positive'], 'suppurate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'torso': ['positive', 'trust', 'negative'], 'agree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gong': ['surprise', 'fear'], 'knavish': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bookstall': ['positive'], 'as': ['positive'], 'ay': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sports_fan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hang_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fifty-fifty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beaming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strike_hard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precognitive': ['positive'], 'novice': ['negative'], 'embrasure': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'congress': ['positive', 'trust', 'disgust'], 'annex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'damnably': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'middling': ['negative'], 'grownup': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'lifelessness': ['positive', 'fear', 'sadness'], 'pirate_ship': ['anger', 'negative'], 'slang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favorable_position': ['positive'], 'gastric': ['positive'], 'menace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neuter': ['anger', 'fear', 'sadness', 'negative'], 'mimic': ['positive', 'negative', 'surprise'], 'hushed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cps': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'original': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'presentment': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'running_noose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upkeep': ['trust', 'negative'], 'fairness': ['positive', 'trust', 'negative', 'disgust'], 'reasoning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pornographic': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'attention_deficit_disorder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piddling': ['negative'], 'dressing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'splashing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tatter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puzzled': ['negative'], 'discrepant': ['anger', 'sadness', 'negative', 'disgust'], 'puzzler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'candid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpreting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rebuild': ['positive', 'anticip'], 'condition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accompanying': ['anticip'], 'marvellous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ingratitude': ['anger', 'negative', 'disgust'], 'dinosaur': ['fear'], 'dusky': ['sadness', 'negative', 'disgust'], 'embayment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'apologue': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'hieratic': ['positive'], 'humongous': ['fear'], 'antibiotic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-abasement': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'lecturing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denouncement': ['anger', 'fear', 'negative', 'disgust'], 'sightlessness': ['sadness', 'negative'], 'rebelliousness': ['anger', 'fear', 'negative', 'disgust'], 'canvass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poliomyelitis': ['fear', 'sadness', 'negative'], 'situated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scupper': ['negative', 'anticip'], 'section': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'street_girl': ['negative'], 'nurse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'higher_status': ['positive', 'trust'], 'contrast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'mollycoddler': ['sadness', 'negative'], 'houri': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'indecision': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'vomiting': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'yellowed': ['fear', 'negative'], 'backlash': ['trust', 'anticip'], 'squashy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'razz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horror-stricken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'childbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skyrocket': ['anger'], 'compliancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'action': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cognisance': ['positive'], 'raze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'smuggle': ['anger', 'fear', 'negative', 'disgust'], 'verbose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Aug': ['anticip', 'positive', 'trust', 'joy'], 'excellently': ['positive'], 'cool_off': ['positive'], 'coercion': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'unostentatious': ['positive'], 'self-love': ['negative'], 'praiseworthily': ['positive', 'trust', 'joy'], 'petroleum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armed_combat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'implore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnification': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pitching': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'no-good': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impossibleness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'toothed_wheel': ['anticip'], 'magnetic_pole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spoilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cognate_word': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coyote': ['fear'], 'kibosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cunning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keeping': ['positive', 'trust'], 'disquietude': ['sadness', 'negative', 'anticip'], 'apportion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'science': ['positive', 'trust'], 'chisel': ['anger', 'positive', 'negative', 'disgust'], 'Romanticism': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'channelise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beautiful': ['positive', 'joy'], 'gallop': ['positive', 'anticip'], 'neglected': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'accept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'autumn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disliked': ['anger', 'sadness', 'negative', 'disgust'], 'vote_out': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'dazzle': ['surprise', 'fear', 'negative'], 'grind_away': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'salvia': ['positive', 'trust', 'joy'], 'earnings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'treacherously': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'unattended': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'creature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tetchy': ['anger', 'negative'], 'refutable': ['positive', 'trust', 'negative', 'disgust'], 'misapprehend': ['anger', 'sadness', 'negative'], 'debility': ['sadness', 'negative'], 'imagery': ['positive', 'anticip', 'joy'], 'biliousness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'wrench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fender': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'veridical': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'pant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immunisation': ['trust'], 'sinning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'labor_union': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'pulverulence': ['negative', 'anticip'], 'police_captain': ['positive'], 'furbish_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solid_food': ['positive', 'trust', 'joy'], 'travelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conceitedness': ['negative'], 'propose': ['anger', 'positive', 'fear', 'trust', 'negative'], 'respire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skipper': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'iridescent': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'misuse': ['negative'], 'likeness': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'always': ['positive'], 'qui_vive': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'downslope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Shangri-la': ['anticip', 'positive', 'trust', 'joy'], 'Polo': ['positive', 'sadness', 'trust'], 'disorganized': ['negative'], 'accelerator': ['anger', 'negative'], 'eyelash': ['anger', 'surprise', 'fear', 'negative'], 'throwin': ['positive', 'trust'], 'in_short': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'exorbitant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'terminal_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legerity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Admiralty_mile': ['surprise', 'trust', 'positive', 'joy'], 'vilification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'silky': ['positive'], 'missed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wakefulness': ['positive', 'fear', 'trust', 'surprise', 'anticip'], 'ministerial': ['positive'], 'expiation': ['positive', 'negative'], 'darling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hard-pressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entrance_fee': ['positive', 'trust', 'negative'], 'drifting': ['fear', 'sadness', 'negative', 'anticip'], 'paucity': ['anger', 'sadness', 'negative', 'disgust'], 'loafer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'proxy': ['trust'], 'well-nigh': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'impulsion': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'wave-particle_duality': ['positive'], 'moving_company': ['positive'], 'positioning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'insolence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instigation': ['negative'], 'grace_of_God': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'expedient': ['positive', 'trust', 'joy'], 'constringe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feature_film': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'number': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ethereal': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Henry_Ford_II': ['positive'], 'pledge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unexplained': ['surprise', 'sadness', 'negative', 'anticip'], 'threatening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heady': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'philanthropy': ['positive'], 'slay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hose_down': ['positive'], 'tangency': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'immediate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appreciation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forthrightness': ['positive', 'trust', 'negative', 'disgust'], 'consult': ['trust'], 'focusing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diffusion': ['negative'], 'rising_prices': ['fear', 'negative'], 'determined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'marriage': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'try_out': ['surprise', 'anticip'], 'insaneness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contour_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'third_power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'livery': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'traffic_circle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mawkish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silvery': ['surprise', 'negative', 'positive'], 'silvern': ['surprise', 'negative', 'positive'], 'numbers_racket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'play': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plat': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'yawn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'yawl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unequal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_a_chance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'covet': ['negative'], 'cover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinner': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'in_earnest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crispiness': ['sadness', 'negative'], 'sluggishness': ['sadness', 'negative'], 'cut-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fulgid': ['positive', 'anticip', 'surprise', 'disgust', 'joy'], 'aghast': ['surprise', 'fear', 'negative', 'disgust'], 'session': ['anger', 'fear', 'negative', 'disgust'], 'financial_support': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'well-endowed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ZIP_code': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'impact': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'indicator': ['trust'], 'undying': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'beat_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bastion': ['anger', 'positive'], 'condom': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gratis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impregnable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synchronization': ['anticip'], 'granulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleeve': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'instruction_manual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delegacy': ['positive', 'trust', 'anticip'], 'harassing': ['anger'], 'inbuilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harebrained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obscure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sew': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'set': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stick_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overwhelm': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'sex': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'see': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'push_aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sea': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outward': ['positive'], 'muted': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Eunectes_murinus': ['fear', 'negative', 'disgust'], 'disjoined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'investment_banker': ['fear', 'trust', 'negative'], 'crosswalk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avoidance': ['fear', 'negative'], 'jerry-built': ['anger', 'negative', 'disgust'], 'hooter': ['surprise', 'fear', 'negative'], 'espouse': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postponement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pagan': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'disproof': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Chancellor_of_the_Exchequer': ['positive', 'trust'], 'recherche': ['positive', 'joy'], 'scamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensitiveness': ['positive'], 'drunk': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'smashing': ['negative'], 'community': ['positive'], 'hollow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'holloa': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'connexion': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'simpleness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worthless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filth': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'acceptance': ['positive', 'trust'], 'hitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mace': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'fogginess': ['positive', 'negative'], 'firm': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sobriety': ['positive', 'trust', 'negative', 'disgust'], 'high-pitched': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'fire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fund': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_time': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'funk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'W._C._Handy': ['positive'], 'judicial': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'stamping_ground': ['fear', 'sadness', 'negative'], 'venous_blood_vessel': ['positive', 'trust'], 'secluded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mote': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'moth': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'swage': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'vanish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skeletal_system': ['sadness', 'negative', 'disgust'], 'funny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'churn': ['negative', 'disgust'], 'jumpat': ['anticip', 'positive', 'fear', 'trust', 'joy'], 'decoy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blowout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elevated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_laid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mavin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lithesome': ['positive'], 'recent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cognoscente': ['positive', 'trust', 'joy'], 'meddlesome': ['negative'], 'regretting': ['sadness', 'negative'], 'make_up': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'clearance': ['positive', 'trust', 'negative', 'anticip'], 'comprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissentient': ['anger', 'fear', 'negative'], 'plaguey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'telegram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emblazon': ['sadness', 'negative', 'disgust'], 'unsuccessful_person': ['fear', 'sadness', 'disgust', 'negative'], 'domesticize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'rumbling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Reconstruction_Period': ['positive', 'anticip'], 'wearable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'possible_action': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meeting_place': ['positive', 'trust'], 'swinger': ['fear', 'sadness', 'disgust', 'negative'], 'chest': ['anger', 'positive', 'sadness', 'trust', 'joy'], 'snappy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'location': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'closelipped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligence_information': ['positive', 'fear', 'trust', 'joy'], 'clutches': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mischance': ['surprise', 'sadness', 'negative', 'disgust', 'fear'], 'flare-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trueness': ['positive', 'trust'], 'lunacy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pertinent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hardofhearing': ['negative'], 'bruit': ['sadness', 'negative'], 'governess': ['trust'], 'straight_person': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'constipate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coruscation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toxicant': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'indigene': ['positive'], 'Ark_of_the_Covenant': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beau_ideal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battalion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amicable': ['positive', 'joy'], 'momentary': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'world-beater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sanity': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cortege': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'twinkle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lamia': ['anger', 'fear', 'negative', 'disgust'], 'blood-red': ['positive'], 'osculate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twinkly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'inclination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'be': ['trust'], 'honcho': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agreement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nerve_tract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'by': ['sadness', 'negative'], 'discontented': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'scepter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hatchet': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'ambush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gonorrhoea': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ACE': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'writing_table': ['negative'], 'burying_ground': ['fear', 'sadness', 'negative'], 'extemporization': ['surprise'], 'tiro': ['negative'], 'minister_of_religion': ['positive', 'trust', 'negative', 'joy'], 'cut_rate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crossness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'chide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brush_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impudent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buttery': ['positive'], 'pastor': ['positive', 'trust', 'negative', 'joy'], 'archaic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'link': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'competition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwiseness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'ling': ['negative'], 'line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harangue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revitalizing': ['positive', 'joy', 'trust', 'anticip'], 'corsage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supervisor': ['positive', 'trust'], 'Department_of_Labor': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'base_of_operations': ['sadness', 'trust', 'negative'], 'formalism': ['negative'], 'concealment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phantom': ['surprise', 'fear', 'sadness', 'negative'], 'make_bold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upright_piano': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Baroness_Jackson_of_Lodsworth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gumptious': ['positive'], 'photoflood': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'Pancho_Villa': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'wrongly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dweeb': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cobblestone': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'hook_up_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bodily': ['positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'effrontery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worsened': ['sadness', 'negative', 'disgust', 'fear'], 'tailored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overtop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aberrance': ['negative', 'disgust'], 'indecorous': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'summit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disencumber': ['positive', 'anticip'], 'walker': ['negative'], 'unbelief': ['negative'], 'essay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serviceman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asp_viper': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'renown': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'menses': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'send': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outwards': ['positive'], 'sens': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dislike': ['anger', 'sadness', 'negative', 'disgust'], 'entangle': ['positive', 'trust', 'negative', 'disgust'], 'foreman': ['positive'], 'garden': ['positive', 'joy'], 'self-will': ['negative'], 'renouncement': ['fear', 'negative'], 'royal_stag': ['positive'], 'young_girl': ['positive', 'joy'], 'obesity': ['sadness', 'negative', 'disgust'], 'thespian': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'disordered': ['negative'], 'fathead': ['negative'], 'mediterranean': ['positive'], 'steam_boiler': ['negative'], 'Samson': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'incidentally': ['surprise'], 'index': ['positive', 'fear', 'negative'], 'twine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'birr': ['positive', 'trust', 'joy'], 'laxity': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'birl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proffer': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'bird': ['joy', 'negative', 'disgust', 'positive', 'anger', 'trust'], 'trial_impression': ['positive', 'trust', 'anticip'], 'lea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stereotyped': ['positive', 'trust', 'negative'], 'lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'eminently': ['positive'], 'leg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lei': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'cosset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'let': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'second-rate': ['negative'], 'aerodynamic': ['positive'], 'playact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overgenerous': ['positive'], 'sentimentality': ['positive'], 'engage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Energy': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'decriminalise': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sizeableness': ['surprise', 'trust', 'positive', 'joy'], 'sire': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'body_of_water': ['positive', 'sadness', 'negative'], 'mortify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'cable_length': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'standing': ['positive', 'negative', 'sadness', 'joy', 'anger', 'trust'], 'unblushing': ['negative', 'disgust'], 'wood_pussy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whipping': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'vocalize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Duncan_Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsecured_bond': ['anticip'], 'celestial_horizon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lodgment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confiscate': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'sharply': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'nitrile': ['fear', 'negative'], 'pilar_cyst': ['anger', 'negative', 'disgust'], 'set_free': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'hereditary_pattern': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'loathsomeness': ['negative', 'disgust'], 'drill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'home_run': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phrenetic': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'depiction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reappraisal': ['surprise', 'fear', 'negative'], 'bend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trumpet': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'negation': ['anger', 'negative'], 'green-eyed': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'animal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venous': ['anger', 'fear', 'sadness', 'negative'], 'luster': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'cristal': ['positive', 'anticip', 'joy'], 'especial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smut': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'aspiring': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'vertebral_column': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'await': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'doze': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'nance': ['fear', 'negative'], 'cyprian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roseate': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'man-eater': ['fear', 'negative', 'disgust'], 'allow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lactate': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'predacious': ['negative'], 'brumous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'short_ton': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taken_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'comma': ['positive', 'trust'], 'operative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'gradualness': ['positive'], 'Secretariat': ['positive'], 'hypothesize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'optical_aberration': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'shudder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spoiling': ['negative'], 'run_up': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'hobby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'belch': ['negative', 'disgust'], 'nada': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kiss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fellow_member': ['fear', 'sadness', 'disgust', 'negative'], 'out_front': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'annotate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'installment': ['positive', 'joy'], 'jussive_mood': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'show_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sufficiently': ['negative'], 'delightful': ['trust', 'positive', 'anticip', 'joy'], 'facing_pages': ['positive'], 'beginner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scanty': ['negative'], 'panier': ['positive'], 'frequence': ['positive'], 'frequency': ['positive'], 'thirteen': ['fear'], 'Treasury': ['trust'], 'banal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agriculture': ['positive', 'trust'], 'wander': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'populace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'microscope': ['trust'], 'cess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saccharide': ['positive'], 'reformist': ['positive'], 'incalculable': ['negative'], 'watch_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'viva_voce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mesmerized': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'apprisal': ['anticip'], 'hatchet_job': ['anger', 'fear', 'negative', 'disgust'], 'unfluctuating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remote_control': ['negative'], 'stimulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'al-Qaida': ['trust', 'negative'], 'James_Mason': ['positive'], 'ethical': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rose-cheeked': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'straining': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ponce': ['positive', 'negative', 'disgust'], 'owner': ['positive', 'trust'], 'cabbage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'gimcrackery': ['negative'], 'ostentatiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eye_blink': ['negative', 'disgust'], 'self-opinionated': ['anger', 'negative'], 'detonator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antimycotic': ['positive', 'trust'], 'iota': ['positive'], 'painful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peg_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malady': ['negative'], 'co-op': ['positive', 'trust'], 'penitential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thresh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coinage': ['anger', 'fear', 'negative', 'disgust'], 'steel': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'quietness': ['positive', 'trust', 'joy'], 'salientian': ['negative', 'disgust'], 'subroutine_library': ['positive'], 'malpractice': ['anger', 'negative'], 'steep': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'torrent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'minginess': ['positive', 'trust', 'joy'], 'bad-tempered': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'relic': ['sadness', 'negative'], 'belted_ammunition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'competency': ['positive', 'trust', 'negative'], 'heft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'soak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bacterium': ['fear', 'sadness', 'disgust', 'negative'], 'Dominicus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adjunct': ['positive', 'trust', 'joy'], 'bonanza': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'soap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mum': ['positive', 'fear', 'trust', 'negative'], 'criminal_maintenance': ['trust', 'negative'], 'oil_production': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfaithfulness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'set_phrase': ['anger', 'positive', 'trust', 'negative'], 'medal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'King_of_Swing': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'slushy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unscramble': ['positive', 'joy', 'trust', 'anticip'], 'flap_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenableness': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'signally': ['positive'], 'dissociate': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'breaker_point': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'understate': ['negative'], 'postcode': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'Lolium_temulentum': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'anticipant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'asylum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Independence': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'condemnable': ['anger', 'fear', 'negative', 'disgust'], 'hops': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Melville_Bell': ['anger', 'fear', 'negative', 'disgust'], 'ragtag_and_bobtail': ['anger', 'positive', 'fear', 'trust', 'negative'], 'zero_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flinch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daybook': ['positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humanness': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'sweetie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bank_building': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fabled': ['positive'], 'baby-sitter': ['trust'], 'dishearten': ['sadness', 'negative'], 'hemorrhoid': ['negative', 'disgust'], 'luminosity': ['positive'], 'coalescence': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'Vicar_of_Christ': ['positive', 'trust'], 'disapprobation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'streamlined': ['positive'], 'coalescency': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'rein': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'anomic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'catastrophic': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'heartburn': ['negative'], 'edition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slanted': ['sadness', 'negative', 'disgust'], 'incurable': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cense': ['anger', 'negative'], 'partisan': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'secureness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'extraneousness': ['negative'], 'injustice': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Orlando_di_Lasso': ['sadness', 'negative'], 'derogatory': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'fetich': ['negative'], 'Johnny_Reb': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'grasp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tantrum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drum': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unflinching': ['positive', 'trust', 'joy'], 'drub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drug': ['sadness', 'negative'], 'sugared': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'figurer': ['positive', 'trust'], 'suspension_system': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'volley': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crafter': ['positive'], 'wealthiness': ['positive', 'trust', 'joy'], 'innate_reflex': ['surprise'], 'authorised': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'Guinea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revamp': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'laity': ['positive', 'trust'], 'arugula': ['anger'], 'typify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stabile': ['positive', 'trust', 'negative'], 'head_of_hair': ['positive'], "Saint_Ulmo's_fire": ['positive', 'trust', 'joy'], 'gondola': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lambent': ['positive'], 'dazzling': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'drinkto': ['positive', 'trust', 'joy'], 'public_prosecutor': ['anger', 'fear', 'negative'], 'scrape_up': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ballast': ['positive', 'sadness'], 'adjunction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rioting': ['anger', 'surprise', 'fear', 'negative'], 'transmission_line': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'dam_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'derivative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gunpowder': ['fear'], 'relaxation_method': ['positive'], 'bolide': ['positive'], 'laser': ['positive', 'trust'], 'grinning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'expiration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maul': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'bronzed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ripe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nictitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'surprisingly': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'chapeau': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physical_contact': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'burster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flight_feather': ['anger', 'fear', 'negative'], 'waspish': ['negative'], 'concealing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'romance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infarction': ['surprise', 'fear', 'negative'], 'conversation_stopper': ['disgust'], 'balm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bale': ['fear', 'negative'], 'bald': ['sadness', 'negative'], 'hangman': ['fear', 'negative'], 'paving': ['trust'], 'line_of_reasoning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'robotic': ['surprise', 'trust'], 'dust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'concordance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deviltry': ['negative'], 'colour': ['anger', 'negative', 'disgust'], 'holy_place': ['positive', 'fear', 'sadness', 'negative'], 'command': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'President_Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'maggot': ['negative', 'disgust'], 'glut': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'glum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enmesh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chronometry': ['positive'], 'beauty_salon': ['anger'], 'glue': ['positive', 'trust', 'negative', 'anticip'], 'grade_insignia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afflicted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'generous': ['positive', 'trust', 'joy'], 'clergyman': ['positive', 'joy'], 'magnify': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'complicity': ['positive', 'negative'], 'chancellor': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'famously': ['positive'], 'cobble': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'corporate_trust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curl_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crisp': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'roughneck': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'tutorship': ['positive', 'trust'], 'stagger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reform-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'replacement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'murk': ['fear', 'negative'], 'guaranty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'habitat': ['positive'], 'thief': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Sultanate_of_Oman': ['positive', 'fear', 'negative', 'anticip'], 'battle_cry': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'deliquium': ['surprise', 'fear', 'sadness', 'negative'], 'ballot': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'rub_down': ['positive', 'joy'], 'henchman': ['trust'], 'disbelief': ['negative'], 'avoid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dago': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forgiven': ['positive'], 'leg_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretch_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Eden': ['anticip', 'positive', 'trust', 'joy'], 'germination': ['anticip'], 'stage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurance_policy': ['positive', 'trust'], 'sister': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'every_bit': ['positive'], 'ingest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idolize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'listen_in': ['negative'], 'seedy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diabolical': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'clotheshorse': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'unbent': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'commitment': ['positive', 'trust'], 'Virgo': ['positive', 'joy', 'trust', 'anticip'], 'disaffected': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'hell_on_earth': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'housing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disapproval': ['anger', 'sadness', 'negative', 'disgust'], 'nontextual_matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stamina': ['anger', 'positive', 'fear', 'trust'], 'bump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thriftiness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'surprisal': ['surprise', 'fear', 'positive', 'joy'], 'naturally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'function': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'averageness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cosmopolitan': ['positive', 'trust'], 'storehouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delivery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'construction': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'illustrative': ['positive', 'sadness', 'joy'], 'count': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'behemoth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'official': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'smooth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reinforcement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaporise': ['fear'], 'horror-struck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freewheel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthrone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'painful_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crepuscle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'soda_water': ['positive', 'sadness', 'negative', 'disgust', 'surprise'], 'recognize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'enthronement': ['positive', 'trust', 'joy'], "drag_one's_heels": ['negative'], 'dissemination': ['negative'], 'executive_director': ['trust'], 'mental_process': ['anger', 'fear', 'negative'], 'mushroom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'promulgation': ['anticip'], 'electronegative': ['anger', 'sadness', 'negative'], 'quartz': ['positive', 'negative'], 'oppression': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Alfred_Edward_Woodley_Mason': ['positive'], 'baffling': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'unswerving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arbiter': ['positive', 'trust'], 'pacify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Page': ['anger', 'fear', 'negative'], 'omnipotent': ['positive'], 'squinch': ['fear', 'negative'], 'frightfully': ['sadness'], 'coquette': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'depravation': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'pension': ['fear', 'negative'], 'tryout': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'buoy': ['positive'], 'Lodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cablegram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agnize': ['positive'], 'hasheesh': ['negative'], 'soupiness': ['positive'], 'leeward': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'Ranger': ['fear', 'trust', 'negative'], 'postmortem': ['fear', 'sadness', 'disgust', 'negative'], 'get_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blistering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denudate': ['sadness', 'negative'], 'blanket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evacuation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'distort': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'manic': ['anger', 'fear', 'negative'], 'eye_mask': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disobedient': ['anger', 'fear', 'negative', 'disgust'], 'hocus-pocus': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'latent_hostility': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bewildered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'racing_shell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutout': ['positive', 'anticip'], 'mental_retardation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'diverting': ['positive', 'joy'], 'saving_grace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'first_appearance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'established': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reconstruction': ['positive', 'anticip'], 'trade_wind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aeroplane': ['positive', 'trust'], 'pursuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moroseness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noncompliant': ['anger', 'negative'], 'celebration': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'study': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mannerism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bunker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motorbus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pound_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'uncivil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'conjunction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cogency': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'experimentation': ['surprise', 'anticip'], 'backrest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cannonball_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'give_chase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_discharge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'adjacency': ['anticip'], 'reign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'escapist': ['anticip', 'positive', 'trust', 'joy'], 'emeritus': ['positive'], 'tariff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battleful': ['anger', 'fear', 'negative'], 'grovel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'face_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'latent_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ascetic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Henry_Ford': ['positive'], 'Marxist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quiver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serpent': ['fear', 'negative', 'disgust'], 'euthanasia': ['fear', 'sadness', 'negative'], 'indifferent': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'rareness': ['surprise'], 'cope_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'branch_out': ['positive'], 'debauchery': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'ratification': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'morbid': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'eyeball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordinary': ['positive'], 'fudge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hole_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'atmospheric_pressure': ['anger', 'positive', 'fear', 'trust', 'negative'], 'physical_object': ['anger', 'positive', 'trust', 'negative', 'anticip'], 'underprice': ['anger', 'sadness', 'negative', 'fear'], 'passado': ['surprise', 'fear', 'negative'], 'greet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nascent': ['anticip'], 'green': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atrocity': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'greed': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'hardhearted': ['sadness', 'negative'], 'hem_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'devote': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consent': ['positive', 'trust'], 'cook_up': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'Dwight_Lyman_Moody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zep': ['anger', 'negative'], 'mayor': ['positive'], 'somnolence': ['negative'], 'supplicant': ['negative'], 'Kathryn_Elizabeth_Smith': ['trust'], 'precipitate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'clock_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'affected': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'female_horse': ['fear', 'negative'], 'Eugene_Sue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fragment': ['positive', 'negative', 'disgust'], 'amenable': ['positive'], 'clogging': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'riding_habit': ['positive', 'negative', 'anticip'], 'moneyed': ['positive'], 'gallows': ['anger', 'fear', 'sadness', 'negative'], 'nonessential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jocund': ['positive', 'joy'], 'ledger_entry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'choice_of_words': ['positive', 'trust', 'negative', 'anticip'], 'taking_hold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bank_bill': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hostel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Chemical_Mace': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'wide-open': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'predetermination': ['fear', 'negative'], 'forte': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forth': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'facial_expression': ['anger'], 'plication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lawless': ['anger', 'surprise', 'sadness', 'negative', 'anticip'], 'Edsel_Bryant_Ford': ['positive'], 'hoodooism': ['negative'], 'mutilate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfulfilled': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'get_rid_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effulgence': ['positive', 'joy'], 'ordering': ['anticip', 'positive', 'trust', 'joy'], 'declarative': ['positive'], 'self-conceited': ['fear', 'negative', 'disgust'], 'quirkiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise'], 'get_behind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misconstrue': ['anger', 'sadness', 'negative'], 'truthfulness': ['positive', 'trust'], 'organize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], "pitcher's_mound": ['positive', 'fear', 'negative', 'anticip'], 'voter_turnout': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'chopper': ['fear', 'negative', 'disgust'], 'equipoise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hearse': ['fear', 'sadness', 'negative'], 'protracted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'discoloration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plentiful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'palpitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airy': ['anticip', 'positive', 'trust', 'joy'], 'inflate': ['negative'], 'damaging': ['anger', 'negative'], 'totter': ['positive', 'anticip'], 'forbiddance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beam_of_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "baby's_room": ['positive', 'trust', 'joy'], 'tithe': ['anger', 'negative'], 'castrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pine_tree': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger'], 'untimeliness': ['surprise'], 'splendidly': ['positive'], 'devious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Edward_Everett_Hale': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mitigatory': ['positive'], 'religious_residence': ['negative'], 'manner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stomach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glide_slope': ['anticip'], 'pantryman': ['positive', 'trust'], 'strength': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conducive': ['positive', 'anticip'], 'physicalsensibility': ['positive', 'joy'], 'Mead': ['positive'], 'nutritive': ['positive', 'sadness'], 'manifested': ['positive'], 'deacon': ['trust'], 'calmness': ['positive'], 'unsophisticated': ['negative'], 'notion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fussy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'fungicidal': ['positive', 'trust'], 'eminent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'subtle': ['anger', 'fear', 'negative', 'disgust'], 'perpetration': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'latent': ['anger', 'surprise', 'negative', 'disgust', 'anticip'], 'guidance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sentence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'basketball_hoop': ['positive', 'anticip', 'joy'], 'Church_Father': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unctuousness': ['disgust'], 'predecessor': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'do': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Charles_Lamb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frowning': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'infrequent': ['surprise', 'negative'], 'cyder': ['positive'], 'misdirect': ['anger', 'negative', 'disgust'], 'unmake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'automatic_pistol': ['surprise', 'trust'], 'sliminess': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ruffle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-mortification': ['fear', 'sadness'], 'graphic_designer': ['positive'], 'jocose': ['positive'], 'gentleman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symmetric': ['positive'], 'tainted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'curve_ball': ['negative'], 'infidel': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'orange_tree': ['positive'], 'research_laboratory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bespoken': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'hoo-ha': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unman': ['fear', 'sadness', 'disgust', 'negative'], 'anele': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'penurious': ['negative'], 'cot': ['positive', 'negative', 'disgust', 'anticip'], 'cow': ['fear', 'sadness', 'disgust', 'negative'], 'coy': ['surprise', 'fear'], 'cod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cog': ['positive', 'trust', 'anticip'], 'deal_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Navy': ['trust'], 'col': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coo': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'con': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negotiation': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'abbreviate': ['negative'], 'accusing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'stillborn': ['sadness', 'negative'], 'push_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'length_of_service': ['positive'], 'petty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flexible': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'coax_cable': ['trust'], 'concert_dance': ['positive'], 'proclivity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beastly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'coherent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surreptitious': ['anticip', 'negative', 'anger', 'surprise', 'fear', 'trust'], "rock'n'roll": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordnance': ['anger', 'fear', 'negative', 'anticip'], 'physician': ['positive', 'trust'], 'trigger-happy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'look_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cheat_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'abrupt': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undischarged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vernal': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revolve_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smorgasbord': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'world-wide': ['positive', 'trust'], 'comparative': ['trust'], 'substantialness': ['positive'], 'infringe': ['fear', 'negative'], 'confirmed': ['positive', 'trust'], 'patent': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'bedchamber': ['positive', 'trust', 'anticip'], 'plated': ['negative'], 'double_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convalescent': ['positive'], 'monarch': ['positive', 'trust'], 'indictment': ['fear', 'negative'], 'unharmed': ['positive', 'trust'], 'Day_of_Judgment': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'raid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'rail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rain': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'flatulence': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'abettal': ['negative'], 'depict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moon-curser': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'sentry_go': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'campy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ofttimes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'objective_lens': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snigger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hark_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'culpableness': ['negative'], 'hallow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'stack_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flooring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hilly': ['negative'], 'passive': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'Maffia': ['fear', 'negative'], 'spread': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'coarseness': ['anger', 'sadness', 'negative', 'disgust'], 'spur_track': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough-and-tumble': ['anger', 'negative'], 'disadvantage': ['negative'], 'skanky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurgent': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cozen': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grizzly': ['sadness', 'negative', 'disgust', 'fear'], 'grizzle': ['anger', 'positive', 'fear', 'trust', 'negative'], 'relation_back': ['positive', 'trust', 'disgust'], 'reassign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'security': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'starvation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antique': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'tatterdemalion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'critique': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'archetype': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'purple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Leo': ['anger', 'positive', 'fear', 'disgust'], 'corking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'action_mechanism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wide_of_the_mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confluent': ['positive'], 'burial_site': ['fear', 'sadness', 'negative'], 'cardiomyopathy': ['fear', 'sadness', 'negative'], 'impenetrable': ['trust', 'negative'], 'trip_the_light_fantastic_toe': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'dotty': ['anger', 'fear', 'sadness', 'negative'], 'cherish': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'go_with': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'dilemma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tetanus': ['negative', 'disgust'], 'complexness': ['negative'], 'mantle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delighted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balancer': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'clomp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formidable': ['fear'], 'balanced': ['positive'], 'lewd': ['positive', 'negative', 'disgust'], 'undiscovered': ['surprise', 'sadness', 'negative', 'anticip'], 'unchanging': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'fight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commanding_officer': ['positive', 'trust'], 'mix_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fizz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sagging': ['negative'], 'vitality': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'awless': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'immune_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affluence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'let_down': ['anger', 'sadness', 'negative', 'disgust'], 'generosity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veterinarian': ['anger', 'positive', 'trust', 'negative'], 'inclusive': ['positive'], 'molt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evidence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manure': ['negative', 'disgust'], 'subsist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disputable': ['positive', 'trust', 'negative'], 'weakened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interested': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carpeting': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'unwilling': ['negative'], 'go_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_brief': ['anticip'], 'guiltless': ['positive', 'trust'], 'oiliness': ['disgust'], 'polite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligence_agency': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'mightily': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Word_of_God': ['trust'], 'disaffirmation': ['negative'], 'castaway': ['fear', 'sadness', 'disgust', 'negative'], 'flag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheater': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reception': ['positive'], "child's_play": ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'crystallise': ['surprise', 'anticip', 'positive', 'joy'], 'President_Carter': ['trust'], 'bolus': ['positive'], 'global': ['anticip', 'positive', 'trust', 'joy'], 'datum': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'wakeful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drop-off': ['fear'], 'Polymonium_caeruleum_van-bruntiae': ['positive', 'joy'], 'honoring': ['positive', 'joy', 'surprise'], 'graph': ['trust'], 'hump': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'flash': ['negative'], 'at_long_last': ['positive', 'anticip'], 'root_cellar': ['negative'], 'protective': ['positive'], 'orthogonal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'stinting': ['positive'], 'woolly': ['negative'], 'blase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liability': ['positive', 'trust'], 'anonymous': ['negative'], 'forgiving': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'blast': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'feeble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fragile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pauperise': ['sadness', 'negative'], 'greenhouse': ['positive', 'trust', 'joy'], 'distasteful': ['anger', 'trust', 'negative', 'disgust', 'anticip'], 'revolution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thinker': ['positive', 'fear', 'negative', 'anticip'], 'pratfall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutting_edge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free-for-all': ['anger', 'fear', 'negative', 'disgust'], 'acrimonious': ['negative'], 'continence': ['surprise'], 'scaffold': ['fear', 'negative'], 'chuff': ['anger', 'negative', 'disgust'], 'Cole_Albert_Porter': ['positive', 'trust', 'joy'], 'continency': ['surprise'], 'satisfy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collateral': ['trust'], 'tumultuousness': ['negative'], 'chicane': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Sauk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoops': ['positive', 'anticip', 'joy'], 'change': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill_will': ['anger', 'negative', 'disgust'], 'Roman_mile': ['surprise', 'trust', 'positive', 'joy'], 'detonate': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'trial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'triad': ['positive', 'trust', 'negative', 'disgust'], 'real_property': ['positive', 'trust', 'negative'], 'retired': ['anticip'], 'run_a_risk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hiking': ['fear', 'sadness', 'disgust', 'negative'], 'lending': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'committal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'seashore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illumination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remaking': ['positive'], 'subvert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'live': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'true_up': ['positive', 'fear', 'trust', 'negative', 'joy'], 'ontheball': ['positive'], 'gladfulness': ['positive', 'joy'], 'entrance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'credulity': ['sadness', 'trust', 'negative'], 'puking': ['disgust'], 'judder': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'misconception': ['anger', 'fear', 'negative', 'disgust'], 'whisk_off': ['negative'], 'logarithm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'anneal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'douche': ['negative'], 'innuendo': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'sex_activity': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scratch_awl': ['positive', 'anticip'], 'spy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'head_for_the_hills': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'full_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'supremacy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheepcote': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serum': ['positive'], 'productive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'carrefour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bankrupt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malevolence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toughie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antagonism': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'nihilism': ['negative'], 'farm_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malevolency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nihilist': ['anger', 'fear', 'negative'], 'relative_frequency': ['positive'], 'allowable': ['positive'], 'entrench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backsliding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'field_day': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'penetrative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brazen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wistful': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'Cavalier': ['anger', 'fear'], 'banding': ['negative'], 'nomination': ['positive'], 'compatibility': ['positive'], 'remember': ['positive', 'trust', 'joy'], 'explicit': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pull_down': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'offend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fireball': ['positive'], 'punting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'gestate': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'forfeit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poor_boy': ['anger', 'negative'], 'comfortableness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cold': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'foreordination': ['fear', 'negative'], 'ethic': ['positive'], 'wiseness': ['anticip', 'positive', 'trust', 'joy'], 'acknowledge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'immortality': ['anticip'], 'suffocate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'topsy-turvyness': ['anger', 'fear', 'sadness', 'negative'], 'waggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Grace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'practice_session': ['positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'halt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sweetened': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'hale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'half': ['negative'], 'backtalk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miracle': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'halo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barrow': ['disgust'], 'wont': ['positive', 'anticip'], 'servant': ['positive', 'trust', 'negative'], 'streaky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phonic': ['positive'], 'Riley_B_King': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'headstrong': ['anger', 'sadness', 'negative'], 'entirely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolving_power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'el': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'en': ['positive'], 'goosy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'convalescence': ['positive'], 'avidity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ex': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'okay': ['anger', 'positive', 'trust', 'anticip', 'joy'], 'eq': ['positive', 'negative'], 'space': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'swing_over': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nonrational': ['positive', 'anticip'], 'showy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'receiving': ['positive', 'anticip', 'surprise', 'joy'], 'viable': ['negative'], 'hand_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tie_up': ['positive'], 'rebel': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'look_out_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waxy': ['trust'], 'squeeze_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slip_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mow_down': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'saintlike': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'promotion': ['positive'], 'sprawling': ['negative'], 'striking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'omitted': ['sadness', 'negative'], 'fall_behind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serve_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impossible': ['surprise', 'sadness', 'negative', 'positive'], 'forwarding': ['positive'], 'size': ['trust', 'negative'], 'duskiness': ['anger', 'fear', 'sadness', 'negative'], 'frogman': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'sheer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'categorical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'callous': ['anger', 'negative', 'disgust'], 'incorporeality': ['fear', 'sadness', 'negative'], 'carousel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'friend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'larder': ['positive'], 'courier': ['trust'], 'moderationist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pelting': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'James_Earl_Carter_Jr.': ['trust'], 'glimmer': ['surprise', 'anticip', 'positive', 'joy'], 'crime_syndicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'progressive_tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rugged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rationalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'optimism': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'optimist': ['positive', 'trust'], 'yesteryear': ['positive', 'trust', 'joy'], 'sublime': ['positive', 'joy'], 'pull_strings': ['anger', 'surprise', 'negative', 'anticip'], 'correction': ['fear', 'negative'], '13th': ['fear'], 'Call': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breakfast': ['positive'], 'veteran': ['anger', 'positive', 'trust', 'negative'], 'objective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impairment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squash_racket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'shed_blood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foothold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'young_person': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'greyish': ['sadness', 'disgust'], 'poster_paint': ['positive', 'trust'], 'cable_tramway': ['fear', 'sadness', 'disgust', 'negative'], 'flawlessly': ['positive'], 'lightsomeness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunset': ['positive', 'anticip'], 'safety_blitz': ['surprise'], 'conservatively': ['positive', 'fear'], 'brainchild': ['positive', 'anticip', 'joy'], 'foaming': ['anger', 'negative'], 'arbour': ['trust'], 'overburden': ['sadness', 'negative'], 'hunting_lodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'androgyne': ['surprise', 'negative'], 'ratio': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curtain_raising': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proportion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'texture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roiled': ['fear', 'negative'], 'transude': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'froward': ['anger', 'sadness', 'negative'], 'revulsion': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cash_in_hand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humourist': ['positive'], 'verbosity': ['negative'], 'water_supply': ['positive', 'sadness', 'negative'], 'breeches': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'raunchy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sonar': ['positive', 'anticip'], 'husband': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'irradiation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'concert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'communications_protocol': ['trust', 'negative', 'disgust'], 'famine': ['sadness', 'negative'], 'stay_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prick_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotatory': ['anger', 'positive', 'negative', 'surprise'], 'corroboration': ['trust'], 'free-base': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ambo': ['positive'], 'herbal': ['positive'], 'weather_eye': ['positive', 'trust', 'anticip'], 'lineament': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'period_of_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'article': ['trust'], 'talented': ['positive'], 'ballpark': ['surprise', 'anticip', 'positive', 'joy'], 'self-interest': ['anticip', 'positive', 'trust', 'joy'], 'comer': ['anticip'], 'chuck_up_the_sponge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'characterization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unaffectionate': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'sweet_pepper_plant': ['positive'], 'COD': ['anger', 'fear', 'trust', 'negative'], 'Pres_Young': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'sess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common_soldier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'punished': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'toss': ['positive', 'trust', 'anticip'], 'blaze_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'press_clipping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chance_event': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhaustion': ['sadness', 'negative', 'anticip'], 'so_far': ['negative'], 'stalking-horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sedition': ['anger', 'sadness', 'negative'], 'pram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atmospheric_condition': ['positive'], 'actualise': ['trust'], 'landslide': ['fear', 'sadness', 'negative'], 'baccalaureate': ['positive'], 'soil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memorialise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bias': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embrace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bestial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dressing_table': ['negative'], 'indebtedness': ['positive', 'trust'], 'media': ['positive', 'trust', 'negative', 'surprise', 'anticip'], 'epoch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moth-eaten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pedantic': ['positive', 'trust'], 'finish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ice_rink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fruit': ['positive', 'sadness', 'negative'], 'tradition': ['positive'], 'theater': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'traps': ['negative'], 'prevenient': ['anticip'], 'wedge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duple': ['positive', 'anticip'], 'tot_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'continuanceinaction': ['anticip'], 'James_Henry_Leigh_Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'civilized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Stephen_Samuel_Wise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slugger': ['anger', 'fear', 'sadness', 'negative'], 'touch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revaluation': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'tirade': ['anger', 'negative', 'disgust', 'anticip'], 'break_of_the_day': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'daydreaming': ['positive', 'trust', 'joy'], 'outlander': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sunshade': ['negative'], 'gloating': ['positive', 'joy'], 'mournful': ['anger', 'sadness', 'negative', 'fear'], 'momentum': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'lade': ['negative'], 'ream': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'hover': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'frown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'market_keeper': ['trust'], 'quickness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'sissified': ['negative'], 'detract': ['anger', 'negative'], 'execution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lady': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'hovel': ['positive', 'fear', 'sadness'], 'rear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbowed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'harmonical': ['positive'], 'social_organisation': ['positive', 'trust'], 'suppuration': ['negative', 'disgust'], 'abjection': ['negative'], 'brainish': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'earreach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'servile': ['sadness', 'negative', 'disgust', 'fear'], 'changeling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astronomer': ['positive', 'anticip'], 'duration': ['negative', 'anticip'], 'perverse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'slaughtering': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'putter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conservative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'deficit': ['negative'], 'smell_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recorder': ['positive'], 'felt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dejection': ['sadness', 'negative', 'disgust'], 'body-build': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tuition': ['positive', 'trust'], 'sedimentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncivilized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'well-situated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hectic': ['negative'], 'desiccated': ['sadness', 'negative'], 'fondness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reexamine': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'placard': ['surprise'], 'hiatus': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chop': ['fear', 'negative', 'disgust'], 'test_copy': ['positive', 'trust', 'anticip'], 'fell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'isinglass': ['joy', 'negative', 'sadness', 'positive', 'anger', 'surprise'], 'underway': ['positive', 'trust'], 'deranged': ['anger', 'fear', 'negative', 'disgust'], 'military_greeting': ['positive', 'joy'], 'heater': ['positive'], 'passe-partout': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'long-lived': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'renovate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bang_up': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'polyglot': ['positive', 'trust'], 'verily': ['positive', 'trust'], 'operator': ['positive', 'negative'], 'weight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'countermine': ['negative'], 'stoppage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cold-blooded': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'negatively_charged': ['anger', 'sadness', 'negative'], 'stealth': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bromide': ['trust', 'anticip'], 'instantaneity': ['surprise'], 'immaculate': ['positive', 'trust', 'joy'], 'overpaid': ['negative'], 'ordnance_store': ['fear', 'negative'], 'trying': ['sadness', 'negative'], 'irreversible': ['positive'], 'corduroy': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'hire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apology': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'red_cent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bucket': ['trust', 'anticip'], 'dabbling': ['anger', 'negative', 'disgust'], 'taleteller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'determent': ['anger', 'fear', 'negative'], 'draftsman': ['fear', 'negative'], 'atavism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'popularize': ['positive'], 'expect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_pure': ['positive', 'trust', 'joy'], 'subdue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'describe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mover': ['positive'], 'gain_vigor': ['positive'], 'airscrew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'inflated': ['negative'], 'completeness': ['positive', 'negative'], 'credibility': ['positive', 'trust'], 'marvellously': ['positive', 'joy'], 'storage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ghent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relegating': ['negative'], 'blurt_out': ['sadness', 'negative', 'disgust'], 'gaining': ['positive'], 'polar': ['surprise', 'trust', 'negative'], 'desolation': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'take_apart': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'overreach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whimsicality': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'telltale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doubter': ['negative'], 'second-stringer': ['positive', 'negative'], 'Gypsy': ['negative'], 'blow_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forswear': ['anger', 'negative'], 'patchwork': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'splitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tweedle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bequeath': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gaucherie': ['surprise', 'negative'], 'self-renunciation': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'Brown': ['disgust'], 'alleviant': ['positive'], 'juicy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lucifer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solicit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trematode': ['surprise'], 'vert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'confidential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'very': ['positive', 'fear', 'trust', 'negative', 'joy'], 'artistic_creation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bombed': ['negative', 'disgust'], 'minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crowd_together': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'risk_taker': ['surprise', 'negative', 'anticip'], 'austerity': ['sadness', 'trust', 'negative'], 'oleaginousness': ['disgust'], 'randomness': ['negative'], 'pillbox': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'hard_put': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'propinquity': ['anticip'], 'abstract_entity': ['negative'], 'blackout': ['negative'], 'purpleness': ['anger', 'negative', 'disgust'], 'out_or_keeping': ['anger', 'sadness', 'negative', 'disgust'], 'canonical': ['trust'], 'conscience': ['positive', 'trust'], 'Latin': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'HUA': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spry': ['positive', 'sadness', 'negative', 'fear'], 'HUM': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blunderer': ['negative'], 'witnesser': ['trust'], 'monotone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repugnant': ['anger', 'fear', 'negative', 'disgust'], 'recruits': ['trust'], 'gustatory_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'scoria': ['negative'], 'rudimentary': ['positive', 'trust'], 'disorganize': ['negative'], 'strong': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'course_credit': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incalescence': ['negative'], 'divisor': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'ahead': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'soldier': ['anger', 'positive', 'sadness'], 'thaumaturgist': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'permutation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'larrup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nimiety': ['negative'], 'dianoetic': ['positive'], 'ski_binding': ['positive', 'trust'], 'hogg': ['negative', 'disgust'], 'impiety': ['anger', 'negative'], 'chunky': ['negative'], 'dogshit': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'add-on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concerted': ['positive', 'trust'], 'drippy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Labor_Department': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'cleanness': ['positive'], 'injure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appendicitis': ['fear', 'sadness', 'negative'], 'finish_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doubtlessly': ['positive', 'trust'], 'overmodest': ['surprise', 'fear'], 'injury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musical_instrument': ['positive', 'trust', 'negative'], 'Great_Depression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broke': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'mouth-watering': ['positive', 'negative'], 'browned': ['disgust'], 'hurry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dousing': ['anger', 'positive', 'fear', 'trust', 'negative'], 'burned-over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Thelonious_Sphere_Monk': ['positive', 'trust'], 'pusher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radiotherapy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'lawcourt': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'revelry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-regard': ['positive', 'trust'], 'exclude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chops': ['fear', 'negative', 'disgust'], 'thieve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lyre': ['positive', 'joy'], 'foreseen': ['surprise', 'positive', 'anticip'], 'emollient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accusative_case': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unearthly': ['surprise', 'fear', 'negative', 'disgust'], 'gash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'ft': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'prognostic': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rain_down': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'drop_the_ball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idiocy': ['anger', 'sadness', 'negative', 'disgust'], 'maffia': ['fear', 'negative'], 'uncomfortableness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physical_exertion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gasp': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'inconceivable': ['surprise', 'sadness', 'negative', 'positive'], 'morphine': ['sadness', 'negative'], 'documentation': ['trust'], 'nonindulgent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'renewing': ['positive', 'joy', 'trust', 'anticip'], 'genuflect': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clabber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stuffiness': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sappy': ['trust'], 'fair-mindedness': ['positive', 'trust', 'negative', 'disgust'], 'aliveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'feed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'torturous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'staunch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fool_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fruitful': ['positive'], 'animise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anathematise': ['anger', 'fear', 'sadness', 'negative'], 'botcher': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Moody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gipsy': ['negative'], 'Hero_of_Alexandria': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buffoon': ['surprise', 'anticip', 'positive', 'joy'], 'food': ['positive', 'trust', 'joy'], 'awarding': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_executioner': ['anger', 'fear', 'sadness', 'negative'], 'foot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'desperately': ['anger'], 'fully': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'dangerous_undertaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leatherneck': ['trust'], 'take_into_account': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trailer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airiness': ['positive'], 'pamper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dichotomy': ['positive'], 'thirteenth': ['fear'], 'wacky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bickering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreconcilable': ['anger', 'fear', 'sadness', 'negative'], 'talisman': ['positive'], 'semiliquidity': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'vertigo': ['fear', 'negative'], 'presumptuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'procurable': ['positive', 'joy'], 'dunk': ['fear', 'negative'], 'pun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'asp': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bass': ['positive', 'trust'], 'dirt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pud': ['positive'], 'swob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dung': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'pub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heroin': ['positive', 'trust', 'negative'], 'pursual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pup': ['positive', 'trust', 'anticip'], 'bask': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stellate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pus': ['fear', 'negative', 'disgust'], 'gentlewoman': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'unvoluntary': ['negative'], 'angularity': ['trust'], 'caption': ['positive'], 'uprooter': ['anger', 'fear', 'negative'], 'parazoan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Agha': ['positive', 'fear', 'trust', 'negative'], 'probability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Apostle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unfeigned': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'lucullan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'old-hat': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'fall_away': ['surprise', 'negative'], 'villa': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'dependent_upon': ['anticip'], 'athletic_field': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operose': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'obedience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bell_shape': ['anger', 'fear', 'negative', 'disgust'], 'obtainable': ['positive', 'joy'], 'eddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bailiwick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grimy': ['negative', 'disgust'], 'flattery': ['positive', 'joy'], 'philippic': ['anger', 'negative', 'disgust', 'anticip'], 'kindly': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'impersonal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'John_Barleycorn': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grogginess': ['anger', 'surprise', 'fear', 'negative'], 'premeditate': ['fear', 'negative'], 'uncanny': ['surprise', 'fear', 'negative', 'disgust'], 'snitcher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'kindle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inexperienced_person': ['positive', 'trust'], 'will_power': ['anger', 'fear', 'negative', 'disgust'], 'Father': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_fortune': ['surprise', 'joy', 'trust', 'negative', 'positive'], 'juice': ['negative'], 'substantial': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'sensual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outbound': ['positive'], 'electric_shock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flaming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auctioneer': ['anticip'], 'labour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'call_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'honeycomb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'labor_movement': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'decriminalize': ['anger', 'positive', 'fear', 'trust', 'joy'], 'take_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quote': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gregarious': ['positive'], 'bounteousness': ['anticip', 'positive', 'trust', 'joy'], 'prolongation': ['negative', 'anticip'], 'power_train': ['positive'], 'summit_meeting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fainthearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'skein': ['positive'], 'blend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'Book_of_Genesis': ['anticip', 'positive', 'trust', 'joy'], 'acerbic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boozy': ['negative', 'disgust'], 'booze': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'top-notch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheepskin': ['positive', 'trust', 'anticip'], 'sportive': ['positive', 'joy'], 'central': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pretty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'turncock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upstanding': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meanwhile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'custodian': ['positive', 'trust'], 'lepidote': ['negative'], 'famous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grain_alcohol': ['negative'], 'full-bodied': ['positive'], 'perfume': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sacrifices': ['fear', 'sadness', 'negative', 'disgust'], 'ecrevisse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vestibule': ['anger', 'fear', 'negative'], 'cramp': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pencil_lead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpublished': ['sadness', 'negative', 'anticip'], 'crackle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smarten_up': ['positive'], 'horrid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wot': ['positive', 'trust'], 'wow': ['anger', 'surprise', 'fear', 'negative'], 'dramatics': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'Park': ['surprise', 'anticip', 'positive', 'joy'], 'wop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gritstone': ['positive', 'trust'], 'woo': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'woe': ['sadness', 'negative', 'disgust', 'fear'], 'cuff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'philander': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'theme_song': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sectionalization': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'stallion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'service_program': ['positive', 'negative'], 'readying': ['positive', 'joy', 'trust', 'anticip'], 'adorer': ['anticip', 'positive', 'trust', 'joy'], 'grief-stricken': ['sadness', 'negative'], 'Fish': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'plosion': ['surprise', 'fear', 'negative'], 'suspire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_toilet': ['positive'], 'buzz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stymy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hart': ['positive', 'trust'], 'amass': ['positive', 'trust'], 'whoremaster': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'liken': ['sadness', 'negative'], 'epicene': ['negative'], 'scurfy': ['negative'], 'unthaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visible_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'railroad_car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncalled-for': ['disgust'], 'unaided': ['fear', 'sadness', 'negative'], 'indian_lodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maintenance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoodoo': ['negative'], 'wet': ['disgust'], 'grille': ['positive'], 'John_the_Divine': ['negative', 'disgust'], 'nutcase': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'utmost': ['positive'], 'conspirator': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'governor': ['trust'], 'musical_composition': ['disgust'], 'fire-raising': ['anger', 'fear', 'negative'], 'loony_toons': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straggling': ['fear', 'negative'], 'overlooked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idol_worship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoot_the_breeze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clerical': ['positive', 'trust'], 'belong': ['surprise', 'fear', 'sadness', 'negative'], 'octad': ['anticip', 'positive', 'trust', 'joy'], 'shackle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'madly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'modification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpolation': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'recommencement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verificatory': ['trust'], 'temporary': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'optic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overweight': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'watering_hole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cyst': ['fear', 'sadness', 'disgust', 'negative'], 'haunting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luminescence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fire-eater': ['trust'], 'theology': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forefend': ['surprise', 'fear', 'sadness', 'negative'], 'nobleman': ['positive', 'trust'], 'mislaid': ['negative'], 'Fang': ['fear'], 'frontier_settlement': ['fear'], 'primary_feather': ['positive'], 'unknown_quantity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'capitulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guinea_pig': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'passable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Sicilian_Mafia': ['fear', 'negative'], 'prudish': ['anger', 'positive', 'trust', 'negative'], 'habituate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transformation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'immatureness': ['anger', 'negative', 'anticip'], 'march': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evaluate': ['positive', 'trust'], 'characterise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_question': ['negative'], 'self-contradictory': ['anger', 'fear', 'sadness', 'negative'], 'dockage': ['negative'], 'overriding': ['positive'], 'submission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'signal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'strife': ['anger', 'sadness', 'negative', 'disgust'], 'immunization': ['trust'], 'tinkerer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'more_or_less': ['negative'], 'falling_off': ['negative'], 'lathe': ['negative'], 'academic_term': ['anger', 'fear', 'negative', 'disgust'], 'unwilled': ['surprise', 'negative'], 'trendy': ['positive'], 'fanfare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gratuity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exceeding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pounding': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'civilization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retrogression': ['negative'], 'tout_ensemble': ['positive', 'trust'], 'run': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rum': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'rub': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hypocritical': ['negative', 'disgust'], 'rug': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'rue': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'macrocosm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Paul_Revere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'faith': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dumb_show': ['positive', 'negative', 'surprise'], 'Lion': ['anger', 'positive', 'fear', 'disgust'], 'liven_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'submarine_sandwich': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shipshape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'valorousness': ['positive'], 'caretaker': ['positive', 'trust'], 'ensue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'birchen': ['anger', 'fear', 'negative', 'disgust'], 'conscientious': ['positive', 'trust', 'negative'], 'mordacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accountability': ['positive', 'trust'], 'consultation': ['anticip', 'positive', 'negative', 'disgust', 'fear', 'trust'], 'heritage': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'foot_soldier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narrator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inclination_of_an_orbit': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'crapper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warlike': ['anger', 'fear', 'negative'], 'upper-case_letter': ['positive'], 'lowness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'bureaucratism': ['trust', 'negative'], 'immure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'foresight': ['positive', 'trust', 'anticip'], 'boldface': ['positive', 'negative'], 'do-or-die': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expressage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spreadhead': ['positive'], 'precept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'languishing': ['fear', 'sadness', 'negative'], 'sharing': ['positive', 'trust', 'joy'], 'seethe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Circumcision': ['positive'], 'rose_wine': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'antecedence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enquirer': ['positive'], 'strung-out': ['negative'], 'stagnancy': ['sadness', 'negative'], 'forgo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'final_solution': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'forge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disfavour': ['negative'], 'shrivel_up': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'bravado': ['negative'], 'cloud-covered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oldness': ['fear', 'sadness', 'negative'], 'heroine': ['positive', 'trust'], 'required': ['negative'], 'humiliated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heath': ['fear', 'negative'], 'depth': ['positive', 'trust'], 'evenly': ['positive'], 'washy': ['negative'], 'low-spirited': ['sadness', 'negative'], 'Hydra': ['fear', 'negative'], 'go': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gm': ['trust'], 'United_States_Department_of_Defense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fourth-year': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'news_program': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'baron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earthbound': ['negative'], 'wizard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'personal_chattel': ['positive', 'trust', 'negative'], 'arid': ['sadness', 'negative'], 'ripened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'passion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snare_drum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Phosphorus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'due_date': ['anger', 'negative', 'anticip'], 'uninfected': ['positive'], 'prudence': ['positive', 'sadness', 'trust', 'anticip'], 'enslaved': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'discouragement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defamatory': ['anger', 'negative'], 'emancipationist': ['negative'], 'sickish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'genetic_science': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'insuperable': ['fear', 'sadness', 'negative'], 'nourishing': ['positive', 'sadness'], 'disconfirming': ['anger', 'sadness', 'negative'], 'trip_the_light_fantastic': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'hot_seat': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'musical_theater': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'oddball': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'punishing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Doomsday': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'doss_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rationalness': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'click': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'shout_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Trygve_Halvden_Lie': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'opaque': ['negative'], 'edifice': ['positive', 'negative', 'anticip'], 'rotter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'valet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotten': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'experiment': ['surprise', 'anticip'], 'rotted': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Swift': ['positive'], 'evilness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'melancholy': ['sadness', 'negative'], 'hip_joint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unregularity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stanch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'woolly-headed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'comma_butterfly': ['positive', 'trust'], 'knock_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwholesomeness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'repel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'well-disposed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Utopian': ['anticip', 'positive', 'trust', 'joy'], 'insurance_underwriter': ['fear', 'trust', 'negative'], 'tenuity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yard_bird': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waste_material': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strapper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wishful_thinker': ['anticip', 'positive', 'trust', 'joy'], 'indefensible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'celestial_pole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oceanic_abyss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'improve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'missile': ['fear'], 'nebulose': ['sadness'], 'ostler': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'out_of_true': ['negative'], 'archer': ['anticip'], 'together_with': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'nurture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligence_agent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'poetise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'escaped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Almighty': ['positive', 'trust'], 'suds': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scout_troop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'press_cutting': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'blissfulness': ['positive', 'joy'], 'prospicience': ['positive', 'trust', 'anticip'], 'boasting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poetry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neurotic': ['fear', 'negative', 'disgust'], 'Gore': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'elliptical': ['positive', 'sadness', 'negative', 'anticip'], 'deplore': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'normalize': ['positive', 'trust'], 'entree': ['positive', 'negative'], 'jiffy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cantillate': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'prance': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'debasement': ['negative'], 'dolphinfish': ['surprise', 'trust', 'positive', 'joy'], 'spelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'married_couple': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'giving_birth': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'giving_medication': ['positive', 'trust', 'joy'], 'prettify': ['positive', 'joy'], 'consecrated': ['positive'], 'agenda': ['trust'], 'immensity': ['surprise', 'trust', 'positive', 'joy'], 'unsolved': ['fear', 'negative', 'anticip'], 'unbreakable': ['positive'], 'Smith': ['trust'], 'metric_unit': ['positive'], 'subversive': ['anger', 'surprise', 'negative', 'positive'], 'exclusion': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'death_penalty': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'be_amiss': ['anger', 'sadness', 'negative'], 'youngster': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'enshrine': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'Volunteer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'sword': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'auto': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Brother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'adjournment': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'foiling': ['anger', 'negative'], 'mode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commonwealth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'working_class': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'chunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggravated': ['anger', 'fear', 'negative'], 'turnkey': ['positive', 'fear', 'trust', 'surprise'], 'lukewarm': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'shut_down': ['trust', 'anticip'], 'get_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fathom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wick': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'around_the_bend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caravan_inn': ['fear', 'trust'], 'trashy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mesh_topology': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diagonal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dietetical': ['positive', 'anticip'], 'ancestry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advisor': ['positive', 'trust'], 'barkeeper': ['trust'], 'precaution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'route': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'diminished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elector': ['trust'], 'keel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lamb': ['positive', 'trust', 'joy'], 'incarnate': ['trust'], 'Lama': ['positive'], 'hiding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fella': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyperbolic': ['negative'], 'lese_majesty': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'aviator': ['positive', 'trust'], 'attach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Virgo_the_Virgin': ['positive', 'joy', 'trust', 'anticip'], 'circulate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'formalities': ['trust'], 'Bride': ['anticip', 'positive', 'trust', 'joy'], 'small_beer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synergistic': ['positive', 'trust'], 'overwhelming': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'commensurateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spurn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bee': ['anger', 'positive', 'fear', 'joy'], 'discolor': ['sadness', 'negative', 'disgust'], 'transgression': ['negative'], 'crack-up': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'point_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spurt': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'providing': ['positive', 'joy', 'trust', 'anticip'], 'sultry': ['positive'], 'supplanting': ['trust', 'negative'], 'exhibit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'White_River': ['anticip', 'positive', 'trust', 'joy'], 'unchanged': ['positive'], 'sardonic': ['negative'], 'torment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constrained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'border': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unadulterated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instancy': ['surprise'], 'instance': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'butcherly': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'jail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'visor': ['surprise', 'anticip'], 'adieu': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sternutation': ['surprise', 'negative', 'disgust'], 'missioner': ['positive'], 'resplendent': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'visualize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nuisance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloodthirsty': ['anger', 'fear', 'negative', 'disgust'], 'unaired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eject': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effervescing': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'proceedings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bona_fide': ['positive'], 'fire_warden': ['fear', 'trust', 'negative'], 'good_manners': ['positive'], 'affair': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'go_around': ['anger', 'fear', 'sadness', 'negative'], 'reprehensible': ['anger', 'fear', 'negative', 'disgust'], 'poesy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfathomable': ['sadness', 'negative'], 'labial_pipe': ['positive', 'trust', 'negative', 'surprise', 'joy'], 'read/write_head': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'one': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unploughed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'envy': ['anger', 'positive', 'trust', 'negative', 'joy'], 'so_long': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wreak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reactive': ['positive', 'trust', 'anticip'], 'shinny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stableman': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'fuel': ['trust', 'anticip'], 'bobtail': ['negative'], 'adherent': ['positive', 'trust', 'joy'], 'crumbling': ['sadness', 'negative'], 'swirl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redeem': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'maternalism': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'minacious': ['anger', 'fear', 'negative', 'disgust'], 'evolution': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'hopped-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nimbleness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shy': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'ordain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'shrunk': ['negative'], 'calumniatory': ['negative'], 'deracination': ['trust', 'negative'], 'conversancy': ['positive', 'trust', 'anticip'], 'accuser': ['anger', 'fear', 'negative'], 'burying': ['anger', 'sadness', 'fear', 'negative'], 'mendicancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inkling': ['surprise', 'anticip', 'positive', 'joy'], 'legacy': ['trust'], 'theocracy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conversance': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'puff_of_air': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'program_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concentrate_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contusion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'empathise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horribly': ['negative'], 'marshy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willpower': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'correctly': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horrible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'openhearted': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'frontward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nutritious': ['positive', 'sadness'], 'sole': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'writ_of_mandamus': ['fear', 'negative'], 'foreshadow': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'duodecimal': ['fear'], 'approval': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precious': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'undetermined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pleasure_seeker': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'antisocial': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'slip_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'habitual': ['anticip'], 'individuation': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'competent': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'cohere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haltere': ['anger', 'fear', 'sadness', 'negative'], 'addition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disintegrate': ['fear', 'negative', 'disgust'], 'minimise': ['negative'], 'do-nothing': ['anger', 'sadness', 'negative', 'disgust'], 'cocotte': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'releasing': ['positive'], 'Dragon': ['fear'], 'ghoulish': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'snivel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expenditure': ['negative'], 'prescription': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'esthetical': ['positive', 'joy'], 'novel': ['positive'], 'ripen': ['positive', 'anticip'], 'make_clean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sombreness': ['sadness', 'negative'], 'foray_into': ['anger', 'surprise', 'fear', 'negative'], 'resident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unsavory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'congeneric': ['trust'], 'rain_cats_and_dogs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'putsch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'calamitous': ['anger', 'fear', 'sadness', 'negative'], 'odontalgia': ['fear', 'negative'], 'receiving_set': ['anger', 'surprise', 'anticip', 'positive'], 'dickens': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'blight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absorb': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lay_waste_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'razzing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaticination': ['anticip'], 'transaction': ['trust'], 'reflection': ['fear'], 'wooly-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'flattop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mottle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gladsomeness': ['positive', 'joy'], 'cowcatcher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurrectionist': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'accurate': ['positive', 'trust', 'negative'], 'drop_curtain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cultivable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'Sunday': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stag_party': ['negative'], 'disputation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'low-level': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sense_of_equilibrium': ['positive'], 'fill_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snicker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fine-tune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'space-reflection_symmetry': ['anger', 'sadness', 'negative', 'disgust'], 'atomic_number_79': ['positive'], 'homework': ['trust', 'positive', 'fear', 'joy', 'anticip'], 'turbulency': ['anger', 'fear', 'sadness', 'negative'], 'fate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pansa': ['negative', 'disgust'], 'avant-garde': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'turbulence': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'spiff_up': ['positive'], 'prominent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'renegade': ['anger', 'negative'], 'candy': ['positive'], 'war_machine': ['fear'], 'filiation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sissy': ['negative'], 'backlog': ['positive', 'negative'], 'caterpillar_track': ['anticip'], 'cognate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_going': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'semblance': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'incubus': ['fear', 'negative', 'disgust'], 'liking': ['positive', 'trust', 'joy'], 'lower_jaw': ['fear', 'negative', 'disgust'], 'knock_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Bull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free_energy': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'incandescence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nitwitted': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shape_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'choker': ['anger', 'surprise', 'negative', 'disgust'], 'expansion': ['anger', 'positive', 'negative'], 'imperfectly': ['negative'], 'misrepresentation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cultivatable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'exacerbation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sinister': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'recognized': ['positive'], 'benumbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misbegot': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], "schoolma'am": ['anger', 'negative', 'disgust'], 'evocation': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'electric_resistance': ['anger', 'negative'], 'scissors_grip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'system_of_logic': ['positive', 'trust', 'negative'], 'Lucy_Stone': ['anger', 'positive', 'fear', 'trust', 'negative'], 'jubilee': ['positive', 'joy', 'surprise'], 'seraphic': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'rejoice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impatience': ['sadness', 'negative', 'anticip'], 'blabbermouthed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mastermind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secondary_coil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vein': ['positive', 'trust'], 'jinx': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prophetic': ['anticip'], 'seism': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'gumwood': ['anger', 'negative'], 'Bob_Hope': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'low_density': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overflow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'badmouth': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'low-spiritedness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'write_off': ['negative'], 'katzenjammer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carriage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'limit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lie_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offstage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'motley_fool': ['negative', 'disgust'], 'twist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pastiche': ['positive'], 'nookie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baksheesh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infatuated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'castigation': ['fear', 'negative'], 'folie': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'Panthera_tigris': ['fear', 'negative'], 'dead_body': ['positive', 'trust', 'negative'], 'crummy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fledgling': ['surprise', 'fear'], 'jamming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Vanessa_Stephen': ['anger', 'fear', 'negative', 'disgust'], 'inescapable': ['negative'], 'Inner_Light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evanescence': ['surprise', 'sadness', 'negative'], 'appoint': ['anger', 'sadness', 'negative', 'disgust'], 'undulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dynamic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'protest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disembarrass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obligor': ['fear', 'negative'], 'rescue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vociferous': ['anger', 'negative', 'disgust'], 'statistical_regression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'examen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bring_about': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'dominate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'risible': ['negative', 'disgust'], 'genteelness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'naturalist': ['positive'], 'solution': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'huffy': ['anger', 'sadness', 'negative', 'disgust'], 'naturalise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'washout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenderheartedness': ['positive', 'joy'], 'demarcation_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lustre': ['surprise', 'anticip', 'positive', 'joy'], 'pander': ['anticip', 'positive', 'trust', 'joy'], 'coquet': ['anticip', 'joy', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'inelegance': ['negative'], 'desirous': ['positive'], 'rekindle': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'neb': ['fear', 'negative', 'disgust'], 'unskilled': ['anger', 'sadness', 'negative', 'disgust'], 'conditional_relation': ['negative'], 'fetish': ['anger', 'fear', 'negative'], 'net': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pus': ['negative', 'disgust'], 'Renascence': ['positive'], 'private_investigator': ['anger', 'positive', 'trust', 'negative'], 'fag_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nanna': ['positive'], 'porno': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'nanny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vegetive': ['sadness', 'negative', 'disgust'], 'nosedive': ['positive', 'fear', 'negative', 'surprise'], 'interpret': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vulnerability': ['fear', 'sadness', 'negative'], 'sloven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buckler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lap_covering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'county': ['trust'], 'saccade': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'mugful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counts': ['trust'], 'lodgement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regorge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ratty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embrangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verdancy': ['negative'], 'panacea': ['positive'], 'tighten_up': ['anger'], 'typo': ['negative'], 'recommend': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gilding': ['positive'], 'type': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simple_regression': ['negative'], 'posting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moulder': ['negative', 'disgust'], 'loony': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vegetal': ['sadness', 'negative', 'disgust'], 'chum_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'call_for': ['positive', 'trust'], 'spec': ['trust'], 'frantic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bog_down': ['positive', 'trust', 'negative', 'disgust'], 'give': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'refulgent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assent': ['positive'], 'freshen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polio': ['fear', 'sadness', 'negative'], 'pergola': ['trust'], 'Phoenix': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'scrivener': ['positive', 'anticip'], 'ataraxis': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'stupidity': ['negative'], 'tin_can': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duty_tour': ['anger', 'positive', 'fear', 'negative'], 'run_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abdomen': ['anger', 'sadness', 'negative', 'disgust'], 'soldier_of_fortune': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'do-gooder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unintimidated': ['positive', 'trust', 'joy'], 'summarize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rundle': ['trust', 'negative'], 'cinque': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soberness': ['positive', 'trust', 'negative', 'disgust'], 'ensnarl': ['negative'], 'ensnare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radio_receiver': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toady': ['fear', 'sadness', 'negative', 'disgust'], 'automatic_rifle': ['surprise', 'trust'], 'soaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'superhighway': ['fear'], 'field_hut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'deletion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unemployed': ['fear', 'sadness', 'negative'], 'drowsiness': ['negative'], 'blazon_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'link_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'big_bucks': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brightness': ['positive'], 'daydream': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'hoarfrost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interruption': ['surprise', 'negative'], 'mathematical_function': ['surprise', 'negative'], 'tatty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mystification': ['surprise', 'fear'], 'combust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taught': ['trust'], 'caustic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dawn': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venial': ['negative'], 'railroad_tie': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'revolting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adhesion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sluggish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grease': ['negative', 'disgust'], 'William_Lloyd_Garrison': ['positive', 'trust'], 'John_Major': ['positive', 'trust', 'joy'], 'revenge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shriveled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bestow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mistress': ['anger', 'negative', 'disgust'], 'greasy': ['disgust'], 'auction_off': ['anticip'], 'lout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steward': ['positive', 'trust'], 'prodigal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'tumble-down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ism': ['trust'], 'domesticate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'loud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'role_player': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'great_deal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoop': ['positive', 'anticip', 'joy'], 'hoot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theatrical_performance': ['sadness', 'negative'], 'plurality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoof': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'payload': ['anger', 'sadness', 'negative', 'fear'], 'hood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monotonous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hydrant': ['anger', 'surprise', 'sadness', 'negative'], 'scrape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neutralization': ['anger', 'fear', 'negative'], 'interlude': ['positive'], 'counterpoison': ['positive', 'trust', 'anticip'], 'brabble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inferno': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lovelorn': ['anger', 'sadness', 'negative', 'fear'], 'compunction': ['sadness', 'negative'], 'villager': ['positive', 'trust'], 'pill_pusher': ['positive', 'trust'], 'cruelly': ['anger', 'fear', 'negative'], 'matted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravisher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snappishness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legalize': ['anger', 'positive', 'fear', 'trust', 'joy'], 'matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'childlike': ['anger', 'negative', 'disgust'], 'unpointed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threadbare': ['trust', 'anticip'], '24-hour_interval': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frigidness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'monition': ['fear', 'negative'], 'fold_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbrace': ['positive', 'anticip', 'negative', 'disgust', 'joy'], 'sliding_board': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reprieve': ['positive', 'trust', 'joy'], 'alibi': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'impotent': ['negative'], 'niece': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'demoralizing': ['sadness', 'negative'], 'affirmatively': ['positive', 'trust'], 'inconsistency': ['negative'], 'socialscience': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'medical': ['positive', 'fear', 'trust', 'anticip'], 'digress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baseball_field': ['positive', 'joy'], 'discontent': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rapture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visitor': ['positive', 'joy', 'anticip'], 'brilliance': ['positive', 'trust', 'anticip'], 'brilliancy': ['surprise', 'anticip', 'positive', 'joy'], 'current_of_air': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'sundial': ['trust', 'anticip'], 'insurance_firm': ['fear', 'trust', 'negative'], 'eating_away': ['negative'], 'resisting': ['anger', 'fear', 'sadness', 'negative'], 'divinity': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tyke': ['negative'], 'discretional': ['positive'], 'remittance': ['positive', 'sadness', 'negative'], 'integrate': ['fear', 'negative', 'disgust'], 'edict': ['surprise', 'fear', 'negative', 'anticip'], 'stow': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'stop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_an_eye_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'break_off': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'smart_as_a_whip': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'meditate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smug': ['anger', 'fear', 'negative', 'disgust'], 'devolution': ['negative'], 'Allium_tricoccum': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unwieldiness': ['fear', 'sadness', 'negative', 'disgust'], 'fertility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'attest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reference': ['positive'], 'sonny_boy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plot_of_ground': ['negative'], 'venter': ['disgust'], 'knowledgeableness': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'use_of_goods_and_services': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Butler': ['positive', 'trust'], 'boo-boo': ['sadness', 'negative', 'disgust'], 'half-wit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'production_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'trial_by_ordeal': ['anger', 'surprise', 'negative'], 'scrap': ['negative'], 'jolty': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'favourable_reception': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flying_field': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tantamount': ['trust'], 'kept_woman': ['anger', 'negative', 'disgust'], 'electric_automobile': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'weather_condition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lash_out': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'disenchantment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bemuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filibusterer': ['negative'], 'bunkum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modeling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carnivorous': ['fear', 'negative'], 'excavate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mucky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vote_down': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'move_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spick-and-span': ['positive', 'trust', 'joy'], 'feathering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'protection': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'longanimity': ['positive'], 'distinction': ['positive'], 'instrumentality': ['trust'], 'springy': ['positive'], 'cast_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'large-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flavourless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physical_process': ['positive', 'sadness', 'surprise', 'joy'], 'brassy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "apothecaries'_ounce": ['anger', 'negative', 'disgust', 'anticip'], 'eradication': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unsloped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Greek_Orthodox': ['trust'], 'knockabout': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'roily': ['fear', 'negative'], 'lissome': ['positive'], 'oak_tree': ['anger', 'positive', 'sadness', 'negative', 'joy'], 'sunshine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'British_Labour_Party': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'autochthonic': ['fear', 'sadness', 'disgust', 'negative'], 'exception': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'tang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'trial_run': ['anger', 'positive', 'negative'], 'near': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mesomorphic': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anchor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'metropolitan': ['positive'], 'derisory': ['anger', 'negative', 'disgust'], 'party_favour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], "grease_one's_palms": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'landed_estate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overstated': ['negative'], 'pathfinder': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'surmisal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lustreless': ['negative'], 'sweep_over': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'Stalinism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'discriminatory': ['fear', 'negative', 'disgust'], 'get_around': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'formidability': ['anger', 'positive', 'fear', 'trust'], 'jealous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'obstructor': ['anger', 'fear', 'sadness', 'negative'], 'practiced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'romp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shower_bath': ['positive', 'trust'], 'medical_exam': ['positive', 'fear', 'trust', 'anticip'], 'detonating_device': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moods': ['negative'], 'look_upon': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sporting': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'tactile_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'identify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'facts': ['positive', 'trust'], 'landing_place': ['anticip', 'positive', 'trust', 'joy'], 'outbalance': ['positive', 'anticip'], 'diarist': ['positive'], 'artlessness': ['negative'], 'designate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opt': ['positive'], 'unfitting': ['anger', 'sadness', 'negative', 'disgust'], 'fluidity': ['anger', 'joy', 'sadness', 'negative'], 'inequitable': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'ope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carrying_into_action': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'febricity': ['fear', 'negative'], 'airheaded': ['negative'], 'low-down': ['negative', 'disgust'], 'banshee': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'esthetics': ['positive', 'joy'], 'admittedly': ['positive', 'trust', 'negative', 'joy'], 'curtness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'wrongfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unexplored': ['sadness', 'negative', 'anticip'], 'metrical_unit': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'fellow_traveler': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'conciliation': ['positive', 'joy', 'trust', 'anticip'], 'vomitive': ['negative', 'disgust'], 'tripper': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'holdup': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'scrimmage': ['surprise', 'fear', 'negative'], 'straight_thrust': ['surprise', 'fear', 'negative'], 'invoice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'trace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collect': ['positive', 'trust'], 'notification': ['anticip'], 'daytime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piece_of_music': ['disgust'], 'flounder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beget': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Freemason': ['positive'], 'magnetic_variation': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mischief-making': ['negative'], 'burl': ['negative'], 'burn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throw_away': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'burp': ['negative', 'disgust'], 'burr': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keeper': ['trust'], 'headstone': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'presentiment': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denuded': ['sadness', 'negative'], 'metrical': ['positive', 'trust'], 'palisade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'anovulant': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'craftsman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nerve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motivate': ['anger', 'fear', 'negative', 'anticip'], 'formerly': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'castanets': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'intellectual': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'spell_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frightened': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'unrehearsed': ['negative'], 'ill-sorted': ['anger', 'sadness', 'negative', 'disgust'], 'paving_material': ['trust'], 'rough_drawing': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'unseat': ['sadness'], 'stalk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lurid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fork': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'form': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'add_on': ['positive', 'trust'], 'surveil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ford': ['positive'], 'pass_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'powerfully': ['positive', 'fear'], 'syndicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fort': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'advocator': ['trust'], 'meliorist': ['positive'], 'unvarying': ['positive', 'trust'], 'foul-up': ['sadness', 'negative', 'disgust'], 'afflictive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cosmos': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'temper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bowed_stringed_instrument': ['anger', 'sadness', 'negative'], 'shin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'true_cat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'classic': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'sidestep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sticky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revitalize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mediocre': ['negative'], 'commuting': ['positive'], 'nonpareil': ['positive'], 'shit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'botch_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'end_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alerts': ['surprise', 'fear', 'anticip'], 'half-witted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-complacency': ['positive'], 'male_child': ['negative', 'disgust'], 'Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diet': ['positive', 'anticip'], 'partiality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coronal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'embryonic_membrane': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'authorities': ['fear'], 'causal_agent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assume': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blushing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'flexibleness': ['positive'], 'olive_drab': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'social_class': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'befriend': ['positive', 'trust', 'joy'], 'skip': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'primed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'invent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abatement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill-mannered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'skin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'primer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'drink_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yummy': ['positive'], 'deceitful': ['anger', 'sadness', 'negative', 'disgust'], 'answerer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deject': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snotty-nosed': ['anger', 'positive', 'trust', 'negative', 'joy'], 'unruffled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elliptic': ['positive', 'sadness', 'negative', 'anticip'], 'Assumption_of_Mary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antediluvian': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'string': ['anger', 'sadness', 'negative'], 'anon.': ['negative'], 'evangel': ['positive', 'trust'], 'gestation': ['positive', 'trust', 'joy'], 'bilingualist': ['positive'], 'twenty-one': ['anger', 'fear', 'negative'], 'banished': ['anger', 'fear', 'sadness', 'negative'], 'grave_accent': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'telephone_number': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accidentally': ['surprise'], 'two-timer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'magnet': ['positive', 'trust'], 'humanistic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brownish': ['disgust'], 'shave': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'malefactor': ['fear', 'negative'], 'undoer': ['anger', 'fear', 'negative'], 'oscillation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Romance': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'lxxx': ['fear'], 'slake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sort_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misinterpretation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "shoemaker's_last": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'template': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'audited_account': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'hummer': ['positive'], 'tractor_trailer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'transportation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Coward': ['fear', 'sadness', 'disgust', 'negative'], 'objector': ['anger', 'fear', 'negative'], 'weir': ['fear', 'negative', 'disgust'], 'unknowing': ['negative'], 'detest': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'congestion': ['negative'], 'deceit': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'burst_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'environs': ['positive', 'negative', 'anticip'], 'comptroller': ['trust'], 'knee_breeches': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'sapidity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Cosa_Nostra': ['fear', 'negative'], 'priceless': ['positive'], 'seawall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'human_beings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colloquial': ['positive'], 'sorrowfulness': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sympathetic': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'dolorous': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'troops': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'flunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noisome': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'nozzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissembling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cautious': ['positive', 'fear', 'trust', 'anticip'], 'rigid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'growing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleeping_room': ['positive', 'trust', 'anticip'], 'deceased': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crazy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'overzealous': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Sus_scrofa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'justness': ['anger', 'positive', 'trust', 'negative'], 'craze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purr': ['positive', 'trust', 'joy'], 'place_of_origin': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'tilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'till': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'jump_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overseas_telegram': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'pure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tile': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pathway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'purl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grok': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'designer': ['positive'], 'home_plate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'misrepresented': ['anger', 'negative'], 'blame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'praiseworthy': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'perfidy': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'gelatin': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'designed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barbarousness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'relinquish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infallibility': ['trust'], 'aimless': ['fear', 'sadness', 'negative', 'anticip'], 'outline': ['anticip'], 'Fury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maybe': ['surprise'], 'fluent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thorny': ['fear', 'negative'], 'patronise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Cole_Porter': ['positive', 'trust', 'joy'], 'verify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incandescent_lamp': ['negative'], 'gesture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cute': ['anger', 'positive', 'sadness', 'negative', 'fear'], 'cant_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entryway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pointed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stability': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'terrace': ['positive', 'anticip', 'negative', 'disgust', 'joy'], 'blab_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pointer': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'day_of_the_month': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'pound_sterling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plagiarizer': ['anger', 'negative'], 'smoothie': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'tonic': ['positive'], 'unplanned': ['negative'], 'captivated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Beijing_dialect': ['positive', 'trust'], 'killer': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shatter': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'interview': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'punitory': ['anger', 'fear', 'sadness', 'negative'], 'touching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mismatched': ['positive', 'negative'], 'cognition': ['positive', 'sadness'], 'peasant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'gladiolus': ['positive', 'fear', 'joy', 'anticip'], 'surfeit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrevealed': ['anticip'], 'bookshop': ['positive'], 'richly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'Split': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'preaching': ['positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'Lug': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'aloof': ['negative'], 'ascendent': ['positive', 'trust', 'surprise'], 'impurity': ['negative', 'disgust'], 'interference': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperative': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'Stone': ['anger', 'positive', 'fear', 'negative'], 'monster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hefty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'previse': ['fear', 'negative', 'anticip'], 'scalawag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'customs': ['positive'], 'jakes': ['negative', 'disgust'], 'grist': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'language': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hades': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pollard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visual_aspect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exotic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'dwelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lone': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'XIII': ['fear'], 'cuticle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'American_Stock_Exchange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stash_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'autocrat': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'toad_frog': ['negative', 'disgust'], 'plaint': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Post': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interdict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cosmonaut': ['positive'], 'stipulation': ['trust'], 'meshing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doings': ['anger', 'surprise', 'negative', 'disgust'], 'victorian': ['anger', 'positive', 'trust', 'negative'], 'orgy': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'venture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gigantic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'camouflaged': ['surprise'], 'tantalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'send_word': ['anger', 'positive', 'fear', 'trust', 'negative'], 'gaudery': ['negative', 'disgust'], 'conspiracy': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'sulk': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'unaffixed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fort_up': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'economic_rent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solidity': ['positive', 'trust'], 'pain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pail': ['trust', 'anticip'], 'tallies': ['fear', 'trust'], 'bay_window': ['positive', 'trust'], 'entreaty': ['positive', 'joy', 'negative', 'anticip'], 'pair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mettle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conspicuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gyre': ['positive'], 'debilitation': ['sadness', 'negative', 'anticip'], 'in_writing': ['positive'], 'Domino': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'napkin': ['fear', 'sadness', 'negative', 'disgust'], 'fille': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mammary_gland': ['positive', 'fear', 'trust', 'negative'], 'reassurance': ['positive', 'trust'], 'obstructive': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'set_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curler': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motor_horn': ['surprise', 'fear', 'negative'], 'salon': ['anger'], 'fervour': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'Chrysanthemum_morifolium': ['positive', 'fear', 'negative'], 'flack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cat_valium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiddler': ['negative'], 'machinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 're-create': ['anger', 'positive', 'negative', 'disgust'], 'black': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raising': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'historied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'positron_emission_tomography': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'social_club': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'midriff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slyness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'procreation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disfiguration': ['fear', 'sadness', 'disgust', 'negative'], 'head_trip': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'swollen-headed': ['negative'], 'misbehaviour': ['anger', 'surprise', 'negative', 'disgust'], 'ascribable': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'summary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encroacher': ['anger', 'fear', 'sadness', 'negative'], 'ruddy': ['positive'], 'kernel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'lethargy': ['sadness', 'negative'], 'honesty': ['positive', 'trust', 'negative', 'disgust'], 'blurred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incidental_expense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'green_groceries': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'puma': ['surprise', 'fear'], 'steadfast': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sceloporus_occidentalis': ['positive'], 'bathetic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'behind': ['negative'], 'embark_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reading': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ruta_graveolens': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'foreword': ['anticip'], 'tup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'killing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tun': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'tub': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'trolling': ['anticip', 'negative', 'anger', 'surprise', 'fear', 'trust'], 'stab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'survival': ['positive'], 'stinker': ['negative', 'disgust'], 'warmness': ['positive', 'joy'], 'nomenclature': ['positive'], 'bald-faced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disappointment': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'forecasting': ['anticip'], 'cancer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'postal_service': ['anger', 'fear', 'negative', 'anticip'], 'cancel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mortification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'custody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strong_suit': ['positive'], 'tumour': ['fear', 'sadness', 'negative'], 'caricature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distich': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'certify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solitudinarian': ['sadness', 'trust'], 'lead_up': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'shortening': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dysphemistic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'line-shooting': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'give_voice': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'graveyard': ['fear', 'sadness', 'negative'], 'hodgepodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'zoftig': ['positive', 'anticip', 'joy'], 'self-respecting': ['positive'], 'bespeak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'residential_area': ['positive'], 'dependent_on': ['anticip'], 'overdose': ['negative'], 'captivity': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'approbative': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'disconnected': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legitimise': ['anger', 'positive', 'fear', 'trust', 'joy'], 'compile': ['positive', 'trust'], 'dirty_dog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Midweek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voodooism': ['anger', 'fear', 'negative'], 'key_fruit': ['positive', 'negative', 'disgust', 'surprise'], 'margin': ['sadness', 'negative'], 'bathe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Andrew_Dickson_White': ['anticip', 'positive', 'trust', 'joy'], 'endowed': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sincere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'middle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'choke_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'single-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'receptacle': ['negative'], 'same': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manipulable': ['anger', 'positive', 'negative'], 'authentication': ['trust'], 'acerbity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Oman': ['positive', 'fear', 'negative', 'anticip'], 'deference': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Quercus_marilandica': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intermediary': ['positive', 'trust', 'anticip'], 'munch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sleepiness': ['negative'], 'traducement': ['anger', 'fear', 'negative', 'disgust'], 'totally': ['positive', 'trust'], 'blue_devil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drain': ['negative'], 'accountable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'trust'], 'root_word': ['positive', 'trust', 'surprise'], 'criminalise': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'quartz_glass': ['positive', 'negative'], 'fume': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'travel_rapidly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criminalism': ['anger', 'fear', 'negative', 'disgust'], 'imprint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretcher': ['fear', 'sadness'], 'foul_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warriorlike': ['anger'], 'take_account': ['positive', 'trust', 'negative'], 'swath': ['anger', 'surprise', 'fear', 'negative'], 'trespasser': ['anger', 'surprise', 'fear', 'negative'], 'astonishment': ['surprise', 'positive', 'joy'], 'presentable': ['positive'], 'inhibition': ['negative'], 'hold_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrorize': ['anger', 'fear', 'sadness', 'negative'], 'nosy': ['trust', 'negative', 'anticip'], 'chamber': ['positive', 'trust', 'anticip'], 'audience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anarchic': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'robbery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'drainage': ['negative'], 'witchcraft': ['anger', 'fear', 'sadness', 'negative'], 'dole': ['positive', 'sadness', 'negative'], 'go_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smoking_compartment': ['negative'], 'narcotising': ['negative'], 'dolt': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'booming': ['positive', 'anticip', 'joy'], 'gross': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrinkly': ['sadness', 'trust', 'negative'], 'inject': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high_school': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'USDA': ['positive', 'trust'], 'broker': ['positive', 'negative'], 'worn_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urban_center': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monogamousness': ['trust'], 'squarely': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'giggle': ['positive', 'joy'], 'opium': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'tease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'island': ['negative'], 'bear_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smattering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hearable': ['negative'], 'knave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'round_out': ['fear', 'sadness', 'negative'], 'lands': ['fear', 'sadness', 'negative'], 'chronological_succession': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'point-blank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnetite': ['positive'], 'gear_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "hangman's_halter": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggrandizement': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'superbia': ['positive', 'joy'], 'argumentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magic_spell': ['anger', 'fear', 'negative'], 'day_by_day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vodoun': ['anger', 'fear', 'negative'], 'tholepin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tycoon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorrel': ['negative'], 'drug_abuse': ['positive', 'negative', 'anticip'], 'buggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bookstore': ['positive'], 'hesitancy': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'belated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peckish': ['anger', 'negative'], 'commonality': ['trust'], 'bon_ton': ['positive', 'negative', 'anticip'], 'goat_god': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suitcase': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ossification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taking_into_custody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deliberation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'measure_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garrulous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lifetime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'deterrent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frighten_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retiring': ['positive'], 'hybrid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drouth': ['negative'], 'field': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opacity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'obsessed': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'shelter': ['positive', 'trust'], 'vertex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'brandy': ['negative'], 'committal_to_writing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tackle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revolve': ['anger', 'fear', 'sadness', 'negative'], 'dramatic_play': ['anger', 'sadness', 'negative'], 'Major': ['positive', 'trust', 'joy'], 'remote': ['negative'], 'clangour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tantalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'topsy-turvy': ['anger', 'negative'], 'hugely': ['positive'], 'nutrient': ['positive', 'sadness'], 'deluxe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'represent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'needful': ['negative'], 'liar': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'sezession': ['negative'], 'fly-by-night': ['fear', 'negative'], 'invariable': ['positive', 'trust'], 'alerting': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sonorousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'talky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cooperative': ['positive', 'trust'], 'invariably': ['positive', 'trust'], 'talks': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'misadvise': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'unobstructed': ['positive', 'joy'], 'reluctant': ['anger', 'fear', 'negative', 'disgust'], 'red-hot': ['positive', 'joy', 'anticip'], 'Lucille_Ball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tranquillity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supply_ship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'pull_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rambunctious': ['anger', 'fear', 'negative', 'disgust'], 'regularise': ['positive'], 'overdone': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'scout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'os_frontale': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'benevolent': ['trust'], 'skeletal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mistaking': ['negative'], 'trio': ['positive'], 'gang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stupefied': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'titled': ['sadness', 'negative'], 'periodicity': ['trust'], 'lawyer': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'misrepresent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unorthodoxy': ['fear'], 'A-one': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'centering': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'crepuscule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appealingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stoop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'theological_system': ['anticip'], 'vociferation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untroubled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'outgoing': ['positive'], 'tiresomeness': ['negative'], 'sand_trap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'K': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vale': ['trust'], 'beacon': ['positive'], 'elbow_room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kerosine': ['fear'], 'rocket_salad': ['anger', 'fear'], 'mourning': ['anger', 'sadness', 'negative', 'fear'], 'search': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tortoise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airport': ['anticip'], 'narrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fatten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pathological': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Devil': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'transit': ['anticip'], 'general_agent': ['fear', 'trust', 'negative'], 'forcibly': ['anger', 'fear', 'negative'], 'sanction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extinction': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'establish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlightened': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'final_result': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'libertine': ['negative', 'disgust'], 'cultivation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lassie': ['positive', 'joy'], 'letter_writer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rubbing': ['anger'], 'formality': ['trust'], 'nimbus': ['anticip', 'positive', 'trust', 'joy'], 'brisk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjuring_trick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dew': ['negative', 'disgust'], 'exercising_weight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clergy': ['trust'], 'heaven-sent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'aspirant': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'hirudinean': ['fear', 'negative', 'disgust'], 'inventor': ['positive'], 'conniving': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dandy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mail_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interbreed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'black_and_white': ['negative', 'disgust'], 'sheep_pen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physical_composition': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'self-control': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'mutable': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'petite': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'uprising': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blacken': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'interpose': ['anger', 'positive', 'fear', 'negative'], 'par': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faculty': ['positive', 'trust'], 'spirit_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coax': ['trust'], 'monetary_standard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'P': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coat': ['negative'], 'Darling_River': ['positive', 'trust', 'joy'], 'in_particular': ['surprise'], 'coal': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'sect': ['anger', 'fear', 'negative', 'disgust'], 'usurped': ['anger', 'fear', 'negative'], 'evanesce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pleasure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'setback': ['sadness', 'negative'], 'dough': ['positive'], 'existence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gun_muzzle': ['fear', 'negative'], 'down_payment': ['trust'], 'pour_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'assailable': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cash_in': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'shortstop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'religious_doctrine': ['positive', 'trust'], 'theocratic': ['anger', 'sadness', 'trust', 'negative', 'fear'], 'spontaneous_abortion': ['fear', 'sadness', 'disgust', 'negative'], 'long_dozen': ['fear'], 'late': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thinning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dolly': ['joy'], 'sanctification': ['positive', 'trust', 'joy'], 'clamor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bereft': ['anger', 'sadness', 'negative', 'fear'], 'seeking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'libido': ['positive'], 'unauthentic': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'detach': ['negative'], 'affixation': ['positive'], 'crispness': ['sadness', 'negative'], 'countersign': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'anaesthetic_agent': ['sadness', 'negative'], 'token': ['sadness', 'negative'], 'goofy': ['trust'], 'subjugation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'wild_ox': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'boisterous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'wrawl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'meshes': ['negative'], 'urarthritis': ['negative'], 'clams': ['positive'], 'nakedness': ['positive'], 'idea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brokenheartedness': ['sadness', 'negative'], 'endearment': ['positive', 'trust', 'joy'], 'seniority': ['positive', 'trust'], 'stand_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luminousness': ['positive'], 'funding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'innervation': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'pigeon': ['negative'], 'avenge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pathetic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncheerful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pleasant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'contrivance': ['positive'], 'disposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entrancing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eventuality': ['fear', 'negative', 'anticip'], 'recast': ['positive', 'trust', 'anticip'], 'omit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diddlysquat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'audacity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'corkscrew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vauntingly': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'squash_racquet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'campground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wages': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wager': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clapperclaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'thaumaturgy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Judgment_Day': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'construct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paint': ['positive', 'joy'], 'pains': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mama': ['positive', 'fear', 'negative'], 'kos': ['negative'], 'compartment': ['fear', 'trust'], 'bema': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'needle': ['positive'], 'mentality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prehend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gruesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discussion_section': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'missionary_work': ['positive', 'trust', 'anticip'], 'compliments': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incision': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eyeshot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'riddance': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fatten_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'economic_system': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'interactive': ['positive', 'trust'], 'death_rate': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'emanation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Marco_Polo': ['positive', 'sadness', 'trust'], 'intestine': ['anger', 'positive', 'trust', 'disgust'], 'boat_paddle': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'trip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'onset': ['anticip'], 'commentary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'province': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'equipping': ['anger', 'fear', 'negative'], 'cast_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'significant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sir_Noel_Pierce_Coward': ['fear', 'sadness', 'disgust', 'negative'], 'musical_harmony': ['positive', 'trust', 'joy'], 'saturate': ['negative', 'disgust'], 'penalisation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'faithless': ['sadness', 'negative', 'disgust'], 'charitable': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'squelcher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pennant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squelch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'weigh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crap-shooter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ghostwrite': ['fear', 'negative'], 'sanctity': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'carefully': ['positive'], 'nervous': ['fear', 'negative', 'anticip'], 'lamp_oil': ['fear'], 'suspensor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prowess': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'notation': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'permission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'batten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finery': ['positive'], 'high-handed': ['anger', 'fear'], 'cheapen': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'batter': ['anger', 'fear', 'sadness', 'negative'], 'annexation': ['negative'], 'cumulate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'inaugurate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'transitional': ['anticip'], 'pill_roller': ['positive', 'trust'], 'crabmeat': ['anger', 'negative'], 'reputable': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'armature': ['anger', 'fear', 'negative'], 'gospel': ['positive', 'trust'], 'motiveless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'double-crosser': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cotton_gin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Chaos': ['anger', 'fear', 'sadness', 'negative'], 'arouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keister': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theoretic': ['positive'], 'unacknowledged': ['sadness'], 'bellied': ['negative'], 'beautification': ['positive', 'trust', 'joy'], 'myriad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'abrade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bucket_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obelisk': ['fear', 'negative'], 'alimony': ['negative'], 'electric_fan': ['negative'], 'nescient': ['negative', 'disgust'], 'knock_about': ['anger', 'fear', 'sadness', 'negative'], 'alinement': ['positive'], 'indiscriminately': ['surprise'], 'sexual_intercourse': ['positive', 'trust', 'disgust'], 'hard_knocks': ['anger', 'fear', 'sadness', 'negative'], 'befoulment': ['negative', 'disgust'], 'sozzled': ['negative'], 'supply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shutdown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'openness': ['positive'], 'supple': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'toddle': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'Saratoga_chip': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfavorable_judgment': ['anger', 'positive', 'sadness', 'negative'], 'underage': ['negative'], 'unavowed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weighed_down': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'secret': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annihilating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proposal_of_marriage': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'bone_marrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'cruelty': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'pricey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'understand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guided_missile_destroyer': ['anger', 'fear', 'negative'], 'malarky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Swedish_mile': ['surprise', 'negative', 'trust', 'positive', 'joy'], 'bile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laxness': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'bill': ['anger', 'negative', 'disgust', 'anticip'], 'tolerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Asa_Gray': ['sadness', 'negative', 'disgust'], 'sexuality': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diseased_person': ['fear', 'sadness', 'negative'], 'sea_mew': ['fear', 'trust'], 'fun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'guarantor': ['anger', 'positive', 'fear', 'trust', 'negative'], 'shoddy': ['anger', 'negative', 'disgust'], 'geezerhood': ['positive', 'fear', 'trust', 'negative'], 'debased': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cacoethes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rancor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decoration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrink_back': ['anger', 'negative'], 'lodge_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'personation': ['negative'], 'ingrain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misdemeanour': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emphasize': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], "mare's_nest": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'lenient': ['positive'], 'attenuation': ['sadness', 'negative'], 'itch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inunct': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'assignment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verboten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggregate': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'carver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musical_score': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'spent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morrow': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'scummy': ['negative', 'disgust'], 'landmark': ['trust'], 'written_matter': ['anger', 'positive', 'negative', 'disgust'], 'recant': ['anger', 'negative'], 'spend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'temperamental': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'resistive': ['positive'], 'atomic': ['trust'], 'dishonesty': ['negative', 'disgust'], 'alignment': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'malformation': ['fear', 'sadness', 'negative', 'disgust'], 'preferent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'conscienceless': ['negative', 'disgust'], 'alternate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shouting': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'telephone_dial': ['trust', 'negative', 'anticip'], 'bridal': ['anticip', 'positive', 'trust', 'joy'], 'impoverished': ['negative'], 'excited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'takein': ['positive'], 'rebound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reconnoitre': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'precipitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phlebotomize': ['fear', 'sadness', 'disgust', 'negative'], 'air_pocket': ['fear', 'sadness', 'negative'], 'forepart': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resoluteness': ['anger', 'positive', 'sadness', 'negative'], 'scrip': ['positive', 'trust'], 'Chosen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'gravy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'impeach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compendious': ['positive', 'trust'], 'unsurmountable': ['fear', 'sadness', 'negative'], 'divvy_up': ['anticip', 'positive', 'trust', 'joy'], 'pet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pew': ['disgust'], 'integration': ['negative'], 'pes': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'pen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bogus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pee': ['positive', 'sadness', 'negative'], 'sericeous': ['positive'], 'commentator': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'invade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolutely': ['positive'], 'nose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crony': ['anticip', 'positive', 'trust', 'joy'], 'mettlesome': ['positive', 'anticip', 'joy'], 'classical_music': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'cronk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chanting': ['positive'], 'chargeable': ['fear', 'sadness', 'negative'], 'crone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hackneyed': ['trust', 'anticip'], 'conciliatory': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'cutting_tool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offshoot': ['positive'], 'fire_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maelstrom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transmittable': ['fear', 'negative', 'disgust'], 'lantern_slide': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'neutrality': ['trust'], 'jockey': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'doll': ['joy', 'negative', 'disgust', 'positive', 'anger', 'trust'], 'infected': ['positive', 'trust', 'negative', 'disgust'], 'forward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warlock': ['fear'], 'Doroteo_Arango': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'Psalm': ['positive'], 'groovy': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'rejection': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'blockage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hedge_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verruca': ['positive', 'negative', 'disgust', 'surprise'], 'halfhearted': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'uninitiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_chair': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'interlocutory': ['positive'], 'groove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'skittish': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'responder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nepotism': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'congruence': ['positive', 'trust'], 'possessor': ['positive', 'trust'], 'engineering': ['positive'], 'dispensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prevail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'table_service': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'furbelow': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sense_experience': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dimmed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excreta': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'spasm': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'aggregated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phonation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tenaciousness': ['positive', 'sadness', 'anticip', 'joy'], 'amused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'touch_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'home_base': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Adam_Smith': ['trust'], 'stroller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rassling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discards': ['negative'], 'sea_tang': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'query': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disintegration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extraterrestrial_being': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'gusset': ['trust'], 'baby_buggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'side_arm': ['negative'], 'adjoin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rail_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'internment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'gravel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bombilation': ['positive', 'fear', 'negative', 'anticip'], 'assay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'as_such': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'human-centred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confounding': ['anger', 'fear', 'sadness', 'negative'], 'reverberate': ['negative'], 'subservient': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'severely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'respectful': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'knight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'shambling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'supine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strike_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mobilize': ['positive', 'trust'], 'unsatisfied': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'hardening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'buckram': ['negative'], 'crow': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'tinny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plosive_consonant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inebriety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earliness': ['positive', 'negative', 'anticip'], 'speckle': ['negative'], 'giving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synergetic': ['positive', 'trust'], 'famish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'executor': ['trust'], 'speech_communication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ALT': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'fear', 'trust'], 'remark': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resurrect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rain_buckets': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'traditional_knowledge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger'], 'sightly': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'manna': ['positive'], 'private': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'public_security': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oval': ['positive', 'sadness', 'negative', 'anticip'], 'appellation': ['trust'], 'transportation_system': ['anticip'], 'preindication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contrariety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'overbear': ['anger', 'negative'], 'oily': ['disgust'], 'insufficiency': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'coruscate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ashamed': ['sadness', 'negative', 'disgust'], 'tattered': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'arranging': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'harvest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pathos': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'echo_sounder': ['positive', 'anticip'], 'graven_image': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'vaudeville': ['positive', 'negative'], 'sibilate': ['anger', 'fear', 'negative', 'disgust'], 'defrayment': ['negative'], 'unreal': ['positive'], 'praise': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'poseur': ['positive'], 'admiralty': ['positive', 'trust'], 'vulturous': ['negative'], 'gin_mill': ['anger'], 'contempt': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'celestial_latitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'thin-skinned': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger'], 'thin_out': ['negative'], 'changeless': ['positive', 'trust'], 'philosophy': ['trust'], 'nullify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bemire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threesome': ['positive', 'trust', 'negative', 'disgust'], 'detective_work': ['positive'], 'fray': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scurvy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'longsighted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haze_over': ['sadness', 'negative'], 'tamper': ['anger', 'negative'], 'fallback': ['negative'], 'ignite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meter': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bunce': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bunco': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'tickling': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'bunch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dirtiness': ['negative', 'disgust'], 'lb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unstained': ['positive'], 'acres': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marsh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'crotch_hair': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'latitude': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'criminal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'check_mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trying_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mandate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grandness': ['positive'], 'caskful': ['fear', 'sadness', 'negative'], 'simple_mindedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memoir': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hagfish': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'jockstrap': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'monkey_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commixture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thwart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hired_gun': ['anger', 'negative'], 'jailor': ['positive', 'fear', 'trust', 'surprise'], 'abrogation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hot_chocolate': ['anticip', 'positive', 'trust', 'joy'], 'programmer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fondle': ['positive'], 'defend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wholly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thickset': ['positive', 'trust'], 'Calidris_canutus': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'public_debate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insolvent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ref': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'red': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hedged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concave_shape': ['negative'], 'mock_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pharmaceutical': ['positive'], 'frank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bleed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cured': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'overweening': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'retain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intrinsicality': ['positive', 'joy', 'surprise', 'anticip'], 'ruction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anovulatory_drug': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'unproductiveness': ['negative'], 'betroth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'land_up': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'frazzle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unconscious_mind': ['negative'], 'layabout': ['negative'], 'monkey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vulgar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'film_director': ['positive', 'trust'], 'strong-armer': ['anger', 'fear', 'negative', 'disgust'], 'writhe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pea_plant': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pipe_organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'magnetic_force': ['positive'], 'in_full': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'silklike': ['positive'], 'slack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrapnel': ['fear'], 'anomalousness': ['surprise', 'fear', 'negative'], 'calamity': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'beamish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'regenerated': ['joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'tidy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comfortable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'separatrix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minimal_brain_damage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'countryman': ['trust'], 'waken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bitty': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'get_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hue_and_cry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsettled': ['anger', 'fear', 'negative', 'disgust'], 'provoked': ['anger', 'fear', 'negative'], 'mooring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auberge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eight': ['anticip', 'positive', 'trust', 'joy'], 'handbag': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'make-do': ['negative'], 'transcript': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'rigourousness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'exaggerated': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'Scorpio_the_Scorpion': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'discursive': ['positive'], 'absurd': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'outlive': ['positive'], 'supported': ['positive', 'negative'], 'gin_rummy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supporter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coloring': ['sadness', 'negative', 'disgust'], 'ambiguity': ['negative'], 'equilibrium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ring_mail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprejudiced': ['positive', 'trust'], 'benumb': ['positive', 'sadness', 'negative'], 'organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'virginal': ['positive', 'joy', 'trust', 'anticip'], 'defame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motherhood': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'cachet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'conform': ['positive'], 'untrue': ['negative'], 'swing_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puddle': ['negative'], 'yearning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scholastic': ['positive', 'negative'], 'ill-bred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unpretending': ['positive'], 'square_toes': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'exploited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pedigree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exclusive_right': ['positive', 'trust', 'joy'], 'laureate': ['positive', 'trust'], 'unchecked': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'flying_lizard': ['fear'], 'gemstone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pudden-head': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'optional': ['positive'], 'military_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deadlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'instant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freely': ['positive', 'trust', 'joy'], 'oral_contraceptive': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'secernment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'assure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insidious': ['anger', 'fear', 'negative', 'disgust'], 'busted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predispose': ['anticip'], 'Delicious': ['positive', 'joy'], 'passing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glorious': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'comment': ['positive'], 'teasing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commend': ['positive', 'trust', 'joy'], 'form_of_address': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'laugh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'prop_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'perplexed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'climate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eructation': ['anger', 'surprise', 'fear', 'negative'], 'maturity_date': ['anger', 'negative', 'anticip'], 'vapid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parity_bit': ['anger', 'sadness', 'negative', 'disgust'], 'Trygve_Lie': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'value': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excrement': ['negative', 'disgust'], 'permeate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'likable': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'prosy': ['negative'], 'milk_shake': ['negative'], 'prose': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'bloodless': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lynchpin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'portray': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'didactic': ['positive'], 'state_of_flux': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'Hunter': ['fear', 'anticip', 'sadness', 'negative'], 'E._B._White': ['anticip', 'positive', 'trust', 'joy'], 'defiant': ['anger', 'negative'], 'supercharge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bullying': ['anger', 'fear', 'negative'], 'mephitis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'besmirch': ['anger', 'fear', 'negative', 'disgust'], 'retard': ['fear', 'sadness', 'disgust', 'negative'], 'center': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'statute_title': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'weapon': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cash_register': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'usual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Cam': ['anger', 'surprise', 'fear', 'negative'], 'dilapidation': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'granddad': ['trust'], 'underlying': ['positive', 'trust'], 'surpass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protecting': ['positive', 'trust'], 'clean-cut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bragging': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'check_bit': ['anger', 'sadness', 'negative', 'disgust'], 'bench': ['trust', 'anticip'], 'backpacker': ['sadness', 'negative'], 'citizen': ['positive'], 'ravel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'articles': ['trust'], 'testy': ['anger', 'negative'], 'judiciary': ['trust', 'anticip'], 'self-gratification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corporeality': ['negative'], 'insert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'security_measures': ['fear', 'negative'], 'porous': ['negative'], 'mastication': ['anger', 'sadness', 'negative'], 'rabbet': ['positive'], 'works': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bafflement': ['surprise', 'fear'], 'decease': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'feast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corroborate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligence_officer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'interment': ['anger', 'sadness', 'negative', 'fear'], 'refill': ['positive'], 'maladroitness': ['fear', 'sadness', 'disgust', 'negative'], 'rale': ['fear'], 'first_rudiment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discernability': ['positive'], 'slight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combative': ['anger', 'fear', 'negative', 'disgust'], 'guff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leave_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worthy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tautological': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-informed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'panel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retribution': ['anger', 'fear', 'sadness', 'negative'], 'inconsiderate': ['anger', 'sadness', 'negative', 'disgust'], 'ball_carrier': ['positive'], 'flake': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'decimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baseless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'character_assassination': ['anger', 'fear', 'sadness', 'negative'], 'tree_sloth': ['negative', 'disgust'], 'saneness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rhythmical': ['surprise', 'positive', 'joy'], 'demonstrable': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'improperness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'pigeon_loft': ['negative'], 'demeanour': ['anger', 'surprise', 'negative', 'disgust'], 'bazaar': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'firefighter': ['trust'], 'elision': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'offprint': ['negative'], 'buy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'olde_worlde': ['positive', 'trust', 'joy'], 'bur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bus': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incrustation': ['negative', 'disgust'], 'I._F._Stone': ['anger', 'positive', 'fear', 'negative'], 'bun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'bum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Jerome_Kern': ['negative'], 'subdivision': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bud': ['anticip', 'positive', 'trust', 'joy'], 'embargo': ['negative'], 'til_now': ['negative'], 'wise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warmth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_it': ['anticip'], 'shared_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eighter': ['anticip', 'positive', 'trust', 'joy'], 'penetrating': ['negative', 'disgust'], 'Saint_Brigid': ['anticip', 'positive', 'trust', 'joy'], 'wide-eyed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wash_drawing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumscription': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'admonitory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'reading_material': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revocation': ['negative'], 'latria': ['positive', 'trust', 'joy'], 'ledge': ['positive', 'sadness', 'trust', 'joy'], 'redden': ['negative'], 'hydrofoil': ['negative'], 'puzzlement': ['surprise', 'fear'], 'traumatic': ['anger', 'fear', 'sadness', 'negative'], 'prestigiousness': ['positive', 'trust', 'joy'], 'variation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weaponry': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'thumping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'godsend': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'contraceptive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resort_hotel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_up': ['positive', 'sadness', 'disgust'], 'flush_toilet': ['negative', 'disgust'], 'lightlessness': ['sadness', 'negative', 'fear'], 'gatekeeper': ['positive', 'trust', 'joy'], 'two-dimensional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'growling': ['anger', 'fear', 'negative', 'disgust'], 'Henry_Sweet': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'chip_in': ['positive'], 'photographic_plate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hate': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'trolley': ['fear', 'sadness', 'disgust', 'negative'], 'beat_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tweet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bosomy': ['positive', 'anticip', 'joy'], 'rankle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pure_tone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pride': ['positive', 'joy'], 'buoy_up': ['positive'], 'divergent': ['surprise', 'negative'], 'derogate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rabidness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'softened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'missionary': ['positive'], 'roadstead': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'irresoluteness': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'ovation': ['positive', 'sadness', 'anticip', 'negative', 'joy'], 'vitriolic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Alfred_Hawthorne': ['positive', 'fear', 'negative', 'anticip'], 'rose-colored': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'relics': ['sadness'], 'degeneracy': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'enjoy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scribbler': ['positive', 'anticip'], 'go_along': ['anticip'], 'porcine': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'guardedly': ['positive', 'fear'], 'Cy_Young': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'persuade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough_out': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'emptiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ransack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airplane_pilot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faecal': ['negative', 'disgust'], 'yarn-dye': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'specification': ['trust'], 'PIN_number': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mischievous': ['negative'], 'conduct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zesty': ['positive', 'negative'], 'solidness': ['positive', 'trust'], 'George_Herman_Ruth': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ulterior': ['negative'], 'gather_up': ['positive', 'trust'], 'asymmetry': ['disgust'], 'pate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'path': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shortness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'eighter_from_Decatur': ['anticip', 'positive', 'trust', 'joy'], 'orthodoxy': ['trust'], 'connoisseur': ['positive', 'trust', 'joy'], 'auction': ['anticip'], 'abolition': ['negative'], 'faulting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feudal_system': ['anger', 'sadness', 'negative'], 'mutual': ['positive'], 'verdure': ['negative'], 'tie-in': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'visible': ['trust'], 'viscera': ['negative', 'disgust'], 'sympathise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orthodontic_braces': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'haschisch': ['negative'], 'justifiedly': ['positive'], 'lessening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breathe': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blather': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'trading_operations': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_Education': ['positive', 'trust'], 'masticate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sir_Hiram_Stevens_Maxim': ['positive', 'trust'], 'moil': ['negative', 'disgust'], 'stigmatise': ['anger', 'negative', 'disgust'], 'setin': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'join': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mi': ['negative'], 'entertained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pay_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Bishop_of_Rome': ['positive', 'trust'], 'dither': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quarrel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_in_line': ['anger', 'surprise', 'negative', 'anticip'], 'loosen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debone': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gingiva': ['anger', 'negative'], 'high-sounding': ['negative'], 'move_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'coefficient_of_correlation': ['positive'], 'weathervane': ['surprise', 'sadness'], 'Lord': ['positive', 'trust'], 'knickknack': ['positive', 'surprise'], 'collude': ['surprise', 'fear', 'negative'], 'end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trill': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'peculation': ['negative'], 'ancestor': ['positive', 'joy', 'trust', 'negative', 'surprise'], 'raffle': ['surprise', 'anticip'], 'unhorse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scion': ['negative', 'disgust'], 'claptrap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mess': ['anger', 'trust', 'negative', 'disgust'], 'protuberance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demanding': ['anger', 'positive', 'fear', 'negative'], 'curb_bit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mesh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mesa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arbitrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'environ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remold': ['positive', 'trust', 'anticip'], 'rankness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'coronate': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'thesis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'strangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'George_Walker_Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'Hero': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hypocrisy': ['negative'], 'circularise': ['positive'], 'lip_service': ['negative'], 'comprehend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'goodish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolutism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'roost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depopulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misdirection': ['negative'], 'Felis_concolor': ['surprise', 'fear'], 'felicitous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'eatage': ['negative'], 'leading': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victory': ['anticip', 'positive', 'trust', 'joy'], 'woolgather': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'title-holder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wheel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'true_pine': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger'], 'combining': ['anticip'], 'goo': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'trumpeter': ['negative'], 'god': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'millennium': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'haggling': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'underwrite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'showstopper': ['disgust'], 'living_room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acrobat': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publication': ['negative', 'anticip'], 'denture': ['negative'], 'inexpensive': ['positive'], 'labored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'break_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cooperating': ['positive', 'trust'], 'scrunch_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolute_frequency': ['positive'], 'flashiness': ['anger', 'negative'], 'palpable': ['surprise'], 'put-down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheerless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'analgesic': ['positive', 'trust'], 'canonicals': ['trust'], 'beat-up': ['anger', 'fear', 'sadness', 'negative'], 'ceiling': ['positive', 'trust'], 'tool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toot': ['negative'], 'march_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cable_car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tent-fly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foul-smelling': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'blazonry': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'expo': ['positive', 'joy', 'negative', 'anticip'], 'garrulousness': ['negative'], 'arraignment': ['anger', 'fear', 'sadness', 'negative'], 'donkey': ['negative', 'disgust'], 'fashion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruckus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'talking': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'further': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'staggeringly': ['positive'], 'regulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spade': ['negative'], 'elegance': ['anticip', 'positive', 'trust', 'joy'], 'client': ['positive', 'trust', 'negative'], 'cleft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effectiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perfective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visionary': ['anticip', 'positive', 'trust', 'joy'], 'rumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toy_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carcinoma': ['fear', 'sadness', 'negative'], 'coil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unorthodox': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'slip_up': ['negative'], 'prostitute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soupy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'signature_tune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treaty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orderly': ['positive', 'negative'], 'enterprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inspire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Guru': ['positive', 'trust'], 'reorganize': ['positive'], 'random': ['fear', 'sadness', 'negative', 'anticip'], 'word_of_advice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stand_firm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'end_of_the_world': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'verbalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chivvy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-favoured': ['negative'], 'foursquare': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mixture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mug_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Maya_Lin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unassisted': ['fear', 'sadness', 'negative'], 'blinking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geek': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'enfeeblement': ['sadness', 'negative', 'anticip'], 'falsify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distillate': ['positive'], 'nut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roll_of_tobacco': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nun': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'nul': ['surprise', 'sadness', 'negative'], 'marchland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depressive': ['sadness', 'negative'], 'rarity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise'], 'nub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gladiator': ['fear'], 'capacity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'propulsion': ['anger', 'negative'], 'smutty': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Latinian_language': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'adventuresome': ['positive'], 'confusion': ['anger', 'fear', 'negative'], 'boss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adage': ['positive'], 'bosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contamination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'blowback': ['trust', 'anticip'], 'protect': ['positive', 'trust', 'negative'], 'favourable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precipitous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haphazardness': ['anger', 'negative'], 'participating': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'escapade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monograph': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'partial_derivative': ['negative'], 'neck_opening': ['negative'], 'self-respect': ['positive', 'trust'], 'pardner': ['positive', 'trust'], 'epidemic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maudlin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laughingstock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beef': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'faltering': ['fear', 'negative'], 'juvenile_delinquency': ['negative'], 'beer': ['positive', 'joy'], 'splatter': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'uncommon': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'concentrical': ['positive'], 'snipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sought_after': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Elia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lessen': ['negative', 'anticip'], 'lesser': ['negative', 'disgust'], 'fallow': ['negative'], 'pull_together': ['positive', 'trust'], 'preponderant': ['positive'], 'monocracy': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'indigenous': ['fear', 'sadness', 'disgust', 'negative'], 'surcharge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'camp_bed': ['positive', 'negative', 'disgust', 'anticip'], 'tie_beam': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Trotskyite': ['anticip', 'positive', 'trust', 'joy'], 'muteness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complex': ['negative'], 'inventory': ['trust'], 'several': ['trust'], 'schooltime': ['trust'], 'accusive': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'monotonic': ['negative'], 'postmark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excise_tax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magical_spell': ['anger', 'fear', 'negative'], 'shadower': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'forceful': ['positive', 'trust'], 'greatest': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'fungicide': ['positive', 'trust'], 'shadowed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toque': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'work_over': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'subsidization': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'exuberate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'harmonise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forfeiture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unvoiced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brainsick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pettishness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'natural_process': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devil_dog': ['trust'], 'humanity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'botch': ['sadness', 'negative', 'disgust'], 'screak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sanitary': ['positive'], 'befit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amok': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'medical_specialist': ['trust'], 'moral_philosophy': ['positive'], 'gift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Martin_Luther_King': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'US_Constitution': ['positive', 'trust', 'negative'], 'blood-related': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flight_strip': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'specific': ['trust'], 'ditty': ['positive', 'joy'], 'mosquito': ['anger', 'negative', 'disgust'], 'estate_of_the_realm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overtone': ['negative'], 'stereotype': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'detraction': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'pseud': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'female_person': ['positive'], 'displeasure': ['negative', 'disgust'], 'escape': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'act_on': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'stools': ['negative', 'disgust'], 'manducate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ululation': ['anger', 'surprise', 'fear', 'negative'], 'embodied': ['negative'], 'spic-and-span': ['positive', 'trust', 'joy'], 'armed': ['anger', 'positive', 'fear', 'negative', 'joy'], 'ice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prejudicial': ['anger', 'negative'], 'outstation': ['fear'], 'self-consciousness': ['sadness', 'negative', 'anticip'], 'subordination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'espionage': ['negative'], 'cord': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'core': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corn': ['anger', 'negative'], 'corp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garnishee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'control_board': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'limitation': ['anger', 'positive', 'sadness', 'negative'], 'beldam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surround': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Parousia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misleading': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'sept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'primitive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slow-witted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accommodate': ['anticip', 'positive', 'trust', 'joy'], 'skeleton_in_the_cupboard': ['sadness', 'negative', 'disgust'], 'electorate': ['trust'], 'low-pitched': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'softheartedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diggings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disinterest': ['trust'], 'attestant': ['trust'], 'outward-bound': ['positive'], 'opus': ['disgust'], 'indocile': ['anger', 'surprise', 'negative', 'anticip'], 'inebriant': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unpretentious': ['positive'], 'purposely': ['surprise', 'negative'], 'head': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medium': ['anticip', 'positive', 'trust', 'negative', 'surprise'], 'sense_of_right_and_wrong': ['positive', 'trust'], 'heal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'heat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heap': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoarded_wealth': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'humiliate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'counsel': ['anger', 'positive', 'fear', 'trust', 'negative'], 'bargain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Duncan_James_Corrow_Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kitschy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adore': ['anticip', 'positive', 'trust', 'joy'], 'felicitation': ['positive', 'joy'], 'adorn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brightly': ['positive', 'joy'], 'obfuscation': ['surprise', 'fear'], 'bring_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinful': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pelter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hempen_necktie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willingly': ['positive'], 'junto': ['fear', 'negative'], 'Begin': ['surprise', 'fear', 'negative', 'anticip'], 'techy': ['anger', 'positive', 'trust', 'negative', 'joy'], 'junta': ['negative'], 'dollar_bill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'littleness': ['negative'], 'evergreen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'incestuous': ['negative', 'disgust'], 'reconsider': ['positive', 'trust'], 'preceding': ['positive', 'trust', 'joy'], 'tunny': ['positive', 'sadness', 'negative'], 'enamor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfrequented': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'scratchy': ['anger', 'positive', 'trust', 'negative', 'joy'], 'ululate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fortissimo': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'bullet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withhold': ['negative'], 'cross-file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'backward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deliberateness': ['negative'], 'take_hold': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'particular': ['trust'], 'livelihood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disjuncture': ['sadness', 'negative', 'anticip'], 'square_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turbid': ['sadness'], 'flowered': ['positive'], 'right_smart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'folderol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrawny': ['negative'], 'advantage': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'impend': ['fear', 'anticip'], 'weapons_system': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sloppy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'the_three_estates': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taphouse': ['anger'], 'Vipera_aspis': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inauspicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'time_of_year': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accumulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Rex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'police_cruiser': ['trust'], 'lark_about': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'takeoff': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Reb': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'bake': ['anger', 'negative'], 'Red': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asceticism': ['sadness', 'trust', 'negative'], 'spectral': ['fear', 'negative', 'disgust'], 'distaste': ['negative', 'disgust'], 'choral': ['positive', 'joy'], 'constitution': ['positive', 'trust', 'negative'], 'oral_contraceptive_pill': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'spire': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'steady_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hypothecate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'title_of_respect': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'humorist': ['positive'], 'spirt': ['joy', 'negative', 'disgust'], 'costless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'den': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ulceration': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'good-for-naught': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pay_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissipated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unidentified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dec': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mental_testing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weird': ['surprise', 'fear', 'negative', 'disgust'], 'morals': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'compare': ['sadness', 'negative'], 'Robert_Brown': ['disgust'], 'military_officer': ['positive', 'trust'], 'sawbuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'eruditeness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surroundings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barkeep': ['trust'], 'revered': ['anticip', 'positive', 'trust', 'joy'], 'riot': ['anger', 'surprise', 'fear', 'negative'], 'malefic': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'chocolate': ['anticip', 'positive', 'trust', 'joy'], 'downhearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mussiness': ['anger', 'trust', 'negative', 'disgust'], 'bicycle-built-for-two': ['trust'], 'auction_sale': ['anticip'], 'local': ['anticip'], 'reflux': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'waylay': ['anger', 'surprise', 'fear', 'negative'], 'laughter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'unconditional': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'performer': ['positive', 'negative'], 'corrupted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'garbled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economic_crisis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business_enterprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stroke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theistic': ['anger', 'sadness', 'trust', 'negative', 'fear'], 'holdwater': ['trust'], 'afterlife': ['anticip'], 'eloquent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scarceness': ['anger', 'fear', 'sadness', 'negative'], 'innumerable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wizardly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prelim': ['positive', 'trust', 'surprise', 'anticip'], 'demoniacal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unbelievable': ['surprise', 'sadness', 'negative', 'positive'], 'irrational': ['fear', 'negative', 'disgust'], 'keepsake': ['positive', 'sadness', 'negative'], 'double_birdie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unawares': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business_relationship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'outlandish': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tipped': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dethaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unutterable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'business_leader': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'misbegotten': ['negative', 'disgust'], 'flood_lamp': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'article_of_faith': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unfreeze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superscript': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'refund': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dry_land': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'sonnet': ['positive', 'sadness', 'joy'], 'top_dog': ['positive', 'negative', 'anticip'], 'drop_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canary': ['positive'], 'embezzlement': ['negative'], "drag_one's_feet": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worship': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apex': ['positive'], 'macho-man': ['positive'], 'coordinates': ['positive'], 'WIMP': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'meridian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_out': ['sadness', 'negative'], 'sparing': ['positive'], 'unveiling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pharynx': ['anger', 'fear', 'negative'], 'warrantee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warranted': ['negative'], 'producing': ['positive'], 'rescind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equality': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'airman': ['positive', 'trust'], 'opera': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disunited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nodding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'realise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'realism': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_depression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'time_to_come': ['anticip'], 'downheartedness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'matt-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pillager': ['sadness', 'negative'], 'goose_egg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splashy': ['negative'], 'ultimately': ['positive', 'anticip'], 'infuriated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plug_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unco': ['positive'], 'theory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'booby': ['trust', 'negative'], 'satanic': ['anger', 'negative'], 'bouffant': ['negative'], 'light-headed': ['negative'], 'tie_down': ['trust'], 'disillusionment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impose': ['anger', 'positive', 'fear', 'negative'], 'let_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unborn': ['negative'], 'origin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feign': ['negative'], 'incongruous': ['anger', 'negative'], 'awfully': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'close_at_hand': ['fear', 'anticip'], 'soaring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-denial': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'alike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disinterested': ['negative'], 'deed_of_conveyance': ['trust'], 'arsehole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'even-tempered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chastity': ['positive', 'trust', 'anticip'], 'convention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'friendly_relationship': ['positive', 'trust', 'joy'], 'Dove': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'unfaltering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soporific': ['negative'], 'hum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hut': ['positive', 'fear', 'sadness'], 'tempera': ['positive', 'trust'], 'holder': ['positive', 'trust'], 'intrinsically': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'manic_disorder': ['anger', 'fear', 'negative'], 'looting': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'start_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'require': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diplomatic': ['positive', 'trust'], 'obtuseness': ['negative'], 'insulant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'all-inclusive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instauration': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'ana': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pro': ['positive', 'trust'], 'excusatory': ['positive', 'trust'], 'prostitution': ['sadness', 'negative', 'disgust'], 'ant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mates': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commissioning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitch_contour': ['positive'], 'transcription': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'make_unnecessary': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'fatuousness': ['negative'], 'emphasis': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'thermometer': ['positive', 'trust'], 'public_press': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "cobbler's_last": ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'freshman': ['surprise', 'fear'], 'vibrancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_open': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'splendid': ['positive', 'joy', 'surprise'], 'coin_bank': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'perch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recipe': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'unchurch': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'protrusion': ['fear', 'negative'], 'wine-colored': ['negative', 'disgust'], 'prime_minister': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'rational_number': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'piranha': ['fear', 'negative', 'disgust'], 'crime': ['anger', 'negative'], 'hinge_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backwardness': ['negative'], 'crimp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overhead_railway': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'newspaperwoman': ['positive', 'trust'], 'pendency': ['negative'], 'begging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tailor': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'treachery': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'closure': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pinnacle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sexual_climax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'picnic': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'innards': ['negative', 'disgust'], 'dickhead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simmering': ['anticip'], 'obliging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asperity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'underpaid': ['anger', 'sadness', 'negative'], 'excogitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harmonised': ['positive'], 'detect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commutation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belittled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wasteyard': ['anger', 'sadness', 'negative', 'fear'], 'anodyne': ['positive', 'trust'], 'prentice': ['trust'], 'untrustworthy': ['anger', 'negative'], 'caucus': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'good-looking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dutiful': ['positive', 'trust', 'anticip'], 'camarilla': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'bunko': ['negative'], 'goodbye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'region': ['anticip'], 'unspoilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'propagation': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'root_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'senator': ['positive', 'trust'], 'deportee': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'snoopiness': ['negative'], 'crossbeam': ['anger', 'negative', 'anticip'], 'color': ['sadness', 'negative', 'disgust'], 'resentment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vingt-et-un': ['anger', 'fear', 'negative'], 'play_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polo': ['positive', 'sadness', 'trust'], 'poll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'runaway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moral_force': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bet_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'votive': ['trust'], 'velum': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'gaiter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tittle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hardly': ['sadness', 'negative', 'fear'], 'WAN': ['sadness', 'negative', 'fear'], 'drink_in': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mocking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'robber': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'paying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shaft': ['positive', 'fear', 'trust', 'anticip'], 'amend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nothingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Crusade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Wisconsinite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'specialiser': ['trust'], 'puncher': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'top_side': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_to_bed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ontogeny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'volition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'helmet': ['positive', 'fear'], 'resentful': ['anger', 'negative'], 'alphabet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jiggery-pokery': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'agitated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shifty': ['negative'], 'moronic': ['negative'], 'applaud': ['surprise', 'trust', 'positive', 'joy'], 'devoid': ['positive', 'trust'], 'enormousness': ['surprise', 'trust', 'positive', 'joy'], 'provost': ['positive', 'trust'], 'sexual_activity': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'pivot_man': ['positive', 'trust'], 'rubeola': ['fear', 'sadness', 'disgust', 'negative'], 'recital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'car_horn': ['surprise', 'fear', 'negative'], 'matureness': ['anger', 'negative', 'anticip'], 'exultation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'termination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'model': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clod': ['sadness', 'negative', 'disgust', 'anticip'], 'stammering': ['negative'], 'clog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'softwood': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'clot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theatrical_role': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pariah': ['fear', 'sadness', 'disgust', 'negative'], 'clop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manse': ['anger', 'fear', 'negative'], 'differentiation': ['positive'], 'perilous': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'announcement': ['anticip'], 'perfect_tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dauntless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regent': ['positive', 'trust'], 'except': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handclasp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Bessie_Smith': ['trust'], 'mat_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'record_book': ['positive', 'trust', 'negative'], 'headroom': ['positive', 'negative', 'anticip'], 'loaner': ['positive', 'trust'], 'standstill': ['anger', 'negative'], 'ill-timed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meaninglessness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'unelaborated': ['negative'], 'gooff': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'pacific': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'cachexia': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pain_pill': ['positive', 'trust'], 'informant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutters': ['positive'], 'play_along': ['trust'], 'prolific': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sailing_master': ['trust', 'anticip'], 'highest': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'defenceless': ['fear', 'sadness', 'negative'], 'legal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delectation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nutty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compulsion': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Emily_Post': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declaratory': ['positive'], 'communicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monsoon': ['sadness', 'negative'], 'Rock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'on': ['trust'], 'Prime_Minister': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'demarcation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zealous': ['positive', 'trust', 'joy'], 'paralysis': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'off-color': ['negative'], 'ox': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'in_demand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tick_off': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tributary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'os': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amber': ['positive'], 'vicar': ['positive', 'trust'], 'hellcat': ['negative'], 'undervalue': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'garnet': ['positive'], 'garner': ['positive', 'trust'], 'abrogate': ['negative'], 'Christmas_carol': ['positive', 'trust', 'joy'], 'incendiary_bomb': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'strictly': ['positive', 'trust'], 'strict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detectable': ['positive'], 'nitril': ['fear', 'negative'], 'condone': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'carouse': ['anger', 'surprise', 'fear', 'negative'], 'grunge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jug': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'strenuous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jut': ['anger', 'positive', 'fear', 'negative'], 'grungy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'terminus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excruciate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preside': ['positive', 'trust'], 'strongly': ['positive'], 'Old_Ironsides': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muzzy': ['negative'], 'metastasis': ['anticip', 'positive', 'negative', 'disgust', 'fear', 'trust'], 'politics': ['anger'], 'idiot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diarrhea': ['disgust'], 'loyal': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'insurance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idiom': ['anger', 'positive', 'trust', 'negative'], 'stumbler': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'modishness': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'unneeded': ['negative'], 'dismayed': ['surprise', 'fear', 'negative', 'disgust'], 'bounder': ['negative'], 'ICE': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fetid': ['negative', 'disgust'], 'courtly': ['positive', 'trust'], 'nucleus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'included': ['positive'], 'spouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ratter': ['anger', 'negative'], 'invest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'odds': ['surprise', 'trust', 'negative', 'anticip'], 'Equus_caballus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'curve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unscathed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curvy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fizzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dekametre': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'skreigh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foot_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scattered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seals': ['trust'], 'surgical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'follow': ['trust'], 'settlement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'throw_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polarity': ['surprise'], 'soft_touch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coxa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mental_capacity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subjected': ['sadness', 'negative'], 'removal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'program': ['positive'], 'put_behind_bars': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'presentation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'backslide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fill-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'woman': ['positive', 'trust'], 'worse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equivocal': ['positive', 'trust', 'negative'], 'induce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cadaver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worst': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'induct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venereal_infection': ['positive', 'trust', 'negative', 'joy'], 'unattainable': ['anger', 'sadness', 'negative'], 'grandfather': ['trust'], 'trench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unproblematic': ['anger', 'negative', 'disgust'], 'epicurean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manslaughter': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'ten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neediness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'design': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hair_curler': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erectness': ['fear'], 'prepossess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hesitation': ['fear', 'negative'], 'gunk': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'deeply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boodle': ['positive'], 'Mick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thraldom': ['fear', 'sadness', 'negative'], 'segmentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defalcation': ['negative'], 'communicable': ['fear', 'negative', 'disgust'], 'elite_group': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'transfigure': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'epitome': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'net_income': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breakable': ['positive'], 'eudaemonia': ['positive', 'trust', 'disgust'], 'misinterpret': ['anger', 'sadness', 'negative'], 'difficulty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precipitant': ['negative'], 'sophisticate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crybaby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'options': ['trust', 'negative', 'anticip'], 'unit_of_measurement': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'ill-affected': ['negative'], 'snug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fagged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turn_up': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ease_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wretched': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disapprove': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'verticalness': ['fear'], 'heinousness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'squish': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'data_file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equation': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'patient_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excursion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freeze_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embarrassing': ['positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'murmur_vowel': ['positive', 'fear', 'sadness', 'negative'], 'water_system': ['positive', 'sadness', 'negative'], 'abandonment': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'light_bulb': ['negative'], 'coerce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'admission_fee': ['positive', 'trust', 'negative'], 'imitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arise': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'cultivate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'earpiece': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Egyptian_cobra': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'desperation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cleansing': ['positive'], 'life_sentence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'Ishmael': ['fear', 'sadness', 'disgust', 'negative'], 'emulate': ['positive'], 'fungus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'numb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotund': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dissolving': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'unstinting': ['positive'], 'footer': ['negative'], 'ricochet': ['negative'], 'criminal_prosecution': ['negative', 'disgust'], 'forethought': ['positive'], 'chip_at': ['anticip', 'positive', 'trust', 'joy'], 'Solomon_Bellow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'discomfited': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mission': ['positive', 'trust', 'anticip'], 'proverbial': ['positive'], 'ginmill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airplane_propeller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'unite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concentric': ['positive'], 'flounce': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pack_together': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'riding_horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glide': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'susceptible': ['negative'], 'secret_agent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'electioneering': ['anger', 'positive', 'fear', 'negative'], 'co-ordinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'drive_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oxidization': ['negative'], 'muddied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'incitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incompleteness': ['negative'], 'light-green': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gnarly': ['negative'], 'insensibility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predator': ['fear', 'negative', 'disgust'], 'speechless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set-back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belittle': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unmeaningness': ['sadness', 'negative'], 'smoothness': ['positive'], 'unreasoning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cantonment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inequality': ['anger', 'fear', 'sadness', 'negative'], 'letting': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'inherent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stemma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formulate': ['anger', 'negative'], 'let_up': ['negative'], 'coal_oil': ['fear'], 'pry_bar': ['anger', 'trust', 'negative', 'anticip'], 'scratching': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seditious': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shamefaced': ['anger', 'sadness', 'negative'], 'presenter': ['positive', 'fear'], 'Eight': ['anticip', 'positive', 'trust', 'joy'], 'exteriority': ['positive'], 'paradise': ['anticip', 'positive', 'trust', 'joy'], 'boldness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ersatz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blaring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disinfect': ['positive'], 'attendant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Male': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'generate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiat': ['surprise', 'fear', 'negative', 'anticip'], 'hold_open': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'public_square': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'circuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhealthy': ['fear', 'sadness', 'disgust', 'negative'], 'drunken_revelry': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'conglutination': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'blank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corporal': ['negative'], 'moan': ['fear', 'sadness'], 'temperature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tare': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'swart': ['sadness', 'negative', 'disgust'], 'edginess': ['sadness', 'negative', 'anticip'], 'Frost': ['negative'], 'exhortation': ['positive'], 'lobby': ['anger', 'fear', 'negative'], 'swarm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prescient': ['positive', 'anticip'], 'moat': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'lugworm': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'aureate': ['positive'], 'wax_light': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'aeronaut': ['positive', 'trust'], 'thaumaturge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'vial': ['positive', 'joy'], 'instruction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deputise': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'human_foot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'executioner': ['anger', 'fear', 'sadness', 'negative'], 'enamored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acculturation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outstanding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strengthen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'give_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carry-over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyperbolize': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'overblown': ['negative', 'disgust'], 'pilot_program': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lackadaisical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Al_Gore': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'comportment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chairman': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'flexure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'populous': ['disgust'], 'slenderly': ['negative'], 'heating_system': ['anger', 'fear', 'negative', 'disgust'], 'thruway': ['fear'], 'enticing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reckon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pillage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'house_physician': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'subsidy': ['anger', 'negative', 'disgust'], 'religious_rite': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'Stephen_Foster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'adder': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'arriere_pensee': ['positive', 'trust', 'negative', 'disgust'], 'louche': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissolver': ['fear', 'trust', 'sadness', 'negative'], 'oppressiveness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Zen': ['positive', 'trust', 'joy'], 'devalue': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'drunkenness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rakish': ['positive'], 'biological_science': ['positive'], 'memorandum': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'military_operation': ['anger', 'fear', 'negative'], 'stoned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'melody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggravate': ['fear', 'negative'], 'ethical_drug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'penalty': ['anger', 'fear', 'sadness', 'negative'], 'nonchalance': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'pigwash': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'transcendental': ['positive'], 'carmine': ['positive'], 'derived_function': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counterpoint': ['negative'], 'avarice': ['anger', 'negative', 'disgust'], 'tawny-brown': ['disgust'], 'procrastination': ['negative'], 'fallible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outpouring': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'activity': ['negative'], 'dizziness': ['fear', 'negative'], 'signify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'martyrdom': ['fear', 'sadness', 'negative'], 'upsurge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wimpish': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'chaplain': ['trust'], 'collapsible_shelter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untested': ['positive'], 'afters': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'efficacious': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'surgical_process': ['anger', 'fear', 'negative'], 'forlorn': ['sadness', 'negative', 'disgust'], 'berserk': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'lamenting': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'plethoric': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recently': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succeed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tabularize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go-ahead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Saint_John_the_Apostle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'trade_good': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lyrical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bronze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cowardliness': ['fear', 'negative'], 'license': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Spike_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'Corvus_corax': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rip_off': ['anger', 'positive', 'negative', 'disgust'], 'sloth': ['negative', 'disgust'], 'flier': ['anger', 'negative', 'disgust', 'anticip'], 'duplicity': ['anger', 'negative'], 'reasons': ['anger'], 'sepsis': ['fear', 'sadness', 'negative'], 'whelp': ['positive', 'trust', 'anticip'], 'radiolocation': ['trust'], 'whelm': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'gustatory_perception': ['positive', 'negative', 'disgust'], 'bolster': ['positive'], 'complication': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'dun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hand-to-hand_struggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'due': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'anuran': ['negative', 'disgust'], 'pa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confabulation': ['positive', 'fear', 'joy', 'negative', 'anticip'], 'armory': ['trust'], 'varnish': ['trust'], 'quintet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunblind': ['negative'], 'goodly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'temperament': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incoming': ['positive', 'trust'], 'corrode': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'think_about': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tent_flap': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'compactness': ['anger', 'fear'], 'criminal_offence': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'waul': ['fear', 'sadness', 'negative'], 'intrude_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sliver': ['negative'], 'arriver': ['anticip'], 'exsanguine': ['positive'], 'cartridge': ['fear'], 'trucking_rig': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'birch': ['anger', 'fear', 'negative', 'disgust'], 'robust': ['positive'], 'knack': ['positive'], 'lower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earmark': ['positive', 'negative'], 'barretter': ['positive', 'sadness'], 'riffle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'grievance': ['anger', 'sadness', 'negative', 'disgust'], 'selective_service': ['negative'], 'precedence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battery_charger': ['positive'], 'monitor_lizard': ['positive', 'fear', 'trust'], 'precedency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Scripture': ['positive', 'trust', 'negative'], 'originative': ['positive'], 'ostiary': ['positive', 'trust', 'joy'], 'pimiento': ['positive'], 'loading': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'likeable': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'exhibition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chaparral': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'deadened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'vindicate': ['anger', 'positive'], 'condemnation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sac': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'go_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "ship's_boat": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggravation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nipple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'clothes_designer': ['positive', 'trust'], 'perpetual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fucking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embroil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denigration': ['anger', 'fear', 'negative', 'disgust'], 'trumping': ['anger', 'surprise', 'negative', 'disgust'], 'pretension': ['anger', 'negative'], 'fork_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pesterer': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'soppy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jumpy': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'piece_of_cake': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'physiological_reaction': ['surprise', 'trust'], 'juju': ['negative'], 'lummox': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tinker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmortgaged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'questionmark': ['positive', 'fear', 'negative', 'anticip'], 'hogwash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordeal': ['anger', 'surprise', 'negative'], 'unfortunate_person': ['sadness', 'negative'], 'impermeable': ['anger', 'fear'], 'stricken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'repulsion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'black_magic': ['surprise', 'fear', 'negative', 'anticip'], 'put_one_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'judicial_decision': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phonograph_recording': ['positive'], 'deafness': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'Sue': ['anger', 'sadness', 'negative'], 'vagabond': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handedness': ['positive', 'trust'], 'soldierly': ['anger'], 'numerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'rip_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sonny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pundit': ['negative'], 'fast': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'melodic': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'mundane': ['positive', 'trust'], 'settlor': ['positive', 'fear'], 'forbidding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'showcase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mystify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonplussed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'atomic_number_47': ['surprise', 'negative', 'positive'], 'stalking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gratifying': ['positive', 'joy'], 'play_a_joke_on': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'cream_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beguiling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humanitarian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cover_charge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'involuntariness': ['negative'], 'nervous_impulse': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'scrapie': ['anger', 'fear', 'sadness', 'negative'], 'warning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lemon': ['negative', 'disgust'], 'pleasure_trip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cramped': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'income': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divine_revelation': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'vaulting': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'adult_female': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'chirp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flirtation': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'closed_book': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gang_fight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enfolding': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'declination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dodging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weighty': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'severable': ['positive', 'trust', 'joy'], 'farsighted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unripened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rooftree': ['fear'], 'festal': ['positive', 'joy'], 'hellion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dumbbell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dampish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disposal': ['negative'], 'shanghai': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'fall_guy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sure_as_shooting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battue': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'obstinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'stable': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'guttle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hiram_Ulysses_Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materialist': ['negative', 'disgust'], 'talons': ['anger', 'fear', 'negative'], 'materialise': ['anticip'], 'drinking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materialism': ['negative'], 'physiognomy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incoherent': ['negative'], 'fly_high': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'footmark': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'assemblage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smirch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'State': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protrude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angle_of_inclination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snack_counter': ['anger', 'fear', 'sadness', 'negative'], 'kris': ['positive', 'trust', 'negative'], 'cast_anchor': ['anger', 'positive', 'sadness', 'trust'], 'relent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cubbyhole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garishness': ['anger', 'positive', 'trust', 'negative'], 'fearlessness': ['positive'], 'cozy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'industriousness': ['positive', 'trust'], 'giant': ['fear'], 'John_Roy_Major': ['positive', 'trust', 'joy'], 'desired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'separation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vividness': ['positive', 'trust'], 'frolicsome': ['positive', 'joy'], 'swashbuckler': ['anger', 'fear', 'negative', 'disgust'], 'tractableness': ['positive'], 'longwise': ['trust'], 'rede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lodging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'summation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'droopy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'witchery': ['anger', 'fear', 'sadness', 'negative'], 'use': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lenify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'doodle': ['negative'], 'germ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bitterly': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dishevel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muck_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prejudicious': ['anger', 'negative'], 'sort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parliament': ['trust'], 'musician': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sore': ['anger', 'sadness', 'negative', 'disgust'], 'whang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rare': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pecuniary_resource': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bridesmaid': ['positive', 'trust', 'joy'], 'augment': ['positive'], 'weighting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lumber': ['negative'], 'itchiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'makewayfor': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'spying': ['positive'], 'wampum': ['positive'], 'villain': ['anger', 'fear', 'negative', 'disgust'], 'wizen': ['negative', 'disgust'], 'united': ['positive', 'trust'], 'tone_of_voice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_organization': ['positive', 'trust'], 'prognosis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grudgingly': ['negative'], 'tension': ['anger', 'negative'], 'lesion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unforgivable': ['anger', 'sadness', 'negative', 'disgust'], 'hazard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tractability': ['positive'], 'barricaded': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'readiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depicted_object': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'courage': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'retrogress': ['negative'], 'saturated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Aspinwall': ['positive', 'trust'], 'tyrant': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'abstruse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'takings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Charles_Frederick_Worth': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'quiesce': ['positive'], 'kickshaw': ['positive', 'trust', 'anticip'], 'permanent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contemplative': ['positive', 'sadness'], 'turban': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'orange': ['positive'], 'conformance': ['positive'], 'arse_about': ['negative'], 'illegitimate_enterprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orthodox': ['trust'], 'trenchant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'ill-used': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'negligent': ['negative'], 'untouchable': ['negative'], 'experimental_condition': ['anger', 'positive', 'fear', 'negative'], 'sustentation': ['trust', 'negative'], 'liquify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impaired': ['anger', 'fear', 'sadness', 'negative'], 'viscid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beingness': ['positive'], 'bewilderment': ['surprise', 'fear'], 'profound': ['positive', 'trust'], 'stand_in': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'dissolvent': ['fear', 'trust', 'sadness', 'negative'], 'unpredictable': ['surprise', 'negative'], 'admonisher': ['positive', 'fear', 'trust'], 'conservatism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deteriorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erratic': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ponderosity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Noel_Coward': ['fear', 'sadness', 'disgust', 'negative'], 'tabloid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loquacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pithiness': ['positive', 'trust', 'surprise'], 'disarray': ['anger', 'fear', 'negative'], 'thrifty': ['positive', 'trust'], 'hollering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'induction': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'despairing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'promptly': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'reverberance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sabre': ['anger', 'fear', 'negative'], 'comrade': ['positive', 'trust'], 'overtake': ['anger', 'fear', 'negative'], 'illicit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crystallization': ['positive', 'negative'], 'uproot': ['fear', 'sadness', 'negative'], 'marriage_proposal': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'pismire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_intercourse': ['positive'], 'bouquet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straw_man': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'listless': ['sadness', 'negative'], 'depend_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steamy': ['fear', 'negative'], 'effervescent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coordination_compound': ['negative'], 'disoblige': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salutary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biting_louse': ['negative', 'disgust'], 'inmate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flip-flop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unembodied': ['fear', 'sadness', 'negative'], 'ticklish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'agility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contestation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'academy': ['positive'], 'venal': ['anger', 'sadness', 'negative', 'disgust'], 'goblin': ['fear', 'negative', 'disgust'], 'solid_ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vilipend': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'infernal_region': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infectious': ['fear', 'sadness', 'disgust', 'negative'], 'screeching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'individual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lilliputian': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'judgment_of_conviction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unaccountable': ['sadness', 'trust', 'negative', 'disgust', 'anticip'], 'fetter': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Vipera_berus': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mogul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sincerity': ['positive', 'fear', 'sadness'], 'thepast': ['negative'], 'beehive': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'come-on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'olfactory': ['negative', 'anticip'], 'admittance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caducous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'troy_ounce': ['anger', 'negative', 'disgust', 'anticip'], 'deprave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'willful': ['anger', 'sadness', 'negative'], 'roue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vegetation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'combat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turn_over': ['positive', 'trust', 'negative'], 'harmful': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'fend_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cognation': ['trust'], 'discourage': ['anticip', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'refreshing': ['positive'], 'looker': ['trust'], 'Requiem': ['sadness'], 'savageness': ['anger', 'fear', 'negative'], 'diagnostics': ['fear', 'trust', 'negative', 'anticip'], 'undimmed': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'please': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excoriation': ['negative'], 'tidings': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terra_firma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'planning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suffer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plentifulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spindle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spurring': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tribulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'off-the-cuff': ['negative'], 'prosecute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overeating': ['negative', 'disgust'], 'spue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interlingual_rendition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coggle': ['positive', 'anticip'], 'half-crazed': ['anger', 'fear', 'negative'], 'unison': ['positive'], 'rafts': ['negative', 'disgust'], 'ogre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'expel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dreariness': ['negative'], 'caryopsis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mental_faculty': ['positive', 'trust'], 'lapidate': ['negative'], 'dress_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'still': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'junky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diverge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'viper': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'recessional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'torpedo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'financial_aid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'file_cabinet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embarrassment': ['surprise', 'fear', 'sadness', 'negative'], 'hypothesis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'probing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sonorous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noetic': ['positive'], 'caudally': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'write_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaporing': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'commando': ['fear', 'trust', 'negative'], 'unconvincing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'password': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'packaging': ['positive'], 'subscribe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower_jawbone': ['fear', 'negative', 'disgust'], 'respect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beauty_shop': ['anger'], 'untrusting': ['anger', 'negative', 'anticip'], 'storyteller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tote_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tutor': ['positive'], 'literal': ['negative'], 'outflow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tawdry': ['anger', 'negative', 'disgust'], 'turning_point': ['trust'], 'sufficient': ['negative'], 'meritorious': ['positive', 'trust', 'joy'], 'locomote': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'painter': ['surprise', 'fear'], 'align': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'ejection': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Methedrine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'primacy': ['positive'], 'layer': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'o.d.': ['negative'], 'dual': ['positive', 'anticip'], 'duad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tongue-tied': ['negative'], 'tail_end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radiation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'cross': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'member': ['fear', 'sadness', 'disgust', 'negative'], 'eschaton': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'duteous': ['positive', 'trust', 'anticip'], 'harvest_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indicant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scum_bag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grandeur': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'impuissance': ['negative'], 'succulent': ['positive', 'negative'], 'one-twelfth': ['fear'], 'placation': ['positive', 'joy', 'trust', 'anticip'], 'beast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhumed': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'pestle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'screenland': ['surprise', 'sadness', 'anticip', 'negative', 'fear'], 'fighting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piss': ['positive', 'sadness', 'negative'], 'perpetrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scissor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butterball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bending': ['negative'], 'ministration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbridled': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'high-risk': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'snake_eyes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'replenish': ['positive'], 'glossiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fibril': ['anger', 'positive', 'joy', 'anticip'], 'Scheol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_a_blank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapid': ['surprise'], 'panther': ['surprise', 'fear'], 'enact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'tizzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'captivating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interrogation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transposition': ['trust', 'negative'], 'presume': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'helpful': ['positive', 'trust', 'joy'], 'howitzer': ['positive'], 'correlation_coefficient': ['positive'], 'endowment': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'raffish': ['positive'], 'pantomime': ['positive', 'negative', 'surprise'], 'virginity': ['positive', 'anticip'], 'military_unit': ['anger', 'positive', 'fear', 'trust', 'negative'], 'mark_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'growth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succinctness': ['positive', 'trust', 'surprise'], 'take_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'religious_sect': ['anger', 'fear', 'negative', 'disgust'], 'divinyl_ether': ['anger', 'fear', 'sadness', 'negative'], 'godforsaken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'philosopher': ['positive', 'trust'], 'instantaneous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eonian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obey': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'handmaiden': ['positive', 'trust', 'negative'], 'lying_under_oath': ['surprise', 'fear', 'negative'], 'Mill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'response_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'settle_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cycle_per_second': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extension': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'saddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hookup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hero_sandwich': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sectarian': ['anger', 'fear', 'negative'], 'gulping': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'crusted': ['anger', 'negative', 'disgust'], 'create': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bent_grass': ['anticip'], 'own': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'owe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chew_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gurgle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'platoon': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'intention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_married': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breeding': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'cliff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alienated': ['sadness', 'negative'], 'preceptor': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shank': ['anger', 'fear', 'negative'], 'tenement_house': ['negative'], 'challenger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boringness': ['negative'], 'Ted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'point_in_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demonstrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rickety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'first_moment': ['positive', 'anticip'], 'horned_pout': ['anger', 'sadness', 'negative', 'disgust'], 'habiliment': ['positive', 'sadness', 'trust', 'negative'], 'humbling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cherry-red': ['positive'], 'resumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Inachis_io': ['positive'], 'abbot': ['trust'], 'ocean_trip': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'immobilize': ['negative'], 'Mungo_Park': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common_law': ['surprise'], 'get_worse': ['fear', 'sadness', 'negative'], 'supporting_players': ['positive', 'trust'], 'gruffness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'earthly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crowned_head': ['positive', 'trust'], 'comfort_station': ['positive'], 'insipid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'galvanise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'necrosis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'jewel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intentionally': ['surprise', 'negative'], 'foul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despotical': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'forgather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preface': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hit_the_hay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'book_binding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggression': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'increase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parsimoniousness': ['positive', 'trust', 'joy'], 'outwit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_recruit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'albumen': ['anticip', 'positive', 'trust', 'joy'], 'sputter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immature': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'courtmartial': ['trust'], 'theatre_of_operations': ['positive', 'joy'], 'rashly': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'momentaneous': ['surprise'], 'tantalizing': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leisurely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unify': ['positive', 'trust'], 'worshiper': ['trust'], 'disturb': ['sadness', 'negative'], 'basics': ['positive', 'trust'], 'brutish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'philosophical_system': ['trust'], 'specially': ['surprise'], 'temperateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnetic_iron-ore': ['positive'], 'drop_away': ['surprise', 'negative'], 'valiant': ['positive'], 'loathing': ['anger', 'fear', 'negative', 'disgust'], 'relieving': ['positive'], 'thunder': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'schism': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'lowliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resilient': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'payoff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'admiral': ['positive', 'trust'], 'cull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unseemly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwillingness': ['negative'], 'elaborate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knavery': ['negative', 'disgust'], 'criticism': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'exuviate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criticise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'James_Bond': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'off-white': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'prison_guard': ['positive', 'fear', 'trust', 'surprise'], 'spiny_lobster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cocaine': ['sadness', 'negative'], 'eternal_damnation': ['anger', 'fear', 'sadness', 'negative'], 'temporary_expedient': ['surprise'], 'browse': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'faerie': ['positive', 'fear', 'negative'], 'symphony': ['positive', 'anticip', 'joy'], 'strike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Recent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blabbermouth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buncombe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sortie': ['surprise', 'fear', 'negative'], 'obiter_dictum': ['trust'], 'lay_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lord': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'eagre': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'disharmonious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'over-embellished': ['anger', 'negative', 'disgust'], 'pursue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reword': ['positive', 'trust', 'negative'], 'shelve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plunger': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'example': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scavenge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hip_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'currency': ['positive'], 'caution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counseling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enchantress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'labialise': ['fear', 'sadness', 'negative'], 'pigsty': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'feature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'archimandrite': ['trust'], 'dignified': ['positive'], 'fanaticism': ['fear'], 'abstraction': ['negative'], 'cat_sleep': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'grandad': ['trust'], 'animate_being': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'vocalization': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'motortruck': ['trust'], 'unselfish': ['positive'], 'break_loose': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'fictional': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'communistic': ['negative'], 'gouty_arthritis': ['negative'], 'foodstuff': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'line_of_descent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrogation': ['negative'], 'wrought': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'polish_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'textile': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'contuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unforeseen': ['surprise'], 'heretofore': ['negative'], 'drum_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hawthorn': ['fear'], 'put-upon': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'doghouse': ['sadness'], 'slate': ['positive'], 'renunciation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enjoining': ['negative'], 'interrupt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "ship's_bell": ['anger', 'fear', 'negative', 'disgust'], 'volcano': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'series': ['trust', 'anticip'], 'pick_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Teddy_boy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'substantially': ['positive', 'trust'], 'bed_covering': ['positive'], 'numeration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 're': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurance_agent': ['fear', 'trust', 'negative'], 'tricksy': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'foundation': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'Word': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strawman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enormous': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'retrenchment': ['fear', 'negative'], 'rumple': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'gynandromorph': ['surprise', 'negative'], 'speedy': ['surprise', 'positive'], 'tempting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bagful': ['negative', 'disgust'], 'hearsay': ['sadness', 'negative'], 'monetary_fund': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'by-line': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'business_concern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clarity': ['positive'], 'basketball': ['positive', 'anticip', 'joy'], 'exchequer': ['trust'], 'betrothed': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'traumatize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corvette': ['trust'], 'brashness': ['anger', 'positive', 'trust', 'negative'], 'incognizant': ['negative'], 'cordially': ['positive', 'joy'], 'transmittal': ['trust'], 'unplowed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tag_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nirvana': ['anticip', 'positive', 'trust', 'joy'], 'chairwoman': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'natal_day': ['surprise', 'anticip', 'positive', 'joy'], 'crawl': ['fear', 'sadness', 'negative', 'disgust', 'anticip'], 'honest-to-god': ['sadness', 'negative'], 'exudate': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'tree': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'rusty': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'penalization': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'project': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sulfurous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skimmed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willingness': ['positive', 'negative'], 'runner': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'untrained': ['negative'], 'antagonistic': ['anger', 'sadness', 'negative', 'disgust'], 'crop_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'runnel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'James_Usher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'benighted': ['anger', 'sadness', 'fear', 'negative'], 'sterile': ['sadness', 'negative'], 'good_deal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soaked': ['negative'], 'gripe': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'amusing': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'soaker': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'imprudent': ['sadness', 'negative'], 'opinionative': ['anger', 'negative'], 'addict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensualism': ['positive', 'joy', 'anticip'], 'groundbreaker': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'dummy': ['trust', 'negative'], 'powderise': ['fear'], 'camp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'camo': ['surprise', 'anticip'], 'howl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'detriment': ['negative'], 'incorporate': ['fear', 'negative', 'disgust'], 'infrequency': ['surprise', 'negative'], 'participate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lethal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'low_temperature': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'layout': ['sadness'], 'itinerant': ['negative'], 'quaint': ['positive', 'trust', 'joy'], 'maturation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cougar': ['surprise', 'fear'], 'mental_lexicon': ['positive', 'trust'], 'inoperative': ['anger', 'negative'], 'denounce': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pocket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_straitened_circumstances': ['anger', 'positive', 'fear', 'negative'], 'relish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blanched': ['positive'], 'indigen': ['positive'], 'adherence': ['positive'], 'hasten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frigidity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'radium': ['anger', 'surprise', 'fear', 'negative'], 'take_advantage': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radius': ['trust', 'negative'], 'hero': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resigned': ['sadness', 'negative'], 'Edmund_Burke': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'pricking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'itty-bitty': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'pablum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'humankind': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'cubby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skimpy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'souvenir': ['sadness', 'negative'], 'defiance': ['anger', 'fear', 'negative', 'disgust'], 'debt': ['sadness', 'negative'], 'navy_blue': ['trust'], 'Virginia_reel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disdain': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fallacious': ['anger', 'sadness', 'negative', 'disgust'], 'Blessed': ['positive', 'joy'], 'planned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'logic': ['positive', 'trust', 'negative'], 'wipeout': ['negative'], 'argue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leading_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step-in': ['negative'], 'steatocystoma': ['anger', 'negative', 'disgust'], 'extravasate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gleaming': ['surprise', 'anticip', 'positive', 'joy'], 'pregnancy': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'rallying_cry': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'reconsideration': ['positive', 'trust'], 'round_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'advert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'privilege': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'superhuman': ['positive'], 'nonparallel': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'graphical': ['positive', 'joy'], 'sprightliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'longitudinally': ['trust'], 'worker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'snap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'port_wine': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'legal_expert': ['anger', 'positive', 'trust', 'negative'], 'tear_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gritty': ['positive', 'anticip', 'joy'], 'contemn': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'viii': ['anticip', 'positive', 'trust', 'joy'], 'wonted': ['anticip'], 'bin': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'congratulation': ['positive', 'joy'], 'full-bosomed': ['positive', 'anticip', 'joy'], 'distorted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expending': ['negative'], 'elicit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhaust_hood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dementia_praecox': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'frontal_bone': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'commencement_exercise': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'severity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'damages': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mischievousness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'emphatic': ['positive', 'trust'], 'American_Samoa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'titivate': ['positive'], 'haggard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balminess': ['negative'], 'lay_aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divagate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simulated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noesis': ['positive', 'sadness'], 'sheeny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ex_post_facto': ['negative'], 'subdued': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'divination': ['anticip'], 'previous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handshake': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'old-fashioned': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'Carry_Amelia_Moore_Nation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotary_motion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disparity': ['anger', 'sadness', 'negative', 'disgust'], 'obedient': ['anger', 'negative'], 'innocent': ['positive', 'trust'], 'striation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'savoriness': ['positive'], 'intermediation': ['positive'], 'elevation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quirk': ['surprise', 'sadness', 'negative', 'disgust'], 'business_office': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knock-down': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roister': ['anger', 'surprise', 'fear', 'negative'], 'subsidence': ['sadness', 'negative'], 'desire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'specie': ['positive'], 'deviance': ['sadness'], 'get_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'altercate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bacchanalia': ['anger', 'surprise', 'fear', 'negative'], 'creek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'creed': ['positive', 'trust'], 'admission_price': ['positive', 'trust'], 'harassment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'creep': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cultism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blackleg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crank_up': ['anger', 'negative'], 'bring_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polluted': ['fear', 'sadness', 'disgust', 'negative'], 'contributing': ['positive', 'anticip'], 'disheartened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'exposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'periphery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theological': ['trust'], 'palatable': ['positive'], 'transfer_of_training': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitchy': ['positive', 'anticip', 'negative', 'joy'], 'substituted': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger'], 'yoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defensive': ['positive'], 'losing': ['anger', 'sadness', 'negative'], 'memorable': ['surprise', 'trust', 'positive', 'joy'], 'shaken': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'impendent': ['fear', 'anticip'], 'prime_of_life': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'multifariousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Phoxinus_phoxinus': ['negative', 'disgust'], 'fend_off': ['surprise', 'fear', 'sadness', 'negative'], 'soc': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sob': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pricy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'facility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_commission': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'son': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'respectable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sou': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'furnishing': ['positive', 'negative', 'anticip'], 'ADHD': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hospice': ['sadness'], 'support': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constantly': ['positive', 'trust'], 'flatus': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'authorized': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'trappings': ['positive', 'negative', 'anticip'], 'launching': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bedrock': ['positive', 'trust'], 'back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stoolpigeon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fraudulent_scheme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bolster_up': ['positive'], 'misinform': ['anger', 'negative', 'disgust'], 'extremity': ['fear', 'sadness', 'disgust', 'negative'], 'inside': ['positive', 'trust', 'joy'], 'paprika': ['positive'], 'bring_home_the_bacon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redolent': ['negative', 'disgust'], 'leer': ['anger', 'surprise', 'negative', 'disgust'], 'canonize': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'coldsore': ['anger', 'negative', 'disgust'], 'nestling': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'desecrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'film_editing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superfluous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pronounced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mariner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tallness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snooze': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'entrust': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hygienic': ['positive'], 'virtuousness': ['positive', 'trust'], 'conferrer': ['positive', 'fear'], 'pension_off': ['fear', 'negative'], 'necromancy': ['surprise', 'fear', 'negative', 'anticip'], 'liverish': ['positive', 'anticip'], 'strong-growing': ['anger', 'fear', 'negative'], 'activated': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'umbrage': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'disrepute': ['anger', 'negative'], 'pantywaist': ['negative'], 'Robert_Frost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uneven': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'reverting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Last_Judgement': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'persevere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Logos': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'icing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'one_by_one': ['surprise', 'anticip', 'positive'], 'spate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blow_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orifice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Rand': ['negative'], 'peg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pea': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'leave': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'settle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speculation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spiritual': ['fear', 'negative', 'disgust'], 'sigh': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'line_of_business': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'sign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'value-system': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], "apothecary's_shop": ['positive', 'trust'], 'anaconda': ['fear', 'negative', 'disgust'], 'on_the_loose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Thanksgiving_Day': ['positive', 'joy'], "chemist's": ['positive', 'trust'], 'parachuting': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'latch_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sequestrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jeopardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motor_lodge': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'melt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theca': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meld': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'jury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contiguous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'large_number': ['disgust'], 'valuation_reserve': ['positive'], 'dementedness': ['fear', 'sadness', 'negative'], 'torpid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'understanding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnetism': ['positive'], 'dipsomania': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'slide_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'witticism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnetise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'redemption': ['anticip', 'positive', 'trust', 'joy'], 'brilliant': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'uprightness': ['fear'], 'fomenter': ['positive', 'trust'], 'ineffective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmovable': ['positive', 'trust', 'negative'], 'absenteeism': ['negative'], 'socialist_economy': ['fear', 'disgust'], 'logical': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'DOE': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'loquacity': ['negative'], 'fake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quick-wittedness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'flagging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Tennessean': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'bended': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crammed': ['fear', 'sadness', 'negative'], 'back_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'angry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wicket': ['positive'], 'papal': ['trust'], 'barbellate': ['fear', 'negative'], 'bender': ['negative'], 'broken-down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theoretical': ['positive'], 'prosecutor': ['anger', 'fear', 'negative'], 'wicked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afternoon_tea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'getoff': ['surprise', 'fear', 'sadness', 'negative'], 'ignorant': ['surprise', 'negative', 'disgust'], 'virtue': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sanctified': ['positive'], 'pretend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detached': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'record-keeper': ['positive'], 'pile_up': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'awesome': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unanticipated': ['surprise'], 'allowed': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'stole': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'brush_wolf': ['fear'], 'savor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'muscle_spasm': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'encampment': ['positive', 'sadness'], 'hog': ['negative', 'disgust'], 'geometrical_regularity': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'improving': ['positive'], 'natural': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'nomadic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ghostwriter': ['fear', 'negative'], 'opinionated': ['anger', 'negative'], 'pollution': ['negative', 'disgust'], 'drunken': ['negative', 'disgust'], 'innocuous': ['positive', 'trust'], 'privation': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'footstep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'augury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astringent_drug': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'Din_Land': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dapper': ['positive'], 'frivol_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'H.M.S._Bounty': ['anticip', 'positive', 'trust', 'joy'], 'horrify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tendency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splurge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avid': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'aesculapian': ['positive', 'fear', 'trust', 'anticip'], 'overhaul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dual-lane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nymph': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'torn': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tort': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'suspicion': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'apparent_motion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slick_up': ['positive'], 'deliver_the_goods': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hard_cash': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'swastika': ['anger', 'fear', 'negative'], 'limbo': ['anger', 'fear', 'negative'], 'Buck': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Sister': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'exculpation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'nation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amulet': ['positive'], 'unpitying': ['anger', 'fear', 'negative', 'disgust'], 'reckoning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twilight': ['sadness', 'negative', 'disgust'], 'tumid': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'goner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Alexander_Bell': ['anger', 'fear', 'negative', 'disgust'], 'electric_organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'syncopation': ['surprise', 'fear', 'sadness', 'negative'], 'spiritualist': ['anticip', 'positive', 'trust', 'negative', 'surprise'], 'amnesty': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'didactics': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stalling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'square': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'arbitrariness': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'crushing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_water': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'owing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terpsichore': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'neighbourhood': ['anticip'], 'saturnalia': ['anger', 'surprise', 'fear', 'negative'], 'in_vain': ['sadness', 'negative', 'disgust'], 'nominating_address': ['positive'], 'primary_coil': ['positive'], 'astray': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profanation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'crack_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'investigation': ['anticip'], 'intermit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'multiformity': ['positive', 'negative'], 'cissy': ['negative'], 'ascendant': ['positive', 'joy', 'trust', 'negative', 'surprise'], 'dumbfound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eat_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disrespect': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'mime': ['positive', 'negative', 'surprise'], 'matchless': ['positive'], 'bumpy': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'patronage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fraudulent': ['anger', 'sadness', 'negative', 'disgust'], 'waste_pipe': ['negative'], 'enkindle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undesirable': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'change_form': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unloose': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'arithmetic_mean': ['positive', 'anticip'], 'poke_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'open': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ripping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'languish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'city': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operable': ['negative'], 'wrath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convent': ['positive', 'trust'], 'infullswing': ['positive', 'joy', 'trust', 'anticip'], 'bite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shiver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foreclose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cite': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irresistible_impulse': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'illusionist': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'call_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lucent': ['positive'], 'impractical': ['anticip', 'positive', 'trust', 'joy'], 'depressed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'yelping': ['anger', 'surprise', 'fear', 'negative'], 'stammer': ['anger', 'positive', 'fear', 'trust', 'negative'], 'folly': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'corruptible': ['anger', 'sadness', 'negative', 'disgust'], 'typography': ['positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'counselor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'damned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chaplet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'smutch': ['negative'], 'argument': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Jerome_David_Kern': ['negative'], 'buried': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'get_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'downwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dole_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rumination': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'coincide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'blinding': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'to-do': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'compress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'first_derivative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'niggardness': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'crochet': ['negative'], 'energize': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'average': ['surprise', 'trust', 'positive', 'negative', 'anticip'], 'drive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'spill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annihilative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dolor': ['sadness', 'negative'], 'free_will': ['positive', 'sadness', 'trust', 'anticip'], 'liquidity': ['anger', 'joy', 'sadness', 'negative'], 'give_ear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mother_fucker': ['anger', 'negative', 'disgust'], 'merit': ['anger', 'positive', 'joy', 'trust', 'anticip'], 'jactitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opportunism': ['anticip', 'positive', 'trust', 'joy'], 'bright': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'scarce': ['sadness', 'negative', 'fear'], 'big_businessman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parsimony': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_issue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liberation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outrage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excision': ['negative'], 'clank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'explosion': ['anger', 'surprise', 'fear', 'negative'], 'psychiatrist': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'assistant': ['positive', 'trust'], 'freezing': ['negative'], 'clang': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'active_voice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'submerge': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'nonextant': ['sadness', 'negative'], 'bad_blood': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'built_in_bed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resource': ['positive', 'anticip', 'joy'], 'touch-and-go': ['fear', 'anticip', 'sadness', 'negative'], 'saliva': ['anticip'], 'worried': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'priest': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'Ashcan_School': ['anticip', 'positive', 'trust', 'joy'], 'graduation_exercise': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'uncover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resiny': ['positive', 'anticip', 'negative', 'joy'], 'all-fired': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'temperance': ['positive', 'trust'], 'aroused': ['fear', 'negative'], 'nostrum': ['positive'], 'ostensibly': ['negative'], 'fierceness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moldy': ['negative', 'disgust'], 'sable': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dark-brown': ['disgust'], 'pitiless': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'smoothy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'panache': ['anger', 'positive', 'sadness', 'negative', 'fear'], 'vertical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apparition': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'screen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capitalistic': ['positive'], 'recitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concentrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'computer_error': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'oust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puerile': ['negative'], 'pass_over': ['anticip'], 'pas_seul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_action': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vibrating_reed': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'belie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mane': ['positive'], 'calumniate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'riddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_assistance': ['positive', 'trust', 'disgust'], 'good-by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expedition': ['positive', 'anticip'], 'concede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotational_latency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drive_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'needlelike': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrecorded': ['negative'], 'reflex': ['surprise', 'trust'], 'luff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hilarity': ['positive', 'joy'], 'enable': ['positive', 'trust', 'negative'], 'gist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'layperson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'curbing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diffuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'queasy': ['fear', 'negative', 'anticip'], 'profane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'consultant': ['positive', 'trust'], 'pettiness': ['negative'], 'candy_kiss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conveyance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thorniness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bowdlerise': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'spotlight': ['anger', 'fear', 'negative'], 'monochromous': ['negative', 'disgust'], 'purse': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'coexisting': ['positive', 'trust'], 'perpetually': ['trust'], 'denying': ['negative', 'anticip'], 'unionize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'licit': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sterling': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'barbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill_service': ['anger', 'sadness', 'negative', 'disgust'], 'lyssa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recapture': ['positive', 'trust'], 'booster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commemorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cold_shoulder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veau': ['sadness', 'trust'], 'clobber': ['anger', 'fear', 'sadness', 'negative'], 'ringer': ['anger', 'negative'], 'tenancy': ['positive'], 'veal': ['sadness', 'trust'], 'quixotic': ['anticip', 'positive', 'trust', 'joy'], 'poach': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'elysian': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fateful': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unaccepted': ['surprise', 'sadness', 'negative', 'positive'], 'come_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'presumption': ['trust'], 'turned_on': ['fear', 'negative'], 'disputatious': ['anger', 'negative', 'disgust'], 'look_sharp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'esprit': ['positive'], 'usurious': ['negative', 'disgust'], 'starving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crusty': ['anger', 'negative', 'disgust'], 'around': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'venthole': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'dart': ['anger', 'positive', 'fear', 'negative'], 'dark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snarl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'darn': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'purulence': ['negative', 'disgust'], 'vacuum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snarf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bridge_player': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'field_of_study': ['fear', 'negative'], 'duck_soup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malignancy': ['fear', 'sadness', 'negative'], 'allocution': ['anticip'], 'touch_base': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malignance': ['fear', 'sadness', 'negative'], 'inter': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'intestinal': ['disgust'], 'fuck_off': ['anger', 'sadness', 'negative', 'disgust'], 'crabbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asperse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Salmon_P._Chase': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'supplementary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'book_of_instructions': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cannabis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corrosive': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'refer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vacillation': ['fear', 'negative'], 'biased': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'zest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yobbo': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'throwback': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretch_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'package': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legerdemain': ['negative'], 'unseasonable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throw_overboard': ['anger', 'fear', 'sadness', 'negative'], 'chivalry': ['positive'], 'turn_around': ['anger', 'surprise', 'negative', 'disgust'], 'do_work': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'homeless': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'apologize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'portrayal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goliath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hew': ['anger', 'sadness', 'negative'], 'hep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sailplaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispassion': ['positive', 'trust', 'negative', 'disgust'], 'lapsing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fertilise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'espousal': ['anticip', 'positive', 'trust', 'joy'], 'hem': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'hen': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'denotative': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'bristled': ['fear', 'negative'], 'follicular': ['negative'], 'fidgetiness': ['negative', 'anticip'], 'estoppel': ['negative'], 'unreliable': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'fancify': ['positive', 'joy'], 'jerky': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'handsome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sagaciousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'robustness': ['fear', 'negative'], 'impute': ['trust'], 'copyist': ['positive', 'anticip'], 'Lester_Willis_Young': ['positive', 'anticip', 'surprise', 'joy'], 'fright': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fond_regard': ['positive'], 'get_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_and_quarter': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'midwife': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'laboratory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tranquil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appalling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'living_accommodations': ['trust'], 'whit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'try_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'athirst': ['negative', 'anticip'], 'chain_armor': ['anger', 'fear', 'negative', 'anticip'], 'sanguine': ['positive'], 'tight': ['surprise', 'trust', 'positive', 'negative', 'anticip'], 'blood_relative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incomprehensible': ['surprise', 'negative'], 'military_service': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'shop_steward': ['positive', 'trust'], 'snitch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rostrum': ['positive'], 'sobbing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mask': ['surprise', 'negative', 'anticip'], 'clowning': ['surprise', 'negative'], 'mash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parallelism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensibility': ['positive'], 'retch': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'save_up': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'debris': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'welfare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dogged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tinsel': ['positive', 'joy'], 'tail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chewing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'degeneration': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'slack_water': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appointment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bechance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blockade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diary': ['positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plushy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falsifying': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'firebomb': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'chamaeleon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'cable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulsing': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'joined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'large': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'deftness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'harry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'largo': ['positive'], 'Christ_Within': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overspill': ['negative'], 'herpes_virus': ['negative', 'disgust'], 'honourable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrub_up': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'offbeat': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'overcasting': ['negative'], 'cherry_tree': ['positive'], 'sentient': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'empower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lobbyist': ['negative'], 'handgrip': ['positive'], 'legend': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'mental_confusion': ['anger', 'fear', 'negative'], 'overawe': ['fear', 'sadness', 'disgust', 'negative'], 'palpebra': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emulator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peanut': ['anger', 'sadness', 'negative'], 'Cartesian_product': ['positive', 'fear', 'anticip', 'negative', 'joy'], 'give-up_the_ghost': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'waste-yard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sureness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'widowman': ['sadness'], 'casket': ['fear', 'sadness', 'negative'], 'indispose': ['anger', 'negative', 'disgust'], 'good-tempered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pearl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sitter': ['trust'], 'gorgeous': ['positive', 'joy'], 'high-handedness': ['negative'], 'lee_side': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'ballad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'befitting': ['positive'], 'meatman': ['anger', 'fear', 'negative', 'disgust'], 'batsman': ['anger', 'fear', 'sadness', 'negative'], 'pay_heed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eatable': ['positive', 'trust'], 'sizing': ['trust', 'negative'], 'fleece': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'endpoint': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'Panthera_leo': ['anger', 'positive', 'fear', 'disgust'], 'inductive_reasoning': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'genus_Cancer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'land_mile': ['surprise', 'negative', 'trust', 'positive', 'joy'], 'ingredient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prompt': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'life-threatening': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'scan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manduction': ['positive', 'trust', 'joy'], 'scab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbiased': ['positive', 'sadness', 'negative'], 'scar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imminent': ['fear', 'anticip'], 'glowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cajole': ['trust'], 'pinnace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaticinator': ['positive', 'trust', 'anticip'], 'unsound': ['surprise', 'fear', 'negative'], 'waver': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'ethics': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'authentic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'identity_element': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'register': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rest_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fundamental': ['positive', 'trust'], 'unfirm': ['fear'], 'dig_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'worldly_concern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mousse': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'distortion': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'brim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divagation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quagmire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brig': ['joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'wet-nurse': ['positive', 'trust', 'joy'], 'queerness': ['surprise', 'sadness', 'negative', 'disgust'], 'mummer': ['positive'], 'Helen_Wills_Moody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have-to_doe_with': ['trust'], 'conjugation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'interiority': ['positive'], 'fellow_traveller': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'zippo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scriber': ['positive', 'anticip'], 'subtlety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'wry': ['positive', 'trust', 'negative'], 'blueing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sucker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abrasion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unconditioned_reflex': ['surprise', 'trust'], 'diplomatical': ['positive', 'trust'], 'speculate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hereafter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nauseous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'work_party': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clear_the_throat': ['fear'], 'found': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolute': ['positive'], 'reduce': ['negative'], 'slowdown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'measurement': ['positive', 'trust'], 'thunderbolt': ['negative'], 'lose_weight': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'moon_on': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'salute': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bungler': ['negative'], 'belief': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demure': ['surprise', 'fear'], 'John_Ford': ['positive'], 'qualify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clique': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contingence': ['fear', 'negative', 'anticip'], 'lingual': ['positive'], 'tree_diagram': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'sicken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'Fatherhood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cyanide': ['fear', 'negative'], 'canescent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'contingency': ['fear', 'negative', 'anticip'], 'black_eye': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'engagement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rooted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'god-awful': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'belligerent': ['anger', 'fear', 'negative'], 'feeder': ['positive'], 'Reverend': ['positive', 'joy'], 'rooter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'Bruce_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'halfway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glitter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inapplicable': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'leverage': ['anticip', 'positive', 'trust', 'joy'], 'jet': ['joy', 'negative', 'disgust'], 'introduction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'litany': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'docking_facility': ['negative'], 'codswallop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elaboration': ['anger', 'positive', 'negative'], 'warmly': ['positive', 'joy'], 'satirical': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'chomp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'reverential': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'boom_out': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pop_the_question': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taxis': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provenience': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'residence_hall': ['anger', 'fear', 'negative'], 'teensy': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'field_of_battle': ['fear', 'negative'], 'suffocating': ['sadness', 'negative', 'disgust', 'fear'], 'beforehand': ['surprise', 'fear', 'anticip', 'positive', 'joy'], 'defect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apery': ['surprise', 'negative'], 'pedestrian': ['negative'], 'caress': ['positive'], 'jeopardize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commotion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reliance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'internal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'frail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curse_word': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sevens': ['trust'], 'wedded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'martyrize': ['fear', 'sadness', 'negative'], 'institutionalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tuna_fish': ['positive', 'sadness', 'negative'], 'actionable': ['anger', 'negative', 'disgust'], 'look_up': ['trust'], 'diversionary_attack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deceitfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'chowder': ['positive'], 'gold': ['positive'], 'bald-headed': ['sadness', 'negative'], 'lengthwise': ['trust'], 'evaporation': ['positive'], 'statecraft': ['positive', 'trust', 'anticip'], 'freight': ['anger', 'sadness', 'negative', 'fear'], 'retrovert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'degraded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ho-hum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'writer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falling_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rout_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorrowing': ['anger', 'sadness', 'negative', 'fear'], 'Confederate': ['positive', 'trust'], 'hush-hush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordained': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'closing_off': ['sadness', 'negative'], 'downpour': ['surprise', 'fear', 'sadness', 'negative'], 'banned': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'peril': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'banner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enemy': ['anger', 'fear', 'negative', 'disgust'], 'progressive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrifically': ['positive', 'joy'], 'go_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enema': ['disgust'], 'outlaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpick': ['positive', 'joy', 'trust', 'anticip'], 'jade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'startup': ['anticip', 'positive', 'trust', 'joy'], 'potent': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backfire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ballock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill-treatment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'spirits': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pickup': ['fear'], 'viciousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beatify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compliment': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'endure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'knowing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'state_of_war': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'candor': ['positive', 'trust', 'negative', 'disgust'], 'metal_drum': ['sadness', 'negative'], 'premises': ['positive'], 'incident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tramp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diminution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dividend': ['anticip', 'positive', 'trust', 'joy'], 'legislature': ['trust'], 'cryptic': ['positive', 'trust'], 'tangible': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'straighten_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intercept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Saint_Bride': ['anticip', 'positive', 'trust', 'joy'], 'football_game': ['positive', 'anticip', 'joy'], 'loudmouth': ['negative'], 'allegiance': ['positive', 'trust'], 'US_Senate': ['trust'], 'frosty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'church': ['anticip', 'positive', 'trust', 'joy'], 'intestate': ['negative'], 'mewl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chew_the_fat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instalment': ['positive', 'joy'], 'young_carnivore': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'mercantilism': ['trust'], 'champion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reticence': ['negative'], 'representative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'deport': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'formless': ['negative'], 'hardness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inclement': ['negative'], 'uncertain': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'joyfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straight': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'computer_address': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'error': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Miss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'douche_bag': ['negative'], 'comport': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'occlusive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solemnisation': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'investment_trust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Viola': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'fetching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diametrical': ['surprise'], 'pouffe': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'premonition': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forgiveness': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'special_K': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mortifying': ['positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comprehensive': ['positive'], 'upbringing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rabid': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'necessity': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'fabrication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annunciation': ['anticip'], 'purebred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expend': ['negative'], 'surrogate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'glasshouse': ['positive', 'trust', 'joy'], 'Son': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feces': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glitz': ['anger', 'negative'], 'correlativity': ['positive'], 'befuddled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Labor': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'Amytal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'small-arm': ['anger', 'fear', 'negative'], 'run_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dastard': ['anger', 'fear', 'negative', 'disgust'], 'admission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aloha': ['positive', 'anticip', 'joy'], 'sail_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'health_spa': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrongdoer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'herculean': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liqueur': ['positive', 'anticip', 'negative', 'joy'], 'harvesting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hokey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gismo': ['positive'], 'shitty': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'suffering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blackjack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formal': ['positive', 'trust'], 'sorting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cut_back': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'extravagance': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'continue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scape': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'squanderer': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'clipping': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'senate': ['trust'], 'spring': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'beckon': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'felonious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'palm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pall': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'curious': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'sprint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Friend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'data_link': ['sadness', 'trust', 'negative'], 'masculinity': ['positive'], 'memory_loss': ['negative'], 'odor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sanguineous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'carol': ['positive', 'trust', 'joy'], 'carom': ['anger', 'fear', 'negative'], 'unintentional': ['surprise', 'negative'], 'holy_terror': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verifying': ['trust'], 'posse_comitatus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pop_music': ['positive', 'sadness', 'negative', 'disgust', 'surprise'], 'parcel_of_land': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'unnerving': ['fear'], 'poaching': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'legal_profession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'striver': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'litigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'graciously': ['positive'], 'poster': ['surprise'], 'oils': ['negative'], 'slump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Holocaust': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'undeserving': ['anger', 'sadness', 'negative', 'disgust'], 'alabastrine': ['positive'], 'overrefinement': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'up': ['positive'], 'lesbianism': ['negative'], 'storing': ['positive'], 'genial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guck': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'graspable': ['negative'], 'sharp-sightedness': ['surprise', 'fear', 'anticip', 'positive'], 'consignee': ['trust'], 'snaffle': ['anger', 'fear', 'negative'], 'first_light': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nautical': ['trust'], 'encrustation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'United_States_Constitution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'school_term': ['anger', 'fear', 'negative', 'disgust'], 'stiffly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smidge': ['positive'], 'retrace': ['positive', 'anticip'], 'cosmic_string': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retract': ['anger', 'negative'], 'freighter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'deviate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorcerer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scapegoat': ['anger', 'fear', 'negative'], 'trouser': ['positive', 'fear', 'trust', 'negative', 'surprise'], 'besiege': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'lucid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prosecution': ['negative', 'disgust'], 'weather_sheet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sphacelus': ['fear', 'anticip', 'sadness', 'disgust', 'negative'], 'holey': ['negative'], 'olfactory_perception': ['anticip', 'positive', 'negative', 'sadness', 'fear', 'trust'], 'crinkle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retardation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fresh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sharp-set': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_a_crap': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'scratch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knotted': ['negative'], 'soften': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enjoyable': ['positive', 'joy'], 'fuzee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'impanel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moorland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'young': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'matinee_idol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yaup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'separationist': ['anger', 'negative', 'disgust'], 'cable_television_service': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'twee': ['anger', 'positive', 'trust', 'negative'], 'written_report': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vade_mecum': ['trust'], 'precinct': ['negative'], 'wipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'stodgy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transmission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'racy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'try': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'race': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trite': ['trust', 'anticip'], 'devaluate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anticipative': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'shrimpy': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'military_posture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'licensed': ['positive', 'trust'], 'imply': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'contributive': ['positive', 'anticip'], 'correspond': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leakage': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aboveboard': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'expressed': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'silverish': ['surprise', 'negative', 'positive'], 'aground': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Reed': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'oration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Reef': ['negative'], 'resident_physician': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'coagulum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'punch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laddie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puckish': ['negative'], 'poverty': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'licence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'casing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'technical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shuffling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'screech': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engrossment': ['anger', 'positive', 'fear', 'trust', 'negative'], 'dyad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buxom': ['positive', 'anticip', 'joy'], 'extirpate': ['fear', 'sadness', 'negative'], 'runabout': ['positive', 'trust', 'joy'], 'base_runner': ['positive'], 'speechmaker': ['trust'], 'panic-struck': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'irrepressible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'forefathers': ['positive', 'trust', 'joy'], 'shipwreck': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'give_way': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'criminal_offense': ['anger', 'negative'], 'unplug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rubbish': ['negative', 'disgust'], 'pain_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well_over': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'challenge': ['anger', 'fear', 'negative'], 'Margaret_Court': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cherubic': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'coffin': ['fear', 'sadness', 'negative'], 'pawl': ['positive', 'trust'], 'pawn': ['positive', 'trust', 'negative', 'disgust'], 'slim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'full_general': ['positive', 'trust'], 'spruce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slip': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pelvis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'interest_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aristocratical': ['positive', 'sadness', 'fear', 'negative'], 'come_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bedaze': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fits': ['anger', 'negative'], 'marrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'hawk': ['fear'], 'solidarity': ['trust'], 'misappropriation': ['negative'], 'nanny-goat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counter': ['anticip', 'surprise', 'trust', 'positive'], 'element': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'writ': ['positive', 'trust'], 'nuclear_meltdown': ['sadness', 'negative'], 'ingress': ['anger', 'positive', 'fear', 'trust', 'negative'], 'kittenish': ['surprise', 'anticip', 'positive', 'joy'], 'state_of_grace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'marked-up': ['negative', 'disgust'], 'move': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thrall': ['fear', 'sadness', 'negative'], 'freedom_fighter': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'coffee_shop': ['positive'], 'decay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chosen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'dispose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperfection': ['negative'], 'misapprehension': ['anger', 'sadness', 'negative'], 'lustrelessness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affectedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high_society': ['positive', 'fear', 'negative', 'anticip'], 'solacement': ['positive'], 'launder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dock': ['negative'], 'obscureness': ['fear', 'negative'], 'legendary': ['positive'], 'Stephen_Collins_Foster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rotation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrangler': ['negative'], 'display_panel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'truth': ['positive', 'trust'], 'imbibe': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'true_statement': ['positive', 'trust'], 'star_sign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sportsman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chin_wagging': ['positive', 'fear', 'joy', 'negative', 'anticip'], 'castigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irritation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'meth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'borderline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismissal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'autochthonous': ['fear', 'sadness', 'disgust', 'negative'], 'unreciprocated': ['sadness', 'negative'], 'superbly': ['positive', 'joy'], 'hilarious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'differential_coefficient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'graze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regulatory': ['fear', 'negative'], 'jowl': ['fear', 'negative', 'disgust'], 'rowdiness': ['anger', 'fear', 'sadness', 'negative'], 'morbidness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'data_point': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'serenity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ham_it_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hackamore': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sexually_transmitted_disease': ['negative'], 'loo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thus_far': ['negative'], 'hertz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waterspout': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'opportune': ['positive', 'joy'], 'deceptive': ['anger', 'negative', 'disgust'], 'system': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'expediency': ['anticip', 'positive', 'trust', 'joy'], 'crappy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'inalienable': ['positive'], 'lacing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gummy': ['disgust'], 'aerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chagrin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'depressing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'burlesque': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'vouch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accompaniment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unexpended': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'retraction': ['negative'], 'inhumaneness': ['sadness', 'negative'], 'warfare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beseem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggressor': ['anger', 'fear', 'sadness', 'negative'], 'reproduction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crab_louse': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'pertussis': ['negative'], 'devotion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marriage_broker': ['anticip'], 'rank_and_file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Angle': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'beggar': ['sadness', 'negative'], 'inclemency': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'reassuring': ['positive', 'joy', 'trust', 'anticip'], 'gentle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defending': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_into_place': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postulational': ['trust'], 'elevated_railroad': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'boxful': ['anger'], 'awed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rarefy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pie-eyed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lily': ['positive'], 'smuggling': ['negative'], 'accuracy': ['positive', 'trust'], 'courtesy': ['positive'], 'olfactory_modality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'segment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'addiction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jocularity': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'hypocrite': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'socialistic': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'chalk_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'locust': ['fear', 'negative'], 'face': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tranquillise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'painting': ['positive', 'joy'], 'fact': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'incarcerate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'characterisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tubercle': ['positive', 'trust'], 'economise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'briny': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'bring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brine': ['surprise', 'trust', 'positive', 'joy'], 'write_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'principal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disillusion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burnished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conciliate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soak_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ram_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'wretchedness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'indecisiveness': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'suaveness': ['positive'], 'handle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distressful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bonds': ['negative'], 'impinging': ['positive'], 'muttering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impeachment': ['negative'], 'generalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'listener': ['fear', 'trust'], 'go_back': ['anticip'], 'defenseless': ['fear', 'sadness', 'negative'], 'shaping': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smash': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sanely': ['positive'], 'victuals': ['positive'], 'summon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'default': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'allegation': ['anger', 'negative'], 'unfeasible': ['negative'], 'packer': ['sadness', 'negative'], 'young_woman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sousing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'packet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morning_time': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'austereness': ['anger', 'fear', 'sadness', 'negative'], 'linguist': ['positive', 'trust'], 'CRO': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'innovator': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'mien': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperative_form': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'synod': ['positive', 'trust'], 'couturier': ['positive'], 'distressingly': ['sadness', 'negative'], 'taunting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'felony': ['negative'], 'f_number': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pistol': ['negative'], 'disgruntled': ['anger', 'sadness', 'negative', 'disgust'], 'aureole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'configuration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absentee': ['sadness', 'negative'], 'observable': ['positive', 'trust'], 'gross_profit': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'galore': ['positive'], 'ball_field': ['positive', 'joy'], 'dead_end': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'honest-to-goodness': ['positive', 'sadness', 'trust', 'negative'], 'Scribe': ['positive', 'anticip'], 'ticktock': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'conflagration': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mean_value': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'distil': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'reproductive_memory': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'incitive': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'accursed': ['anger', 'fear', 'sadness', 'negative'], 'outsider': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pettifoggery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steadiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prevision': ['anticip'], 'Eruca_sativa': ['anger'], 'cruddy': ['negative', 'disgust'], 'sour_grass': ['negative'], 'nobleness': ['positive', 'trust', 'anticip'], 'mannequin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inductance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'runway': ['anger', 'sadness', 'negative', 'disgust', 'anticip'], 'bathtub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'groin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turning_away': ['fear', 'negative'], 'immobilise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'music_director': ['positive', 'trust'], 'insanely': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counterweight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cattle_farm': ['positive'], 'sherlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'adultery': ['sadness', 'negative', 'disgust'], 'tenor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lunatic': ['anger', 'fear', 'negative', 'disgust'], "banker's_acceptance": ['positive', 'trust'], 'lengthening': ['negative', 'anticip'], 'outbreak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infinity': ['positive', 'joy', 'trust', 'anticip'], 'nerve-wracking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drink': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'emeer': ['positive'], 'infinite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fascinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mention': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drawing': ['anticip'], 'enunciation': ['positive', 'trust', 'negative', 'anticip'], 'de-escalate': ['negative'], 'flesh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rooms': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'commemoration': ['positive', 'sadness', 'anticip', 'joy'], 'move_up': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'roomy': ['positive'], 'Brigid': ['anticip', 'positive', 'trust', 'joy'], 'extempore': ['negative'], 'Book_of_Job': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flight_of_stairs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'housework': ['positive'], 'spinner': ['fear', 'sadness', 'negative'], 'laying_claim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exempt': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'irresponsible': ['negative'], 'government': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'inundation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hosepipe': ['positive'], 'unbalance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'supervise': ['positive', 'fear', 'trust'], 'whopping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_figure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprotected': ['negative'], 'strategian': ['positive', 'trust', 'anticip'], 'imprison': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'nerves': ['fear'], 'inexperienced': ['positive', 'trust', 'negative', 'joy'], 'therapeutic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rolling_wave': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daylight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trump_out': ['surprise', 'fear', 'trust', 'negative', 'positive'], 'archeological_site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bedding': ['positive', 'negative', 'disgust', 'joy'], 'entireness': ['positive', 'trust'], 'comestible': ['positive', 'trust'], 'letters_patent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'microscope_stage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voluptuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenability': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'cumber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tire_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_stock': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'adversary': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'iris': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bewilder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirl_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'podium': ['positive'], 'merited': ['anger', 'positive', 'joy', 'trust', 'anticip'], 'slayer': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'common_sense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'territorial_dominion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'centrist': ['positive'], 'rectify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forward_motion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belt_along': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'assess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sonant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Labour': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'lung': ['anger'], 'solar_day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'higher_rank': ['positive', 'trust'], 'kooky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impeding': ['anger', 'negative'], 'convergency': ['anticip'], 'complacency': ['positive'], 'titillating': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'trust'], 'whitlow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convergence': ['anticip'], 'complacence': ['positive'], 'valuation': ['surprise', 'trust'], 'disbursement': ['negative'], 'marquis': ['positive'], 'nail_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'triumphant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convince': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distribution': ['negative'], 'baptism': ['positive', 'joy'], 'appraise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beating-reed_instrument': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'heterotaxy': ['trust', 'negative'], 'rightly': ['positive'], 'contribute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rubble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'sibling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'inn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissimulator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'gun_for_hire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'renowned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'law_of_similarity': ['positive'], 'predominant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oviform': ['positive', 'sadness', 'negative', 'anticip'], 'reckless': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'literary_argument': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victimise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vignette': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scintillate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coloration': ['sadness', 'negative', 'disgust'], 'ghost': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'reflex_action': ['surprise'], 'mushroom_cloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'confinement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unspeakable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ciao': ['positive', 'anticip', 'joy'], 'desirable': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'controversial': ['anger', 'negative'], 'mansion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defraud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'methamphetamine_hydrochloride': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'beauty_parlour': ['anger'], 'calendar_method': ['positive', 'surprise', 'joy'], 'spew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excoriate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'psychometric_test': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tickle': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'expatiate': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'bike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'play_a_trick_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'political_economy': ['positive', 'trust'], 'dapple': ['sadness', 'negative'], 'chill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ash_tree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rainproof': ['positive'], 'offhanded': ['negative'], 'schmalzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'productiveness': ['positive'], 'inhalation': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'traitorousness': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'begrudge': ['anger', 'positive', 'trust', 'negative', 'joy'], 'waterlogged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'back_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'room_decorator': ['positive', 'trust'], 'immoveable': ['positive', 'trust', 'negative'], 'flowage': ['fear'], 'unrest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pinch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nigger': ['negative'], 'savourless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'triumph': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'chew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decadency': ['anger', 'sadness', 'negative', 'disgust'], 'speck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blasphemy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'bubbling': ['anger', 'negative'], 'in_advance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horn': ['surprise', 'fear', 'trust', 'negative', 'positive'], 'approximation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenderise': ['positive', 'trust', 'joy'], 'blaspheme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subaltern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decadence': ['anger', 'sadness', 'negative', 'disgust'], 'meekly': ['positive'], 'deliberate': ['positive', 'trust', 'negative'], 'revolutionize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consequent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scissor_grip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discase': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'crunch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'festive': ['positive', 'joy'], 'revels': ['positive', 'joy'], 'kindred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conglomerate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'anarchism': ['anger', 'fear', 'negative'], 'daughter': ['positive', 'joy'], 'bird_louse': ['surprise', 'anticip', 'negative', 'disgust', 'positive'], 'taken_for_granted': ['trust'], 'conjunctive': ['positive', 'trust'], 'eccentric_person': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'anarchist': ['anger', 'fear', 'negative'], 'maunder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doleful': ['anger', 'sadness', 'negative', 'fear'], 'glittering': ['positive', 'joy'], 'funeral_director': ['sadness'], 'envious': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'infield': ['positive', 'joy'], 'arsenous_anhydride': ['fear', 'sadness', 'disgust', 'negative'], 'unretentive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firing_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subversiveness': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Inferno': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'total': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'herbaceous_plant': ['positive'], 'gloss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negative': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Keystone_State': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memoranda': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'plagiarize': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'infusion': ['positive'], 'award': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aware': ['positive'], 'gymnastic_horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'runniness': ['anger', 'joy', 'sadness', 'negative'], 'public_mover': ['positive'], 'ineptness': ['fear', 'sadness', 'disgust', 'negative'], 'stop_dead': ['negative'], 'player': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transparence': ['positive'], 'transparency': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'applaudable': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'spicery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transferral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hang_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swordplay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acrobatic': ['positive'], 'farce': ['fear', 'sadness', 'disgust', 'negative'], 'agony': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'specter': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'methanol': ['negative'], 'hitman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rookie': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'hostler': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'operatic': ['negative'], 'beach': ['joy'], 'gamble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'journeying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fever': ['fear', 'negative'], 'publiciser': ['negative'], 'movable': ['positive', 'trust', 'negative'], 'hunt_club': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foresightfulness': ['positive', 'trust', 'anticip'], 'coloured': ['positive', 'sadness', 'negative', 'disgust'], 'computer_architecture': ['trust'], 'austere': ['sadness', 'fear', 'negative'], 'hasty': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'facilitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'encompassing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'break_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'modesty': ['positive'], 'decide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postal_code': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'point_of_view': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bombing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'decompose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workable': ['negative'], 'savory': ['positive', 'negative'], 'bitchiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harmony': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'versus': ['anger', 'negative'], 'bane': ['anger', 'fear', 'negative', 'disgust'], 'band': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bang': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'payback': ['anger', 'fear', 'sadness', 'negative'], 'bank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crock': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'spigot': ['anger', 'surprise', 'sadness', 'negative'], 'tampering': ['negative'], 'slavery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rocks': ['negative'], 'properness': ['negative'], 'crystalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mangled': ['positive', 'negative', 'anger', 'surprise', 'fear', 'trust'], 'logy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loge': ['anger'], 'blood_kinship': ['trust'], 'Eumenides': ['anger', 'fear', 'sadness', 'negative'], 'hooked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remorse': ['sadness', 'negative'], 'medicine': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'hooker': ['positive', 'negative'], 'bedevilment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veto': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'standard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'throbbing': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'morass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oriental_alabaster': ['positive'], 'homocentric': ['positive'], 'September': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upthrow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'caprice': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'in_the_lead': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'regress': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'fermentation_alcohol': ['negative'], 'keep_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meshed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Bridget': ['anticip', 'positive', 'trust', 'joy'], 'larboard': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'guzzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dependableness': ['positive', 'trust'], 'delicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'navigator': ['trust', 'anticip'], 'grocery_store': ['positive'], 'subnormality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'closed_in': ['trust', 'anticip'], 'youthfulness': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'snags': ['negative'], 'farming': ['positive', 'trust'], 'filibuster': ['negative'], 'Calluna_vulgaris': ['negative'], 'grandchildren': ['positive', 'joy', 'trust', 'anticip'], 'happily': ['positive', 'joy'], 'Gent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diversified': ['positive'], 'regurgitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prolificacy': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'military_expedition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intrusion': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'subterraneous': ['negative'], 'minus': ['anger', 'sadness', 'negative'], 'carte_du_jour': ['negative'], 'effectuate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'navigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Casimir_Funk': ['sadness', 'negative', 'disgust', 'fear'], 'stalls': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'retributory': ['anger', 'negative'], 'high-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'realm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'necktie': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'laden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bonne': ['positive'], 'luxury': ['positive', 'joy'], 'transmit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snowflake': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'quieten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weeding': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'maiden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'timidity': ['fear', 'negative', 'anticip'], 'knock_rummy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anatomy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chalk_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'autopsy': ['fear', 'sadness', 'disgust', 'negative'], 'mess_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calculated': ['positive'], 'indorsement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough_water': ['anger', 'fear', 'negative'], 'demoralized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'intensity_level': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'profundity': ['positive', 'trust'], 'voting': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'Monitor': ['positive', 'fear', 'trust'], 'doped': ['sadness'], 'flagstone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dopey': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'co-occur': ['surprise'], 'foraging': ['negative'], 'painfully': ['sadness', 'negative'], 'implementation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'layman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'adequate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'achromatic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commonplace': ['trust', 'anticip'], 'electrical_fuse': ['positive', 'sadness', 'trust', 'negative'], 'day-by-day': ['anticip'], 'leisure': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'exulting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nasty': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'headlong': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'cleanly': ['positive'], 'covering': ['fear', 'sadness', 'negative', 'disgust'], 'architectural_plan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tell_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dialog_box': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ictus': ['fear'], 'wannabe': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'gaud': ['positive', 'surprise'], 'miserably': ['sadness', 'negative'], 'line_of_gab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chemical_decomposition_reaction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Foster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'damnation': ['anger', 'fear', 'sadness', 'negative'], 'miserable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tax_return': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afloat': ['fear', 'sadness', 'negative', 'anticip'], 'compensation': ['positive'], 'unable': ['sadness', 'negative', 'disgust'], 'wienerwurst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contraband': ['anger', 'fear', 'negative', 'disgust'], 'financial_obligation': ['positive', 'trust'], 'terms': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blossom_out': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'remedial': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'simmer_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overestimated': ['negative'], 'nonage': ['negative'], 'brat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bray': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'femme_fatale': ['fear', 'negative'], 'vegetable_marrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'ignition_lock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firmness_of_purpose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bran': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'supplementation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'freakish': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'dawdler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seizure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frenetic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhappily': ['sadness', 'negative', 'disgust'], 'slaveholding': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'first-come-first-serve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'passionateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accentuate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'acuity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jabbering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prima_donna': ['positive', 'fear', 'negative', 'surprise'], 'spellbind': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'juridic': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'chicanery': ['surprise', 'trust', 'negative', 'anticip'], 'ait': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'air': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'applier': ['anticip'], 'aid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'property': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cathartic': ['positive'], 'plateful': ['negative'], 'coconspirator': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'transparentness': ['positive'], 'suffocative': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'uplift': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'perform': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inaugural_address': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'authorise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incorrectly': ['negative'], 'mist_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unconcern': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'decedent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweet-talk': ['trust'], 'working_man': ['positive', 'trust', 'negative'], 'concretion': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'prescribed': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'fat_person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'episodic': ['negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'possibly': ['surprise'], 'shakiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contact': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'stringent': ['negative'], 'kale': ['positive'], 'athletic': ['positive'], 'photo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhumation': ['anger', 'sadness', 'negative', 'fear'], 'gravity': ['positive', 'trust', 'negative', 'disgust'], 'restitute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cervix': ['negative'], 'exalt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tea_cozy': ['positive', 'trust', 'negative'], 'board': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free-and-easy': ['negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'viking': ['anger', 'fear', 'negative', 'disgust'], 'birth_control_pill': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'scrimpy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'troika': ['positive'], 'unification': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tuition_fee': ['positive', 'trust'], 'retreat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jornada': ['negative'], 'disinclination': ['fear', 'negative'], 'isotropy': ['anticip', 'positive', 'trust', 'disgust', 'joy'], 'augur': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'clamant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scorbutus': ['negative', 'disgust'], 'porthole': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'indistinguishability': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'mental_rejection': ['negative', 'disgust'], 'noxious': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'indoctrination': ['anger', 'fear', 'negative'], 'denied': ['sadness', 'negative'], 'beating': ['anger', 'fear', 'sadness', 'negative'], 'hare': ['anticip', 'positive', 'trust', 'joy'], 'deflation': ['fear', 'negative'], 'pose': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'confer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illustration': ['positive', 'trust'], 'Alexander_Pope': ['positive', 'trust'], 'posy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taker': ['positive', 'sadness', 'trust'], 'post': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caprine_animal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chafe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chaff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rallying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obi': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'typeface': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comminate': ['anger', 'fear', 'sadness', 'negative'], 'octopus': ['disgust'], 'ruefulness': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'float': ['positive', 'fear', 'anticip', 'sadness', 'negative'], 'bound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gearing': ['positive'], 'wan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'C.O.D.': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'wag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'presumptuousness': ['trust'], 'olfactory_property': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'way': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'war': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ball_of_fire': ['positive'], 'logical_thinking': ['positive'], 'becoming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'converse': ['positive'], 'forgetful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legal_instrument': ['positive', 'trust', 'negative'], 'anaesthetic': ['sadness', 'negative'], 'true': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'absent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'nursemaid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emir': ['positive'], 'emit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'digression': ['sadness'], 'computing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stooge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muscular': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blank_space': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incursion': ['fear', 'negative'], 'Mandarin_Chinese': ['positive', 'trust'], 'food_waste': ['negative', 'disgust'], 'frolic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operating_instructions': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hero-worship': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'extravasation': ['anger', 'surprise', 'fear', 'negative'], 'truncate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bus_topology': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'welcome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Koran': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seeable': ['trust'], 'supervisory_program': ['positive', 'trust'], 'snake_in_the_grass': ['fear', 'negative', 'disgust'], 'pouch': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'radioactivity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'sloughy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demoralising': ['sadness', 'negative'], 'precedent': ['surprise'], 'distinctive_feature': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'ethyl_ether': ['anger', 'fear', 'sadness', 'negative'], 'debauch': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'consul': ['trust'], 'unmixed': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'grateful': ['anger', 'positive', 'negative', 'disgust', 'joy'], 'witty': ['positive', 'joy'], 'certainly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrinkage': ['anger', 'negative', 'disgust'], 'compensate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhythm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tusk': ['surprise', 'fear', 'negative'], 'division': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_vibrant_sounds': ['positive', 'trust', 'joy'], 'pressure_group': ['negative'], 'gauche': ['negative'], 'sunbathe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kitten': ['positive', 'trust', 'joy'], 'crustlike': ['negative', 'disgust'], 'discrete': ['fear', 'anticip', 'sadness', 'negative'], 'wise_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'full-grown': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'affiliation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grump': ['anger', 'negative'], 'scarcity': ['anger', 'fear', 'sadness', 'negative'], 'helpless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Edward_Thatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contract_bridge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emetic': ['negative', 'disgust'], 'emersion': ['positive', 'negative'], 'cargo': ['anger', 'sadness', 'negative', 'fear'], 'curse': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'floating-point_operation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'havoc': ['anger', 'fear', 'negative'], 'uniform': ['positive'], 'curst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sequential': ['trust', 'anticip'], 'appeal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frothing': ['anger', 'negative'], 'disclaim': ['anger', 'trust', 'negative', 'disgust'], 'fractious': ['negative'], 'roaring': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'exemption': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'pictorial': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'worthful': ['positive'], 'pulley_block': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'paragon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gesticulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stingy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divine_guidance': ['trust', 'positive', 'anticip', 'surprise', 'joy'], 'prove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aborigine': ['positive'], 'chilliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meliorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Anguilla_sucklandii': ['positive', 'sadness', 'negative'], 'impureness': ['negative', 'disgust'], 'repentance': ['fear', 'sadness'], 'commissioned': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immediate_payment': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'imperturbability': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'crawl_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'violent_storm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'graphic': ['positive', 'joy'], 'naughtiness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'indescribable': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'can': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cam': ['anger', 'surprise', 'fear', 'negative'], 'cab': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saddlery': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'attribute': ['trust'], 'topic': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'full_phase_of_the_moon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'clothing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restitution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwavering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redundancy': ['positive', 'sadness', 'anticip', 'negative', 'joy'], 'fuming': ['anger', 'negative'], 'prexy': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'flank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'raptus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tarradiddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'CAD': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dominance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redundance': ['positive', 'sadness', 'anticip', 'negative', 'joy'], 'oscitance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'shoplift': ['anger', 'negative', 'disgust'], 'countermand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motorway': ['fear'], 'oscitancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'coagulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prophylactic_device': ['negative'], 'jerked_meat': ['anger', 'surprise', 'fear', 'negative', 'positive'], 'psychoneurotic': ['fear', 'negative', 'disgust'], 'priestly': ['positive'], 'stymie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throttle_valve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crumple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misapplication': ['negative'], 'bewitching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'playful': ['anger', 'surprise', 'trust', 'positive', 'joy'], 'statistical': ['trust'], 'vocation': ['anger', 'positive', 'trust', 'negative', 'anticip'], 'culmination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjunct': ['positive', 'trust'], 'willow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vicinity': ['anticip'], 'disguise': ['surprise', 'anticip'], 'well_timed': ['positive', 'negative'], 'chattering': ['positive'], 'rake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fuzzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pruner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denominational': ['anger', 'fear', 'negative'], 'lineage': ['positive', 'surprise'], 'internal_representation': ['sadness', 'negative'], 'bawdry': ['negative'], 'intriguer': ['positive'], 'psychoneurosis': ['fear', 'sadness', 'negative'], 'kern': ['negative'], 'tell_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pull_ahead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furtive': ['surprise', 'fear', 'negative', 'anticip'], 'Milk': ['positive', 'trust'], 'domain': ['fear', 'negative'], 'hurried': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'happen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'benefaction': ['positive', 'trust', 'joy'], 'bauble': ['positive', 'surprise'], 'amusement': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'irons': ['negative'], 'irony': ['anger', 'sadness', 'negative', 'disgust'], 'heraldic_bearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'looking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Vanessa_Bell': ['anger', 'fear', 'negative', 'disgust'], 'rational': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'housemaid': ['positive', 'trust', 'joy'], 'ruinous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'volute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scandalize': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'thong': ['anger', 'surprise', 'fear', 'negative'], 'carp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cark': ['anger', 'negative', 'anticip'], 'alluvion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repurchase': ['positive'], 'obligation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ominous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'card': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'care': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vestige': ['surprise', 'fear', 'sadness', 'negative'], 'stave_in': ['negative'], 'deprivation': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'expeditiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mull_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caseful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symmetricalness': ['positive', 'anticip'], 'madam': ['anger', 'positive', 'trust', 'disgust'], 'tippy': ['anger', 'negative'], 'indecent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'directly': ['positive', 'negative', 'anticip'], 'message': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'drove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agonising': ['fear', 'negative'], 'cerebration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'selective_information': ['anger', 'positive', 'fear', 'trust', 'negative'], 'Holy_Communion': ['positive', 'trust', 'joy'], 'alarm_system': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outspokenness': ['positive', 'trust', 'negative', 'disgust'], 'tragic': ['negative'], 'yip': ['anger', 'surprise', 'fear', 'negative'], 'chimaera': ['surprise', 'fear'], 'national': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nutrition': ['positive'], 'expounding': ['positive', 'trust'], 'quay': ['trust'], 'taxation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'copestone': ['fear', 'sadness'], 'reconstructive_memory': ['positive', 'anticip'], 'quad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'quag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scalpel': ['fear', 'negative'], 'the_pits': ['anger', 'fear', 'negative'], 'give_suck': ['positive', 'trust', 'joy'], 'perfective_tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'respectability': ['positive'], 'go_after': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'troublesome': ['anger', 'fear', 'negative'], 'contentious': ['anger', 'fear', 'negative', 'disgust'], 'aspersion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assassinator': ['anger', 'fear', 'sadness', 'negative'], 'slam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vox_populi': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slag': ['negative'], 'commercial_enterprise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bump_around': ['sadness', 'negative', 'fear'], 'undercurrent': ['anger', 'negative'], 'wassail': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'beggarly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raddled': ['sadness', 'negative', 'fear'], 'prick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'price': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intercession': ['trust'], 'rationale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'successive': ['trust', 'anticip'], 'forever': ['trust'], 'sidekick': ['anticip', 'positive', 'trust', 'joy'], 'gypsy': ['negative'], 'mussitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rambling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cragged': ['negative'], 'storage_locker': ['positive', 'sadness', 'trust'], 'fifth': ['fear'], 'profligate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'testis': ['sadness', 'negative'], 'upgrade': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'last-place': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jolt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'injectant': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'only': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'malcontent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'recuperation': ['positive'], 'cannon': ['anger', 'fear', 'negative'], 'loath': ['anger', 'fear', 'negative', 'disgust'], 'celebrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deprecate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'imbecile': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'preempt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'craftsmanship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effectual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entomb': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'set_in_motion': ['positive', 'fear', 'negative', 'anticip'], 'betise': ['negative'], 'asleep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'afoul': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'culpable': ['negative'], 'sport': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crawfish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mandarin': ['positive', 'trust'], 'come_to': ['trust'], 'Master_of_Architecture': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'victimised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smooth_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coolheaded': ['positive'], 'comeback': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'installation': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'pertain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reasonableness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monk': ['positive', 'trust'], 'Supreme_Being': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aura': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crispen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evict': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cycles/second': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'PET': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'impeccant': ['positive', 'trust'], 'deviating': ['negative'], 'juvenile': ['negative'], 'George_Ellery_Hale': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'proved': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'informed': ['anger', 'positive', 'fear', 'trust', 'negative'], 'prurient': ['positive', 'negative', 'disgust'], 'collocation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'linguistic': ['positive'], 'informer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'telephone_exchange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'patriarchal': ['positive', 'trust'], 'Scotch_malt_whisky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asphyxiate': ['anger', 'fear', 'sadness', 'negative'], 'dalliance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cesspool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proven': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'get_in': ['anticip'], 'meagre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruby': ['positive'], 'argent': ['surprise', 'negative'], 'credit_entry': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stave_off': ['surprise', 'fear', 'sadness', 'negative'], 'pedant': ['positive', 'negative'], 'trick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notoriety': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'orientation': ['positive', 'negative', 'disgust', 'anticip'], 'alcoholic': ['positive', 'sadness', 'negative', 'disgust', 'surprise'], 'dish_antenna': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'commander': ['positive', 'trust'], 'morphologic': ['trust'], 'foresightful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'edification': ['anticip', 'positive', 'trust', 'joy'], 'turgidness': ['negative', 'disgust'], 'unshakable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "stone's_throw": ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'delusive': ['fear', 'negative'], 'stilt': ['negative', 'disgust'], 'figuring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noble': ['positive', 'trust'], 'corpulency': ['sadness', 'negative', 'disgust'], 'eyeshade': ['surprise', 'anticip'], 'mutually_exclusive': ['anger', 'fear', 'sadness', 'negative'], 'postulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'validate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enchanting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bondage': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'constitutional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sustainment': ['trust', 'negative'], 'severe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breeze': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'miscellany': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piquantness': ['anger', 'positive', 'fear', 'negative'], 'permissible': ['positive'], 'transmitting': ['anticip', 'positive', 'negative', 'disgust', 'fear', 'trust'], 'armour': ['positive', 'fear', 'trust'], 'uninstructed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'valuable': ['positive'], 'deputy_sheriff': ['trust'], 'go_steady': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rudderless': ['negative'], 'inquisitory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'disheartenment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'domicile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'epithelial_duct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'cogitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spectacular': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruler': ['anger', 'positive', 'fear', 'trust', 'negative'], 'conical_buoy': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'oldtimer': ['anger', 'positive', 'trust', 'negative'], 'listening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recipient': ['anticip'], 'proponent': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'conversing': ['positive'], 'primary_quill': ['positive'], 'collective': ['positive', 'trust'], 'greeting': ['surprise', 'positive'], 'orison': ['positive', 'trust', 'negative', 'anticip'], 'untangle': ['positive', 'joy', 'trust', 'anticip'], 'oblivion': ['anger', 'fear', 'negative'], 'landslip': ['fear', 'sadness', 'negative'], 'social_unit': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'feverishness': ['fear', 'negative'], 'sexual_love': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refreshen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sum-up': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sr.': ['sadness', 'negative'], 'antipathetic': ['anger', 'negative', 'disgust'], 'plagiarisation': ['fear', 'negative', 'disgust'], 'roll_out': ['positive', 'joy', 'trust', 'anticip'], 'throb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'James_Neville_Mason': ['positive'], 'equivalent': ['positive', 'trust', 'negative'], 'radial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unease': ['sadness', 'negative', 'anticip'], 'quest_for': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'uneasy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'leftover': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'osculation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electrify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wolf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remonstrance': ['anger', 'fear', 'negative'], 'mental_ability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stratagem': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'inclusion': ['trust'], 'flood_tide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'supervising': ['negative'], 'log': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rear_end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissolute': ['negative', 'disgust'], 'lop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'water_parting': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'low': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sallying_forth': ['anger', 'surprise', 'fear', 'negative'], 'forrad': ['positive', 'trust'], 'Wiley_Post': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leach': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'groan': ['fear', 'sadness', 'disgust', 'negative'], 'car_park': ['surprise', 'anticip', 'positive', 'joy'], 'sad_sack': ['negative'], 'patrimonial': ['trust'], 'signal_detection': ['positive'], 'sadness': ['sadness', 'trust', 'negative', 'fear'], 'break_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blush_wine': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'get_the_better_of': ['anger', 'sadness', 'negative'], 'brittleness': ['sadness', 'negative'], 'quandary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'traveling_bag': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reliability': ['positive', 'trust'], 'George_Mason': ['positive'], 'bawdyhouse': ['negative', 'disgust'], 'Garland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'light_ballast': ['positive', 'sadness'], 'hot_dog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outer_space': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sepulchral': ['fear', 'negative', 'disgust'], 'chemical_equilibrium': ['positive'], 'woeful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expropriation': ['negative'], 'esthetic': ['positive', 'joy'], 'drift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'camp_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wedlock': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'untidy': ['negative', 'disgust'], 'requisition': ['sadness', 'negative'], 'imperfectness': ['negative'], 'banishment': ['anger', 'sadness', 'negative', 'disgust'], 'precondition': ['trust'], 'skeleton': ['sadness', 'negative', 'disgust'], 'groundwork': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'midsection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opprobrious': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'talkativeness': ['negative'], 'skim_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fervor': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'U.S._Senate': ['trust'], 'passivity': ['negative'], 'flake_off': ['negative'], 'esthesia': ['positive'], 'nanus': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ask_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deficient': ['sadness', 'negative'], 'shimmy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memory_board': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wantonness': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'John_Milton_Cage_Jr.': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'colossal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unblinking': ['positive', 'trust', 'joy'], 'vivacious': ['positive', 'joy'], 'gyration': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'possibleness': ['surprise', 'trust', 'negative', 'anticip'], 'penalise': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'rasping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atomic_number_15': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scorching': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'unattached': ['negative'], 'priming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dummy_up': ['trust', 'negative'], 'capital_of_Arizona': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'loose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rophy': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'icteric': ['fear', 'negative'], 'handwriting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unproven': ['anticip'], 'whine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unproved': ['anticip'], 'invalidate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'family': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fatuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'glitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lewdness': ['anger', 'fear', 'negative', 'disgust'], 'khan': ['fear', 'trust'], 'bicker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'every_which_way': ['surprise'], 'mysterious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prison_house': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'instrumental': ['positive'], 'excuse': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'impulse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'corpulent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'imperfect_tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offender': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'offended': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revitalising': ['positive', 'joy', 'trust', 'anticip'], 'sexual_urge': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'history': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'trust'], 'visage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cowl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stinging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'CAT': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'priestlike': ['positive'], 'firmly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gaffer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throwing_stick': ['trust', 'anticip'], "Venus's_curse": ['positive', 'trust', 'negative', 'joy'], 'buy_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impassivity': ['sadness', 'negative', 'disgust'], 'sneak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'agaze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remediation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invasion': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'humbug': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'drear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bilgewater': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'spectre': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'untoward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negligible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dread': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deterioration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dream': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crafty': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bustle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materialistic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'help': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'playground_slide': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'slouch': ['negative'], 'urine': ['positive', 'sadness', 'negative'], 'soon': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'wiener': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soot': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'helm': ['positive', 'sadness', 'negative', 'fear'], 'hell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'racecourse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Delilah': ['fear', 'negative'], 'uniformness': ['positive'], 'teeming': ['disgust'], 'deformation': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Wisdom_of_Solomon': ['anticip', 'positive', 'trust', 'joy'], 'Ussher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vomit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yr': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'irrationality': ['negative'], 'stopper': ['disgust'], 'chamfer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imprisoned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower_rank': ['negative'], 'lean_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trusty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unnatural': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chopine': ['positive'], 'issue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parturition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impertinence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misstatement': ['anger', 'negative', 'disgust'], 'reason': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knock_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbecoming': ['anger', 'negative', 'disgust'], 'launch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'perceptible': ['positive'], 'run-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'assign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beggary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'risk_of_infection': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'government_minister': ['positive', 'trust', 'negative', 'joy'], 'knocking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arsenal': ['trust'], 'dominating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rate_of_flow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arbitration': ['anticip'], 'ostracize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'transcendent': ['positive'], 'shamed': ['anger', 'sadness', 'negative'], 'scheme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'schema': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aerial_tramway': ['fear', 'sadness', 'disgust', 'negative'], 'apprentice': ['positive', 'trust', 'joy'], 'guiding_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'floozie': ['negative'], 'anticipate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erotic': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'trust'], 'block_out': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'stargaze': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'strip_show': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'silver-tip': ['fear', 'negative'], 'withered': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Ezra_Pound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'God': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'urgently': ['anger'], 'congenator': ['trust'], 'Good_Book': ['positive', 'trust', 'negative'], 'poulet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cumbersome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thought': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evasion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-chosen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'camouflage': ['surprise', 'anticip'], 'on-going': ['anticip'], 'intermediator': ['positive', 'trust', 'anticip'], 'experienced': ['positive', 'trust', 'negative'], 'unstuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exsert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'promiscuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plunder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mace': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'bridle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lay_on_the_line': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'political_relation': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'James_Jerome_Hill': ['positive', 'fear', 'negative', 'anticip'], 'popularity': ['positive'], 'unreasonable': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'keep_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pick_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perseverance': ['positive', 'sadness', 'anticip', 'joy'], 'crackpot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'languid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flicker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caries': ['negative', 'disgust'], 'mainsheet': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'intromission': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'top_of_the_inning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paranoia': ['fear', 'negative'], 'striptease': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Pisces_the_Fishes': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'randy': ['fear', 'negative'], 'grandiloquent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'trust'], 'humdrum': ['negative'], 'hardened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legible': ['positive', 'negative'], 'dominant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'direct_contrast': ['negative'], 'outlast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'show_off': ['negative'], 'consecration': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'streetwalker': ['negative'], 'fight_off': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'alteration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withdrawal': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'jury-rigged': ['negative'], 'poisoned': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'courteous': ['positive'], 'disapproving': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'defendable': ['fear', 'negative'], 'fragmentize': ['positive', 'negative', 'disgust'], 'schizophrenia': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'hesitating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'becloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constellation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potently': ['positive', 'fear'], 'forswearing': ['fear', 'negative'], 'conditions': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'making_love': ['positive', 'trust', 'joy'], 'unconscious': ['negative'], 'oddness': ['surprise', 'sadness', 'negative', 'disgust'], 'mismated': ['anger', 'sadness', 'negative', 'disgust'], 'rudiments': ['positive', 'trust'], 'scholarly_person': ['positive', 'trust', 'joy'], 'distinguish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protector': ['positive', 'trust'], 'secrete': ['disgust'], 'spotting': ['positive'], 'thermocouple_junction': ['anticip'], 'unrestrained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weather_vane': ['surprise', 'sadness'], 'stamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'looseness_of_the_bowels': ['disgust'], 'damp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inkpad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'damn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blueness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fenland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dame': ['joy', 'negative', 'disgust', 'positive', 'anger', 'trust'], 'decisiveness': ['negative'], 'Martha_Jane_Burk': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'church_bench': ['disgust'], 'Allied': ['positive', 'trust'], 'preciseness': ['positive'], 'bidding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assigning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loon': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'loom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'look': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'socialist': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rope': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'socialism': ['fear', 'disgust'], 'Brown_University': ['disgust'], 'endanger': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'loot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'on_the_qui_vive': ['trust', 'surprise', 'fear', 'anticip', 'positive'], 'loop': ['fear', 'sadness', 'negative'], 'bawdiness': ['anger', 'fear', 'negative', 'disgust'], 'hoax': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'ready': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyperbole': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'constructive_eviction': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'get_it_on': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'work_shift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discredit': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'conflict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'covetous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'censure': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'decency': ['anger', 'positive', 'disgust'], 'assortment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'George_Herbert_Walker_Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'older': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'she-goat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'docked': ['negative'], 'cytosmear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theoretical_account': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aesthetical': ['positive', 'joy'], 'secession': ['negative'], 'docket': ['trust'], 'seal_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'extortionate': ['negative', 'disgust'], 'chore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morsel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handbasket': ['positive', 'anticip', 'joy'], 'retirement': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'decayed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exercising': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remaining': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'lacking': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'gamy': ['sadness', 'negative', 'fear'], 'endemic_disease': ['fear', 'sadness', 'disgust', 'negative'], 'game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vertical_flute': ['positive'], 'outright': ['positive'], 'theater_director': ['positive', 'trust'], 'resole': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'ironical': ['positive', 'trust'], 'mathematical': ['trust'], 'largeness': ['negative'], 'cathexis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'escargot': ['trust', 'negative', 'anticip'], 'mortgagor': ['fear'], 'pestis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crock_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'savage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'venturesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'becalm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flush_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minimal': ['negative'], 'clownish': ['surprise', 'negative'], 'Johnny_Cash': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'stem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ampul': ['positive', 'joy'], 'ache': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taboo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'letup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reappear': ['surprise'], 'beauty_parlor': ['anger'], 'congressman': ['trust'], 'classics': ['anticip', 'positive', 'trust', 'joy'], 'shiny': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'misbehavior': ['anger', 'surprise', 'negative', 'disgust'], 'make_merry': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'nonsense': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'say-so': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smelly': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'Ruth': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'convulsion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sashay': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'adeptness': ['surprise', 'positive'], 'worshipper': ['trust'], 'renewal': ['positive', 'anticip'], 'ball_up': ['anger', 'sadness', 'negative', 'disgust'], 'kick_back': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'disallowed': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'manufacture': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'up-and-coming': ['positive'], 'inept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'specialty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provoking': ['anger', 'negative', 'disgust'], 'properly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'segregation': ['sadness', 'negative'], 'fishy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bevel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armed_services': ['fear'], 'intuitive': ['positive', 'anticip'], 'nestle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'accustomed': ['anticip'], 'Oliver_Stone': ['anger', 'positive', 'fear', 'trust', 'negative'], 'work-shy': ['negative'], 'mortgage_holder': ['trust'], 'abruptness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mindful': ['positive'], 'malicious_gossip': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'apropos': ['positive', 'negative'], 'sullen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abstruseness': ['fear', 'negative'], 'upstage': ['negative'], 'hoopla': ['surprise', 'fear', 'negative', 'disgust', 'anticip'], 'jesting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pretended': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'validity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'pretender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reservation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mouth_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wellbeing': ['positive', 'trust', 'disgust'], 'Village': ['positive', 'trust'], 'rencontre': ['negative'], 'get_through': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cheerful': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'religious_order': ['anger', 'fear', 'negative', 'disgust'], 'ruminate': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'illegible': ['negative'], 'vacuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'arrogance': ['negative'], 'culinary': ['positive', 'trust'], 'whoredom': ['sadness', 'negative', 'disgust'], 'excluded': ['sadness', 'negative', 'disgust'], 'suite': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'virtuous': ['positive', 'joy', 'trust', 'anticip'], 'core_out': ['sadness', 'negative'], 'murderous': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'take_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quelling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'preponderance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'accoucheur': ['trust'], 'trough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cellular': ['disgust'], 'warning_signal': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peridot': ['positive'], 'excruciating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'mercurial': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'snuff_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'argus-eyed': ['positive', 'fear', 'trust'], 'instrument_panel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agnatic': ['positive', 'negative', 'anticip'], 'panic-stricken': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'booty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'picket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oz.': ['anger', 'negative', 'disgust', 'anticip'], 'encroachment': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decreed': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'hose': ['positive'], 'booth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pornography': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'poke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holdtrue': ['trust'], 'colonel': ['positive', 'trust'], 'applesauce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imitator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infuse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'poky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'slowness': ['fear', 'sadness', 'disgust', 'negative'], 'meandering': ['negative'], 'brooch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Revere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'newness': ['positive'], 'indivisible': ['trust'], 'chant': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'referable': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'overseer': ['positive', 'trust'], 'nameless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wig': ['negative', 'disgust'], 'impassiveness': ['sadness', 'negative', 'disgust'], 'come_alive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'win': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assertion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feller': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plant_louse': ['surprise', 'anticip', 'negative', 'disgust', 'positive'], 'circumscribe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wiz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lower-ranking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blockaded': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'remains': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adequacy': ['anger', 'positive', 'negative'], 'hydra': ['fear', 'negative'], 'crab': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'agreeable': ['positive', 'trust'], 'means': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'romanticism': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lyric_poem': ['positive', 'joy'], 'trip_out': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'whiteelephant': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'unfaithful': ['sadness', 'negative', 'disgust'], 'starter': ['surprise', 'fear'], 'irreparable': ['fear', 'sadness', 'negative'], 'armed_forces': ['fear'], 'painkiller': ['positive', 'trust'], 'atone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'alarm_clock': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'Judy_Garland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'wonderful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ford_Hermann_Hueffer': ['positive'], 'skirt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flaky': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'arrangement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reestablish': ['positive'], 'circular': ['anger', 'negative', 'disgust', 'anticip'], 'luxuriously': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'fatigue': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'belongings': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Secession': ['negative'], 'reave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'espial': ['positive'], 'of_age': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'magisterial': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'xenophobia': ['fear', 'negative'], 'lordly': ['anger', 'negative'], 'bullheadedness': ['negative'], 'carry_on': ['anticip'], 'pretending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'look_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acantha': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anchorite': ['sadness', 'trust'], 'vilify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'physicalness': ['negative'], 'guerrilla': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'spellbound': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'imbalance': ['disgust'], 'underbred': ['negative', 'disgust'], 'belatedly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'placid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hands': ['trust'], 'handy': ['positive'], 'accelerator_pedal': ['anger', 'negative'], 'grumbling': ['anger', 'negative'], 'predilection': ['positive', 'negative', 'disgust', 'anticip'], 'shaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_endowment': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'beshrew': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'illuminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throw_out_of_kilter': ['anger', 'fear', 'negative', 'disgust'], 'proofreader': ['positive'], 'pertinacity': ['positive', 'sadness', 'anticip', 'joy'], 'confess': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'unlawful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remiss': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'wondrous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pendent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slapdash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obsess': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'chitchat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foreknow': ['anticip', 'surprise', 'trust', 'positive'], 'humiliating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'brainpower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'completely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comeafter': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'body_structure': ['positive', 'trust'], 'bemusement': ['surprise', 'fear'], 'hostile': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'counterpart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intoxicated': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'shred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heartsease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'benediction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clamour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seasonably': ['positive', 'negative'], 'disembodied': ['fear', 'sadness', 'negative'], 'seasonable': ['positive', 'negative'], 'eminence': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'management': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'data': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'perfectly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'post-mortem': ['fear', 'sadness', 'disgust', 'negative'], 'well-favored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'approachable': ['positive', 'negative'], 'manifestation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'reunification': ['positive', 'trust', 'anticip'], 'aught': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "entr'acte": ['positive'], 'clog_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoulder_joint': ['positive', 'trust'], 'abyssal': ['sadness', 'negative'], 'illegitimate_child': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fissiparous': ['anger', 'negative', 'disgust'], 'emptying': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'take_root': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saintly': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'arrogate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ecumenical': ['positive', 'trust'], 'pivotal': ['surprise', 'trust'], 'lecturer': ['positive'], 'technicality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rigor': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'munificent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Whitney_Moore_Young_Jr.': ['positive', 'anticip', 'surprise', 'joy'], 'spleen': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'sergeantmajor': ['positive', 'trust'], 'deface': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unsettle': ['anger', 'fear', 'negative', 'disgust'], 'violation': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hemipterous_insect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'double_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'passe': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'sit_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loveable': ['positive', 'trust', 'joy'], 'rase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'launchpad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modestness': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'dramatize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noteworthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'credited': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rash': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lustfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'infernal': ['anger', 'negative'], 'commendation': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'misty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sprouting': ['anticip'], 'come_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'band_together': ['positive', 'trust'], 'personal_manner': ['positive', 'trust', 'anticip'], 'endless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gray': ['sadness', 'negative', 'disgust'], 'Polemonium_caeruleum': ['positive', 'joy'], 'itemise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gust': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'quarantine': ['fear'], 'watershed': ['trust'], 'topaz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumulus': ['disgust'], 'gran': ['positive'], 'grab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensuality': ['positive', 'joy', 'anticip'], 'Lighthorse_Harry_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'humans': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'portend': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'desperate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'humane': ['positive'], 'irrefutable': ['positive', 'trust'], 'portent': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'widely_distributed': ['positive', 'trust'], 'disjunct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'missing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'punch-drunk': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'heedfulness': ['positive'], 'supernatural': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wavelet': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'grayness': ['sadness', 'negative', 'disgust'], 'hypnotised': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'sabotage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comparable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'welkin': ['anticip', 'positive', 'trust', 'joy'], 'plunk_down': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'derive': ['negative'], 'take_note': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despotic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'psychotherapeutic': ['positive'], 'admit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "rock_'n'_roll": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spliff': ['disgust'], 'nominating_speech': ['positive'], 'hussy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cynicism': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'quit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inhale': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'quip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medico': ['positive', 'trust'], 'yaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'taking_apart': ['fear', 'sadness', 'disgust', 'negative'], 'yap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quiz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slowly': ['negative'], 'misapply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fashion_plate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corresponding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negligently': ['negative'], 'overprotect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spaniel': ['positive', 'trust', 'joy'], 'quotation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ana': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'muster_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coddler': ['sadness', 'negative'], 'commie': ['negative'], 'milling_machinery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'conveying': ['trust'], 'demo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shininess': ['positive', 'negative', 'joy'], 'Kate_Smith': ['trust'], 'bitstock': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'swinging': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sarcoma': ['fear', 'sadness', 'negative'], 'capture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liquidator': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'peat_bog': ['anger', 'negative', 'disgust'], 'strange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underground': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'origination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconventional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eccentric': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Gorilla_gorilla': ['negative'], 'violent_death': ['anger', 'fear', 'sadness', 'negative'], 'fierce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'frequently': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spree': ['negative'], 'magician': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'compeer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endearing': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'defilement': ['negative', 'disgust'], 'well': ['fear', 'negative'], 'nebulous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'build_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'amends': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'welt': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'awning': ['negative'], 'gelidity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wee-wee': ['positive', 'negative', 'anticip'], 'inebriated': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mistaken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wild-eyed': ['anticip', 'positive', 'trust', 'joy'], 'Porter': ['positive', 'trust', 'joy'], 'tenner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meagerly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stratum': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'rood-tree': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'clouded': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'railcar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Martes_zibellina': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'slattern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'livid': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immediately': ['positive', 'negative', 'anticip'], 'sublimate': ['positive', 'trust', 'joy'], 'starry': ['positive', 'anticip', 'joy'], 'balefulness': ['negative'], 'clown': ['surprise', 'anticip', 'positive', 'joy'], 'slosh_around': ['surprise', 'negative', 'disgust'], 'divest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'page': ['anger', 'fear', 'negative'], 'adversity': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'scuffle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Mason': ['positive'], 'motive': ['positive'], 'husk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Erolia_minutilla': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drizzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bantam': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'helplessness': ['anger', 'fear', 'sadness', 'negative', 'anticip'], 'competitor': ['negative', 'anticip'], 'unmannered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'draught': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'accoucheuse': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'salubrity': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'hinder': ['negative'], 'inaccurate': ['negative'], 'journal': ['positive', 'trust'], 'lissom': ['positive'], 'bundle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smidgen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'individualism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freedom': ['positive', 'trust', 'joy'], 'revere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compatible': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'dominion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tongue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'equally': ['positive'], 'attaint': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'articulate': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'field_of_honor': ['fear', 'negative'], 'relinquishment': ['positive', 'negative'], 'crude_oil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conjure_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wimp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invisibility': ['negative'], 'Canis_familiaris': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puff_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jubilation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'neutral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'courts': ['positive', 'joy', 'trust', 'anticip'], 'bovine': ['negative', 'disgust'], 'eat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'storied': ['positive', 'anticip', 'joy'], 'prevalent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denominate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grieve': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'contact_lens': ['positive'], 'pansy': ['negative'], 'accommodative': ['positive', 'trust'], 'religious_cult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bedding_material': ['positive', 'negative', 'disgust', 'joy'], 'validness': ['fear', 'negative'], 'sensualness': ['positive', 'joy', 'anticip'], 'bring_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geological_formation': ['anger', 'positive', 'fear', 'trust', 'negative'], 'grand_Turk': ['fear', 'anticip'], 'lopsided': ['anger', 'negative', 'anticip'], 'regroup': ['positive'], 'execution_of_instrument': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'onwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Australian_crawl': ['fear', 'sadness', 'negative', 'disgust', 'anticip'], 'stumpy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blameworthy': ['negative'], 'grunter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astounding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mourning_band': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pestilence': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'two-fold': ['positive', 'anticip'], 'adulteress': ['anger', 'negative', 'disgust'], 'persistent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parturiency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diagnosis': ['fear', 'trust', 'negative', 'anticip'], 'uneducated': ['sadness', 'negative'], 'validation': ['positive', 'trust', 'anticip'], 'commencement': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disruptive': ['anger', 'surprise', 'fear', 'negative'], 'pardon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'dissolution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plenary': ['positive'], 'hold_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battleground': ['fear', 'negative'], 'constant_quantity': ['positive', 'trust', 'negative'], 'calculate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'Apache': ['fear', 'negative'], 'coition': ['positive', 'trust', 'disgust'], 'promulgated': ['sadness', 'negative', 'anticip'], 'star_topology': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pullman_porter': ['positive', 'trust', 'joy'], 'quiet_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'govern': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plowshare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exonerative': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'vast': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'demerit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'male_person': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'inutility': ['negative'], 'misbeliever': ['negative', 'disgust'], 'sleep': ['negative'], 'moving_ridge': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unauthorised': ['negative'], 'personnel_casualty': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear'], 'winder': ['positive', 'negative', 'disgust', 'surprise'], 'copiousness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'worthlessness': ['fear', 'sadness', 'disgust', 'negative'], 'fatal_accident': ['anger', 'fear', 'sadness', 'negative'], 'gawky': ['negative', 'disgust'], 'wreck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orchestra': ['anger', 'positive', 'sadness', 'trust', 'joy'], 'hazy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haze': ['fear', 'negative'], 'quotation_mark': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unintegrated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Browning_automatic_rifle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mill_around': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'repugnance': ['fear', 'negative', 'disgust'], 'therapeutics': ['anticip', 'positive', 'trust', 'joy'], 'possibility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taking_over': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'trust'], 'dry': ['positive', 'trust'], 'unstableness': ['fear', 'negative', 'disgust'], 'economics': ['positive', 'trust'], 'credit': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'exacting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suitable': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'menial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heedful': ['positive', 'trust'], 'overabundance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reckoner': ['positive', 'trust'], 'die_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mucous_secretion': ['disgust'], 'patent_of_invention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leaky': ['negative'], 'lungs': ['anger'], 'wary': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'wart': ['positive', 'negative', 'disgust', 'surprise'], 'well-heeled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warn': ['anticip', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'bemock': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'frenzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adult': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'V': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ware': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'command_prompt': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verdant': ['positive'], 'somber': ['sadness', 'negative'], 'corona_discharge': ['positive', 'trust', 'joy'], 'judicial_writ': ['positive', 'trust'], 'solitaire': ['positive', 'trust', 'negative', 'anticip'], 'guise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'akin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'informality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'candidature': ['anger', 'fear', 'negative'], 'back_talk': ['surprise', 'negative'], 'bursting_charge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'press_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'back_end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'removal_company': ['positive'], 'lacklustre': ['negative'], 'advancing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twitching': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'faulty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'construe': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'minority': ['negative'], 'president': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'empty-bellied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'brigand': ['negative'], 'St._John': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'attempt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equivalent_word': ['positive', 'fear', 'trust', 'negative'], 'roquette': ['anger'], 'bedazzle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puny': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cockscomb': ['anger', 'fear', 'negative', 'anticip'], 'inhabitant': ['fear', 'negative', 'disgust'], 'banger': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'Harlan_Stone': ['anger', 'positive', 'fear', 'negative'], 'befall': ['negative'], 'ghastly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eavesdropping': ['negative'], 'unsullied': ['positive'], 'miscarry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wickedness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rachis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frisky': ['surprise', 'anticip', 'positive', 'joy'], 'polygamy': ['negative', 'disgust'], 'do_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swot_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'colliery': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encounter': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'persist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Barbara_Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cubital_joint': ['anger'], 'maximal': ['positive'], 'paygrade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nervus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atherosclerosis': ['fear', 'sadness', 'negative'], 'facile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sceptre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cautiousness': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'investiture': ['positive', 'trust', 'joy'], 'bony': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'meat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleepless': ['positive', 'trust'], 'vector_decomposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_off': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'bonk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mead': ['positive'], 'roast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operating_room': ['positive', 'fear', 'trust', 'sadness'], 'side': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'improvise': ['surprise', 'anticip', 'positive'], 'habitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'olfaction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'croup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glinting': ['positive', 'joy'], 'awry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'happenstance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'first-class': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'velvet': ['positive'], 'typecast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quantify': ['positive', 'trust', 'negative'], 'crucial': ['positive', 'sadness', 'trust', 'negative'], 'Muse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_treasury': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'easiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atomic_number_92': ['fear', 'negative'], 'instigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atomic_number_94': ['fear', 'negative'], 'distinguishing_characteristic': ['positive'], 'whiff': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'dodder': ['positive', 'anticip'], 'aboriginal': ['positive'], 'struggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cattiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repulsive_force': ['fear', 'negative', 'disgust'], 'scrounge': ['negative'], 'satiny': ['positive'], 'Curl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lasso': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'naughty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'features': ['negative'], 'swear_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reassure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buttock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upwind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'comforter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ditch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hermaphroditic': ['surprise', 'negative'], 'total_darkness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dwell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hayfield': ['positive'], 'snuggery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'melodic_phrase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bouncing': ['negative'], 'solid_state': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gyp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gambler': ['surprise', 'negative', 'anticip'], 'blameable': ['negative'], 'distance': ['positive', 'anticip', 'joy'], 'affront': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'imputation': ['negative'], 'exorcism': ['fear', 'sadness', 'negative'], 'Chimera': ['surprise', 'fear'], 'open_air': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'loiter': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'hallucination': ['anger', 'fear', 'sadness', 'negative'], 'bench_vise': ['anticip', 'positive', 'trust', 'surprise'], 'picture_show': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seer': ['anticip', 'positive', 'trust', 'joy'], 'buy_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seep': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'quench': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sex_act': ['positive', 'trust', 'disgust'], 'mind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'minx': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pantheon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'seed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angular_shape': ['trust'], 'sounding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'policy_change': ['anger', 'surprise', 'negative', 'disgust'], 'churrigueresque': ['surprise', 'fear', 'negative', 'disgust'], 'travel_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fatty_tissue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'large-hearted': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'divulge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enounce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lowball': ['surprise'], 'translator': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'regular': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'for_sure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treasonous': ['sadness', 'negative'], 'mitigate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'don': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conduce': ['positive'], 'doc': ['positive', 'trust'], 'alarm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'm': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doe': ['positive'], 'principle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'planetary': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'softheaded': ['anger', 'fear', 'sadness', 'negative'], 'unironed': ['positive', 'sadness', 'trust', 'negative'], 'idealisation': ['positive', 'joy'], 'hunger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jurisdiction': ['trust'], 'sneaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'way-out': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'explain': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'turncoat': ['anger', 'negative'], 'sugar': ['positive'], 'brimstone': ['anger', 'fear', 'negative'], 'ebbing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Angel_Falls': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'patter': ['anger', 'negative'], 'rejoicing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heftiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'coast': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'slanderous': ['negative'], 'patten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heat_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'size_up': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'Washington': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'far-right': ['negative'], 'architecture': ['trust'], 'cower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'St._Bride': ['anticip', 'positive', 'trust', 'joy'], 'talk_about': ['positive'], 'fascinating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fluffy': ['positive'], 'physical_structure': ['positive', 'trust', 'negative'], 'subject': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voyage': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'exponent': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'reprinting': ['negative'], 'Second_Advent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'connective': ['trust'], 'Thatch': ['positive', 'trust', 'surprise', 'joy'], 'turbidness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'baboon': ['negative', 'disgust'], 'glossy': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'warrior': ['anger', 'positive', 'fear'], 'lazy': ['negative'], 'triplet': ['positive'], 'visualise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'craunch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'weight_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disorderly': ['anger', 'negative'], 'against': ['anger', 'negative'], 'agonise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rich_people': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'secretaire': ['negative'], 'height': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'initiative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loaded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'arsenic': ['fear', 'sadness', 'disgust', 'negative'], 'rescript': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paralyze': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'abdominal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'futility': ['negative'], 'erect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pan_off': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bring_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'replicate': ['positive', 'anticip'], 'frisk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idol': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'website': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear'], 'mammilla': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pocket_billiards': ['positive', 'fear'], 'efficacy': ['positive'], 'suppress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'decrepit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alleviative': ['positive'], 'electric_arc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heroic_meter': ['positive'], 'regretted': ['sadness', 'negative'], 'picketing': ['anger', 'negative'], 'able-bodied': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sanctum': ['positive', 'fear', 'sadness', 'negative'], 'convalesce': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'concomitant': ['anticip'], 'alimental': ['positive', 'sadness'], 'diaphragm': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'strait-laced': ['anger', 'positive', 'trust', 'negative'], 'defeated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pool_stick': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'abscess': ['sadness', 'negative'], 'make': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jotting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'concavity': ['negative'], 'contaminate': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'President': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'plant_life': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bank_identification_number': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'vitreous_silica': ['positive', 'negative'], 'percolation': ['positive', 'negative'], 'kip': ['negative'], 'kit': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'delight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'working_out': ['anger', 'positive', 'negative'], 'garlic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opportunity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butter': ['positive'], 'first_harmonic': ['positive', 'trust'], 'unseasoned': ['positive'], 'whicker': ['positive', 'trust', 'anticip'], 'strangulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piece_of_writing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'give_vent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materials': ['positive'], 'virile': ['positive'], 'protocol': ['trust', 'negative', 'disgust'], 'consciousness': ['positive'], 'wasteful': ['anger', 'sadness', 'negative', 'disgust'], 'vaporisation': ['positive'], 'serviette': ['sadness'], 'human': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impending': ['fear', 'anticip'], 'legion': ['surprise', 'negative'], 'assassination': ['anger', 'fear', 'sadness', 'negative'], 'character': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'surliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhibitioner': ['positive', 'trust'], 'megrims': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inharmonic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perfunctory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auspicious': ['positive', 'joy', 'trust', 'anticip'], 'dreamy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wanting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensationsoftouch': ['positive'], 'avaritia': ['anger', 'negative', 'disgust'], 'shoulder': ['positive', 'trust'], 'dignity': ['positive', 'trust'], 'daemon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'performing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mushiness': ['positive'], 'unnecessary': ['negative'], 'oncoming': ['anticip'], 'belly-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Thomas_Kyd': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'stir_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'synchroneity': ['anticip'], 'hoo-hah': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theatrical': ['sadness', 'negative'], 'interestingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drudge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pull_the_leg_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protagonism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faery': ['positive', 'fear', 'negative'], 'bone_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unorganized': ['negative'], 'protagonist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'permanent_wave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ungratefulness': ['anger', 'negative', 'disgust'], 'empowerment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conceal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cliche': ['trust', 'anticip'], 'crucifix': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'slaughterer': ['anger', 'fear', 'negative', 'disgust'], 'restate': ['positive', 'anticip'], 'shell_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'marshal': ['positive', 'trust'], 'dim-witted': ['anger', 'negative', 'disgust'], 'sexually_attractive': ['positive'], 'lever_tumbler': ['positive'], 'olfactive': ['negative', 'anticip'], 'daub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carving': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Justice_Department': ['anger', 'positive', 'trust', 'negative'], 'theatre_director': ['positive', 'trust'], 'illustrious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lampoon': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'vehemence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intoxicant': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'pinna': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entombment': ['anger', 'sadness', 'negative', 'fear'], 'lead_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'failure': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'diaper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surrender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protestant': ['fear', 'negative'], 'fancy_man': ['negative', 'disgust'], 'arsenous_oxide': ['fear', 'sadness', 'disgust', 'negative'], 'Harlan_Fisk_Stone': ['anger', 'positive', 'fear', 'negative'], 'propaganda': ['negative'], 'godlessness': ['negative'], 'unsaved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good_morning': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bloodstained': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'fatherhood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anthrax': ['fear', 'sadness', 'disgust', 'negative'], 'pileus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confirmative': ['trust'], 'discriminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agreeing': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'aunty': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'pilot_film': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demesne': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'voltaic': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'insolvency': ['surprise', 'fear', 'sadness', 'negative'], 'articulated_lorry': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sensuous': ['positive', 'joy'], 'outback': ['negative'], 'logical_system': ['positive', 'trust', 'negative'], 'Equus_asinus': ['negative', 'disgust'], 'gorilla': ['negative'], 'Colon': ['positive', 'trust'], 'unimpressed': ['positive', 'negative'], 'decelerate': ['fear', 'sadness', 'disgust', 'negative'], 'intoxicate': ['positive', 'trust', 'negative', 'joy'], 'camber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'customary': ['anticip'], 'proletariat': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'eldest': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'lubrication': ['positive'], 'adjourn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manager': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proletarian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'depend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fancier': ['surprise', 'anticip', 'positive', 'joy'], 'burnout': ['negative'], 'sufferer': ['fear', 'sadness', 'negative'], 'countdown': ['anticip'], 'too-generous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proscenium': ['positive'], 'shoot': ['anger', 'positive', 'fear', 'negative'], 'buccaneering': ['fear', 'negative', 'disgust'], 'pachydermatous': ['anger', 'negative', 'disgust'], 'ma': ['positive', 'fear', 'negative'], 'Basle': ['fear', 'negative'], 'bolt_out': ['negative'], 'excellency': ['positive', 'trust', 'disgust', 'joy'], 'give_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'item': ['surprise', 'anticip', 'positive', 'joy'], 'excellence': ['positive', 'trust', 'disgust', 'joy'], 'caravanserai': ['fear', 'trust'], 'jolly_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anesthetic': ['sadness', 'negative'], 'ill-conceived': ['negative', 'disgust'], 'fleeceable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inconsequential': ['sadness', 'negative'], 'twaddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stealer': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Orthodox': ['trust'], 'overappraisal': ['surprise', 'negative'], 'dweller': ['fear', 'negative', 'disgust'], 'makeup': ['positive', 'trust', 'negative'], 'superstition': ['positive', 'fear', 'negative'], 'federation_of_tribes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ingenuous': ['positive', 'trust'], 'newswriter': ['positive', 'trust'], 'cuckoo': ['negative'], 'shift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bunglesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'somatic': ['positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'expulsion': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'suggestion': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'elect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'culpability': ['negative'], 'gewgaw': ['positive', 'surprise'], 'verge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surmount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gonzo': ['surprise', 'fear', 'negative', 'disgust', 'anticip'], 'wealth': ['positive', 'trust', 'joy'], 'aye': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'joyous': ['positive', 'joy'], 'dude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'connector': ['trust'], 'slog': ['sadness', 'negative', 'disgust'], 'conformable': ['positive'], 'swagger': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lessened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angina_pectoris': ['fear', 'negative'], 'tandem': ['trust'], 'recreant': ['anger', 'negative'], 'multitudinous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'orator': ['trust'], 'demolish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drumfish': ['sadness', 'negative'], 'melodrama': ['anger', 'sadness', 'negative'], 'unimproved': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weakly_interacting_massive_particle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lords': ['positive'], 'grouchy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'progress_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battered': ['anger', 'fear', 'sadness', 'negative'], 'council': ['positive', 'trust', 'anticip'], 'redness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ascesis': ['sadness', 'trust'], 'arbor': ['trust'], 'knee_pants': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'parch': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'drapery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'map': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mankind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hombre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrambling': ['negative'], 'fraudulence': ['anger', 'negative'], 'neck': ['negative'], 'tale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cascade': ['positive', 'trust'], 'rarified': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'deposit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncivilised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'prescription_drug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'talk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shield': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ridgeline': ['fear'], 'shaky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wishing': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'lyric': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adhesive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'object_lesson': ['positive', 'trust', 'anticip'], 'undermined': ['negative'], 'gameboard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'listing': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'muliebrity': ['positive'], 'undisclosed': ['anticip'], 'anteroom': ['negative'], 'idolise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'safari': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phrasal_idiom': ['positive', 'negative'], 'oarlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squad_car': ['trust'], 'scolder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dysphoric': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hijack': ['anger', 'negative'], 'Doctor_of_the_Church': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'eyelid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fistula': ['positive', 'disgust'], 'catholicon': ['positive'], 'tattletale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_in_touch': ['sadness', 'negative'], 'blitzkrieg': ['surprise'], 'ethoxyethane': ['anger', 'fear', 'sadness', 'negative'], 'unfitness': ['sadness', 'negative'], 'smatter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'smudge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advance': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'thing': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'think': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suspender': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'commercialize': ['positive'], 'lollygag': ['negative', 'anticip'], 'crib': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'cheesy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interchange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'little': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modernise': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'murky': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Stan_Laurel': ['positive', 'joy'], 'stinkpot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mermaid': ['fear', 'negative'], 'bloodshed': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'chub_mackerel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'broadcast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preordination': ['fear', 'negative'], 'butt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interred': ['fear', 'sadness', 'negative'], 'cleanse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '10': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '13': ['fear'], 'sailing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'melt_down': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lullaby': ['positive'], 'extemporaneous': ['negative'], 'hearer': ['fear', 'trust'], 'come_in': ['anger', 'positive', 'fear', 'negative'], 'monochrome': ['negative', 'disgust'], 'oil_colour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'bash': ['anger', 'fear', 'negative', 'disgust'], 'hooded': ['fear'], 'colorise': ['sadness', 'negative', 'disgust'], 'efficient': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'drubbing': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'isolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consortium': ['positive', 'fear'], 'endangered': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wretch': ['anger', 'sadness', 'negative', 'disgust'], 'ooze_out': ['negative', 'disgust'], 'amiable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheesecake': ['negative'], 'insanity': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'inspirit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bowels': ['disgust'], 'coveted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mobile_River': ['anticip'], 'Falco_subbuteo': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'hedgehog': ['negative'], 'shop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'on_the_fence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'show': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elevate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrears': ['negative'], 'corner': ['anger'], 'cornet': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'deportation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'safekeeping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plume': ['positive', 'joy'], 'dick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plumb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bossy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'manoeuvre': ['fear', 'trust'], 'bad-mannered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'James_Ussher': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'piece_of_land': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'exaggeration': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dance_orchestra': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'self-abnegation': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'nearly': ['joy', 'fear', 'anticip'], 'endemical': ['fear', 'sadness', 'disgust', 'negative'], 'secondary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harbinger': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'unbodied': ['fear', 'sadness', 'negative'], 'deferral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravishment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worrying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'risky_venture': ['positive', 'anticip'], 'conk_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 're-emerge': ['surprise'], 'relative': ['positive', 'trust'], 'Lucifer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'judicial_system': ['trust', 'anticip'], 'lay_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'camping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ornament': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_hold_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Arthur_Stanley_Jefferson_Laurel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calling_card': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hired_man': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'parental': ['positive', 'negative', 'anticip'], 'legitimacy': ['positive', 'trust'], 'sensory_faculty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throughway': ['fear'], 'diuturnity': ['positive'], 'the_Tempter': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'enthralling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bedraggled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glide_by': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accusation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dereliction': ['negative'], 'luckless': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'freebooter': ['sadness', 'negative'], 'chit_chat': ['positive', 'fear', 'joy', 'negative', 'anticip'], 'unassuming': ['positive'], 'sensible': ['surprise', 'fear', 'trust', 'negative', 'positive'], 'intrude': ['anger', 'negative'], 'acidity': ['positive', 'negative'], 'suppressed': ['anger', 'fear', 'sadness', 'negative'], 'undershirt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'corpuscle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'workshop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dependable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensibly': ['positive'], 'educated': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'traversal': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'Ngaio_Marsh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'predicament': ['fear', 'negative'], 'pirate_flag': ['anger', 'fear', 'negative'], 'invigorate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'higher-ranking': ['positive'], 'ongoing': ['anticip'], 'ignition': ['anger', 'fear', 'negative'], 'superintendence': ['fear', 'sadness', 'negative', 'disgust'], 'huckster': ['fear'], 'residuum': ['positive'], 'inadvertence': ['negative'], 'unwise': ['negative'], 'winding-clothes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'computerized_axial_tomography': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pressing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malformed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ephemeris': ['positive'], 'misunderstand': ['anger', 'sadness', 'negative'], 'throw_off': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dethronement': ['positive', 'trust', 'joy'], 'eternal_rest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arguments': ['anger'], 'dishonorable': ['anger', 'sadness', 'negative', 'disgust'], 'oil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chloroform': ['negative'], 'cauterize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diversion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'word_of_honor': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'occult_arts': ['fear', 'negative', 'disgust'], 'falsification': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'substantive': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'solve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'easing': ['positive'], 'intime': ['positive', 'trust', 'anticip'], 'parody': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'of_course': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'money': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'trust'], 'fatten_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'carrier_bag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enteral': ['disgust'], 'proximal': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'changeableness': ['anger', 'negative'], 'arbitrament': ['anticip'], 'berceuse': ['positive'], 'futurity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pill': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'blank_shell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'linguistic_communication': ['positive'], 'gloom': ['sadness', 'negative'], 'reddened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-to-do': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'washed-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'strong_belief': ['negative'], 'twin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indisputable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stat_mi': ['surprise', 'trust', 'positive', 'joy'], 'sneaker': ['positive'], 'dwelling_house': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'titan': ['fear'], 'ascend': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'chuck': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'sulkiness': ['positive', 'negative'], 'ante': ['positive', 'trust', 'negative', 'joy'], 'erase': ['fear', 'negative'], 'Dr.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'computer_memory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pasture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ascent': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extinct': ['sadness', 'negative'], 'choir': ['positive', 'trust', 'joy'], 'confirm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pioneer': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'decomposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rock_lobster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weight_unit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breastfeed': ['positive', 'trust', 'joy'], 'swell_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'companionship': ['positive'], 'untamed': ['surprise', 'fear', 'sadness', 'negative', 'anticip'], 'inner_circle': ['anger', 'fear', 'negative'], 'smear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fringe': ['negative'], 'mixer': ['positive'], 'moon_curser': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'kinship_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lasting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provisional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'checkup': ['positive', 'fear', 'trust', 'anticip'], 'illiterate_person': ['negative', 'disgust'], 'dagger': ['fear', 'negative'], 'stria': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bountiful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splint': ['negative'], 'blessed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dreaming': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'equivocalness': ['negative'], 'ill-scented': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'phonograph_needle': ['positive'], 'almighty': ['positive'], 'freeze_out': ['negative'], 'madden': ['anger', 'fear', 'negative'], 'libellous': ['negative'], 'maternal_quality': ['positive', 'trust', 'joy'], 'outmatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'early_days': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'purgatory': ['fear', 'negative', 'disgust'], 'sophisticated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ablutionary': ['positive'], 'intoxication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'romantic': ['anticip', 'positive', 'trust', 'joy'], 'drop_a_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ember': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'indisposition': ['fear', 'negative'], 'whoop_it_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exemplar': ['positive'], 'Babe_Ruth': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'jabbing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conqueror': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'embed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'electrifying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sacerdotal': ['positive'], 'conundrum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'USN': ['trust'], 'citation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subprogram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'credibleness': ['positive', 'trust'], 'deep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resultant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lusterless': ['negative'], 'Rider_Haggard': ['sadness', 'negative', 'fear'], 'deem': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fairish': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'planets': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'deed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'metier': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'film': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tedious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'selfish': ['anger', 'positive', 'negative', 'disgust'], 'get_stuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'personnel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'repent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'weensy': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'note_of_hand': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fruitless': ['sadness', 'negative'], 'stilted': ['positive'], 'important': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'legal_philosophy': ['sadness'], 'sneeze': ['surprise', 'negative', 'disgust'], 'conclusive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recklessness': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'sewer': ['negative', 'disgust'], 'husky': ['anger', 'negative', 'disgust'], 'oral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forbidden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dollar': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'all-day_sucker': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'dance_band': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inexhaustible': ['positive'], 'prodding': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'intonate': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'hideout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hideous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'news_report': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bucketful': ['trust', 'anticip'], 'nervelessness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'difference': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'psyche': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extrusion': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'dictatorship': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'applicable': ['negative'], 'juxtaposition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'thermocouple': ['anticip'], 'corn_whisky': ['anger', 'negative'], 'designedly': ['surprise', 'negative'], 'portable': ['positive'], 'Hall': ['anger', 'fear', 'negative'], 'speckless': ['positive', 'trust', 'joy'], 'preposterous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'illogical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hieratical': ['positive'], 'exasperation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'egg_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fulgent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'everlasting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'component': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Elector': ['trust'], 'Archer': ['anticip'], 'table': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silver_gray': ['surprise', 'negative', 'positive'], 'whipping_boy': ['anger', 'fear', 'negative'], 'whimsical': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'proscription': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perpetuate': ['anticip'], 'cowardly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'usurpation': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resupine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Edward_Teach': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'draw_off': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'unapproved': ['negative'], 'ameer': ['positive'], 'legislator': ['trust'], 'readily': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'congener': ['positive', 'trust'], 'eye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trounce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splash': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'libel': ['anger', 'fear', 'trust', 'negative'], 'raft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jubilant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brow': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'justificative': ['positive'], 'scissor_hold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withstander': ['positive', 'trust'], 'unnumbered': ['positive'], 'lemony': ['surprise', 'fear', 'positive', 'negative', 'anticip'], 'attractive_force': ['positive', 'sadness', 'negative'], 'believability': ['positive', 'trust'], 'subterfuge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'abandon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'addle-head': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'sleuth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Episcopalian': ['trust'], 'gravely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sphere': ['fear', 'negative'], 'birdbrain': ['anger', 'negative', 'disgust'], 'attain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fillip': ['surprise', 'anticip', 'positive', 'joy'], 'awkward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fame': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'inclusion_body': ['trust'], 'ensemble': ['positive', 'trust'], 'police_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Don': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advice': ['trust'], 'hostelry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gravelly': ['anger', 'negative', 'disgust'], 'chute': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'DoI': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'Zea_mays': ['anger', 'negative'], 'hypnotized': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'bewray': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'DoC': ['trust'], 'spiteful': ['anger', 'fear', 'negative', 'disgust'], 'blunder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deserted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'responsibility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'DoS': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_Justice': ['anger', 'positive', 'trust', 'negative'], 'DoT': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'catamount': ['surprise', 'fear'], 'radar': ['trust'], 'automatonlike': ['surprise', 'trust'], 'melodyconcord': ['positive'], 'excogitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thrilling': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'square-toed': ['anger', 'positive', 'trust', 'negative'], 'adios': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Albert_Gore_Jr.': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'wish-wash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disrespectful': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'capriciousness': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'inception': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complain': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'association': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'auspicate': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ashen': ['positive'], 'ashes': ['sadness', 'negative'], 'someone': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'deteriorated': ['sadness', 'negative', 'disgust'], 'nonmigratory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'greyness': ['sadness', 'negative', 'disgust'], 'forthright': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hard': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'plug_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sober': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surly': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'gloominess': ['sadness', 'negative'], 'hart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orient': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'childish': ['anger', 'negative', 'disgust'], 'crowing': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'of_the_essence': ['positive', 'sadness', 'trust', 'negative'], 'seaport': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notary_public': ['trust'], 'debenture_bond': ['anticip'], 'vitiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'print': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fortitude': ['positive', 'trust', 'joy'], 'disobedience': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'circumstance': ['positive'], 'motherfucker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laughable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tortuousness': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'reinforcer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ammonium_hydroxide': ['disgust'], 'desiccate': ['sadness', 'negative'], 'plot': ['positive', 'anticip', 'joy'], 'church_doctrine': ['positive', 'trust'], 'predate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mercy_killing': ['fear', 'sadness', 'negative'], 'copper': ['anger', 'positive', 'fear', 'negative'], 'pipage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barbarian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'find_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'done': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoal': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cheery': ['positive', 'anticip', 'surprise', 'joy'], 'revive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'militant': ['anger', 'fear', 'negative'], 'leash': ['positive', 'trust', 'negative', 'disgust'], 'assumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_along': ['negative'], 'conduit': ['disgust'], 'pare': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'travail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'para': ['anger', 'sadness', 'negative', 'disgust'], 'odium': ['anger', 'fear', 'negative', 'disgust'], 'park': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'part': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'believe': ['positive', 'trust'], 'carnage': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'savagery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filum': ['anger', 'positive', 'joy', 'anticip'], 'ungodly': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'sedate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declare': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'flitter': ['fear', 'negative'], 'relief_pitcher': ['trust'], 'nominee': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'Revelation': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'idler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disgustful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_out': ['trust'], 'majority': ['positive', 'trust', 'joy'], 'building_block': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'insufferable': ['surprise', 'sadness', 'negative', 'positive'], 'Kid': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'easygoing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'reflex_response': ['surprise', 'trust'], 'most': ['positive', 'fear', 'negative'], 'place_upright': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pauperize': ['sadness', 'negative'], 'melodic_theme': ['positive'], 'goodwill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'stereotypic': ['positive', 'trust', 'negative'], 'mediation': ['positive'], 'standoff': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'frowsty': ['negative', 'disgust'], 'express_mirth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malignant': ['anger', 'fear', 'negative'], 'ruin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhappy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roughshod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'override': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '8': ['anticip', 'positive', 'trust', 'joy'], 'devastate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'matte': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wonky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theft': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Lordship': ['positive'], 'silk': ['positive'], 'sill': ['anger', 'joy', 'sadness', 'negative', 'disgust'], 'merchandise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slack_off': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'huff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contagious': ['fear', 'negative', 'disgust'], 'John_Cage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'remove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flesh_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'body_waste': ['negative', 'disgust'], 'severing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'locating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fledged': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'secondary_winding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scruffy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cynical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excavation': ['surprise', 'negative', 'anticip'], 'intemperate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Scorpion': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'niggling': ['negative'], 'lion': ['anger', 'positive', 'fear', 'disgust'], 'dustup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'satiric': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'reconditeness': ['fear', 'negative'], 'changeable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forthcoming': ['positive', 'negative', 'anticip'], 'majuscule': ['positive'], 'fang': ['fear'], 'powerhouse': ['positive'], 'endocarditis': ['fear', 'sadness'], 'distraught': ['sadness', 'negative'], 'burned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complementary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'low-water_mark': ['negative'], 'barrack': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'scuttle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreverence': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'Maker': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'pillock': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'chastening': ['negative'], 'reverse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fine_art': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sultan': ['fear', 'anticip'], 'jumpiness': ['fear'], 'archway': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'hornlike': ['fear', 'negative'], 'spume': ['surprise', 'anticip', 'positive', 'negative', 'joy'], 'simple': ['anger', 'negative', 'disgust'], 'geomorphologic': ['trust'], 'eviction': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'bounciness': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'bluff_out': ['negative'], 'consuming': ['positive'], 'pocketbook': ['negative', 'disgust'], 'dropping': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'amnesia': ['negative'], 'intrusive': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'chattel': ['positive', 'trust', 'negative'], 'gay': ['positive', 'joy'], 'gat': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'gas': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vane': ['surprise', 'sadness'], 'gag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gad': ['fear', 'negative', 'disgust'], 'chatter': ['positive'], 'other_than': ['surprise'], 'rat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bring_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lingo': ['negative'], 'redevelopment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'violently': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'transom': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'enervate': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'shunning': ['fear', 'negative'], 'rheumatism': ['anger', 'fear', 'sadness', 'negative'], 'Alexander_Melville_Bell': ['anger', 'fear', 'negative', 'disgust'], 'dishonor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engrossed': ['surprise', 'negative'], 'externalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'benign': ['positive', 'joy'], 'discourse': ['positive'], 'ampule': ['positive', 'joy'], 'grammatical_construction': ['anger', 'positive', 'sadness', 'negative', 'anticip'], 'measure_out': ['positive', 'trust'], 'devolvement': ['negative'], 'absolved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purpose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chili_pepper': ['negative'], 'timid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'motionless': ['positive', 'joy', 'surprise', 'anticip'], 'mesmerism': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'craved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squatty': ['negative'], 'mesmerise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'toil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'functionary': ['trust', 'negative'], 'prevention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'vindictive': ['anger', 'fear', 'negative', 'disgust'], 'distracting': ['anger', 'negative', 'anticip'], 'discipline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superficial': ['negative'], 'deliberately': ['surprise', 'negative'], 'Snake': ['fear', 'negative'], 'get_onto': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumcision': ['positive'], 'administrative': ['trust'], 'squawk': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'displace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'judgement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smallness': ['negative'], 'beg_off': ['negative'], 'semi': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'flub': ['sadness', 'negative', 'disgust'], 'flue': ['surprise', 'joy', 'trust', 'negative', 'positive'], 'rider': ['positive', 'anticip'], 'flux': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unhearable': ['negative'], 'depositary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mediocrity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_car': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'naughtily': ['sadness', 'negative'], 'humorous': ['positive', 'joy'], 'goldbrick': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'put_option': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'martial': ['anger'], 'doorkeeper': ['positive', 'trust', 'joy'], 'infest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Burke': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'acquaintance': ['positive', 'trust', 'anticip'], 'rote_learning': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'pelt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'genetic_mutation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overprice': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'lusterlessness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pelf': ['positive'], 'larn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismally': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'patient': ['positive', 'negative', 'anticip'], 'rapping': ['anger', 'negative'], 'taxing': ['anger', 'sadness', 'negative', 'fear'], 'wayward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'devolve_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'craw': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'readability': ['positive'], 'hawkish': ['anger', 'fear', 'negative'], 'goods': ['positive'], 'constraint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goody': ['positive', 'trust', 'anticip'], 'break_open': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ounce': ['anger', 'negative', 'disgust', 'anticip'], 'homophile': ['negative'], 'prohibitionist': ['positive', 'trust'], 'bluster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jimmy': ['anger', 'trust', 'negative', 'anticip'], 'kick_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hard-boiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trustingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clack': ['positive'], 'remembrance': ['positive', 'sadness', 'anticip', 'joy'], 'gramme': ['trust'], 'lesson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bring_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pathologic': ['fear', 'sadness', 'disgust', 'negative'], 'vamoose': ['negative'], 'industrial_plant': ['positive', 'trust', 'anticip'], 'mussitate': ['anger', 'negative'], 'parting': ['sadness'], 'derangement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'ferine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'opponent': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'frenzied': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'embrown': ['disgust'], 'cram': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'atrophic_arthritis': ['anger', 'fear', 'sadness', 'negative'], 'aversion': ['anger', 'fear', 'negative', 'disgust'], 'jumbo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shut_up': ['positive'], 'Cross': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'singly': ['surprise', 'anticip', 'positive'], 'single': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flossy': ['positive'], 'tiling': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Mar': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adjudicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cohesive': ['positive', 'trust'], 'forewarned': ['fear', 'negative', 'anticip'], 'assassinate': ['anger', 'fear', 'negative'], 'Man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_completion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Cash': ['anticip', 'positive', 'joy', 'anger', 'fear', 'trust'], 'prepared': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'human_elbow': ['anger'], 'display_board': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'at_random': ['surprise'], 'shrewd': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moderateness': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'dispassionate': ['sadness', 'negative'], 'brainiac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tube': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'native_sulfur': ['anger', 'fear', 'negative'], 'slovenly_woman': ['anger', 'negative', 'disgust'], 'facts_of_life': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charge_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fecund': ['positive'], 'P.A._system': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'corroding': ['negative'], 'rivalry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stupefying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhyme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Navy_SEAL': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'accuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splattering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'guard_dog': ['positive', 'trust'], 'recreation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'iniquity': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'insubordinate': ['positive'], 'sewage': ['negative', 'disgust'], 'insertion': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'exuberant': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'precipitately': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'metal_glove': ['positive', 'fear', 'trust'], 'protraction': ['anticip'], 'primary_election': ['positive', 'negative'], 'habituation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Assault': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mirror_symmetry': ['anger', 'sadness', 'negative', 'disgust'], 'exercise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissection': ['disgust'], 'exchange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spill_the_beans': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leveraging': ['positive'], 'larger-than-life': ['positive'], 'averment': ['trust'], 'nimble': ['positive', 'sadness', 'negative', 'fear'], 'unthinking': ['anger', 'negative', 'disgust'], 'take_aim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pantomimer': ['positive', 'negative', 'surprise'], 'numbness': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'conceit': ['negative'], 'looter': ['sadness', 'negative'], 'concupiscent': ['positive', 'negative', 'disgust'], 'existent': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'courting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radio-controlled_aircraft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abominate': ['anger', 'negative', 'disgust'], 'blizzard': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'decrease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'etymon': ['positive', 'trust', 'surprise'], 'gateway': ['trust'], 'dissonance': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'nauseated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aviate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispirited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upcoming': ['positive'], 'trait': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'trail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'train': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unbelieving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'unforgiving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'account': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reprize': ['positive'], 'mandarin_orange_tree': ['positive', 'trust'], 'obvious': ['positive', 'trust'], 'inviolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feebleness': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'President_George_W._Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'infantry': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'reserves': ['anger', 'fear', 'sadness', 'negative'], 'ascension': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'synchronise': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'magnificently': ['positive'], 'lamb': ['positive', 'trust', 'joy'], 'lama': ['positive'], 'revolving_door': ['anger', 'fear', 'sadness', 'negative'], 'democracy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boxing': ['anger'], 'furnace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leak_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tactfulness': ['positive', 'fear', 'trust'], 'mephistophelian': ['fear', 'negative', 'disgust'], 'luxuria': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'inst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legality': ['anger', 'fear', 'negative', 'disgust'], 'bluff': ['positive', 'negative'], 'physic': ['positive'], 'trifling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ambiguous': ['positive', 'trust', 'negative'], 'inkiness': ['sadness', 'negative', 'fear'], 'bind': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bing': ['anger', 'fear', 'negative', 'anticip'], 'picturesque': ['positive', 'joy'], 'sidelong': ['trust'], 'nonstarter': ['fear', 'sadness', 'disgust', 'negative'], 'animadversion': ['negative'], 'postmortem_examination': ['fear', 'sadness', 'disgust', 'negative'], 'hydrocephaly': ['fear', 'sadness', 'disgust', 'negative'], 'arcanum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'looping': ['fear', 'sadness', 'negative'], 'rigorousness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'clown_around': ['surprise', 'anticip', 'positive', 'joy'], 'gramps': ['trust'], 'untempting': ['sadness', 'negative', 'disgust'], 'braggart': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'judicatory': ['trust', 'anticip'], 'sinistrality': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'decorum': ['anger', 'positive', 'disgust'], 'Negro': ['sadness', 'negative'], 'kindergarten': ['trust'], 'impervious': ['positive'], 'descendants': ['anticip', 'positive', 'trust', 'joy'], 'spell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiesta': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'self-satisfaction': ['positive'], 'heathenish': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'courtroom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rise_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thrill': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'freshness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blazing': ['anger', 'negative', 'disgust'], 'reata': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'topical_anaesthetic': ['anticip'], 'reed_organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'virulent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_the_Interior': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mucilage': ['anger', 'negative'], 'junkie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'licking': ['sadness', 'negative'], 'tantalization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'matt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relinquishing': ['positive', 'negative'], 'point_of_accumulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'messenger': ['trust'], 'stud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stun': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fthm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sharp-worded': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hanker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'folderal': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'takeon': ['sadness', 'negative', 'fear'], 'dissatisfactory': ['anger', 'sadness', 'negative', 'disgust'], 'pocket-size': ['negative'], 'nether_region': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grieving': ['anger', 'sadness', 'negative', 'fear'], 'slacken_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'savour': ['positive', 'negative', 'disgust'], 'one_dollar_bill': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'strategic': ['positive'], 'disinvest': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shake_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'hostile_expedition': ['positive', 'anticip'], 'ancient': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'call_out': ['surprise'], 'pedigreed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thwarting': ['anger', 'negative'], 'life_force': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'blackball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnanimousness': ['positive', 'trust', 'anticip'], 'John_Mill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liquor': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cabin': ['positive', 'trust'], 'eavesdrop': ['negative'], 'completed': ['positive', 'joy'], 'falderol': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'dreary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discretionary': ['positive'], 'resist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demented': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumspect': ['positive', 'anticip'], 'amplitude': ['anticip', 'positive', 'trust', 'joy'], 'take_off': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'coronation': ['positive', 'trust', 'joy'], 'gambol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imaginative': ['positive'], 'panic_attack': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'neutralize': ['positive', 'joy', 'negative', 'disgust', 'anticip'], 'fluctuation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snow_leopard': ['anger', 'negative', 'disgust', 'anticip'], 'Goodman': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'unlikely': ['negative'], 'pelvic_girdle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unfeelingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpellation': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'parky': ['negative'], 'costliness': ['positive'], 'skillful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mid': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'mix': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'rhythm_method_of_birth_control': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'neaten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erosive': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'mir': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'bemused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hankering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'propagate': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'enate': ['positive', 'negative', 'anticip'], 'sedan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sally': ['anger', 'surprise', 'fear', 'negative'], 'overestimation': ['surprise', 'negative'], 'stranded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'request': ['positive', 'trust'], 'crediting': ['positive', 'trust'], 'approach_pattern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'break_of_day': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'traveller': ['positive', 'anticip'], 'galvanizing': ['positive', 'surprise', 'joy'], 'disconnectedness': ['sadness', 'negative', 'anticip'], 'sidetrack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'floodlight': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'gasping': ['fear', 'negative'], 'Worth': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'staff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bush-league': ['anger', 'surprise', 'fear', 'negative'], 'fumbler': ['negative'], 'satan': ['fear', 'negative', 'disgust'], 'outwear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inferior': ['sadness', 'negative'], 'recidivate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mislay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demigod': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'air_pressure': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'finical': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'shelling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gunman': ['anger', 'negative'], 'enhancer': ['negative'], 'sluttish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'object_lens': ['positive', 'trust', 'negative', 'anticip'], 'Passion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'escape_from': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'level_best': ['positive'], 'pattern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'safety_fuse': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'transpose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regretful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurance_company': ['fear', 'trust', 'negative'], 'firmness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invertebrate_foot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'innumerous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'festering': ['negative', 'disgust'], 'exclaim': ['surprise'], 'drop_behind': ['negative', 'disgust'], 'taking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swallow': ['positive'], 'Mafia': ['fear', 'negative'], 'relevant': ['positive', 'trust', 'negative'], 'beguiler': ['anger', 'negative'], 'abortive': ['sadness', 'negative'], 'beguiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puerility': ['positive', 'joy'], 'flourishing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'square_block': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hurriedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idle_words': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gaze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proposal': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'curtail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'protuberant': ['negative'], 'refreshful': ['positive'], 'dramatic_art': ['positive', 'joy'], 'bulk': ['positive', 'trust', 'joy'], 'finished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fork_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bulb': ['negative'], 'volunteer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'cypher': ['negative'], 'sensationalistic': ['fear', 'negative'], 'synodic_month': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'garbage_dump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kinfolk': ['positive', 'trust', 'negative', 'disgust'], 'almost': ['positive', 'fear', 'negative'], 'dissent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contiguity': ['anticip'], 'Moron': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'answerability': ['positive', 'trust'], 'anathematize': ['anger', 'fear', 'sadness', 'negative'], 'disengage': ['negative'], 'slammer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'SOB': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oink': ['anger', 'sadness', 'negative', 'disgust'], 'go_through': ['negative'], 'foxy': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sporting_house': ['negative', 'disgust'], 'infer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stamen': ['positive', 'trust'], 'pothouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sunburn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slaphappy': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'magnetics': ['positive'], 'pickpocket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'variable_quantity': ['surprise'], 'knotty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'come_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inwardness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'pamperer': ['sadness', 'negative'], 'lovesome': ['positive', 'trust', 'joy'], 'acidulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ratify': ['positive', 'joy', 'trust', 'surprise'], 'taillike': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'necessitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wipe_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sexual_perversion': ['anger', 'sadness', 'negative', 'disgust'], 'well-worn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pretermit': ['negative'], 'pushchair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'add': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ado': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heartiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'match': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'molding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'news_media': ['trust'], 'deceased_person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accessible': ['positive', 'negative'], 'propel': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'authority': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrub': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'rattlesnake': ['fear'], 'bill_of_fare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'masked': ['surprise', 'negative', 'anticip'], 'assuming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'thinly': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cooccur': ['surprise', 'positive'], 'stellar': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'crossing': ['positive'], 'petit_larceny': ['sadness', 'negative'], 'raiding': ['negative'], 'about': ['positive', 'fear', 'negative'], 'actual': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'certainty': ['surprise', 'anticip', 'negative', 'positive'], 'material_body': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pain_in_the_neck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fleshy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'amusive': ['positive', 'negative', 'disgust', 'joy'], 'buy_the_farm': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'obliterated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'functional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'esteem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gray-headed': ['sadness', 'negative'], 'ridge': ['fear'], 'credit_rating': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stainless': ['positive'], 'luminary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'younker': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'gross_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwished': ['sadness', 'negative'], 'glib': ['negative'], 'pitilessness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'moo-cow': ['fear', 'sadness', 'disgust', 'negative'], 'repeated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiller': ['fear', 'negative'], 'six-gun': ['anger', 'fear', 'sadness', 'negative'], 'Panthera_uncia': ['anger', 'negative', 'disgust', 'anticip'], 'dekameter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'infanticide': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'fantan': ['trust'], "ABC's": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artillery_unit': ['fear', 'negative'], 'unfavorable_position': ['negative'], 'chain_armour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in-between': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salad_days': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proceeds': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oaf': ['surprise', 'sadness', 'negative', 'disgust', 'anticip'], 'oak': ['anger', 'positive', 'sadness', 'negative', 'joy'], 'impossibility': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'oar': ['sadness', 'negative', 'anticip'], 'thread_maker': ['fear', 'sadness', 'negative'], 'gooselike': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'miscreation': ['fear', 'sadness', 'negative', 'disgust'], 'wallow': ['sadness', 'negative', 'disgust'], 'Polygonia_comma': ['positive', 'trust'], 'brownness': ['disgust'], 'requital': ['anger', 'fear', 'sadness', 'negative'], 'hold_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wallop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manna_from_heaven': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'come-at-able': ['anger', 'positive', 'sadness', 'negative', 'anticip'], 'toss_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sense_of_hearing': ['fear', 'negative'], 'entreat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloodsucker': ['fear', 'negative', 'disgust'], 'becharm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scouter': ['anger', 'positive', 'negative'], 'limited': ['anger', 'positive', 'sadness', 'negative'], 'hitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enteric': ['disgust'], 'lay_eyes_on': ['negative'], 'yonder': ['anger', 'fear', 'negative'], 'poorly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muzzle': ['fear', 'negative'], 'violate': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cabriolet': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'powderpuff': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'basketball_game': ['positive', 'anticip', 'joy'], 'agitator': ['positive', 'trust'], 'under': ['anger', 'fear', 'sadness', 'negative'], 'conjecture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phial': ['positive', 'joy'], 'religious_service': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'jack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frailty': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'underreckoning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'long-wearing': ['positive', 'trust'], 'Irish_pound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bicycle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ungenerous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'consistent': ['positive'], 'manus': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'infiltration': ['positive', 'negative'], 'channelize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discontentedness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'worsen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poison': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'equilibrise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissoluteness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insinuate': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'histrion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endorse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feisty': ['anger', 'sadness', 'negative'], 'get_over': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'represented': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aftermath': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'enrol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undulation': ['positive', 'fear', 'trust', 'negative'], 'forum': ['positive', 'trust'], 'venturer': ['anger', 'fear', 'negative'], 'cosmopolite': ['positive', 'trust'], 'herniation': ['negative', 'disgust'], 'brain-teaser': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mentor': ['positive', 'trust'], 'red_ink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'punishment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'hairsbreadth': ['positive', 'trust', 'negative', 'disgust'], 'swearing': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'stray': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skin_senses': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'encirclement': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'strap': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'clog_dance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rakehell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Book': ['positive', 'trust', 'negative'], 'slicker': ['anger', 'negative'], 'manoeuver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swingy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hospital': ['positive', 'fear', 'trust', 'sadness'], 'mediate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swinge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tradesman': ['trust'], 'assessment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mystical': ['fear', 'negative', 'disgust'], 'barbarous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpenetrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grief': ['sadness', 'negative'], 'deciduous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'panoptic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hutch': ['positive', 'fear', 'sadness'], 'micturate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tremendously': ['positive'], 'moral_excellence': ['positive', 'trust', 'joy'], 'install': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appendage': ['fear', 'sadness', 'disgust', 'negative'], 'aggrandize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear'], 'ingenuity': ['positive'], 'keep_going': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mayhem': ['anger', 'fear', 'negative'], 'fanatism': ['fear'], 'scolding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vagrant': ['fear', 'sadness', 'negative', 'anticip'], 'evenhandedly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'aching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiredly': ['sadness', 'negative'], 'cyberspace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moisten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'reason_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frailness': ['sadness', 'negative'], 'bootlick': ['fear', 'sadness', 'negative', 'disgust'], 'delicacy': ['positive', 'trust', 'anticip'], 'creative_person': ['positive'], 'adhesive_friction': ['positive', 'negative'], 'snarling': ['anger', 'negative'], 'Martha_Jane_Burke': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'complexity': ['negative'], 'ultimate': ['positive', 'sadness', 'anticip'], 'aloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vapor': ['positive'], 'misadventure': ['surprise', 'sadness', 'negative', 'disgust', 'fear'], 'Lunaria_annua': ['positive', 'trust', 'negative', 'disgust'], 'alternation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clayey': ['anger', 'fear', 'sadness', 'negative'], 'underside': ['positive', 'sadness', 'negative', 'fear'], 'nonimitation': ['positive', 'trust'], 'womanhood': ['positive', 'trust'], 'besotted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entranced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compelling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hunt_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "St._Elmo's_fire": ['positive', 'trust', 'joy'], 'confuse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disreputable': ['anger', 'fear', 'negative', 'disgust'], 'protactinium': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'shadowy': ['fear', 'negative'], 'wicket_gate': ['positive'], 'affiliate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sisterhood': ['anger', 'surprise', 'sadness', 'trust', 'positive'], 'cranny': ['negative'], 'waffle': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'ordinary_bicycle': ['positive'], 'double-decker': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Satanic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'depress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsighted': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fraught': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Chancellor': ['trust'], 'Howard_Carter': ['trust'], 'heavenly': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bitingly': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'rabidity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eternal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stipend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'masterpiece': ['positive', 'joy'], 'icky': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'addlehead': ['anger', 'negative', 'disgust'], 'ritual': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'correctness': ['trust'], 'quintessence': ['anger', 'fear', 'sadness', 'negative'], 'legal_document': ['positive', 'trust', 'negative'], 'hopeless': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ill_turn': ['anger', 'sadness', 'negative', 'disgust'], 'aspire': ['positive', 'anticip', 'joy'], 'tick_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perceptual_constancy': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'sword_lily': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hearing_loss': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'rank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bombard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amortization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bandaged': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'traitorous': ['sadness', 'negative', 'disgust'], 'high_up': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'tor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'top': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indeterminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tow': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'tot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ton': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inconvenient': ['anger', 'sadness', 'negative', 'disgust'], 'submersion': ['anger', 'positive', 'fear', 'trust', 'negative'], 'tog': ['negative', 'disgust'], 'tod': ['trust'], 'urban': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'pain_in_the_ass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overdraw': ['anger', 'negative'], 'pondering': ['positive', 'sadness'], 'sync': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'flimflam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alcoholic_beverage': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'doubtfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heart_and_soul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rampage': ['anger', 'fear', 'negative'], 'divisible': ['trust'], 'bloated': ['negative', 'disgust'], 'rub_out': ['fear', 'negative'], 'flame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mirth': ['positive', 'joy'], 'legibility': ['positive'], 'Dubya': ['anger', 'surprise', 'fear', 'negative'], 'inking_pad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'give_the_sack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barde': ['anger', 'positive', 'fear', 'negative'], 'Clarence_Shepard_Day_Jr.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turn_on': ['positive', 'trust', 'anticip'], 'snot': ['negative'], 'snob': ['negative'], 'credit_crunch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clunky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complexed': ['negative'], 'infliction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phantasy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plenty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ceremonial_occasion': ['surprise', 'positive', 'joy'], 'pressure_sensation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'phantasm': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'interject': ['anger', 'positive', 'fear', 'negative'], 'pyrexia': ['fear', 'negative'], 'gravitas': ['positive', 'trust'], 'reputation': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'poisonous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'yank': ['anger', 'surprise', 'fear', 'negative', 'positive'], 'radix': ['trust', 'negative'], 'crotchet': ['fear', 'trust', 'negative'], 'manipulation': ['anger', 'fear', 'negative'], 'sage': ['positive', 'trust', 'joy'], 'skitter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radio': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tax_shelter': ['positive', 'trust'], 'linguistic_scientist': ['positive', 'trust'], 'adoration': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bluing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abjure': ['anger', 'negative'], 'refreshment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disgust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'lodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'announce': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'dullness': ['negative'], 'continuity': ['fear', 'sadness', 'disgust', 'negative'], 'approbatory': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'succinct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hostility': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'watch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fluid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prognosticative': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skin_rash': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'report': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue_runner': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'overbearing': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'catgut': ['anger', 'positive', 'trust'], 'erupt': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'automatic': ['surprise', 'trust'], 'upthrust': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'elevated_railway': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'habit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrest': ['negative'], 'tone_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detection': ['positive'], 'ovalbumin': ['anticip', 'positive', 'trust', 'joy'], 'bent_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'byword': ['positive'], 'gentility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accede': ['positive'], 'reed_instrument': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'interdiction': ['negative'], 'unalienable': ['positive'], 'sissiness': ['positive', 'negative'], 'bellowing': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unconscionable': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'approach': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'incarnation': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dramatise': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'tarry': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'hokum': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'felt_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goddess': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'irregular': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'variance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gamey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salt_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'degage': ['negative'], 'political_campaign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'majestic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'litigant': ['negative'], 'trust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liquidity_crisis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_over': ['negative'], 'simplification': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'submarine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'communion': ['positive', 'trust', 'joy'], 'expected': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear'], 'sloppiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oftenness': ['positive'], 'engine_block': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sprite': ['positive', 'fear', 'negative'], 'second-rater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pennsylvania': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'unaccredited': ['negative'], 'patronizing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weewee': ['positive', 'sadness', 'negative'], 'windup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leprose': ['negative'], 'military_reserve': ['positive', 'negative'], 'lie_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devotedness': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'procedure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purifying': ['positive'], 'compliance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'prolate': ['positive', 'sadness', 'negative'], 'gentle_wind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comminute': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'proportionateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expenses': ['negative'], 'purchasable': ['anger', 'sadness', 'negative', 'disgust'], 'suggest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Old_World_chat': ['positive', 'fear', 'joy', 'negative', 'anticip'], 'overstep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'banality': ['trust', 'anticip'], 'forsaking': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lusty': ['positive', 'negative', 'disgust'], 'satellite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roiling': ['fear', 'negative'], 'pick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deflect': ['anger', 'negative', 'anticip'], 'amatory': ['anticip', 'positive', 'trust', 'joy'], 'rearwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_effect': ['positive', 'trust', 'negative'], 'gabble': ['negative'], 'electronic_organ': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'savings': ['positive'], 'incapable': ['anger', 'sadness', 'negative'], 'mother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appease': ['positive'], 'market_place': ['positive'], 'mending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'get_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ingeminate': ['positive', 'anticip'], 'slackness': ['negative'], 'work_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ell': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vibration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meanly': ['positive'], 'elf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eld': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'teenager': ['positive', 'negative'], 'misprint': ['negative'], 'domesticise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'tolerable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'subject_area': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spanner': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'authorship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roach': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'appearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swill': ['negative', 'disgust'], 'candidness': ['positive', 'trust', 'negative', 'disgust'], 'hunt': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'dishonest': ['anger', 'sadness', 'negative', 'disgust'], 'zoom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foetor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regiment': ['fear'], 'hunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flaps': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arbitrary': ['anger', 'negative'], 'fixity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roamer': ['anger', 'positive', 'negative'], 'apposition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disfigurement': ['fear', 'sadness', 'disgust', 'negative'], 'burgeon_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smarmy': ['positive'], 'proceeding': ['anticip'], 'self-effacing': ['fear', 'negative'], 'ear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vestal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intolerant': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'splendor': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'ray_of_light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'executable': ['negative'], 'blooper': ['sadness', 'negative', 'disgust'], 'discount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bylaw': ['trust'], 'yawp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'latrine': ['negative', 'disgust'], 'plum': ['positive', 'fear', 'negative', 'anticip'], 'enshroud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trustworthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'guest': ['positive', 'trust', 'negative'], 'square_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glowering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'schizophrenic_disorder': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'familiar_spirit': ['anticip', 'positive', 'trust', 'joy'], 'crack_cocaine': ['fear'], 'civic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'civil': ['positive', 'trust', 'joy'], 'filter_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'naturalized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have_words': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'serve_well': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Enlightenment': ['positive', 'trust', 'joy'], 'cubicle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spikelet': ['anger', 'positive', 'negative'], 'git': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sneezing': ['surprise', 'negative', 'disgust'], 'gig': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'virgin': ['positive', 'joy', 'trust', 'anticip'], 'puffiness': ['fear', 'negative'], 'newsperson': ['positive', 'trust'], 'chance_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wavering': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'questionable': ['positive', 'trust', 'negative', 'disgust'], 'intolerance': ['anger', 'fear', 'negative', 'disgust'], 'twelfth_part': ['fear'], 'Witwatersrand': ['negative'], 'wireless': ['anger', 'surprise', 'anticip', 'positive'], 'satisfactorily': ['positive'], 'gold_rush': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quicksilver': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'decorate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fundament': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruiner': ['anger', 'fear', 'negative'], 'forearm': ['anger', 'anticip'], 'fury': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bubble_over': ['negative'], 'cocain': ['sadness', 'negative'], 'annoying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'injurious': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'fly_the_coop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hinge_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loosening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alcove': ['anger', 'fear', 'negative'], 'vanquisher': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'unbalanced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'node': ['positive', 'trust', 'negative'], 'subsidize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cleric': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'toad': ['negative', 'disgust'], 'silver_medal': ['surprise', 'negative', 'positive'], 'discharge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cast_aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'exigent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intimacy': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'handbill': ['negative', 'anticip'], 'discerp': ['sadness', 'negative'], 'coach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sourness': ['positive', 'negative'], 'focus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'empathize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'icy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'environment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charge': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'quash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avowal': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'monish': ['anticip', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'brave_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'outmoded': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'imposture': ['negative'], 'slam_dance': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'coop': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'underpay': ['anger', 'sadness', 'negative'], 'gravitate': ['anticip'], 'inexistence': ['negative'], 'belt_out': ['anger', 'surprise', 'fear', 'negative'], 'untenable': ['negative'], 'cook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coon': ['negative'], 'cool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encroach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guzzling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invader': ['anger', 'fear', 'sadness', 'negative'], 'ex-serviceman': ['anger', 'positive', 'trust', 'negative'], 'obsolete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'T._H._White': ['anticip', 'positive', 'trust', 'joy'], 'voucher': ['trust'], 'mental_hospital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bacteria': ['fear', 'sadness', 'disgust', 'negative'], 'Haggard': ['sadness', 'negative', 'fear'], 'fade_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pin_tumbler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finding_of_fact': ['fear'], 'spattering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'male': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'shove': ['anger', 'positive', 'fear', 'negative'], 'healthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravaging': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'guilty': ['anger', 'sadness', 'negative'], 'manufacturing_business': ['positive'], 'denunciation': ['anger', 'fear', 'negative', 'disgust'], 'hospitality': ['positive'], 'lowbred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'emerge': ['surprise', 'fear', 'sadness', 'negative'], 'convolution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'erudite': ['positive'], 'connivance': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'brush_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Communion': ['positive', 'trust', 'joy'], 'paralyzed': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'roseola': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'vivid': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hordeolum': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'launch_pad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'analgetic': ['positive', 'trust'], 'necessitous': ['negative'], 'handler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irrelation': ['sadness', 'negative', 'fear'], 'bombastic': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'muffle': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Eve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'academician': ['positive', 'trust'], 'flapping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prophecy': ['anticip'], 'smarminess': ['disgust'], 'achieve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tittivate': ['positive'], 'nexus': ['negative'], 'fight_back': ['anger', 'negative'], 'therapeutical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'counting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligible': ['negative'], 'escritoire': ['negative'], 'rawness': ['positive', 'joy'], 'dress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '1': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cardinal': ['positive', 'negative', 'disgust', 'surprise'], 'deductive_reasoning': ['surprise', 'fear', 'sadness', 'negative'], 'forestage': ['positive'], 'gospel_truth': ['positive', 'trust'], 'paramount': ['positive'], 'professing': ['positive', 'trust'], 'information': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'impartial': ['positive', 'trust'], 'scoff': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'maritime': ['trust'], 'receptivity': ['positive'], 'muggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fallal': ['positive', 'surprise'], 'dynamical': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'liquid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'propriety': ['negative'], 'divinity_fudge': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stonemason': ['positive'], 'trouble_oneself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rottenness': ['negative', 'disgust'], 'plausive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'White': ['anticip', 'positive', 'trust', 'joy'], 'past_tense': ['positive', 'trust', 'joy'], 'lonely': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'messiness': ['negative'], 'Ulysses_Grant': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'venire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conquer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lustful': ['positive', 'negative', 'disgust'], 'boozing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'occult': ['fear', 'negative', 'disgust'], 'tern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'term': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'name': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'customs_duty': ['positive'], 'clutch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insobriety': ['negative'], 'distorted_shape': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'disciplinal': ['positive'], 'synchronize': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'one_shot': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'hypothesise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'climb_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'call_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'individually': ['surprise', 'anticip', 'positive'], 'ailment': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'exanimate': ['fear', 'sadness', 'negative'], 'spiciness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'political_sympathies': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'apothecary': ['positive', 'trust'], 'colourize': ['sadness', 'negative', 'disgust'], 'obsession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infarct': ['surprise', 'fear', 'negative'], 'inadequacy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'muckle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contemporise': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'gram': ['trust'], 'antiphonal': ['positive', 'trust', 'anticip'], 'mapping': ['surprise', 'trust', 'negative', 'positive'], 'oasis': ['anticip', 'positive', 'trust', 'joy'], 'flyer': ['anger', 'negative', 'disgust', 'anticip'], 'marionette': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'tranquilize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpaid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'place': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thigh-slapper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'childhood': ['positive', 'joy'], 'branding_iron': ['negative'], 'skim_over': ['anger', 'sadness', 'negative', 'disgust'], 'revenue': ['anger', 'sadness', 'negative', 'disgust'], 'act_as': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'generative': ['positive', 'negative', 'joy'], 'array': ['positive'], 'engineer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ventilate': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'given': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'district': ['fear', 'trust'], 'provenance': ['anticip', 'positive', 'negative', 'joy', 'anger', 'trust'], 'flutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrifying': ['surprise', 'sadness', 'negative', 'disgust', 'fear'], 'renter': ['positive', 'trust'], 'bounty': ['anticip', 'positive', 'trust', 'joy'], 'giver': ['positive', 'fear'], 'girder': ['positive', 'trust'], 'cope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'state_of_matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "bull's_eye": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'copy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'specify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'population': ['positive'], 'local_anaesthetic': ['anticip'], 'Concord': ['positive', 'trust'], 'sere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aesthetic': ['positive', 'joy'], 'outcome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'froth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'Fucus_serratus': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'generalization': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'scorecard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transmission_system': ['anticip', 'positive', 'negative', 'disgust', 'fear', 'trust'], 'narrow-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'come_off': ['negative'], 'popular_opinion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ideal': ['anticip', 'positive', 'trust', 'joy'], 'seedcase': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'unavailing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fracture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cephalalgia': ['negative'], 'blunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sellable': ['positive'], 'betrayal': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cleared': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flood_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'misfire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'adopt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hungry': ['negative', 'anticip'], 'operate_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extreme_right-winger': ['negative'], 'overgrow': ['negative'], 'permeable': ['anger', 'fear'], 'trespass': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excitableness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hustler': ['positive', 'negative'], 'Helen_Wills': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'watertight': ['positive'], 'bottle_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'partake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invocation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slimly': ['negative'], 'impressment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hedge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reveal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attentiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warhorse': ['anger', 'positive', 'trust', 'negative'], 'edit_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workman': ['positive', 'trust', 'negative'], 'obliterate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imposing': ['positive', 'trust'], 'vizor': ['surprise', 'anticip'], 'snack_bar': ['anger', 'negative'], 'distraint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instrumentate': ['positive'], 'outside': ['negative'], 'hiss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memorialisation': ['positive', 'sadness', 'anticip', 'joy'], 'dinero': ['positive'], 'communicatory': ['positive'], 'animus': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'file_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pronto': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'acedia': ['negative', 'disgust'], 'duty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cabal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'key': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'pow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colony': ['fear', 'negative', 'anticip'], 'travelling_bag': ['negative', 'disgust'], 'pop': ['positive', 'sadness', 'negative', 'disgust', 'surprise'], 'satisfaction': ['negative'], 'atrociously': ['sadness'], 'dependant_upon': ['anticip'], 'pod': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'teammate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gerald_R._Ford': ['positive'], 'double-faced': ['anger', 'sadness', 'negative', 'disgust'], 'rein_in': ['positive'], 'Hellenic': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'blessing': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'tiger': ['fear', 'negative'], 'well-fixed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minister': ['positive', 'trust', 'negative', 'joy'], 'craftiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'careful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irrelevant': ['negative'], 'dribble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'premature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'melioration': ['positive', 'trust', 'joy'], 'cutting_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'aphoristic': ['trust'], 'satinpod': ['positive', 'trust', 'negative', 'disgust'], 'mound': ['positive', 'fear', 'negative', 'anticip'], 'cetacean': ['negative'], 'noncritical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'coupled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'scintillant': ['positive', 'joy'], 'contrive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discrepancy': ['anger', 'fear', 'sadness', 'negative'], 'kick_the_bucket': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'funeral_undertaker': ['sadness'], 'couplet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discriminative_stimulus': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decisively': ['positive'], 'candied': ['positive'], 'check': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'persona': ['positive', 'negative', 'disgust', 'anticip'], 'general_assembly': ['trust'], 'nest': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'refusal': ['negative'], 'ness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decently': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lamentation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lute': ['positive', 'negative', 'disgust', 'joy'], 'unqualified': ['anger', 'sadness', 'negative', 'disgust'], 'cartoon': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fasting': ['sadness', 'negative'], 'relegation': ['negative'], 'magical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperil': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-generated': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'disbursal': ['negative'], 'Heron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plumb_bob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fineness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'satin': ['positive'], 'fastness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anamnesis': ['positive', 'sadness', 'anticip', 'joy'], 'conveyance_of_title': ['trust'], 'rosy': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'disrupt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sociality': ['positive'], 'impound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refutal': ['fear'], 'cold-eyed': ['sadness', 'negative'], 'inflation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'portion_out': ['anticip', 'positive', 'trust', 'joy'], 'confined': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accepted': ['positive'], 'exquisitely': ['positive'], 'flyblown': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wrongful': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'snort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'four-in-hand': ['trust'], 'substandard': ['sadness', 'negative'], 'mathematical_operation': ['anger', 'fear', 'negative'], 'joking': ['positive'], 'uncloudedness': ['positive'], 'pay_back': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'grind_to_a_halt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shortcoming': ['negative'], 'gibelike': ['anger', 'sadness', 'negative', 'disgust'], 'Ameiurus_Melas': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'ornamentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accueil': ['positive'], 'bodacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'journeyman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roly-poly': ['sadness', 'negative', 'disgust'], 'cornucopia': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'jeer': ['anger', 'negative', 'disgust'], 'faineant': ['negative'], 'stand': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'equalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pig_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balsamic': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'in_spades': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'garb': ['negative', 'disgust'], 'mental_quickness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'breakwater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forewarn': ['fear', 'negative', 'anticip'], 'accounts': ['trust'], 'unfertile': ['sadness', 'negative'], 'dislocated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potpourri': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conciseness': ['positive', 'trust', 'surprise'], 'burry': ['fear', 'negative'], 'grease-gun': ['anger', 'fear', 'negative', 'anticip'], 'regard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ELF': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imbecilic': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'foundation_garment': ['trust', 'positive', 'anticip', 'joy'], 'promote': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emancipate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwellness': ['positive', 'fear', 'sadness', 'negative', 'disgust'], 'feeler': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'security_system': ['positive', 'fear', 'trust', 'negative'], 'ennui': ['sadness', 'negative'], 'inoculation': ['trust', 'anticip'], 'undoable': ['anger', 'sadness', 'negative'], 'ruffian': ['anger', 'fear', 'sadness', 'negative'], 'cellblock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Saint_Mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encompass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heather': ['negative'], 'voice_communication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coruscant': ['positive', 'joy'], 'compel': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'heathen': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'go_over': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'sully': ['sadness', 'negative'], 'briefly': ['anticip'], 'replenishment': ['positive'], 'winking': ['negative', 'disgust'], 'unbend': ['positive', 'anticip'], 'lengthiness': ['anticip'], 'despoil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recognise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Italian_sandwich': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disagreeing': ['anger', 'sadness', 'negative'], 'apparel': ['negative', 'disgust'], 'tanned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'all': ['positive', 'trust'], 'diss': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'quizzical': ['anger', 'sadness', 'negative', 'disgust'], 'alb': ['trust'], 'swerving': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'call_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_lion': ['anger', 'positive', 'fear', 'disgust'], 'disc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dish': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wanton': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispirit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'homage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsatisfying': ['anger', 'sadness', 'negative', 'disgust'], 'leave_office': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diddly-squat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oblation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'admonition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_control': ['positive'], 'gibbosity': ['anger', 'positive', 'fear', 'negative'], 'awful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high_quality': ['positive'], 'sentimental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proscribed': ['anger', 'fear', 'negative', 'disgust'], 'intimidate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'academic_degree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agnise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dental_caries': ['negative', 'disgust'], 'programme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'louvre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reins': ['positive'], 'sleep_with': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'jugful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'loll_around': ['negative'], 'slothfulness': ['negative', 'disgust'], 'whap': ['anger'], 'localization': ['anticip'], 'crust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overload': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wham': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pooh-pooh': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'multitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Rush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'passiveness': ['negative'], 'unwaveringly': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'behaviour': ['anger', 'surprise', 'negative', 'disgust'], 'faker': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'personable': ['positive'], 'piquant': ['positive', 'negative'], 'subscribe_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jewel_casket': ['fear', 'sadness', 'negative'], 'imaging': ['positive', 'anticip', 'joy'], 'right_wing': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'wakeless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maid_of_honor': ['positive', 'trust', 'joy'], 'proceed': ['anticip'], 'flavouring': ['positive', 'sadness'], 'reproach': ['anger', 'sadness', 'negative', 'disgust'], 'faint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irritate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Robert_Edward_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'unthinkable': ['anger', 'fear', 'negative', 'disgust'], 'minor': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'prosecuting_officer': ['anger', 'fear', 'negative'], 'retarding_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'basically': ['positive'], 'mellow': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'incurvature': ['negative'], 'glad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parable': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'sleeveless': ['sadness', 'negative'], 'crossbreed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfairness': ['anger', 'sadness', 'negative'], 'pony': ['anticip', 'positive', 'trust', 'joy'], 'tortious': ['anger', 'negative', 'disgust'], 'mental_disorder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pond': ['positive', 'trust', 'negative', 'anticip'], 'allege': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Caucasian': ['anticip', 'positive', 'trust', 'joy'], 'concordat': ['positive', 'trust'], 'court': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'escape_cock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acrimony': ['fear', 'negative'], 'goad': ['fear', 'negative', 'disgust'], 'overbalance': ['positive', 'anticip'], 'titillation': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'niminy-piminy': ['anger', 'positive', 'trust', 'negative'], 'bawdy': ['negative'], 'goat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blackamoor': ['sadness', 'negative'], 'shady': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recrudesce': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'assailant': ['anger', 'fear', 'sadness', 'negative'], 'shade': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'essence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonperformance': ['anger', 'negative', 'disgust'], 'Harkat_ul-Mujahedeen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outraged': ['anger', 'negative'], 'style': ['positive', 'anticip'], 'prat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'call': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pray': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undueness': ['negative'], 'resort': ['anticip'], 'physical_science': ['positive'], 'thoroughbred': ['positive'], 'sucking': ['anger', 'sadness', 'negative'], 'nautical_mile': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'geological_period': ['trust'], 'frigate': ['fear'], 'unnumerable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'debacle': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'friendship': ['positive', 'trust', 'joy'], "cable's_length": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nicotine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_scientist': ['positive'], 'dubitable': ['negative'], 'organised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Reading': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reverent': ['negative'], 'clandestine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adhere': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chaffer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reverend': ['positive', 'joy'], 'shipment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'huntsman': ['fear', 'anticip', 'sadness', 'negative'], 'juvenility': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'platitude': ['trust', 'anticip'], 'mellowness': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'svelte': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'execration': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'genus_Lama': ['positive'], 'bushed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'consequence': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'bushel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ding': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dine': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'feel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debit_entry': ['sadness', 'negative'], 'aseptic': ['sadness', 'negative'], 'feet': ['negative'], 'sympathy': ['positive', 'sadness'], 'notify': ['anger', 'positive', 'fear', 'trust', 'negative'], 'soapy': ['positive'], 'anathemize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Department_of_Transportation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'grime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flimsy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brisken': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'overbold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spew_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aristocracy': ['positive'], 'disqualification': ['negative'], 'oversupply': ['negative', 'disgust'], 'checklist': ['positive', 'trust'], 'index_number': ['trust'], 'outrageous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superfluity': ['surprise', 'fear', 'sadness', 'negative'], 'architect': ['positive', 'trust'], 'inventiveness': ['positive'], 'cognitive_process': ['anger', 'fear', 'negative'], 'restful': ['positive', 'negative'], 'risky': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'recording_label': ['trust'], 'foresighted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holy_person': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'suspicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bookworm': ['positive', 'negative'], 'engulf': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'vileness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hard_up': ['anger', 'positive', 'fear', 'negative'], 'unprocessed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhapsodic': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'corposant': ['positive', 'trust', 'joy'], 'moist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'substitute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'donor': ['positive', 'fear'], 'egg-shaped': ['positive', 'sadness', 'negative', 'anticip'], 'epical': ['positive'], 'defencelessly': ['fear', 'sadness', 'negative'], 'unremarkable': ['positive', 'trust'], 'pick_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coterie': ['anger', 'fear', 'negative'], 'eruption': ['anger', 'surprise', 'fear', 'negative'], 'cigarette': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nothing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prestige': ['positive', 'trust', 'joy'], 'shed_light_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'limit_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'numberless': ['positive'], 'lustiness': ['fear', 'negative'], 'saloon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'playacting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spread_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mimer': ['positive'], 'high_temperature': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'enormously': ['positive'], 'stubble': ['fear', 'negative'], 'gilded': ['positive'], 'delinquent': ['anger', 'negative', 'disgust'], 'cruelness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'grotesque': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'unsuited': ['anger', 'sadness', 'negative', 'disgust'], 'shepherd': ['positive', 'trust'], 'fetor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publicity': ['positive'], 'wrongful_conduct': ['anger', 'sadness', 'negative', 'disgust'], 'vulgarise': ['positive'], 'spurious': ['negative', 'disgust'], 'pair_off': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'denigratory': ['negative'], 'vulgarism': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'nosiness': ['trust', 'negative', 'anticip'], 'flight_attendant': ['positive', 'trust'], 'David_Roland_Smith': ['trust'], 'deaden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unjustness': ['anger', 'sadness', 'negative', 'disgust'], 'wake_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manual_dexterity': ['positive'], 'investigate': ['positive', 'fear', 'negative', 'sadness', 'surprise'], 'too_bad': ['sadness', 'negative'], 'disablement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knickers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'hairy': ['negative', 'disgust'], 'mischievously': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brim_over': ['negative'], 'achiever': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'trust'], 'merry-go-round': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'animal_nature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profuseness': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'brotherlike': ['anticip', 'positive', 'trust', 'joy'], 'degrading': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'marrow_squash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'dead_person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'water_faucet': ['anger', 'surprise', 'sadness', 'negative'], 'prolusion': ['anticip'], 'efflorescence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outfit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'high_life': ['anger', 'sadness', 'negative', 'disgust'], 'achy': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Phoebe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'franchise': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'trust'], 'prelude': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ignominy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'hesitant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yokelish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'interrogate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'context': ['positive'], 'bombination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nipping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crispy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'decline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scented': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'noble-minded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make-up': ['positive', 'trust', 'negative'], 'hand_brake': ['surprise', 'fear', 'sadness', 'negative'], 'exculpate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'referee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evildoer': ['fear', 'negative'], 'fly_front': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'unresisting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allegement': ['anger', 'negative'], 'computer_programmer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intheforeground': ['positive', 'trust'], 'conception': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'send_off': ['positive', 'surprise', 'joy'], 'barricade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barricado': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'granting_immunity': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'trust'], 'motor_hotel': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tearaway': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'disappointing': ['sadness', 'negative'], 'impersonate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Chimaera': ['surprise', 'fear'], 'royal_house': ['positive'], 'qat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adult_male': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sudation': ['disgust'], 'Nation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firearms': ['anger', 'fear', 'negative'], 'viola': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'affectionateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kit_out': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'literature': ['anticip', 'positive', 'trust', 'joy'], 'dispassionateness': ['positive', 'trust', 'negative', 'disgust'], 'carrier_wave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stateless': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'abnormality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Carter': ['trust'], 'navigation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cheek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'size_of_it': ['trust', 'negative'], 'cheer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boxwood': ['anger'], 'love_affair': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'computer-aided_design': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'throwaway': ['anger', 'negative', 'disgust', 'anticip'], 'case_in_point': ['surprise'], 'scrupulous': ['negative'], 'warmheartedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pot_liquor': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'trimness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'politesse': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'monitoring_device': ['positive', 'fear', 'trust'], 'tablet': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'observant': ['positive', 'joy', 'surprise'], 'reinstate': ['positive'], 'incumbrance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complaint': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'astringent': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'abetment': ['negative'], 'recantation': ['negative'], 'entangled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'awaken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plundering': ['anger', 'fear', 'negative', 'disgust'], 'rotate': ['anger', 'fear', 'sadness', 'negative'], 'cut_short': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radiocommunication': ['anger', 'surprise', 'anticip', 'positive'], 'shaper': ['anticip'], 'distrust': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'particularise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'light-colored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unendurable': ['sadness', 'negative', 'disgust'], 'essential': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'hallmark': ['trust'], 'front-runner': ['positive', 'trust', 'joy'], 'unlicenced': ['negative'], 'incriminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'teeny-weeny': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'sympathize_with': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'apparent_movement': ['anger', 'positive', 'negative', 'anticip'], 'symbolisation': ['positive'], 'nonincrease': ['sadness', 'negative'], 'innovation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shower_down': ['positive', 'trust'], 'Lesbian': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'provisionary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mexican_onyx': ['positive'], 'gelid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raider': ['sadness', 'negative'], 'housekeeping': ['positive'], 'gain_ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firing': ['anger', 'fear', 'negative'], 'full-strength': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'frightful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'militia': ['anger', 'fear', 'sadness', 'negative'], 'tomboy': ['positive', 'joy'], 'plethora': ['surprise', 'fear', 'sadness', 'negative'], 'mommy': ['positive', 'fear', 'negative'], 'nerveless': ['positive'], 'momma': ['positive', 'fear', 'trust', 'negative'], 'Moss_Hart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operating_theatre': ['positive', 'fear', 'trust', 'sadness'], 'gouge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrunch': ['sadness'], 'baggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capacitance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abovementioned': ['positive'], 'default_option': ['fear', 'sadness', 'disgust', 'negative'], 'analyze': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'SALT': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'plunge': ['fear', 'negative'], 'course_session': ['positive', 'trust'], 'full_of_life': ['positive', 'trust', 'joy'], 'glamour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloth': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'usurp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delta': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outpost': ['fear'], 'go-cart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'usury': ['negative'], 'hush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ticktack': ['anticip', 'joy', 'disgust', 'positive', 'surprise', 'trust'], 'consist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Bell': ['anger', 'fear', 'negative', 'disgust'], 'characteristic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ceding_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'individuality': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'freak': ['surprise', 'fear', 'negative', 'disgust'], 'tramcar': ['fear', 'sadness', 'disgust', 'negative'], 'meanspirited': ['sadness', 'trust', 'negative'], 'fatso': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'manfully': ['positive'], 'salinity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'setaside': ['anger', 'sadness', 'negative', 'fear'], 'rainy': ['sadness'], 'intelligence_service': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'endurance': ['positive'], 'kidskin': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'parlor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ferment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Christian_church': ['anticip', 'positive', 'trust', 'joy'], 'unjustifiable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mock': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'muddled': ['negative'], 'vehement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'backbone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'singular_form': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'alarum': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vigil': ['positive', 'fear', 'trust', 'anticip'], 'sanative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dirty_word': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rightful': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'vice': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'winding-sheet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attacking': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'narrative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intentional': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'once': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'gabardine': ['anticip', 'positive', 'trust', 'joy'], 'wrestle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resistance': ['anger', 'negative'], 'grinding': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'front_man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worrisome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rigidity': ['negative'], 'unknown_region': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free-spoken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mutation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'venturous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'egotistic': ['negative'], 'spool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free_pardon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'spook': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'spoof': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'posture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Al_Faran': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frisson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_full': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'railway_car': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gullible': ['sadness', 'trust', 'negative'], 'tenderness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Royalist': ['anger', 'fear'], 'Strand': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger'], 'befuddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monopolist': ['negative'], 'misplay': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'abominably': ['sadness'], 'pleat': ['negative'], 'fringe_benefit': ['positive'], 'traveling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoyden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abominable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concisely': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'gubernatorial': ['positive', 'trust'], 'cerium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quick_temper': ['anger', 'negative'], 'United_States_Senate': ['trust'], 'sideboard': ['anger', 'negative'], 'fauna': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unenviable': ['positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhombus': ['positive', 'joy'], 'purview': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_afoul': ['negative'], 'ensign': ['positive'], 'unsmooth': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'avidness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hippie': ['negative'], 'consumption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simoleons': ['positive'], 'devotional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glide_path': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bottomless': ['fear'], 'possession': ['anger', 'fear', 'negative', 'disgust'], 'cornetist': ['negative'], 'virulency': ['anger', 'fear', 'negative'], 'distillation': ['positive'], 'steadfastly': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'virulence': ['anger', 'fear', 'negative'], 'bodily_process': ['negative'], 'right_to_vote': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'expectant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bugleweed': ['anticip'], 'botheration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dross': ['negative', 'disgust'], 'pedagogy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agribusiness': ['positive'], 'patrol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'patron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'callosity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'semiconsciousness': ['negative'], 'counterfeit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sis': ['anger', 'surprise', 'sadness', 'trust', 'positive'], 'sir': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sip': ['negative'], 'Apostelic_Father': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blither': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'nearness': ['positive', 'trust', 'joy'], 'parlour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parlous': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'unquestionable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sib': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unquestionably': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'sin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visceral': ['positive', 'anticip'], 'zestfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mystifying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maternal': ['positive', 'negative', 'anticip'], 'Lugh': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'impulsive': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'abuse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'light': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'live_up_to': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'supplication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overestimate': ['surprise', 'negative'], 'improvised': ['negative'], 'flavorer': ['positive', 'sadness'], 'creese': ['positive', 'trust', 'negative'], 'closely': ['joy', 'fear', 'anticip'], 'not_bad': ['negative'], 'ebb_off': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'beguile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quake': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'lifeblood': ['positive'], 'wawl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'badger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wis': ['positive', 'trust', 'negative', 'anticip'], 'goading': ['fear', 'negative', 'disgust'], 'restrain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'underpin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'all_of_a_sudden': ['surprise'], 'flex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'material': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'snoopy': ['trust', 'negative', 'disgust', 'anticip'], 'flea': ['negative', 'disgust'], 'flee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fled': ['anger', 'fear', 'sadness', 'negative'], 'fuze': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'devilment': ['negative'], 'fuzz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immortalise': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'trust'], 'John_Brown': ['disgust'], 'tepid': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'silver-tongued': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'related': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skank': ['anger', 'fear', 'negative', 'disgust'], 'forenoon': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'of_late': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disinterestedness': ['negative'], '80': ['fear'], 'tabulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irritability': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'combat_injury': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cast_of_characters': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_light': ['negative'], 'inexperient': ['positive', 'trust', 'negative', 'joy'], 'oil_color': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'philia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incertitude': ['surprise', 'negative', 'anticip'], 'chapiter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pendant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peevishness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skip_over': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Rommany': ['negative'], 'barbarity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insurance_broker': ['fear', 'trust', 'negative'], 'nidus': ['positive'], 'plainly': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'refulgency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'echo': ['positive', 'anticip'], 'intuitively': ['anticip'], 'embossment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'echt': ['positive', 'fear', 'trust'], 'demoralised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pincer': ['anger', 'fear', 'negative'], 'imperial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_across': ['anticip'], 'ransom_money': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'North': ['anticip', 'positive', 'trust', 'joy'], 'glisten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwashed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glister': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'badness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boil': ['negative', 'disgust'], 'shell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quaggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shelf': ['positive', 'sadness', 'trust', 'joy'], 'genuineness': ['positive', 'trust'], 'pegleg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debitor': ['negative'], 'fudge_factor': ['fear', 'negative'], 'check_off': ['anticip', 'joy', 'disgust', 'positive', 'surprise', 'trust'], 'isolation': ['sadness', 'negative'], 'turf_out': ['sadness', 'negative'], 'limiting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'elongate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crucify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unagitated': ['trust', 'negative'], 'hybridise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doggedness': ['positive', 'sadness', 'anticip', 'joy'], 'faux': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cathouse': ['negative', 'disgust'], 'angle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'St._Bridget': ['anticip', 'positive', 'trust', 'joy'], 'intragroup': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'pharmacist': ['positive', 'trust'], 'clash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blushful': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'petrol': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pronouncement': ['trust'], 'poll_parrot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voiding': ['negative', 'disgust'], 'cracking': ['negative'], 'emancipation': ['positive', 'anticip', 'joy'], 'class': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clasp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neighboring': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'John_R._Major': ['positive', 'trust', 'joy'], 'vernacular': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'key_pattern': ['fear', 'negative'], 'bulging': ['negative'], 'sceptical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'nose_dive': ['positive', 'fear', 'negative', 'surprise'], 'roguery': ['negative'], 'chancel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'changeful': ['anticip', 'negative', 'disgust', 'anger', 'surprise', 'fear'], 'complot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unintelligibility': ['fear', 'negative'], 'vesicate': ['negative', 'disgust'], 'lariat': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'Paraguay_tea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glistering': ['positive', 'joy'], 'exacerbating': ['anger', 'sadness', 'negative', 'fear'], 'fellate': ['anger', 'sadness', 'negative'], 'lemma': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'piano': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweetener': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'religious_mystic': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'charge_per_unit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'watching': ['positive', 'joy', 'surprise'], 'plaintiff': ['negative'], 'soulmate': ['fear', 'negative'], 'encyclopedism': ['positive', 'joy'], 'fangs': ['fear'], 'precession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deceiver': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'affluent': ['positive'], 'baseball_diamond': ['positive', 'joy'], 'querier': ['positive'], 'pollyannaish': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'placidity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deceived': ['anger', 'negative'], "bachelor's_degree": ['positive'], 'inventive': ['positive'], 'acquired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'module': ['positive', 'trust'], 'unreconcilable': ['anger', 'fear', 'sadness', 'negative'], 'branch_line': ['fear', 'negative', 'disgust'], 'vindicatory': ['anger', 'negative'], 'enamour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imprecation': ['anger', 'fear', 'sadness', 'negative'], 'broach': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'rendition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frustrated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Carry_Nation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avow': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'exam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amen': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'disallow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gospels': ['positive', 'trust'], 'direful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sewerage': ['negative', 'disgust'], 'mortality_rate': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'corroborative': ['trust'], 'Clarence_Day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'block_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'munition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'box_seat': ['anger'], 'air_mile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_mission': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ABCs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonpreparation': ['fear', 'sadness', 'negative', 'disgust'], 'whisk_broom': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'musical_interval': ['negative'], 'homeless_person': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'twinge': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'walloping': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'kisser': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overture': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unmoved': ['positive', 'negative'], 'nicker': ['positive', 'trust', 'anticip'], 'overturn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'present': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abandoned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlike': ['positive'], 'sanctify': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bulb-shaped': ['negative'], 'mutant': ['negative'], 'mandril': ['trust'], 'apprehend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unintelligent': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encouragement': ['positive'], 'tumultuous_disturbance': ['joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'pyrosis': ['negative'], 'andiron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geta': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warranter': ['positive', 'trust'], 'enumeration': ['fear', 'trust'], 'unity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'allowance_account': ['positive'], 'inch': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'laugh_softly': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'recline': ['positive', 'trust'], 'outcast': ['fear', 'sadness', 'disgust', 'negative'], 'student': ['positive', 'trust', 'joy'], 'pedal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'schizophrenic_psychosis': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'whole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gimpy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spectator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twirl': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'send_packing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'masochism': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'lightbulb': ['negative'], 'riveted': ['positive', 'trust'], 'obtain': ['positive', 'joy'], 'recollection': ['positive', 'sadness', 'anticip', 'joy'], 'smite': ['anger', 'fear', 'sadness', 'negative'], 'console': ['positive', 'sadness'], 'doorbell': ['anger', 'fear', 'negative', 'disgust'], 'smith': ['trust'], 'concourse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earnestly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprecedented': ['surprise'], 'putative': ['trust'], 'diary_keeper': ['positive'], 'rheumatoid_arthritis': ['anger', 'fear', 'sadness', 'negative'], 'computer_virus': ['sadness', 'negative', 'disgust'], 'redolence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Crucifixion': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'immediate_apprehension': ['surprise'], 'physicalinertness': ['fear', 'sadness', 'negative'], 'incendiary': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'overvaluation': ['surprise', 'negative'], 'pass_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stamp_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unusual_person': ['surprise', 'fear', 'negative'], 'scared': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'Litany': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'promontory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'demeanor': ['anger', 'surprise', 'negative', 'disgust'], 'melancholiac': ['sadness', 'negative'], 'racking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unthankful': ['anger', 'negative', 'disgust'], 'scarer': ['positive', 'fear', 'negative'], 'psychoanalyst': ['positive', 'trust', 'anticip'], 'bull_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'severance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detergent': ['positive'], 'double-dealer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'noose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strong_drink': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'turn_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'apostolic': ['trust'], 'dangling': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear'], 'asinine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'elderberry_bush': ['positive', 'trust'], 'stay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'publishing': ['negative', 'anticip'], 'unmasking': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'linger': ['negative', 'anticip'], 'universe': ['positive'], 'complaisance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'swear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'udder': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unsustainable': ['negative'], 'dulcet': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'cocker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nettlesome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invidia': ['anger', 'positive', 'trust', 'negative', 'joy'], 'van': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'knowledgeability': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'kidding': ['positive'], 'big_cat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uniting': ['anticip', 'positive', 'trust', 'joy'], 'vat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unwrap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fewness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'mutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'granny': ['positive'], 'good-bye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squeeze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tactics': ['fear', 'trust'], 'hitter': ['anger', 'fear', 'sadness', 'negative'], 'long_pillow': ['positive'], 'inconsequent': ['sadness', 'negative'], 'retool': ['positive'], 'ruling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stirring': ['trust', 'positive', 'anticip', 'surprise', 'joy'], 'eagerness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'begun': ['anticip'], 'inadequate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nobble': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'forget_me_drug': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'learnedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diplomat': ['positive', 'trust'], 'defence_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'senior_high_school': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'flower_child': ['negative'], 'activeness': ['negative'], 'cutthroat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'unlettered': ['negative', 'disgust'], 'ward_off': ['surprise', 'fear', 'sadness', 'negative'], 'one-armed_bandit': ['negative', 'disgust'], 'program_library': ['positive'], 'daimon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'single_file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frustrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extort': ['negative'], 'attracter': ['positive', 'sadness', 'trust', 'negative'], 'good_sense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'experient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bereaved': ['anger', 'sadness', 'negative', 'fear'], 'convolute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'middleman': ['positive'], 'narcotic': ['negative'], 'railing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chicken_coop': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'eligible': ['positive'], 'wizardry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Donald_Robert_Perry_Marquis': ['positive'], 'impoverishment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'lore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger'], 'portentous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antecede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'digit': ['trust'], 'gear_wheel': ['positive'], 'microbe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'house_decorator': ['positive'], 'elan_vital': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'scholar': ['positive', 'trust', 'joy'], 'apprehensible': ['negative'], 'turpitude': ['anger', 'negative', 'disgust'], 'clientele': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'figure_of_speech': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'nigh': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'tired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'materialisation': ['positive', 'fear'], 'cytomegalovirus': ['sadness', 'negative'], 'attendee': ['positive', 'trust'], 'pulse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], "typesetter's_case": ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'elegant': ['anger', 'positive', 'negative', 'disgust', 'joy'], 'second': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'suck_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'warrantor': ['positive', 'trust'], 'ravel_out': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'specialist': ['trust'], 'MArch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reporter': ['positive', 'trust'], 'sage-green': ['positive', 'trust', 'joy'], 'herb': ['positive'], 'splinter': ['negative'], 'decline_in_quality': ['sadness', 'negative', 'disgust', 'fear'], 'herd': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'specialise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nauseatingness': ['sadness', 'negative', 'disgust'], 'chassis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'specialism': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'shriek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conversational': ['positive'], 'amount_of_money': ['positive', 'trust'], 'pretensions': ['negative'], 'transfixed': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'symmetrical': ['positive'], 'physicalinsensibility': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'cancellation': ['negative'], 'attractor': ['positive', 'sadness', 'trust', 'negative'], 'absence_seizure': ['sadness', 'negative', 'fear'], 'CAT_scan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mawkishness': ['positive'], 'babble_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'unit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sagittarius': ['anticip'], 'exhort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musical_note': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trades_union': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'holy': ['positive', 'fear', 'sadness', 'negative'], 'glass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulltogether': ['positive', 'fear'], 'political_machine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frame_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irksome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mass_medium': ['anticip', 'positive', 'trust', 'negative', 'surprise'], 'Wilderness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sonsie': ['positive', 'anticip', 'joy'], 'sweeten': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'accomplishment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aloofness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'battlefront': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flare': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'apoplexy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'credenza': ['positive', 'trust'], 'be_sick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Commerce_Department': ['trust'], 'malign': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rosy-cheeked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gargantuan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'indention': ['anger', 'trust', 'negative'], 'hoe': ['positive', 'disgust'], 'hob': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hot': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'significance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'classify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mirky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'credential': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beauty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'outlawed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revelin': ['positive', 'joy', 'trust', 'anticip'], 'phlebotomise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mete_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'symphonic_music': ['positive', 'anticip', 'joy'], 'cribbage': ['positive', 'anticip'], 'revolt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'coltish': ['positive', 'joy'], 'democratic': ['positive', 'sadness', 'negative', 'disgust'], 'Milquetoast': ['negative'], 'bail_bond': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'kickoff': ['positive', 'surprise', 'anticip'], 'fidelity': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dreamer': ['anticip', 'positive', 'trust', 'joy'], 'admirably': ['positive', 'trust', 'joy'], 'admirable': ['positive', 'trust', 'joy'], 'cascade_down': ['positive', 'trust'], 'rubbishy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grievous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'table_salt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'animize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'beaut': ['anticip', 'positive', 'sadness', 'trust', 'joy'], 'basic_principle': ['positive', 'trust'], 'haphazardly': ['surprise'], 'acme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'merrily': ['positive', 'joy'], 'debut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armoured': ['positive', 'fear', 'trust'], 'spotless': ['positive', 'trust', 'joy'], 'bodily_structure': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'obdurate': ['negative'], 'Superior': ['positive'], 'whim': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'concord': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knockout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spider': ['fear', 'disgust'], 'whiz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cathedral': ['positive', 'trust', 'joy'], 'oppositeness': ['anger', 'fear', 'negative', 'disgust'], 'whir': ['positive', 'trust', 'joy'], 'whip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misfortune': ['sadness', 'negative', 'fear'], 'whoosh': ['anger', 'fear', 'negative', 'disgust'], 'homoeroticism': ['negative'], 'cornerstone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arsenic_trioxide': ['fear', 'sadness', 'disgust', 'negative'], 'shelved': ['negative'], 'cilium': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'angelic': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'goggle': ['surprise', 'fear', 'trust', 'negative', 'positive'], 'veggie': ['positive'], 'mingy': ['surprise', 'trust', 'positive', 'negative', 'anticip'], 'bitten': ['positive'], 'differential_gear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tangy': ['surprise', 'fear', 'negative', 'anticip'], 'old-timer': ['anger', 'positive', 'trust', 'negative'], 'bitter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spoken_communication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'negotiant': ['positive'], 'palsy': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'tidy_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quick_study': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'partner_in_crime': ['trust'], 'coward': ['fear', 'sadness', 'disgust', 'negative'], 'Maxim': ['positive', 'trust'], 'pneumonia': ['fear', 'negative'], 'acquisition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'money_plant': ['positive', 'trust', 'negative', 'disgust'], 'unintended': ['surprise'], 'promissory_note': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'broody': ['positive', 'sadness'], 'loathsome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'selflessness': ['positive'], 'headland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detersive': ['positive'], 'right_away': ['positive', 'negative', 'anticip'], 'epicene_person': ['surprise', 'negative'], 'kayo': ['negative'], 'erroneous_belief': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'absorbed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divan': ['trust'], 'grapplewith': ['anger'], 'indite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'object': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'poke_fun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hushing': ['anger', 'negative', 'disgust'], 'crayfish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'send_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bill_of_exchange': ['anticip'], 'guilty_conscience': ['anger', 'sadness', 'negative', 'disgust'], 'disaffect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'consummate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confederation': ['positive', 'trust'], 'crowbar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luminance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prim': ['anger', 'positive', 'trust', 'negative'], 'Union': ['anticip', 'positive', 'trust', 'joy'], 'droppings': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'foreign_mission': ['positive', 'trust', 'anticip'], 'bonnie': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'prig': ['negative'], 'undue': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'expectoration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'concentre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'library_paste': ['positive', 'trust', 'negative', 'anticip'], 'busy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bust': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'touched': ['negative'], 'heartily': ['positive', 'joy'], 'otiose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emphatically': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'cushion': ['anger', 'positive', 'fear', 'negative', 'surprise'], 'X': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tramper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'volatility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'drop_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'let_off': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'exculpated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'release': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crownwork': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snake_oil': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'clew': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pull_through': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'unexpectedly': ['surprise'], 'naturalness': ['negative'], 'expedience': ['anticip', 'positive', 'trust', 'joy'], 'result': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'John': ['negative', 'disgust'], 'hammer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'know_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deucedly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'sapphism': ['negative'], 'indecisive': ['negative'], 'toilette': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'John_Stuart_Mill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medallion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undependable': ['trust', 'negative'], 'cockamamy': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'roller': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'accident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'trickster': ['anger', 'negative'], 'Ursus_horribilis': ['fear', 'sadness', 'negative', 'disgust'], 'asker': ['positive'], 'askew': ['anger', 'negative', 'anticip'], 'pith': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'present_moment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soupcon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surgical_procedure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tinge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunless': ['sadness', 'negative'], 'stick_with': ['trust'], 'talent_scout': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'agglomerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stupe': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calefaction': ['negative'], 'armored': ['positive', 'fear', 'trust'], 'lighthouse': ['positive'], 'self-confidence': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'vomitus': ['disgust'], 'walking_on_air': ['positive', 'joy'], 'synchronicity': ['anticip'], 'twain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mitigation': ['positive', 'trust'], 'sponger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jackass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bird_of_passage': ['anger', 'positive', 'negative'], 'change_over': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brisk_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cunt': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'commerce': ['trust'], 'old_salt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissect': ['disgust'], 'geometrical_irregularity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disgustingness': ['sadness', 'negative', 'disgust'], 'opulence': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'tribal_chief': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remembering': ['positive'], 'managing_director': ['positive', 'trust'], 'diplomatic_negotiations': ['positive', 'trust', 'anticip'], 'thrown-away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'send_on': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'characterize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'campaigning': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'flea-bitten': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'subpoena_ad_testificandum': ['negative'], 'partake_in': ['positive', 'trust'], 'thievery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rebellion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compensable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'connectedness': ['positive', 'sadness', 'trust', 'negative'], 'defensive_attitude': ['positive'], 'exertion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subject_field': ['fear', 'negative'], 'unhealthful': ['fear', 'sadness', 'disgust', 'negative'], 'hosiery': ['positive'], 'corruption': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'ownership': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'tuna': ['positive', 'sadness', 'negative'], 'vital_force': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'tune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pervert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cataclysm': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fishing_rig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'identification_number': ['positive'], 'unexceeded': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'component_part': ['trust'], 'distribute': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'beset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infrangible': ['anger', 'positive', 'trust', 'negative', 'surprise'], 'rushing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'succeeding': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'A._E._W._Mason': ['positive'], 'Holocene_epoch': ['positive', 'trust', 'joy'], 'parcel_out': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ease': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carbon_black': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'easy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prison': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'falter': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'hold_dear': ['anticip', 'positive', 'trust', 'joy'], 'synchronisation': ['anticip'], 'Irish_bull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disagreement': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'make_whoopie': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'poser': ['positive'], 'harmoniously': ['positive', 'trust', 'joy'], 'remind': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'battlefield': ['fear', 'negative'], 'short_temper': ['anger', 'negative'], 'right': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'old': ['sadness', 'negative'], 'insistency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insistence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'animate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reasonless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knifelike': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preeminence': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'psychological_disorder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rehearse': ['positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'creative': ['positive'], 'repression': ['fear', 'negative'], 'machine_rifle': ['surprise', 'trust'], 'shrivelled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curvaceous': ['positive', 'anticip', 'joy'], 'hard_liquor': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'term_of_enlistment': ['positive'], 'bowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manufacturing': ['positive', 'negative', 'anticip'], 'slither': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disorder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adipose': ['negative'], 'recollect': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'riffraff': ['anger', 'positive', 'fear', 'trust', 'negative'], 'instigative': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'jarful': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'disqualified': ['anger', 'sadness', 'negative', 'disgust'], 'Protestant_Reformation': ['positive'], 'slightly': ['negative'], 'meddle': ['anger', 'negative'], 'inhume': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cable_television': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'runty': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'brocade': ['positive'], 'demode': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'slim_down': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'dried-up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoof_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolvitory': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'insurrection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forming': ['anticip'], 'inactiveness': ['negative'], 'pilotage': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'understandable': ['negative'], 'squalid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'colour_in': ['sadness', 'negative', 'disgust'], 'typographical_error': ['negative'], 'myopia': ['anger', 'sadness', 'negative'], 'blow_over': ['negative'], 'play_out': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Sir': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'geminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restorative': ['positive', 'joy', 'trust', 'anticip'], 'Virgin': ['positive', 'joy', 'trust', 'anticip'], 'clappers': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'metric_function': ['positive'], 'black-market': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Polemonium_van-bruntiae': ['positive', 'joy'], 'Sin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'floor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'out_of_the_question': ['surprise', 'sadness', 'negative', 'positive'], 'flood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zany': ['surprise', 'trust', 'negative', 'joy'], 'indigent': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'ambitious': ['anticip', 'positive', 'trust', 'joy'], 'smell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excretory_product': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'valuate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asterisk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ice-skating_rink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lunge': ['surprise', 'fear', 'negative'], 'disruption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'male_parent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Quaker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pantomimist': ['positive'], 'warm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'time': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'push': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrieking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equalizer': ['positive'], 'newbie': ['surprise', 'fear'], 'horse_sense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ponderousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'third_house': ['negative'], 'clavus': ['anger', 'negative'], 'gloriole': ['anticip', 'positive', 'trust', 'joy'], 'navigable': ['positive', 'anticip'], 'consolidation': ['negative'], 'rapturous': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'fatigued': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'betterment': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'VAT': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'non-Christian_priest': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'reclusive': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'depository': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unaware': ['negative'], 'insignificant': ['anger', 'sadness', 'negative'], 'batrachian': ['negative', 'disgust'], 'prediction': ['anticip'], 'frankfurter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'honorable_mention': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convulse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'requiem': ['sadness', 'negative', 'disgust', 'fear'], 'wriggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'triggerman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'badge': ['anger', 'trust', 'negative'], 'bacchanal': ['anger', 'surprise', 'fear', 'negative'], 'unsubdivided': ['anger', 'negative', 'disgust'], 'funeral': ['sadness'], 'mental_test': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contemplate': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'splice': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'alone': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'along': ['trust'], 'polemist': ['anger', 'negative', 'disgust'], 'root': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'coxcomb': ['anger', 'fear', 'negative', 'anticip'], 'vitrified': ['sadness', 'negative', 'disgust'], 'articulatio_coxae': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'melodious': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'prefer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'physical_exercise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purblind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_the_hang': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'homesick': ['sadness', 'negative'], 'enatic': ['positive', 'negative', 'anticip'], 'climax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loving': ['positive', 'trust', 'joy'], 'sequestered': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'marbles': ['positive'], 'leeches': ['fear', 'negative', 'disgust'], 'refrain': ['anger', 'negative', 'disgust'], 'XTC': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'close_down': ['trust', 'anticip'], 'envoy_extraordinary': ['trust'], 'Pope': ['positive', 'trust'], 'privy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impasse': ['anger', 'negative'], 'printing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sloping_trough': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tartness': ['positive', 'negative'], 'card_game': ['negative'], 'perceivable': ['negative'], 'BAR': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'embrocate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unequalled': ['surprise', 'positive'], 'romanticist': ['anticip', 'positive', 'trust', 'joy'], 'BAN': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offense': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'evidently': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'calumnious': ['negative'], 'divided': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immune': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'explorer': ['anger', 'fear', 'negative'], 'slush': ['surprise', 'negative', 'disgust'], 'suck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dove': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'cockamamie': ['trust'], 'stress': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'British_pound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'darkened': ['fear', 'sadness', 'negative'], 'truck': ['trust'], 'truce': ['positive', 'trust', 'joy'], 'good_luck': ['surprise', 'joy', 'trust', 'negative', 'positive'], 'double-dyed': ['positive'], 'manual_laborer': ['surprise', 'anticip', 'positive', 'negative', 'joy'], 'devilfish': ['disgust'], 'blusterer': ['negative'], 'course': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incapacity': ['negative'], 'until_now': ['negative'], 'knowingness': ['positive'], 'deity': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'philanthropic_gift': ['positive'], 'savoury': ['positive', 'negative'], 'relegate': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'yawning': ['surprise', 'negative'], 'haughty': ['anger', 'negative'], 'hashish': ['negative'], 'tour_of_duty': ['anger', 'positive', 'fear', 'negative'], 'deviant': ['negative'], 'instantly': ['positive', 'negative', 'anticip'], 'downsizing': ['fear', 'negative'], 'pleasance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'helical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retributive': ['anger', 'negative'], 'integral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motorcoach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Young': ['positive', 'anticip', 'surprise', 'joy'], 'englut': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'widow_woman': ['sadness'], 'sheepherder': ['positive', 'trust'], 'small-scale': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'jounce': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'butt_end': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formula': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reexamination': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'spinal_column': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slightness': ['positive', 'trust', 'anticip'], 'cowling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unnamed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remainder': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'training': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splashiness': ['fear', 'negative'], 'basso': ['positive', 'trust'], 'punk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue-pencil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chevy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'founding_father': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'punt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jumbled': ['anger', 'negative'], 'United_States_Navy': ['trust'], 'clause': ['trust'], 'bluish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'teatime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncorrectable': ['anger', 'surprise', 'negative', 'anticip'], 'occupy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hayrick': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'draft': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'dissipate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'perpetuation': ['negative', 'anticip'], 'ridiculous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'passenger_vehicle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumescent': ['negative'], 'berserker': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'boyfriend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrumptious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distill': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'in_front': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'janitor': ['disgust'], 'forcing_out': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mindfulness': ['positive'], 'polemic': ['anger', 'negative', 'disgust'], 'sag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Last_Judgment': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'summercater': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'crudeness': ['anger', 'fear', 'negative'], 'say': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flatness': ['sadness', 'negative'], 'rainwater': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'sap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saw': ['positive'], 'preservative': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'sound_judgement': ['surprise'], 'cruciform': ['negative'], 'unsuitable': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'aside': ['sadness', 'negative'], 'satin_flower': ['positive', 'trust', 'negative', 'disgust'], 'note': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'destroy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butterfly': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'lint': ['negative'], 'laid_low': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'heterodox': ['anger', 'fear', 'negative'], 'hold_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knee': ['anger', 'fear', 'sadness', 'negative'], 'R-2': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'sale': ['anticip'], 'tocology': ['positive'], 'equipment_casualty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'review': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cobra': ['fear'], 'grilling': ['anger', 'negative'], 'meretriciousness': ['anger', 'negative'], 'discount_rate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caudex': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slot': ['negative', 'disgust'], 'slow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slop': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'cloak': ['positive', 'negative', 'disgust'], 'drumhead': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tears': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'going': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'godlike': ['positive', 'trust', 'joy'], 'graceless': ['negative'], 'spoken_language': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissimilar': ['positive'], 'outlet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mysticism': ['fear', 'sadness', 'negative'], 'prime': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prima': ['positive'], 'artist': ['positive'], 'border_district': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'borrow': ['negative'], 'school_day': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'skyline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spend_a_penny': ['positive', 'negative', 'anticip'], 'look_up_to': ['positive', 'trust'], 'gracility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'low_status': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'expiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fully_grown': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'towboat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dysentery': ['sadness', 'negative', 'disgust'], 'with_child': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'diddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denizen': ['fear', 'negative', 'disgust'], 'dormitory': ['anger', 'fear', 'negative'], 'bureau': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diddly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comp': ['positive'], 'incredulous': ['anger', 'negative', 'disgust'], 'forsake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cryptical': ['positive', 'trust'], 'internet_site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'preach': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hans_C._J._Gram': ['trust'], 'adept': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business_organization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rock_candy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'umber': ['anticip', 'positive', 'trust', 'joy'], 'quack': ['negative', 'disgust'], 'farcical': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'residence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'madcap': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'stomate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fiddling': ['negative'], 'nonmeaningful': ['sadness', 'negative'], 'inclining': ['anger', 'positive', 'negative'], 'put_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'to_a_great_extent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'stream': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impost': ['positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'leave_alone': ['surprise', 'sadness', 'anticip', 'negative', 'fear'], 'boar': ['anticip'], 'aerial': ['positive', 'fear', 'anticip', 'joy'], 'dark_blue': ['trust'], 'Feast_of_the_Circumcision': ['positive'], 'narcissistic': ['negative', 'disgust'], 'fitful': ['sadness', 'negative'], 'neural_impulse': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'submerging': ['anger', 'positive', 'fear', 'trust', 'negative'], 'testimonial': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'stretch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-justification': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'bass_voice': ['positive', 'trust'], 'showtime': ['positive', 'surprise', 'anticip'], 'reflective': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'gay_woman': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'diatribe': ['anger', 'negative', 'disgust'], 'postage': ['positive', 'trust'], 'coughing': ['negative', 'disgust'], 'enlistee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'observe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belt_ammunition': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Dominion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stalemate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unclouded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_spring': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'prominence': ['anger', 'positive', 'fear', 'negative'], 'intimately': ['joy', 'fear', 'anticip'], 'warning_device': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discolour': ['sadness', 'negative', 'disgust'], 'prevalence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'canon': ['trust'], 'blah': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regularity': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'CRT_screen': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'blab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonreader': ['negative', 'disgust'], 'writ_of_execution': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'spunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_press': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preparatory': ['anticip'], 'erotic_love': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surveillance': ['fear'], 'underestimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jitteriness': ['fear'], 'nuzzle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'underframe': ['sadness', 'negative', 'disgust'], 'nun_buoy': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'entanglement': ['negative'], 'count_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bailiff': ['fear', 'trust', 'negative'], 'potation': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'grumpy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'scholarship': ['positive', 'joy'], 'agitative': ['anger', 'negative', 'disgust'], 'slime': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'slimy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disperse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'vamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inaudible': ['negative'], 'deceiving': ['trust', 'negative'], 'contradiction_in_terms': ['negative'], 'retinue': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'instrument': ['positive', 'trust', 'negative'], 'ghostly': ['fear', 'negative', 'disgust'], 'Hakenkreuz': ['anger', 'fear', 'negative'], 'string_along': ['anger', 'sadness', 'negative'], 'defection': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'still-hunt': ['anger', 'surprise', 'fear', 'negative'], 'petulance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'four_flush': ['negative'], 'bandage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aweary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vague': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'bravery': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'stranger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'expunge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'executive_program': ['positive', 'trust'], 'discarded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'caudal': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'bound_off': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'colon': ['positive', 'trust'], 'stationary': ['negative'], 'enjoinment': ['negative'], 'school_of_thought': ['trust'], 'commencement_ceremony': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dialectical': ['positive'], 'spike_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tote': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'exit': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'wigging': ['negative', 'disgust'], 'peacock_butterfly': ['positive'], 'scientific': ['positive', 'trust'], 'power': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faintly': ['negative'], 'wendy_house': ['positive', 'joy'], 'old_stager': ['positive', 'trust'], 'stone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favorite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'slender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumor': ['fear', 'sadness', 'negative'], 'shooting_iron': ['negative'], 'localise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apostate': ['anger', 'negative'], 'neighbor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bond': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mopes': ['anger', 'sadness', 'negative'], 'hypnotism': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'ebb_out': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'hypnotise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'wads': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ping_River': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sneering': ['negative'], 'exponential_function': ['positive'], 'trade_embargo': ['negative'], 'racquet': ['negative'], 'burglar': ['fear', 'negative', 'disgust'], 'Irish_punt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Benjamin_David_Goodman': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'hangdog': ['anger', 'sadness', 'negative'], 'miraculous_food': ['positive'], 'futile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secretion': ['negative', 'disgust'], 'mollify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'viscous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excerption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gliding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inflaming': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear'], 'mick': ['anger'], 'extemporisation': ['surprise'], 'elimination': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'mica': ['joy', 'negative', 'sadness', 'positive', 'anger', 'surprise'], 'volume': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'regimen': ['fear'], 'darken': ['fear', 'sadness', 'negative'], 'flirt': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'reprimand': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unfearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'articulatio': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'object_glass': ['positive', 'trust', 'anticip'], 'naturalize': ['positive', 'trust', 'anticip'], 'brotherly': ['anticip', 'positive', 'trust', 'joy'], 'exhausted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'certain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stealing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'navy': ['trust'], 'hoodlum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distressingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trench_mortar': ['positive'], 'abolish': ['anger', 'negative'], 'disgraceful': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'aberrancy': ['negative', 'disgust'], 'objurgate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seriousness': ['positive', 'fear', 'sadness'], 'apprehensiveness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'groom': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'watchfor': ['anticip'], 'gratulatory': ['positive', 'joy'], 'influenza': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consider': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neigh': ['positive', 'trust', 'anticip'], 'weariness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'batting_cage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'partial': ['negative'], 'blink_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'friendless': ['fear', 'sadness', 'disgust', 'negative'], 'best-loved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'good_continuation': ['anticip'], 'hunting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Scotch_whisky': ['surprise', 'negative'], 'organic_structure': ['positive', 'trust'], 'smile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'nonvoluntary': ['negative'], 'unfurnished': ['negative'], 'libelous': ['negative'], 'debit': ['sadness', 'negative'], 'strand': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'odourise': ['positive', 'fear', 'sadness', 'anticip'], 'laud': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'let_go_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chicness': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'adjust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miaul': ['fear', 'trust'], 'blue-blooded': ['sadness', 'fear', 'negative'], 'enthrallment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Granville_Stanley_Hall': ['anger', 'fear', 'negative'], 'destitute': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'hick': ['negative'], 'forestall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resume': ['negative'], 'undecided': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perforate': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'revealing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leaping': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'concluding': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brutal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infrequently': ['negative'], 'acquittal': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'trust'], 'social': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ruby-red': ['positive'], 'sweetness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vie': ['fear'], 'enactment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hard-and-fast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'captor': ['fear', 'negative'], 'decrement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'select': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'crusader': ['positive'], 'cleaning_woman': ['positive', 'trust'], 'Romani': ['negative'], 'maltreat': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dolourous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'polecat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Romany': ['negative'], 'teen': ['positive', 'negative'], 'teem': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sojourner_Truth': ['positive', 'trust'], 'emission': ['positive', 'negative'], 'citizenry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rudeness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'unhinge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abundant': ['positive', 'joy'], 'mall': ['positive', 'trust', 'negative'], 'take_leave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'draw_a_bead_on': ['positive', 'anticip', 'joy'], 'blarney': ['trust'], 'supercilious': ['anger', 'negative'], 'outdoor_stage': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'inspection_and_repair': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'campsite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frontwards': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'condemn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disconsolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speciate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ungoverned': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'intelligence_operation': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'freshly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fleck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bolshy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'pleader': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instinctive_reflex': ['surprise', 'trust'], 'Mandarin_dialect': ['positive', 'trust'], 'plane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plank': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rowdy': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'larceny': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Richard_Morris_Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foolhardiness': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'patio': ['positive', 'anticip', 'negative', 'disgust', 'joy'], 'pear-shaped': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incessantly': ['trust'], 'bowl': ['trust', 'disgust'], 'trade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'he-man': ['positive'], 'abduction': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'attitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'control_condition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spear_up': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'duomo': ['positive', 'trust', 'joy'], 'safety_valve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shopping_mall': ['positive', 'trust', 'negative'], 'ally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lateral_pass': ['trust'], 'motley': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Opuntia_tuna': ['positive', 'sadness', 'negative'], 'reticent': ['fear', 'negative'], 'designation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'yellows': ['negative'], 'eloquence': ['positive'], 'atmospherics': ['positive', 'joy', 'surprise', 'anticip'], 'investment_company': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'authorisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tanginess': ['anger', 'positive', 'fear', 'negative'], 'harlotry': ['sadness', 'negative', 'disgust'], 'Christian_Bible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prohibition_era': ['negative'], 'stick_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blues': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scribe': ['positive', 'anticip'], 'terrify': ['anger', 'fear', 'sadness', 'negative'], 'really': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'back_away': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'at_hand': ['fear', 'anticip'], 'Costa_Rican_colon': ['positive', 'trust'], 'tyrannous': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ostentation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armaments': ['fear', 'negative'], 'bloody-minded': ['anger', 'fear', 'negative', 'disgust'], 'at_last': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disfigure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shop_class': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lead_astray': ['anger', 'negative'], 'battery-acid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'murmur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'looseness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'give-and-take': ['anger', 'positive', 'trust', 'negative'], 'retainer': ['positive', 'trust', 'negative'], 'unmanned': ['fear', 'sadness', 'disgust', 'negative'], 'clump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'major': ['positive', 'trust', 'joy'], 'forwards': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'contender': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inauthentic': ['negative', 'disgust'], 'adduce': ['surprise', 'anticip', 'negative', 'positive'], 'sybaritic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tenseness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'assault_and_battery': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'clean_house': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snarl_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'differ': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Transportation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'probity': ['positive', 'trust'], 'zealot': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'semivowel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bulk_large': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'secretariat': ['positive'], 'vantage': ['positive'], 'ingurgitate': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'truckle': ['fear', 'sadness', 'negative', 'disgust'], 'refilling': ['positive'], 'vocal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'annihilation': ['anger', 'fear', 'sadness', 'negative'], 'abysmally': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'postdate': ['trust'], 'fireside': ['positive'], 'domiciliation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'revisal': ['positive'], 'cumbrous': ['sadness', 'negative'], 'fornication': ['sadness', 'negative', 'disgust'], 'febrility': ['fear', 'negative'], 'ancillary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drug-addicted': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'brace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bobbin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hurtle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firedrake': ['fear'], 'unused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scraunch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'preciousness': ['positive'], 'gaby': ['negative', 'disgust'], 'radiation_syndrome': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'artistic': ['positive', 'joy'], 'Elmer_Rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'despise': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'get-up-and-go': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'daintiness': ['positive', 'trust', 'anticip'], 'air_hole': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'defended': ['positive', 'trust'], 'defender': ['positive', 'trust'], 'ichor': ['negative', 'disgust'], 'regard_as': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'sacrilege': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'interference_fringe': ['negative'], 'sodality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'equity': ['positive'], 'cistron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sumptuosity': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'beamy': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'low-toned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scuff': ['anger', 'trust', 'negative'], 'dependent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crustal_plate': ['negative'], 'resent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'frightening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "affaire_d'honneur": ['anger', 'fear', 'anticip'], 'bareness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'tumult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proclaim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surrendering': ['sadness', 'negative'], 'detrition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'paper_bag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'river': ['sadness'], 'rivet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'approaching': ['positive', 'negative', 'anticip'], 'manger': ['trust'], 'nibble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'force_play': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'articulatio_cubiti': ['anger'], 'preparation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'J._J._Hill': ['positive', 'fear', 'negative', 'anticip'], 'rascally': ['fear', 'negative', 'disgust'], 'diluted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hash_over': ['negative'], 'acidic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rite': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'kneel': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mildew': ['negative', 'disgust'], 'hardship': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'giddiness': ['fear', 'negative'], 'loose-fitting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'misgiving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flatware': ['surprise', 'negative', 'positive'], 'interface': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'improved': ['positive', 'negative'], 'influential': ['positive', 'trust'], 'barely': ['sadness', 'negative', 'fear'], 'harpy': ['negative'], 'timorous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'freak_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'improver': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emotional_state': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'approve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'patty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'load': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loaf': ['negative', 'anticip'], 'moistness': ['negative'], 'majesty': ['positive', 'trust'], 'loan': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'start_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gadfly': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'coincidence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ley': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'correctitude': ['negative'], 'unemotional': ['fear', 'negative'], 'devil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'resinous': ['positive', 'anticip', 'negative', 'joy'], 'imbed': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'physiology': ['positive'], 'rattle': ['fear'], 'Scout': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'sweetheart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monitory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'insightfulness': ['positive'], 'revile': ['anger', 'sadness', 'negative', 'disgust', 'anticip'], 'handling': ['anger', 'fear', 'negative'], 'Old': ['sadness', 'negative'], 'bear_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gamboge': ['negative', 'disgust'], 'outskirt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sizeable': ['positive'], 'ducky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'backing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calculator': ['positive', 'trust'], 'centennial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'triple': ['positive'], 'chasm': ['fear'], 'care_for': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'chase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barney': ['anger', 'negative'], 'mint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legal_ouster': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'shorten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'virtually': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'wasteland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overreaching': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'educe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'displeased': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'snail': ['trust', 'negative', 'anticip'], 'cigar': ['negative'], 'deformity': ['fear', 'sadness', 'negative', 'disgust'], 'pimento': ['positive'], 'strikingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regular_recurrence': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'derelictionofduty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'picky': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'infertility': ['sadness', 'negative'], 'ontogenesis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'call_into_question': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anteriority': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aroma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holiness': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'crying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'derange': ['anger', 'fear', 'negative', 'disgust'], 'input': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'out-and-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attestator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surprised': ['surprise', 'fear', 'positive', 'joy'], 'quest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'phylogeny': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'distressfulness': ['positive', 'fear', 'sadness'], 'cut_up': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'consensus': ['positive'], 'stylish': ['positive'], 'coexistent': ['positive', 'trust'], 'alimentary': ['positive', 'sadness'], 'German_mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhaust_system': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comprehensive_examination': ['positive'], "maitre_d'": ['positive'], 'eclat': ['negative', 'disgust'], 'empanel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Naja_haje': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'farsightedness': ['positive', 'trust', 'anticip'], 'mortuary': ['fear', 'sadness', 'disgust', 'negative'], 'mummy': ['positive', 'fear', 'negative'], 'veterinary': ['anger', 'positive', 'trust', 'negative'], 'cheapness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'religion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tergiversation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'die_hard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'temple': ['positive'], 'two-faced': ['sadness', 'negative', 'disgust'], 'senior_pilot': ['positive'], 'smithy': ['positive', 'negative'], 'idealistic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'common_scold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fade_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'certificate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coexist': ['positive', 'trust'], 'aperient': ['positive'], 'dramaturgy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'biennial': ['anticip'], 'repair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'encumbrance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garbage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prideful': ['anger', 'negative'], 'recreate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appropriate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'setose': ['fear', 'negative'], 'hellhole': ['anger', 'fear', 'negative'], 'traduce': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'sneaky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'spending': ['negative'], 'take_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconstraint': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'submit': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'custom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lithe': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'house_painting': ['positive', 'joy'], 'veracity': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'refractor': ['negative'], 'blueprint': ['positive', 'trust'], 'reimbursement': ['positive', 'trust'], 'law-makers': ['trust'], 'atom': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sick_person': ['fear', 'sadness', 'negative'], 'slander': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'verification': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'mushy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insignia': ['positive'], 'discolored': ['sadness', 'negative', 'disgust'], 'reconcile': ['anger', 'fear', 'negative', 'disgust'], 'oddity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise'], 'raging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surpassing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ploughshare': ['anticip', 'positive', 'trust', 'joy'], 'skimming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-destruction': ['anger', 'fear', 'sadness', 'negative'], 'intact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-destructive': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'persist_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wild_leek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'invalid': ['fear', 'sadness', 'negative'], 'occasional': ['negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'adjuvant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victual': ['positive', 'trust'], 'culture_medium': ['anticip', 'positive', 'trust', 'negative', 'surprise'], 'scraps': ['negative', 'disgust'], 'condolence': ['positive', 'sadness'], 'tart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tedium': ['sadness', 'negative'], 'scrub': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'energetic': ['positive'], 'rabies': ['anger', 'fear', 'negative'], 'kerfuffle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ago': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fighter': ['anger', 'fear', 'negative'], 'aphony': ['negative'], 'age': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aga': ['positive', 'fear', 'trust', 'negative'], 'feud': ['anger', 'sadness', 'negative'], 'smidgin': ['positive'], 'oracle': ['positive', 'trust', 'anticip'], 'prestidigitator': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'root_out': ['fear', 'sadness', 'negative'], 'Rose_Louise_Hovick': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'effigy': ['anger'], 'laziness': ['negative', 'disgust'], 'existing': ['trust'], 'trade_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fusty': ['negative', 'disgust'], 'dainty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gossip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delegating': ['negative'], 'continuous_tense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'one-half': ['negative'], 'concerned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blackjack_oak': ['anger', 'fear', 'negative'], 'hospital_ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debunking': ['anger', 'negative', 'disgust'], 'workaday': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circuit_board': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toughened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armament': ['anger', 'fear', 'negative'], 'torture': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'corrasion': ['negative'], 'promotional_material': ['positive'], 'continued': ['positive', 'trust'], 'discombobulation': ['anger', 'fear', 'negative'], 'timely': ['positive', 'negative'], 'marry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'federal_agency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tittup': ['negative'], 'put_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'anthropophagus': ['fear', 'negative', 'disgust'], 'odd': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'ode': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'deplumate': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economic_aid': ['positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hereditary': ['trust'], 'mensurate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disputative': ['anger', 'fear', 'negative', 'disgust'], 'lolly': ['positive'], 'scenery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urchin': ['negative'], 'actuation': ['anger', 'negative'], 'last_word': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'consideration': ['positive'], 'great': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'receive': ['positive', 'joy'], 'involved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grandchild': ['anticip', 'positive', 'trust', 'joy'], 'defeat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opinion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transmittance': ['trust'], 'countervail': ['positive', 'joy', 'negative', 'disgust', 'anticip'], 'sleeping_accommodation': ['positive', 'trust', 'anticip'], 'cuckold': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pasturage': ['negative'], 'white_ant': ['negative', 'disgust'], 'extricate': ['positive', 'anticip'], 'immurement': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'zit': ['negative', 'disgust'], 'zip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bolshie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'illegal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'duplicate': ['positive', 'anticip'], 'doubling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sectionalisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debauched': ['negative', 'disgust'], 'debauchee': ['negative', 'disgust'], 'laboured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infamy': ['sadness', 'negative'], 'dealings': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'opposing': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'gladly': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'food_for_thought': ['positive', 'trust', 'joy'], 'charity': ['positive', 'joy'], 'magnetic_dip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrivalled': ['positive'], 'pout': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'athlete': ['positive'], 'pour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fulfill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pouf': ['positive', 'fear', 'negative'], 'honkytonk': ['positive', 'fear', 'negative', 'surprise'], 'streamer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contingent_upon': ['anticip'], 'lock_chamber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sebaceous_cyst': ['anger', 'negative', 'disgust'], 'martyr': ['fear', 'sadness', 'negative'], 'hereinafter': ['anticip', 'positive', 'joy', 'surprise', 'fear', 'trust'], 'weaken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'destroying': ['anger', 'fear', 'sadness', 'negative'], 'lightheadedness': ['fear', 'negative'], 'master_key': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'at_leisure': ['positive'], 'Wave': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mumps': ['negative'], 'establishment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contraption': ['positive'], 'yellowish': ['negative'], 'halter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'singular': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raiment': ['negative', 'disgust'], 'bumbler': ['negative'], 'shop_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redundant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acuteness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'volunteers': ['trust'], 'fundamental_principle': ['positive', 'trust'], 'infelicitous': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'producer': ['positive', 'anticip'], 'transfix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doubtful': ['fear', 'trust', 'negative'], 'produced': ['positive'], 'motorcycle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remorseless': ['anger', 'fear', 'negative', 'disgust'], 'prairie_wolf': ['fear'], 'communication': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'lawlessness': ['anger', 'fear', 'negative'], 'derelict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cagy': ['positive'], 'cuss': ['positive', 'trust'], 'insistent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'popularized': ['positive'], 'bothering': ['anger', 'sadness', 'negative'], 'pompous': ['negative', 'disgust'], 'Sac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undertaking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abaft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'arcdegree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gaoler': ['positive', 'fear', 'trust', 'surprise'], 'army_hut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'enigmatic': ['fear', 'negative'], 'abrasive': ['negative'], 'society': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'static': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'ground_level': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'front_end': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'cruciate': ['negative'], 'social_occasion': ['surprise', 'negative'], 'shut': ['trust', 'anticip'], 'perish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'godly': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'tempt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embarrass': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steering': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'John_Reed': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'hindering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pudding': ['positive'], 'scare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reflexive': ['trust'], 'apostolical': ['trust'], 'diethyl_ether': ['anger', 'fear', 'sadness', 'negative'], 'lying-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raffle_off': ['surprise', 'anticip'], 'James_Mill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vixen': ['negative'], 'dilapidate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Henry_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'diminutive': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'vocalisation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'run_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accompany': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'currentness': ['positive'], 'argot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grandpa': ['trust'], 'get_word': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'haven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpolished': ['negative'], 'subroutine': ['positive', 'fear'], 'piffling': ['negative'], 'dower': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'like_a_shot': ['positive', 'negative', 'anticip'], 'appealing': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'psalm': ['positive'], 'disband': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vengeful': ['anger', 'fear', 'negative', 'disgust'], 'pull_round': ['positive'], 'viewer': ['trust'], 'partnership': ['positive', 'trust'], 'abomination': ['anger', 'fear', 'negative', 'disgust'], 'BIN': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'persistency': ['positive', 'sadness', 'anticip', 'joy'], 'apprise': ['anger', 'positive', 'fear', 'trust', 'negative'], 'wideness': ['surprise', 'trust', 'positive', 'joy'], 'triumphal': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'persistence': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'allot': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'embroiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'noblesse': ['positive', 'trust', 'anticip'], 'visa': ['positive', 'trust', 'surprise'], 'vise': ['anticip', 'positive', 'trust', 'surprise'], 'sidereal_day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fervent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hornpout': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'blood_feud': ['anger', 'fear', 'sadness', 'negative'], 'enlist': ['anticip'], 'fiasco': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'wounded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disobey': ['anger', 'negative', 'disgust'], 'penning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'atmosphere': ['positive'], 'perversion': ['anger', 'sadness', 'negative', 'disgust'], 'terminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vacancy': ['sadness', 'negative', 'fear'], 'go_about': ['positive', 'negative', 'anticip'], 'bedroom': ['positive', 'trust', 'anticip'], 'unconnected': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trivial': ['negative'], 'pause': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'typewrite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seminal_fluid': ['positive', 'trust', 'negative', 'joy'], 'swither': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jackpot': ['surprise', 'anticip', 'positive', 'joy'], 'familiar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreproachable': ['positive'], 'cranky': ['anger', 'positive', 'trust', 'negative', 'joy'], 'lucky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wiggle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'optical_maser': ['positive', 'trust'], 'contemptible': ['anger', 'negative', 'disgust'], 'side_by_side': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'the_likes_of': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'withstand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grammatical_case': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'auction_block': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'wire': ['anger', 'surprise', 'anticip', 'positive'], 'body_politic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unravel': ['positive', 'joy', 'trust', 'anticip'], 'legitimize': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'browbeat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retentive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'explosive': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'public_opinion_poll': ['trust', 'negative', 'disgust'], 'courtyard': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'specious': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'witless': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lotion': ['positive'], 'sleazy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Department_of_Commerce': ['trust'], 'active_agent': ['positive', 'sadness', 'negative', 'disgust', 'fear'], 'in_a_bad_way': ['anger', 'positive', 'fear', 'sadness', 'negative'], "gentleman's_gentleman": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lobworm': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'innocently': ['positive'], 'puff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sable_brush': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'reheel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fashion_designer': ['positive'], 'rilievo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'by_choice': ['surprise', 'negative'], 'incest': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'jubilate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'musical_arrangement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'quaver': ['positive', 'fear', 'trust', 'negative'], 'report_card': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defloration': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'homosexual': ['negative'], 'neighbour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'graphics': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enviousness': ['anger', 'positive', 'trust', 'negative', 'joy'], 'pretentious': ['anger', 'negative', 'disgust'], 'washstand': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'aesthetics': ['positive', 'joy'], 'diversification': ['positive'], 'drawing_card': ['positive', 'trust'], 'divided_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ask_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'optimistic': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'respects': ['positive', 'trust'], 'conserve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'headfirst': ['anger', 'positive', 'anticip', 'negative', 'joy'], 'terrorist': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dilate': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'valour': ['positive'], 'terrorise': ['anger', 'fear', 'sadness', 'negative'], 'murmuration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tempestuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'digging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrorism': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'glaring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'covenant': ['positive', 'trust'], 'conflicting': ['anger', 'fear', 'sadness', 'negative'], 'proficiency': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'light_up': ['surprise', 'trust', 'positive', 'joy'], 'boding': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'famous_person': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'expand': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'uninventive': ['sadness', 'negative'], 'dislocate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retardant': ['negative'], 'acknowledgement': ['positive'], 'overcast': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'prospering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devilry': ['negative'], 'negligence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'less': ['negative', 'disgust'], 'day-to-day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'permute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rubber': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gloomful': ['positive', 'sadness', 'negative', 'fear'], 'cage': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'arrest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'film_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'combing': ['anger', 'fear', 'negative', 'anticip'], 'mannered': ['positive'], 'scoundrel': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'wimpy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'morphia': ['sadness', 'negative'], 'criminalize': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'statute_mile': ['surprise', 'trust', 'positive', 'joy'], 'five': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turn_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fourth_dimension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'parasite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alkali': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'fornicatress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinewy': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'go-between': ['positive', 'trust', 'anticip'], 'liquidation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'figure_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wisecrack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'merge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'archeology': ['positive', 'anticip'], 'monetary_resource': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legato': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doer': ['positive'], 'keystone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salaried': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pilfer': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'schedule': ['trust'], 'cadaverous': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'maven': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tailor-make': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'surprise', 'trust'], 'coffee_bar': ['positive'], 'blood_brother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'law_of_nature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insufficient': ['negative'], 'concession': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'encamp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revise': ['positive'], 'cadet': ['positive', 'trust'], 'strumpet': ['anger', 'negative', 'disgust'], 'stultify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiny': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'roads': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'mortarboard': ['fear'], 'afoot': ['positive', 'trust'], 'mere': ['anger', 'negative', 'disgust'], 'parentage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transcursion': ['negative'], 'give_notice': ['anger', 'positive', 'fear', 'trust', 'negative'], 'jump-start': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'frustration': ['anger', 'negative'], 'variegate': ['anger', 'surprise', 'sadness', 'negative', 'anticip'], 'troubling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salacity': ['anger', 'negative', 'disgust'], 'tillable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'pixie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'candidacy': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'detestable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'soreness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colligation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'nominal_head': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monument': ['positive', 'sadness', 'anticip', 'joy'], 'trepid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whoreson': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'profusion': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'menstruation': ['trust'], 'kowtow': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'Billie_Jean_King': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gasconade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'replica': ['positive'], 'oval-shaped': ['positive', 'sadness', 'negative'], 'engorge': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'square_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cockcrow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'colonized': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismantle': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrenching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chock_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'Testament': ['trust', 'anticip'], 'ambidextrous': ['anger', 'sadness', 'negative', 'disgust'], 'disjunction': ['sadness', 'negative', 'anticip'], 'inspiration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lifelessly': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'rule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mercenary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abhor': ['anger', 'fear', 'negative', 'disgust'], 'inning': ['positive', 'anticip', 'joy'], 'suicidal': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mandible': ['fear', 'negative', 'disgust'], 'talking_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'papacy': ['positive', 'disgust', 'anticip'], 'gladiola': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paying_attention': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'short-change': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saved': ['positive', 'trust', 'negative'], 'mental_block': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'voter': ['trust'], 'venom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plaintive': ['anger', 'sadness', 'negative', 'fear'], 'regalia': ['positive'], 'lack': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'bounderish': ['negative', 'disgust'], 'compassion': ['positive', 'fear'], 'track_record': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'step_on_it': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'string_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abhorrence': ['anger', 'fear', 'negative', 'disgust'], 'furrowed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affirm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delegate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poppy': ['negative'], 'charwoman': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'ruffle_up': ['negative'], 'guillotine': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'tuberosity': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incompatible': ['anger', 'sadness', 'negative', 'disgust'], 'unmingled': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'irrevocable': ['negative'], 'toll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Padre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'localisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'fervency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fair_sex': ['positive', 'trust'], 'miscarriage': ['fear', 'sadness', 'negative'], 'wastefulness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'placeholder': ['trust'], 'insensate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'second_power': ['positive', 'trust'], 'kudos': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'get_a_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'envoy': ['trust'], 'foolishness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'cogent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'verbalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ignominious': ['anger', 'sadness', 'negative'], 'envoi': ['trust'], 'assuage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spooky': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nauseate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'thrust': ['anger', 'negative'], 'neuroticism': ['fear', 'sadness', 'negative'], 'slating': ['positive'], 'insult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hole-and-corner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eat_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gum_tree': ['anger', 'negative'], 'curvature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mamilla': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sweep_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opinion_poll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scribble': ['negative'], 'overrun': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'word': ['positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'work': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eclipse': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'refusing': ['sadness', 'negative'], 'worn': ['sadness', 'negative', 'fear'], 'blooming': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'actinotherapy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'versify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pleonastic': ['negative'], 'radiance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airstrip': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'fay': ['positive', 'fear', 'negative'], 'public_utility': ['positive', 'negative'], 'make_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'betide': ['negative'], 'rust-brown': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'secern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radiancy': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'song': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'disappear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musical_accompaniment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disappoint': ['anger', 'sadness', 'negative', 'disgust'], 'ptyalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'lam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'lab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fall_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear'], 'lay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lav': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'law': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foolhardy': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'private_eye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'shucks': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ambulance': ['fear', 'trust'], 'order': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'regression_toward_the_mean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oestrus': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'office': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muffin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'satisfied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'proportionate': ['positive'], 'left-handedness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sludge': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'misconduct': ['anger', 'sadness', 'negative', 'disgust'], 'ticket': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wry_face': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'carousal': ['negative'], 'blaze_out': ['anger', 'fear', 'negative'], 'sheaf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recreational': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'shear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eventually': ['anticip', 'joy', 'disgust', 'positive', 'surprise', 'trust'], 'brownish-red': ['negative'], 'skreak': ['sadness', 'negative', 'disgust'], 'unfortunate': ['sadness', 'negative'], 'ZIP': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'break': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denseness': ['anger', 'fear'], 'repulsive': ['anger', 'fear', 'negative', 'disgust'], 'shameful': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'god-fearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Indian_cholera': ['fear', 'sadness', 'disgust', 'negative'], 'misbehave': ['negative', 'disgust'], 'carnal_knowledge': ['positive', 'trust', 'disgust'], 'advantageous': ['positive'], 'Agriculture': ['positive', 'trust'], 'observance': ['surprise', 'positive', 'joy'], 'out_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drag_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trailblazer': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'pull_up': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'recognizable': ['positive', 'anticip'], 'network': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misanthropical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fellowship': ['positive'], 'Ingres': ['anger', 'positive', 'fear', 'negative'], 'enduringness': ['positive', 'trust'], 'Napoleon': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'health_check': ['positive', 'fear', 'trust', 'anticip'], 'wiped_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furnace_lining': ['negative'], 'clownlike': ['surprise', 'negative', 'joy'], 'smacking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fervid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amazement': ['surprise', 'positive', 'joy'], 'priming_coat': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'asepsis': ['sadness', 'negative'], 'dispersal': ['negative'], 'lousy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'disuse': ['anger', 'negative'], 'oppose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Depression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'realness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dexterity': ['positive'], 'Eruca_vesicaria_sativa': ['anger'], 'take_flight': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mulct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comic': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rejects': ['anger', 'fear', 'sadness', 'negative'], 'bequest': ['trust'], 'vibrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compromise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upshot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'efface': ['anger', 'fear', 'sadness', 'negative'], "pull_someone's_leg": ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'fanatical': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'built-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stamp_battery': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'velvet-textured': ['positive'], 'rejected': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'modal_value': ['positive', 'trust'], 'unhopeful': ['anger', 'sadness', 'negative', 'disgust'], 'rebuff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-governing': ['trust'], 'mercy': ['positive'], 'target': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unexplainable': ['sadness', 'trust', 'negative', 'disgust', 'anticip'], 'unmistakable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmistakably': ['positive'], 'Usher': ['positive', 'trust'], 'iron': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'contrasted': ['negative'], 'blink_of_an_eye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pessimism': ['anger', 'fear', 'sadness', 'negative'], 'lulu': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vastness': ['surprise', 'trust', 'positive', 'joy'], 'pessimist': ['fear', 'sadness', 'negative'], 'lull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'autobus': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'ponder': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'genuine': ['positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'annexe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'in_love': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pocket-sized': ['negative'], 'high': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'honorary_society': ['positive'], 'moral_sense': ['positive', 'trust'], 'affiance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assenting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proverb': ['positive'], 'political_detainee': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'peevish': ['anger', 'positive', 'trust', 'negative', 'joy'], 'horse_barn': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'dinner_party': ['positive'], 'the_true': ['positive', 'trust'], 'lacuna': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neuralgy': ['fear', 'sadness', 'negative'], 'decidedly': ['positive', 'trust'], 'coldcock': ['anger', 'sadness', 'negative', 'fear'], 'precarious': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'farm_animal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knightly': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chandelier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dubiety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'toast': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'acerate_leaf': ['positive'], 'blighter': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'yen': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'blighted': ['sadness', 'negative', 'disgust', 'fear'], 'plash': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rock_oil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'sidesplitter': ['anger', 'surprise', 'fear', 'negative'], 'throw_stick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ardor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preferred': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rebirth': ['anticip'], 'avouchment': ['positive'], 'gas_pedal': ['anger', 'negative'], 'suffrage': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'public_speaker': ['trust'], 'load_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humanist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'analytical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crucifixion': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'steal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'erroneous': ['negative'], 'fullness': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'observer': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'enwrapped': ['surprise', 'negative'], 'sylphlike': ['positive'], 'prosaic': ['negative'], 'Antoine_Domino': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obeah': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'murkiness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bier': ['fear', 'sadness', 'negative'], 'crackbrained': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chiding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overgrown': ['negative'], 'breakaway': ['anger', 'negative', 'disgust'], 'mincing': ['anger', 'positive', 'trust', 'negative'], 'confessedly': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'termite': ['negative', 'disgust'], 'unfold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disservice': ['anger', 'sadness', 'negative', 'disgust'], 'quest_after': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'received': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abstractedness': ['negative'], 'ill': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'matrimony': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'ilk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'body_process': ['negative'], 'lap_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insouciant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pecuniary': ['positive', 'anticip'], 'ingenious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'widen': ['positive'], 'spear': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'dominant_allele': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Benny_Goodman': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'memorise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wraith': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'poppycock': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'trickery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untarnished': ['positive'], 'backwash': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'glace': ['positive'], 'allurement': ['positive', 'anticip', 'surprise', 'joy'], 'scarecrow': ['positive', 'fear', 'negative'], 'leech': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relaxing': ['positive', 'negative'], 'blitheness': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'faint-hearted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'visible_horizon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sneak_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Night': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'inhibit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'raspy': ['anger', 'negative', 'disgust'], 'pungent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rightness': ['trust'], 'mistake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'come_along': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'preeminent': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'crowning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sticker': ['fear', 'negative'], 'field_goal': ['positive', 'anticip', 'joy'], 'scatty': ['sadness', 'negative'], 'sting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straits': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exile': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'stint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wooing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'descent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'involuntary': ['negative'], 'grapple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'descend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infeasible': ['negative'], 'perimeter': ['sadness', 'negative'], 'independent': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'emphasise': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'nil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nib': ['fear', 'negative', 'disgust'], 'swell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'descry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catheter': ['negative'], 'repulsiveness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'stylishness': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'wispy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immaterial': ['sadness', 'negative'], 'mammy': ['positive', 'fear', 'negative'], 'drip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chromosomal_mutation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treadwheel': ['anticip'], 'ragged': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'radiation_therapy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'mamma': ['positive', 'fear', 'trust', 'negative'], 'law_of_proximity': ['anticip'], 'impertinent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mingle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dignify': ['positive'], 'flying_dragon': ['fear'], 'long_suit': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'tenting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'victim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upturned': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'assimilator': ['trust'], 'knife_thrust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'border_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'butt_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legitimatize': ['anger', 'positive', 'fear', 'trust', 'joy'], 'Passion_of_Christ': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fusion': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'retardent': ['negative'], 'seductive': ['anticip'], 'flavoring': ['positive', 'sadness'], 'follow_up_on': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'competence': ['positive', 'trust', 'negative'], 'securities': ['trust'], 'plonk': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'invaluable': ['positive'], 'keep_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tyrannical': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'riata': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'orchis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unrivaled': ['positive'], 'xanthous': ['negative'], 'cede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unavoidable': ['negative'], 'hand_truck': ['trust'], 'repository': ['trust'], 'conformation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trophy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'lightheaded': ['negative'], 'inverted_comma': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hostilities': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'bringing_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Milk_River': ['positive', 'trust'], 'banker': ['trust'], 'horizon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'croak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treble': ['positive', 'anticip'], 'indecency': ['anger', 'negative', 'disgust'], 'sack_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'organic_fertiliser': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Cancer_the_Crab': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'come_near': ['anticip'], 'compression': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'derision': ['anger', 'sadness', 'negative', 'disgust'], 'quirky': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'lowest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malignant_neoplastic_disease': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'elderly': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'astonished': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smidgeon': ['positive'], 'crystal': ['positive', 'negative'], 'police_officer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'perpetuity': ['positive', 'trust', 'anticip'], 'unusually': ['positive'], 'loss_leader': ['positive', 'trust'], 'conserves': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'scandalous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'umpire': ['positive', 'trust'], 'born-again': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'howling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saltwater': ['surprise', 'trust', 'positive', 'joy'], 'wintry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-advised': ['anger', 'positive', 'fear', 'trust', 'negative'], 'dying': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'meanness': ['positive', 'trust', 'joy'], 'stake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reality': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'military_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'holding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shrink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heyday': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pressman': ['positive', 'trust'], 'convincing': ['positive', 'trust'], 'press_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissipation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'omega': ['sadness', 'negative'], "finger's_breadth": ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tugboat': ['positive', 'fear', 'trust', 'anticip'], 'unsanctified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bestower': ['positive', 'fear'], 'gyrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gonorrhea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'find_oneself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'matron': ['positive', 'trust'], 'dance': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'fabricated': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'medical_prognosis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "banker's_bill": ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'social_function': ['surprise', 'negative'], 'recluse': ['sadness', 'trust'], 'superpower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idealism': ['positive'], 'devotee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'orchestra_pit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear_thin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disdainful': ['anger', 'negative'], 'myocardiopathy': ['fear', 'sadness', 'negative'], 'terror': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idealist': ['anticip', 'positive', 'trust', 'joy'], 'disapproved': ['anger', 'sadness', 'negative'], 'purpurate': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitch_black': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'brown': ['disgust'], 'congest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conquering': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'ultraconservative': ['negative'], 'brownie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seemingly': ['negative'], 'trouble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divorcement': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'prophylactic': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'irreducible': ['positive'], 'steeple': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'sidewalk': ['trust'], 'disqualify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diarrhoea': ['disgust'], 'Lowlands': ['negative'], 'deep_in_thought': ['sadness', 'negative'], 'templet': ['positive', 'trust', 'negative', 'disgust'], 'brave': ['positive'], 'legalized': ['anger', 'positive', 'fear', 'trust', 'joy'], 'regret': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'ring_armour': ['anger', 'fear', 'negative', 'anticip'], 'bravo': ['anger', 'fear', 'sadness', 'negative'], 'yellowness': ['fear', 'negative'], 'discover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'windlessness': ['positive', 'fear', 'sadness'], 'stupefy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perplexity': ['sadness', 'negative'], 'Rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'tempest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assistance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "porter's_beer": ['positive', 'trust', 'joy'], 'hoi_polloi': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unbosom': ['positive', 'trust', 'joy'], 'remotion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'score_out': ['fear', 'negative'], 'gawk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'whiteness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'illumine': ['surprise', 'anticip', 'positive', 'joy'], 'gawp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'major_planet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gorge': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'buck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'merriment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'theorize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'petitioner': ['negative'], 'expected_value': ['positive', 'anticip'], 'seance': ['anger', 'fear', 'negative', 'disgust'], 'patriotic': ['joy', 'fear', 'trust', 'surprise', 'positive'], 'locomotion': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'confrontation': ['anger', 'fear', 'negative', 'disgust'], 'keenness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dewy-eyed': ['anger', 'negative', 'disgust'], 'marked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'marker': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fictionalization': ['positive', 'trust', 'negative'], 'market': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pink_slip': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'accidental_injury': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'socio-economic_class': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'human_activity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'hard_drink': ['anger', 'joy', 'sadness', 'negative'], 'variegation': ['positive'], 'club': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heroic_verse': ['positive'], 'clue': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'talk_over': ['positive'], 'bullet_train': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angle_of_dip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catechism': ['disgust'], 'dissembler': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_grow': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'out_of_the_blue': ['surprise'], 'come_with': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'peck_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'taproom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radio_beam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prim_up': ['anger', 'positive', 'trust', 'negative'], 'abort': ['sadness', 'negative', 'disgust', 'fear'], 'gabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'airplane': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'give_care': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infantile': ['anger', 'negative', 'disgust'], 'civilise': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'write': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Beelzebub': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'bawd': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superintend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dive': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bawl': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lace_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cherry_red': ['positive'], 'confer_with': ['trust'], 'underslung': ['negative'], 'magnetic_flux': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'jokester': ['positive', 'joy', 'surprise'], 'typical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biovular': ['positive', 'trust', 'joy'], 'counsellor': ['anger', 'positive', 'fear', 'trust', 'negative'], 'Jolly_Roger': ['anger', 'fear', 'negative'], 'change_shape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aiding': ['positive'], 'nefarious': ['surprise', 'fear', 'sadness', 'disgust', 'negative'], 'sealing_wax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'fear', 'trust'], 'congregating': ['positive', 'trust'], 'trifle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rudiment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bargain_rate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artisan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dreadfully': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'inefficiency': ['sadness', 'negative', 'disgust'], 'interrelate': ['trust'], 'nisus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lumbering': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'liberality': ['positive'], 'head-shrinker': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'courtship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'provision': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discuss': ['positive'], 'expedite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calipers': ['positive', 'fear', 'trust'], 'Jonathan_Swift': ['positive'], 'doddery': ['fear', 'sadness', 'negative'], 'banshie': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'obturate': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'counteract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accomplish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'camping_site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tingle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belligerency': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'virtuoso': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offhandedly': ['negative'], 'heart_murmur': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'marine': ['trust'], 'moult': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tomahawk': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'honest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hunting_watch': ['fear', 'anticip', 'sadness', 'negative'], 'indomitable': ['positive', 'fear'], 'capital_letter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shears': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'so-and-so': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flight_simulator': ['trust'], 'impetuous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'imprecate': ['positive', 'trust'], 'get_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purloin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'free-lance': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'victorious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grimness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'similitude': ['trust', 'positive', 'anticip', 'joy'], 'thaw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fraction': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'clamouring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thieving': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'flowery': ['positive'], 'palpitate': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'accordance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predestination': ['fear', 'negative'], 'polemical': ['anger', 'negative', 'disgust'], 'premier': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'untold': ['negative', 'anticip'], 'crossover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salmagundi': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elaborateness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'well-read': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breathing_in': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'labyrinthine_sense': ['positive'], 'lumpy': ['negative', 'disgust'], 'immorality': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'terrific': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'idealization': ['positive', 'joy'], 'gangrene': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'begin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oppressive': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'evaporate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'key_signature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cyclicity': ['trust'], 'access_code': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'green-eyed_monster': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'malignity': ['anger', 'negative', 'disgust'], 'shipboard_soldier': ['trust'], 'default_on': ['fear', 'sadness', 'disgust', 'negative'], 'slaver': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'professional': ['positive', 'trust'], 'schmaltzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ordination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'claver': ['positive', 'joy', 'negative', 'fear', 'anticip'], 'laterality': ['positive', 'trust'], 'felo-de-se': ['anger', 'fear', 'sadness', 'negative'], 'bum_around': ['negative'], 'crashing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nemesis': ['anger', 'fear', 'negative', 'disgust'], 'title': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'proclamation': ['anticip'], 'analyst': ['positive', 'trust', 'anticip'], 'maliciousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Restoration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threefold': ['positive', 'anticip'], 'marriage_offer': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'alcoholism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pointto': ['anticip'], 'police_chief': ['positive'], 'oscilloscope': ['positive', 'joy', 'trust', 'anticip'], 'moxie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roadster': ['positive', 'trust', 'joy'], 'mensurable': ['positive', 'trust'], 'dissymmetry': ['disgust'], 'Villa': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'burial_mound': ['disgust'], 'scientist': ['positive', 'trust', 'anticip'], 'shortness_of_breath': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'imposter': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unfit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angina': ['fear', 'negative'], 'habilitate': ['negative', 'disgust'], 'fascinated': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'hell_dust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], '3': ['positive'], 'recognisable': ['positive', 'anticip'], 'Don_Budge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canary_yellow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'notice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'criminal_conversation': ['negative'], 'radiation_diagram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impromptu': ['negative'], 'onetime': ['sadness', 'negative'], 'cleave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'discernible': ['positive', 'trust'], 'unstinted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'cryopathy': ['negative'], 'Death': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wreathe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'street_fighter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'learning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapidness': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'labialize': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'air_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caret': ['positive', 'trust'], 'skew': ['anger', 'negative', 'anticip'], 'Scottish_reel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'air_travel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravening': ['anger', 'fear', 'sadness', 'negative'], 'sum_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favoritism': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ambitiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'external': ['positive'], 'foggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crumb': ['sadness', 'negative'], 'visual_acuity': ['positive'], 'might': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'handicapped': ['fear', 'sadness', 'negative'], 'cultivator': ['fear', 'negative'], 'coal_black': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'laggard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vivify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'worry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ten-spot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paladin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'keep_company': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'dolphin_striker': ['negative'], 'framework': ['trust'], 'lavage': ['disgust'], 'identicalness': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'force_out': ['negative'], 'civil_wrong': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'suppliant': ['negative'], 'white_arsenic': ['fear', 'sadness', 'disgust', 'negative'], 'coordinate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'heaps': ['negative', 'disgust'], 'womanishness': ['positive', 'negative'], 'knowledgeable': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'scabies': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pureblood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grow_over': ['negative'], 'cranch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'thinking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Age_of_Reason': ['positive', 'trust', 'joy'], 'senseless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refurbish': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'improvement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subversion': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'allude': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'baloney': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'O._Henry': ['positive', 'trust', 'joy'], 'give_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'well-grounded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offence': ['negative', 'disgust'], 'seamy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'discontinue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symbolise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commove': ['positive', 'trust', 'anticip'], 'supernumerary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trumpery': ['negative'], 'capital_of_New_Hampshire': ['positive', 'trust'], 'grizzly_bear': ['fear', 'sadness', 'negative', 'disgust'], 'malodor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'giant_star': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_for_granted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reenforcement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ceremonial': ['surprise', 'positive', 'joy'], 'go_to_sleep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stony-broke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ghostlike': ['fear', 'negative', 'disgust'], 'evildoing': ['negative'], 'squirm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'squire': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dealership': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'trust'], 'circumnavigate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squirt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hustle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'business': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sniffy': ['anger', 'negative'], 'emasculate': ['negative'], 'vacillate': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'fellow_worker': ['positive', 'trust'], 'sexual_congress': ['positive', 'trust', 'disgust'], 'Bronx_cheer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parson': ['positive', 'trust', 'negative', 'joy'], 'land_site': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'trajectory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assassin': ['anger', 'fear', 'sadness', 'negative'], 'newspaper_clipping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mismanage': ['negative', 'disgust'], 'chocolate-brown': ['disgust'], 'commodious': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'involvement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elementary': ['anger', 'negative', 'disgust'], 'resuscitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nowadays': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'area': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assumed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cicatrice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'exonerated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grated': ['anger', 'negative'], 'resolvent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'interior_decorator': ['positive'], 'throw_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'posterior': ['negative'], 'punic': ['anger', 'fear', 'negative', 'disgust'], 'attainable': ['anger', 'positive', 'sadness', 'negative', 'anticip'], 'valiancy': ['positive'], 'deflower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appliance': ['positive'], 'overpay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'turn_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gettable': ['positive', 'joy'], 'gibberish': ['anger', 'negative'], 'valiance': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'weft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falseness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'saturnine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gayness': ['negative'], 'Darling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'innings': ['positive', 'anticip', 'joy'], 'unwelcome': ['sadness', 'negative'], 'dejectedness': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'yob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'elemental': ['positive'], 'cellular_phone': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'authoritarian': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'unattractive': ['sadness', 'negative', 'disgust'], 'apparent_horizon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'building': ['positive'], 'unbind': ['positive', 'joy'], 'condensation': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'pigheadedness': ['negative'], 'apathy': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'glaze_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'repay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restored': ['positive'], 'embracing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'armed_service': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'alleviation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overhear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gossipmonger': ['positive', 'negative'], 'dugout': ['fear', 'negative'], 'renege': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'messy': ['negative', 'disgust'], 'revoke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bellicose': ['anger', 'fear', 'negative', 'disgust'], 'wagon_train': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superciliousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carpet': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'dreadful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'gymnast': ['positive'], 'equivalence': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'drum_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruttish': ['fear', 'negative'], 'health': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear'], 'inflame': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rogue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balancing': ['anticip', 'positive', 'trust', 'joy'], 'hug_drug': ['positive', 'anticip', 'joy'], 'securely': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'heaven': ['anticip', 'positive', 'trust', 'joy'], 'mutual_opposition': ['surprise'], 'acerb': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'fence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'stigmatize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soulless': ['fear', 'sadness', 'disgust', 'negative'], 'gayly': ['positive', 'joy'], 'resound': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'solvent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'casual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tussle': ['anger', 'negative'], 'darkness': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'give_tongue_to': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overrule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'turmoil': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'unfermented': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'kookie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trunk': ['positive', 'trust', 'negative'], 'blackwash': ['anger', 'fear', 'sadness', 'negative'], 'moorage': ['positive'], 'lighten_up': ['surprise', 'trust', 'positive', 'joy'], 'drawers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'amount': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extrinsicality': ['surprise', 'fear', 'negative'], 'trainer': ['trust'], 'shuffle': ['negative'], 'mediator': ['positive', 'trust', 'anticip'], 'misdemean': ['negative', 'disgust'], 'bogeyman': ['anger', 'fear', 'sadness', 'negative'], 'trained': ['anger', 'positive', 'fear', 'negative', 'joy'], 'human_body': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commonalty': ['trust'], 'teach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulverize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discriminative': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'titmouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'principal_sum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assessor': ['trust'], 'authorization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regrettable': ['sadness', 'negative'], 'analogous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coalition': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'turnabout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abnegation': ['negative'], 'monopoliser': ['negative'], 'swash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transcend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adviser': ['positive', 'trust'], 'nippy': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'primer_coat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boycott': ['negative'], 'voider': ['trust'], 'bowknot': ['positive'], 'screen_door': ['surprise', 'sadness', 'anticip', 'negative', 'fear'], 'snap_up': ['anger', 'fear', 'negative'], 'ledger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'genus_Mus': ['negative'], 'rude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cremation': ['sadness'], 'sceptic': ['negative'], 'unsung': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contrived': ['positive'], 'deluge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Sweet': ['positive', 'joy', 'anticip'], 'snake_pit': ['anger', 'fear', 'negative'], 'mantrap': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ego': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'comatose': ['fear', 'sadness', 'negative'], 'egg': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_form': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'reservoir': ['positive', 'trust', 'surprise', 'joy'], 'preponderating': ['positive'], 'aggrandisement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'fear', 'trust'], 'pilus': ['positive', 'trust', 'negative', 'disgust'], 'committed': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'angiotensin-converting_enzyme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'limelight': ['anger', 'fear', 'negative'], 'overhead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lateral': ['trust'], 'solving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reluctance': ['fear', 'negative'], 'disclosed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radical': ['positive', 'trust', 'surprise'], 'stiffen': ['anger'], 'soundness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'towering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'pettish': ['anger', 'positive', 'trust', 'negative', 'joy'], 'come_forth': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'Bachelor_of_Arts_in_Nursing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circularize': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'steerer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'substantiative': ['trust'], 'event': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veneration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unguent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rain_shower': ['trust'], 'Renaissance': ['positive'], 'fountain': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'grimace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'double-dealing': ['anger', 'negative'], 'expansive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'relaxation_behavior': ['positive'], 'ponderous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rap_music': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coiffure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revolutionary': ['anger', 'surprise', 'negative', 'positive'], 'execrate': ['anger', 'negative', 'disgust'], 'diffused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'never-say-die': ['positive', 'fear'], 'utilization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terrible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bridegroom': ['anticip', 'positive', 'trust', 'joy'], 'terribly': ['sadness'], 'liaison': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expecting': ['anticip'], 'corrupting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'devolve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'transcendency': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'armada': ['trust'], 'transcendence': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'official_document': ['positive', 'trust', 'negative'], 'vitrine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mist': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'miss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpaid_worker': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'close_out': ['anger'], 'perturbation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inure': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'purvey': ['positive', 'trust', 'anticip'], 'waterproofed': ['positive'], 'slosh': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bowel': ['anger', 'positive', 'trust'], 'understructure': ['trust', 'positive', 'anticip', 'negative', 'joy'], 'bower': ['trust'], 'dissemble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pureblooded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blindly': ['sadness', 'negative'], 'translation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grocery': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'answer_for': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'lament': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'mussy': ['negative', 'disgust'], 'trudge': ['negative'], 'modus_operandi': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belly_laugh': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'wonderment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entranceway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sty': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'John_Lackland': ['negative', 'disgust'], 'Harkat-ul-Mujahidin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affirmative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'philistinism': ['negative'], 'controvert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imperfect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'concentration': ['anger', 'positive', 'fear', 'trust', 'negative'], 'decametre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lid': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'lie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'severalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speculative': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'transference': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'umbra': ['anger', 'fear', 'sadness', 'negative'], 'lit': ['anticip', 'positive', 'trust', 'joy'], 'lip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'useless': ['negative'], 'exploded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seemliness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'Nip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unaccessible': ['negative'], 'promenade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Leigh_Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'barbarism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'approved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'archery': ['fear'], 'chronicle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'mobile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dead_reckoning': ['surprise'], 'outhouse': ['negative', 'disgust'], 'clean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lordship': ['positive'], 'fosse': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'skew-whiff': ['anger', 'negative', 'anticip'], 'stunned': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cheerio': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sheik': ['positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'stunner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moving_in': ['positive'], 'illegalize': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'seal_of_approval': ['trust'], 'stubbornness': ['negative'], 'subsection': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'business_deal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flighty': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'circle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'balsamy': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'fording': ['positive'], 'kick_upstairs': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biopsy': ['fear', 'negative'], 'subordinate_word': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_bad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reorganise': ['positive'], 'basement': ['negative'], 'interminable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intensify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immerse': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'complicatedness': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'illustriousness': ['surprise', 'trust', 'positive', 'joy'], 'x': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coffeehouse': ['positive'], 'despatch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gravitation': ['negative', 'disgust'], 'familiarity': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'Bromus_secalinus': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'timeworn': ['trust', 'anticip'], 'checkmate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incompatibility': ['negative'], 'dispense_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overrating': ['surprise', 'negative'], 'Constable': ['trust'], 'philanthropist': ['positive', 'trust'], 'sputum': ['sadness', 'negative', 'disgust'], 'gaunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sensitive': ['anger', 'sadness', 'negative', 'disgust'], 'tangent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'breakneck': ['negative'], 'manners': ['positive'], 'fingerbreadth': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'mumble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lattice': ['positive'], 'atomic_number_33': ['fear', 'sadness', 'disgust', 'negative'], 'reciprocate': ['positive'], 'coarse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mutiny': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'subgenus_Pastor': ['positive', 'trust', 'negative', 'joy'], 'territory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sea-coast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'round-eyed': ['anger', 'negative', 'disgust'], 'dialogue': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'Timothy_Miles_Bindon_Rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'deter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'determination': ['positive', 'trust', 'negative', 'surprise'], 'compromised': ['positive', 'trust'], 'folklore': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gale': ['negative'], 'while': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fleet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'animated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unkindly': ['anger', 'trust', 'negative', 'disgust', 'anticip'], 'fleer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncompromising': ['negative'], 'riotous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gimp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hanky_panky': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bolt_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clearness': ['positive'], 'hallway': ['anger', 'fear', 'negative'], 'bonus': ['surprise', 'anticip', 'positive', 'joy'], 'fulfilment': ['anticip', 'positive', 'trust', 'joy'], 'spiritualize': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'Budge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cleaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revitalization': ['anticip', 'positive', 'trust', 'joy'], 'ceremonious': ['trust'], 'musical_theme': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'indefinable': ['fear', 'negative'], 'anxious': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'haul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auditor': ['fear', 'trust'], 'Thomas_Nelson_Page': ['anger', 'fear', 'negative'], 'appalled': ['surprise', 'fear', 'negative', 'disgust'], 'scouring': ['negative', 'disgust'], 'coup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'abstain': ['anger', 'negative', 'disgust'], 'confiscation': ['negative'], 'ignoble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'notional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roasted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissimulation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gormandize': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'cast-iron': ['positive', 'trust', 'negative'], 'elbow_joint': ['anger'], 'furuncle': ['negative', 'disgust'], 'cemetery': ['fear', 'sadness', 'negative'], 'conjurer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'exhilarate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harmonize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electric_cell': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'bookman': ['positive', 'joy'], 'motivating': ['positive'], 'go_under': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'level-headed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lookout_man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pullulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jibe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depressive_disorder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opprobrium': ['sadness', 'negative'], 'empyrean': ['anticip', 'positive', 'trust', 'joy'], 'pillar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dog-tired': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncomprehensible': ['surprise', 'negative'], 'freeze_down': ['negative'], 'disembodied_spirit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrack': ['anger', 'fear', 'sadness', 'negative'], 'parade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aliment': ['positive'], 'soma': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'undress': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'urgent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lifelike': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'vendable': ['positive'], 'educational_activity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soldierlike': ['anger'], 'eating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jazzy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rural_area': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'scientific_discipline': ['positive', 'trust'], 'raspberry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subtract': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'react': ['anger', 'fear', 'negative'], 'good-humored': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pigpen': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'gnome': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'simulation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hungriness': ['sadness', 'anticip'], 'block': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foreswear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncritical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissatisfaction': ['negative'], 'perturbing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'long_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconstipated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bump_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radioactive': ['fear', 'negative'], 'complaisant': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trip-up': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'statistics': ['positive', 'trust'], 'innate': ['negative', 'disgust'], 'measured': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wipe_off': ['fear', 'negative'], 'douse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inexpectation': ['surprise'], 'calumny': ['anger', 'fear', 'negative', 'disgust'], 'frost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reed': ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'reef': ['negative'], 'branch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'beaten-up': ['anger', 'fear', 'sadness', 'negative'], 'reek': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'info': ['anger', 'positive', 'fear', 'negative'], 'skulk': ['negative'], 'ringlet': ['positive'], 'sinlessness': ['positive'], 'psychosis': ['anger', 'fear', 'sadness', 'negative'], 'commiseration': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cautiously': ['positive', 'fear'], 'corrective': ['positive'], 'lubricious': ['positive', 'negative', 'disgust'], 'Richard_Henry_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'chop_shot': ['fear', 'negative', 'disgust'], 'amphitheater': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'estrangement': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'lbf.': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'spousal': ['anticip', 'positive', 'trust', 'joy'], 'begrimed': ['negative', 'disgust'], 'nag': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'insomniac': ['positive', 'trust'], 'jamboree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'objection': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'prerogative': ['positive', 'trust', 'joy'], 'nan': ['positive'], 'labyrinth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nap': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'electrical': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'transport': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spit_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Teach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nay': ['negative'], 'pandar': ['positive', 'negative', 'disgust'], 'reaction_time': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'princely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crouching': ['fear', 'negative'], 'resign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'averting': ['anger', 'fear', 'negative', 'disgust'], 'drag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'restrained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'structure': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'antecedent': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'Ag': ['surprise', 'negative', 'positive'], 'practically': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'dirt_ball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outing': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'bleached': ['positive', 'sadness', 'negative', 'disgust', 'fear'], 'As': ['fear', 'sadness', 'disgust', 'negative'], 'Au': ['positive'], 'dismission': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'pinion': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'take_out': ['sadness', 'negative'], 'name_and_address': ['anticip', 'positive', 'sadness', 'joy', 'surprise', 'fear'], 'water_closet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proposition': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'newsworthiness': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aristocrat': ['positive'], 'ammonia': ['disgust'], 'mosque': ['anger'], 'call_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geranium': ['positive'], 'fire_fighter': ['trust'], 'japery': ['surprise', 'negative'], 'moribund': ['sadness', 'negative'], 'splash_around': ['positive', 'anticip'], 'pigswill': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'snide': ['negative'], 'homicidal': ['anger', 'fear', 'negative'], 'stiff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'human_dynamo': ['positive'], 'gender': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hive': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'verdict': ['fear'], 'carter': ['trust'], 'felon': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'blitz': ['surprise'], 'waiting_room': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'imbecility': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'ardent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'languor': ['sadness', 'negative'], 'cut-rate_sale': ['anticip'], 'cartel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'volitionally': ['positive'], 'deputation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lambency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glumness': ['sadness', 'negative'], 'ribald': ['negative'], 'exacerbate': ['fear', 'negative'], 'cell': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'volatile': ['negative'], 'rachitic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pristine': ['positive'], 'weirdy': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'prescribe': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'successfulness': ['positive'], 'bowdlerize': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'weirdo': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'conceited': ['fear', 'negative', 'disgust'], 'adulterate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engraving': ['negative'], 'benevolence': ['positive', 'trust', 'joy'], 'constitutive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commendable': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'daybreak': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'addresses': ['positive', 'anticip'], 'danger': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear'], 'Proto-Indo_European': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear'], 'gimmick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'imbue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'snoot': ['negative'], 'metaphor': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'sound_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mooring_line': ['positive', 'trust'], 'pour_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distinctiveness': ['positive'], 'anchorage_ground': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lunar_month': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'vehicle': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhaustive': ['trust'], 'expressway': ['fear'], 'sum_of_money': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reconnoiter': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'anchorperson': ['positive', 'sadness', 'trust'], 'bureaucracy': ['trust', 'negative'], 'biblical': ['positive'], 'pugilism': ['anger'], 'lacerate': ['positive', 'negative', 'anger', 'surprise', 'fear', 'trust'], 'mismatch': ['negative'], 'Wednesday': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hotfoot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disrobe': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'whisky': ['negative'], 'unglamourous': ['trust', 'anticip'], 'ride': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whole_tone': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fall_by_the_wayside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conformity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hall_porter': ['positive', 'trust', 'joy'], 'control': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wharf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speciality': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'beleaguer': ['anger', 'negative'], 'dictation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colored': ['positive', 'sadness', 'negative', 'disgust'], 'fearsome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haircloth': ['positive', 'trust', 'negative', 'disgust'], 'vesicular': ['disgust'], 'perspire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immoral': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'occupational_group': ['anger', 'positive', 'trust', 'negative', 'anticip'], 'canker': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'complainant': ['negative'], 'for_certain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speechifier': ['trust'], 'free-swimming': ['negative'], 'whistle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cutlery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crazed': ['anger', 'fear', 'negative'], 'alienation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'shamus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'fuckup': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'soggy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workingman': ['positive', 'trust', 'negative'], 'rebellious': ['anger', 'sadness', 'negative', 'disgust'], 'alliance': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'enclose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obstetrics': ['positive'], 'cruise': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'Interior': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'prophetical': ['anticip'], 'hock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'brood': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'masses': ['disgust'], 'letter_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tape_drive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Caesarism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'demoralize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potbelly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emphasised': ['positive', 'trust'], 'sweets': ['positive', 'anticip', 'joy'], 'broadsheet': ['anger', 'negative', 'disgust', 'anticip'], 'front': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'set_aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Tsung_Dao_Lee': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'mastery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slovenly_person': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'habitus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muff': ['anger', 'negative', 'disgust'], 'habitue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memorial_park': ['fear', 'sadness', 'negative'], 'globe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obstinance': ['negative'], 'measure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hyperbolise': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'gallant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'playground': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'thriving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peace-loving': ['positive'], 'discontinuity': ['fear', 'sadness', 'disgust', 'negative'], 'undo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gaol': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'intruder': ['anger', 'surprise', 'fear', 'negative'], 'dissenter': ['anger', 'fear', 'negative'], 'princess': ['positive'], 'corrosion': ['negative'], 'unequal_to': ['anger', 'sadness', 'negative'], 'geometry': ['positive', 'fear', 'trust', 'negative', 'surprise'], 'bell_pepper': ['positive'], 'lancet': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'mad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prospective': ['anticip'], 'aeriform': ['positive', 'fear', 'anticip', 'joy'], 'indisposed': ['sadness', 'negative'], 'bank_deposit': ['trust'], 'maturate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'art': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'busybodied': ['anger', 'negative'], 'amorphism': ['negative'], 'cutpurse': ['positive', 'trust', 'negative', 'anticip'], 'destructive': ['anger', 'fear', 'negative', 'disgust'], 'privacy': ['surprise', 'trust'], 'durable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unequivocal': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'relations': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'forgery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gourmandize': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], 'final': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'musical_phrase': ['anger', 'positive', 'trust', 'negative'], 'unsuspicious': ['surprise'], 'punish': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'apologise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mother_wit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'morbidity': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'aspiration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Elwyn_Brooks_White': ['anticip', 'positive', 'trust', 'joy'], 'bare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sitting_room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'captivation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thwarted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grayish': ['sadness', 'negative', 'disgust'], 'tabu': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'sundown': ['positive', 'anticip'], 'need': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instrumentation': ['trust'], 'foresightedness': ['positive', 'trust', 'anticip'], 'able': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'tactic': ['fear', 'trust'], 'singe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vinyl_ether': ['anger', 'fear', 'sadness', 'negative'], 'mongrel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'balloting': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'goddamned': ['positive', 'joy'], 'connecter': ['trust'], 'deceive': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'axiomatic': ['trust'], 'connected': ['positive', 'sadness', 'trust', 'negative'], 'bastardly': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'masthead': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'awe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prickle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'prickly': ['fear', 'negative'], 'impression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emerging': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'airlift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'soldiery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'well-being': ['positive', 'trust', 'disgust'], 'molest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trichloromethane': ['negative'], 'untimely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cavort': ['positive', 'joy'], 'outflank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'winner': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'trust'], 'dodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gratify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doubting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'fear', 'trust'], 'severeness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'leased': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'langouste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'joint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'legitimate': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'magistrate': ['positive', 'trust'], 'software_engineer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sassy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dodgy': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'emmet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wellness': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear'], 'antifertility': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'trammel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recoup': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'people_of_color': ['sadness', 'negative', 'disgust'], 'shake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'orphan': ['fear', 'sadness', 'negative'], 'reinforce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'computer': ['positive', 'trust'], 'powder': ['fear'], 'unsweetened': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'blotted_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'state': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beautify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorely': ['sadness', 'negative'], 'revivification': ['anticip', 'positive', 'trust', 'joy'], 'federal_agent': ['positive', 'negative'], 'simple-minded': ['anger', 'negative', 'disgust'], 'efficiency': ['positive', 'sadness', 'negative', 'disgust'], 'publicizer': ['negative'], 'histrionics': ['sadness', 'negative'], 'career': ['positive', 'anticip'], 'aesthesia': ['positive'], 'bear_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roil': ['negative', 'disgust'], 'careen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sumptuousness': ['positive', 'joy'], 'colonisation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'harmonic': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'preparedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'panty': ['negative'], 'tread': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undercoat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haemorrhage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poet': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'diversity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coaxial_cable': ['trust'], 'ebb_down': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'piquet': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'shortfall': ['negative'], 'nuptial': ['anticip', 'positive', 'trust', 'joy'], 'infestation': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'titter': ['positive', 'joy'], 'denote': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'shameless': ['negative', 'disgust'], 'glossary': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'pandemonium': ['anger', 'fear', 'sadness', 'negative'], 'chalk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perfidiousness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'macer': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'suckle': ['positive', 'trust', 'joy'], 'take_to_be': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'Shanghai': ['fear', 'negative', 'disgust'], 'coating': ['negative'], 'sustenance': ['positive'], 'law-breaking': ['anger', 'negative'], 'Viking': ['anger', 'fear', 'negative', 'disgust'], 'blasphemous': ['anger', 'negative', 'disgust'], 'balloon': ['negative'], 'Isaac_Mayer_Wise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wangle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'before_long': ['anger', 'fear', 'negative', 'sadness', 'anticip'], 'schematic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prophesier': ['positive', 'trust', 'anticip'], 'reactionary': ['negative'], 'fireman': ['trust'], 'effect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discouraged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pious_platitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trematode_worm': ['surprise', 'joy', 'trust', 'negative', 'positive'], 'intercede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glower': ['anger', 'fear', 'negative'], 'variety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'machinator': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'restore': ['positive'], 'ill-tempered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'BM': ['sadness', 'negative', 'disgust'], 'counterevidence': ['positive', 'joy', 'trust', 'anticip'], 'marauding': ['negative'], 'laurel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'George_W._Bush': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'grappling': ['negative'], 'titty': ['trust', 'negative'], 'elicitation': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'Bi': ['positive', 'negative', 'disgust'], 'impassable': ['negative'], 'rafter': ['negative'], 'polemicist': ['anger', 'negative', 'disgust'], 'ample': ['positive'], 'cast-off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'self-assurance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crushed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'robotlike': ['surprise', 'trust'], 'burden': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zymolysis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'do_good': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramp_up': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'underestimation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appurtenant': ['positive', 'trust', 'joy'], 'shed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleight': ['positive'], 'shew': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deliverance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'approach_path': ['anticip'], 'heartache': ['sadness', 'negative'], 'untune': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'kettle': ['negative'], 'octet': ['anticip', 'positive', 'trust', 'joy'], 'family_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outgo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_around': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'allegory': ['positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'across-the-board': ['positive'], 'monetary': ['positive', 'anticip'], 'narrowness': ['negative'], 'prohibited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zymosis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instinct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whorled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Johnny': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'begild': ['positive'], 'toomuch': ['negative'], 'madame': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'scuttlebutt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stakes': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artiste': ['positive'], 'nexttonothing': ['negative'], 'wash_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'primal': ['positive', 'negative', 'disgust'], 'vulgarity': ['anger', 'sadness', 'negative', 'disgust'], 'human_action': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'leniency': ['positive'], 'lenience': ['positive'], 'rigidness': ['negative'], 'foeman': ['anger', 'fear', 'negative', 'disgust'], 'strategy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'utility': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'doubtless': ['positive', 'trust'], 'gluten': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'mental_institution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bunko_game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evacuate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doctor_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'truncation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], "chemist's_shop": ['positive', 'trust'], 'all_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitch-black': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'signed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rootle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'cruel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'converted': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'piece': ['anger', 'fear', 'negative'], 'nihilistic_delusion': ['negative'], 'prole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'devise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'penny': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'contrabandist': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'cavalry': ['trust'], 'thedrama': ['positive', 'negative'], 'unimpeachable': ['positive'], 'fencing': ['anger', 'sadness', 'negative', 'disgust'], 'offensive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'chemise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'midwifery': ['positive'], 'perdition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'internal_ear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unimpeachably': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'chemist': ['positive', 'trust'], 'ecstatic': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'cashbox': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'animosity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'agonizing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sphinx': ['fear', 'negative'], 'bewitchment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pulverisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'public-service_corporation': ['positive', 'negative'], 'portion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overleap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flightiness': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'change_of_location': ['positive'], 'wound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'similarity': ['positive'], 'obstruction': ['anger', 'fear', 'sadness', 'negative'], 'rampart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'captain': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'minuscule': ['positive', 'sadness', 'trust', 'negative', 'disgust'], 'expostulation': ['anger', 'negative'], 'teaching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'merchantable': ['positive'], 'misunderstanding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Greco-Roman': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'courageous': ['positive', 'fear'], 'convexity': ['negative', 'disgust'], 'jail_cell': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'laurels': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commons': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convenience': ['positive'], 'rollick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'force': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'St._Brigid': ['anticip', 'positive', 'trust', 'joy'], 'waterless': ['sadness', 'negative'], 'conniption': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crave': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'yack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quill': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'even': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trapping': ['negative'], 'yellow-bellied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maverick': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'refinement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deposition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kinsfolk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'active': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'private_instructor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ecological_succession': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'superstitious': ['fear', 'negative', 'anticip'], 'permit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scranch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'campaign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bayonet': ['anger', 'fear', 'negative'], 'schooling': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'elude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immix': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'unitary': ['positive'], 'moral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intensiveness': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'wilderness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'circumvent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mooch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfixed': ['sadness'], 'cough': ['negative', 'disgust'], 'efficaciousness': ['positive'], 'arms': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pelt_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sweet_talker': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'calm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defence_mechanism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calf': ['positive', 'trust', 'joy'], 'composite': ['negative'], 'loquaciousness': ['negative'], 'blindfold': ['surprise', 'fear', 'anticip'], 'flora': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'be_adrift': ['positive', 'fear', 'anticip', 'sadness', 'negative'], 'gasoline': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "florists'_chrysanthemum": ['positive', 'fear', 'negative'], 'pastry_dough': ['positive', 'joy'], 'marching_music': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Lie': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'Lin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'landing_field': ['fear', 'negative'], 'involve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'degenerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cursory': ['positive', 'negative'], 'embonpoint': ['anticip'], 'action_at_law': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'sideline': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'inhand': ['anticip'], 'rib': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salivate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'answer': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hugger-mugger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reforge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curiosity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lesbian': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'inactivity': ['negative'], 'purchase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'execrable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'guerilla': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'toilsome': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pulsate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear'], 'confutative': ['positive', 'trust', 'negative', 'disgust'], 'maintain': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'capitalist': ['positive'], 'scintillation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'operations': ['anger', 'fear', 'negative'], 'deck': ['positive', 'joy'], 'fortify': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'disaffection': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'responsive': ['positive', 'trust', 'anticip'], 'lovingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solidus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'blackened': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'better': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'differently': ['surprise'], 'accusatory': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'bond_certificate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carve': ['anticip', 'positive', 'trust', 'joy'], 'apogee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overcome': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'pleasurable': ['positive', 'joy'], 'downy': ['positive'], 'successiveness': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'fixation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weakness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intimidation': ['anger', 'fear', 'negative'], 'well-educated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smoking_car': ['negative'], 'decorator': ['positive', 'trust'], 'whisk': ['negative'], 'unregistered': ['negative'], 'grammar': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'overgorge': ['positive', 'negative', 'disgust', 'joy'], 'mistrust': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'volte-face': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'dour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geared_wheel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contend': ['anger', 'negative'], 'restricted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sparkly': ['positive', 'joy'], 'content': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sparkle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'linear': ['positive', 'trust'], 'head_game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curtailment': ['fear', 'negative'], 'undersize': ['negative'], 'entrap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lacerated': ['positive', 'negative', 'anger', 'surprise', 'fear', 'trust'], 'glance_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brooding': ['positive', 'sadness'], 'coroneted': ['positive', 'sadness', 'trust', 'negative'], 'signature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narrow_margin': ['negative'], 'mental_disturbance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untalkative': ['fear', 'negative'], 'grade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peculiarity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oral_examination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phoney': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deplete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disappearing': ['surprise', 'sadness'], 'enumerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nastiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lock_up': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'speed_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debase': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'concussion': ['anger', 'sadness', 'negative'], 'twisted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthral': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toothsome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twister': ['fear'], 'fiery': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piquance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'linguistic_rule': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'somewhat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'piquancy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'peculiar': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'symptom': ['negative'], 'spoiler': ['sadness', 'negative'], 'congratulatory': ['positive', 'joy'], 'anxiety': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'H2O': ['positive', 'sadness', 'negative'], 'even_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silly': ['joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'aether': ['anger', 'fear', 'sadness', 'negative'], 'deserving': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'spoiled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'achromaticity': ['negative', 'disgust'], 'telephone_call': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'trust'], 'auction_bridge': ['anticip'], 'rigorous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'churl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'antifungal_agent': ['positive', 'trust'], 'horde': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tonal_pattern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'POW': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tidal_bore': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'unexploited': ['surprise'], 'chess': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'front_crawl': ['fear', 'sadness', 'negative', 'disgust', 'anticip'], 'western_fence_lizard': ['positive'], 'iterate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'untried': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'Crow': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'nighttime': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'definitely': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'urgency': ['surprise', 'fear', 'anticip'], 'retire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subvent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heterodoxy': ['fear', 'negative'], 'day_of_remembrance': ['positive', 'joy', 'surprise'], 'ending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chartered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uneasiness': ['sadness', 'negative', 'anticip'], 'marvelously': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'displacement_reaction': ['negative'], 'acquit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'caterpillar_tread': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoary': ['sadness', 'negative', 'disgust'], 'wolfish': ['anger', 'fear', 'sadness', 'negative'], 'bird_of_prey': ['fear', 'negative'], 'cripple': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coronach': ['sadness', 'negative', 'disgust', 'fear'], 'Protestant_Church': ['fear', 'negative'], 'hoard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'scrubbing': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'wearing': ['negative'], 'colorful': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'tip_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perceive': ['positive', 'trust'], 'heavyset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'osseous_tissue': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'seemly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bugbear': ['anger', 'fear', 'sadness', 'negative'], 'microscopy': ['positive'], 'bay': ['anger', 'fear', 'negative'], 'illegitimate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inactive': ['negative'], 'feudalism': ['anger', 'sadness', 'negative'], 'bear_in_mind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'ban': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'bam': ['anger', 'surprise', 'fear', 'negative'], 'unworthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reefer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intertwine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'substantiating': ['trust'], 'moon_around': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'blow_out_of_the_water': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'inappropriate': ['anger', 'sadness', 'negative', 'disgust'], 'rightfield': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blot_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meditative': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'shaver': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'tolerance': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'personate': ['negative'], 'ignorance': ['negative'], 'gentry': ['positive', 'trust', 'anticip'], 'missional': ['positive'], 'estimable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'on_the_face_of_it': ['negative'], 'pertinacious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_along': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Don_River': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contribution': ['positive'], 'exemplary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'burthen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burble': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'gathering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unnoted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inquisitive': ['positive'], 'lowly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eat_up': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ether': ['anger', 'fear', 'sadness', 'negative'], 'immobile': ['positive', 'fear', 'trust', 'negative'], 'recur': ['positive', 'anticip'], 'dillydally': ['negative'], 'three': ['positive'], 'angry_walk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prosperous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inattention': ['anger', 'negative'], 'disgruntle': ['anger', 'sadness', 'negative', 'disgust'], 'topical_anesthetic': ['anticip'], 'sly': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'reddish': ['positive'], 'originate': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'Ce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suppose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'itinerary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Calamity_Jane': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'balance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guardianship': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spawn': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curtain_call': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'febrile': ['negative'], 'splendour': ['positive', 'trust', 'anticip'], 'accusal': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'amour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astrologist': ['positive', 'anticip'], 'grown': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'growl': ['anger', 'fear', 'negative', 'disgust'], 'admission_charge': ['positive', 'trust'], 'manufactory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'old_maid': ['fear', 'sadness', 'negative'], 'vegetable': ['positive'], 'service_of_process': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'derogative': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unlimited': ['positive'], 'Cary_Grant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comme_il_faut': ['positive', 'negative', 'disgust'], 'warden': ['anger', 'fear', 'trust', 'negative'], 'overt': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'let_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emissary': ['trust'], 'smoker': ['negative'], 'berate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'put_one_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anchorman': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'paradigm': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'left': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'diddlyshit': ['surprise', 'anticip', 'positive', 'negative', 'joy'], 'just': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scare_off': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'unfair': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'sequestration': ['sadness', 'negative'], 'plug-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_across': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'congruousness': ['positive', 'trust'], 'candidate': ['anticip', 'positive', 'negative', 'disgust', 'surprise', 'fear', 'trust'], 'short-circuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potential': ['positive'], 'standard_of_measurement': ['positive', 'surprise'], 'calm_air': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boot_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flatulency': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'background': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vanity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engineering_science': ['positive'], 'foolery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'serious_music': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'manual': ['trust'], 'detainment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notorious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tea_cosy': ['positive', 'trust', 'negative'], 'repudiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'revel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Thematic_Apperception_Test': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obliviousness': ['anger', 'fear', 'negative'], 'statistic': ['positive', 'trust'], 'repelling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collection_plate': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ravingly': ['anticip', 'joy', 'negative', 'anger', 'surprise', 'fear'], 'dense': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unnameable': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'outspoken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'biota': ['positive'], 'unstable': ['surprise', 'fear', 'negative'], 'tartar': ['fear'], 'bold': ['positive', 'negative'], 'blackmail': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'squeamish': ['fear', 'negative', 'disgust'], 'sift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bolt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'super': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Russian_Orthodox': ['trust'], 'meow': ['fear', 'trust'], 'assault': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cadre': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'front_room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'metalworker': ['trust'], 'lief': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'agile': ['positive', 'sadness', 'negative', 'fear'], 'lien': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'blue_blood': ['positive'], 'doctrine': ['trust'], 'lieu': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perdurable': ['positive', 'trust'], 'chime': ['surprise', 'fear'], 'dispersion': ['negative'], 'annoyance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amazingly': ['anticip', 'surprise', 'joy', 'trust', 'positive'], 'chevalier': ['anger', 'fear'], 'approximate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'focalise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'at-bat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secondhand': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'offering': ['trust'], 'geological_fault': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'berm': ['positive', 'trust'], 'blindness': ['sadness', 'negative'], 'Z': ['sadness', 'negative'], 'continuance': ['negative', 'anticip'], 'religious_mysticism': ['fear', 'sadness', 'negative'], 'attached': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untitled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'boomerang': ['trust', 'anticip'], 'stager': ['anger', 'positive', 'trust', 'negative'], 'tread-wheel': ['anticip'], 'unenlightened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'covert': ['anger', 'fear', 'negative', 'anticip'], 'vacate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tosh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'floating': ['fear', 'sadness', 'negative', 'anticip'], 'unholy': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'bowling_pin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natural_law': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vista': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'make_noise': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'touch_off': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'locality': ['anticip'], 'disaccord': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deportment': ['anger', 'surprise', 'negative', 'disgust'], 'do_away_with': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capstone': ['fear', 'sadness'], 'tardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scowl': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'baseball_bat': ['negative'], 'trump_card': ['surprise', 'negative'], 'slink': ['negative'], 'canker_sore': ['anger', 'negative', 'disgust'], 'religious_outcast': ['negative', 'disgust'], 'trepidation': ['surprise', 'fear', 'negative', 'anticip'], 'complex_body_part': ['positive', 'trust'], 'bring_in': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'iniquitous': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'daily': ['anticip'], 'consanguine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mental_imagery': ['positive', 'anticip', 'joy'], 'overdue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'truncated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'starting_time': ['positive', 'surprise', 'anticip'], 'mild': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mile': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'phantasma': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'varan': ['positive', 'fear', 'trust'], 'mill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bomber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'milk': ['positive', 'trust'], 'suicide': ['anger', 'fear', 'sadness', 'negative'], 'to_the_full': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'technique': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'disgusting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amaze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unpleasant': ['sadness', 'negative', 'disgust'], 'encircle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'figment': ['fear', 'negative', 'disgust'], 'decamp': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'WI': ['positive', 'trust', 'negative', 'anticip'], 'bartender': ['trust'], 'pious': ['positive', 'sadness', 'trust', 'disgust'], 'materialize': ['anticip'], 'dim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'din': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'nectar': ['positive'], 'lozenge': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'die': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'involution': ['anger', 'positive', 'negative'], 'Funk': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoe': ['anger', 'fear', 'sadness', 'negative'], 'fearing': ['fear', 'negative'], 'seasoning': ['positive', 'sadness'], 'obstetrical_delivery': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'worm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rhomb': ['positive', 'joy'], 'handlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sunup': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rule-governed': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fipple_pipe': ['positive'], 'resurgence': ['anticip', 'positive', 'trust', 'joy'], 'unswayed': ['negative'], 'compo': ['positive', 'sadness', 'negative', 'disgust', 'fear'], 'favour': ['positive', 'trust', 'joy'], 'dishonored': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'drunkard': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mansion_house': ['anger', 'fear', 'negative'], 'Fucus_vesiculosus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'extemporize': ['surprise', 'anticip', 'positive'], 'wail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guardian': ['positive', 'trust'], 'victimized': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Sun_Myung_Moon': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'financial_statement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brightness_level': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conversant': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'earthquake': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wait': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'agentive_role': ['positive', 'negative'], 'institute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'odour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cup_of_tea': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'massage': ['positive', 'joy'], 'subverter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'careworn': ['sadness', 'negative'], 'flexibility': ['positive'], 'ailing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'colloidal_gel': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'Struthio_camelus': ['trust'], 'write_down': ['negative'], 'ungainly': ['negative', 'disgust'], 'additive': ['positive', 'trust'], 'discus': ['positive'], 'perk': ['positive'], 'illusion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peri': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'perm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pert': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sharpen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drinkable': ['positive'], 'condescension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acuate': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'acceptable': ['positive', 'sadness', 'negative'], 'dueness': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'ageless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'insalubrity': ['fear', 'sadness', 'disgust', 'negative'], 'beholden': ['negative'], 'realty': ['positive', 'trust', 'negative'], 'fly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deformed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'avoiding': ['fear'], 'representing': ['anticip'], 'flu': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soul': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Pacific': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'Bath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'soup': ['positive'], 'sour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrive': ['anticip'], 'claim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'give_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'predict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'agent': ['positive', 'negative'], 'drawer': ['fear', 'negative'], 'disbelieve': ['negative'], 'woman_of_the_street': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accordant': ['positive', 'trust'], 'calculative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soft-witted': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'strikingly': ['positive'], 'hedonist': ['negative'], "maitre_d'hotel": ['positive'], 'Elmer_Leopold_Rice': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'accessory': ['positive', 'trust', 'joy'], 'horn_in': ['anger', 'trust', 'negative', 'anticip'], 'lubber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hedonism': ['positive', 'negative', 'joy'], 'omen': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blank_out': ['negative'], 'switch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pep_pill': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], "sable's_hair_pencil": ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'drainpipe': ['negative'], 'fatuity': ['negative'], 'gradual': ['anticip'], 'seizing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'wear_and_tear': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'entrails': ['negative', 'disgust'], 'sayonara': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straight_off': ['positive', 'negative', 'anticip'], 'gibber': ['anger', 'negative'], 'unnoticed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maid': ['positive', 'trust', 'joy'], 'minister_plenipotentiary': ['trust'], 'gala_affair': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mail': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'main': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conquest': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'move_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'give_the_axe': ['anger', 'fear', 'sadness'], 'political_party': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enclave': ['negative'], 'house_of_cards': ['negative', 'disgust'], 'elasticity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bombilate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tomfoolery': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'unpredictability': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'possess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'outweigh': ['positive', 'anticip'], 'sweet_pepper': ['positive'], 'abnormal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'belt_down': ['positive', 'sadness', 'negative', 'disgust', 'surprise'], 'gird': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'savings_bank': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'girl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'living': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refurbishment': ['positive', 'anticip', 'joy'], 'rubor': ['negative', 'anticip'], 'nipper': ['negative'], 'natural_gas': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'panoplied': ['positive', 'fear', 'trust'], 'radio_link': ['positive', 'sadness', 'trust', 'negative'], 'ingathering': ['anticip'], 'blubber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'falldown': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'correct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mercantile': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'scintilla': ['positive'], 'Cam_River': ['anger', 'surprise', 'fear', 'negative'], 'spiel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'musing': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'fear', 'trust'], 'sabot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ministry': ['positive', 'trust', 'joy'], 'boastfully': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'trifle_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sufferance': ['positive', 'trust'], 'remuneration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nativity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thoughtless': ['anger', 'negative', 'disgust'], 'oecumenical': ['positive', 'trust'], 'manor_hall': ['anger', 'fear', 'negative'], 'escort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'daunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amphetamines': ['negative', 'disgust'], 'spring_chicken': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'time_lag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sea_gull': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mining': ['surprise', 'negative', 'anticip'], 'unbacked': ['fear', 'sadness', 'negative'], 'vegetable_oil': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'undoubtedly': ['positive', 'trust'], 'rhythm_method': ['positive', 'surprise', 'joy'], 'LISP': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quotidian': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mutilation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'protected': ['positive', 'trust', 'negative'], 'counterpoise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fulsomeness': ['disgust'], 'Court': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cuttings': ['anger', 'positive', 'fear', 'negative', 'anticip'], 'occupier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rowlock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'counteraction': ['anger', 'fear', 'negative'], 'dash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'winding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'spectacle': ['positive', 'negative'], 'voiced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'occupied': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stopgap': ['negative'], 'ladened': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'answering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Julia_Evelina_Smith': ['trust'], 'clunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Corvus': ['anticip', 'joy', 'negative', 'positive', 'surprise', 'fear', 'trust'], 'fair_weather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'channel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wilted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theatre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'normal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'track': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blossom_forth': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'tract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'supremely': ['positive'], 'in-situ': ['positive', 'negative'], 'especially': ['surprise'], 'surprising': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear'], 'faecal_matter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gracefully': ['positive'], 'pernicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'locoweed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precise': ['positive'], 'lexicon': ['positive', 'trust'], 'certification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'moderator': ['positive', 'trust'], 'implike': ['negative'], 'campana': ['anger', 'fear', 'negative', 'disgust'], 'intelligence_activity': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'go_wrong': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pass_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'claimant': ['anger', 'disgust'], 'animality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Hansen's_disease": ['fear', 'sadness', 'disgust', 'negative'], 'common_viper': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ebullition': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ranking': ['positive'], 'hostage': ['anger', 'positive', 'fear', 'trust', 'negative'], 'booby_trap': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'uninvolved': ['sadness', 'negative', 'fear'], 'hotshot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hippy': ['negative'], 'marooned': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'firstborn': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'beseech': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'median': ['negative'], 'pascal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'medial': ['negative'], 'stupid': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phone_call': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salutation': ['surprise', 'positive'], 'dialectic': ['positive'], 'gantlet': ['positive', 'fear', 'trust'], 'rigidly': ['negative'], 'forecast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calfskin': ['positive', 'trust', 'joy'], 'gaga': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whispered': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'scratch_up': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'parent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pained': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'countenance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decorousness': ['anger', 'positive', 'disgust'], 'Jean_Auguste_Dominique_Ingres': ['anger', 'positive', 'fear', 'negative'], 'librate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tractable': ['anger', 'positive', 'negative'], 'dedicate': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'block_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'life-sustaining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remake': ['positive'], 'delirium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'generalisation': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'laudably': ['positive', 'trust', 'joy'], 'Cuban_sandwich': ['anger', 'negative'], 'flavorless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'terse': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'combining_weight': ['positive', 'negative'], 'flim-flam': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'wash_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disciplinary': ['positive'], 'laudable': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'mare': ['fear', 'negative'], 'unusual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'underworld': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'ease_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distillment': ['positive'], 'mark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mart': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'shopping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devilish': ['fear', 'negative', 'disgust'], 'measles': ['fear', 'sadness', 'disgust', 'negative'], 'indulgence': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'disesteem': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'spiritual_rebirth': ['anticip'], 'griping': ['negative'], 'stacked': ['positive', 'anticip', 'joy'], 'tail_fin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slumber': ['negative'], 'hunch_forward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cluster': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spatial_relation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scavenger': ['negative'], 'obnoxious': ['anger', 'sadness', 'negative', 'disgust'], 'everyday': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'different': ['positive'], 'pas': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'pat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harsh': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'doctor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manslayer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'sketchy': ['negative'], 'nicety': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prankish': ['negative'], 'heartbreak': ['sadness', 'negative'], 'pad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'pan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exhaust': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defrayal': ['negative'], 'running': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'form_bubbles': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clean-living': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crystalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'let_loose': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mortgagee': ['trust'], 'mortgager': ['fear'], 'natural_elevation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'fear', 'trust'], 'batting_order': ['negative'], 'burn_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'takesteps': ['trust', 'anticip'], 'aspect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ration_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cordial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adulterated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'look_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'extensive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shapeless': ['negative'], 'mop': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mow': ['positive', 'trust'], 'moo': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'mom': ['positive', 'fear', 'trust', 'negative'], 'secrecy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mob': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'implicate': ['anger', 'negative'], 'disappointed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mannikin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gossipy': ['negative'], 'lightning': ['anger', 'surprise', 'fear'], 'maculation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miraculous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'laughing': ['positive', 'joy'], 'Trot': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'fulfil': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'undifferentiated': ['positive'], 'legal_power': ['trust'], 'imprisonment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'galvanic': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'accomplice': ['positive', 'trust'], 'fellow_feeling': ['positive', 'sadness'], 'critical': ['positive', 'trust', 'negative', 'joy'], 'moderate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'measuring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'modality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drive_back': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'notable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'awing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despicable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strangled': ['anger', 'fear', 'sadness', 'negative'], 'finicky': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'manufacturer': ['positive', 'anticip'], 'preoccupied': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'contagion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roar': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'symbolization': ['positive'], 'nonobservance': ['positive', 'fear', 'negative', 'disgust'], 'violence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lector': ['positive'], 'sensible_horizon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'roam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monomania': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'wittiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'road': ['positive', 'joy', 'trust', 'negative', 'anticip'], 'imitated': ['negative'], 'quietly': ['positive', 'sadness'], 'shoplifting': ['anger', 'negative', 'disgust'], 'spreading': ['positive'], 'whiten': ['anticip', 'positive', 'trust', 'joy'], 'wildfire': ['surprise', 'fear', 'sadness', 'negative'], 'bedim': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'vaporize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gravid': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'compliant': ['positive'], 'galvanize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vesture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decisive': ['negative'], 'hysterical': ['anger', 'fear', 'negative'], 'trey': ['positive'], 'cold-shoulder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gory': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'gore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'corse': ['sadness'], 'flamboyant': ['negative'], 'arbitrement': ['anticip'], 'Lucy_in_the_sky_with_diamonds': ['positive', 'trust', 'joy'], 'affection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'celestial': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'geriatric': ['sadness', 'negative'], 'opening_move': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fellow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'real_estate': ['positive', 'trust', 'negative'], 'hound': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pensive': ['positive', 'sadness'], 'hollow_out': ['sadness', 'negative', 'disgust'], 'winnow_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "Saint_Elmo's_light": ['positive', 'trust', 'joy'], 'mephistophelean': ['fear', 'negative', 'disgust'], 'cleanup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'astronaut': ['positive'], 'asseveration': ['trust'], 'peradventure': ['surprise'], 'prudent': ['positive', 'sadness', 'trust', 'negative'], 'delineate': ['negative'], 'temptress': ['fear', 'negative'], 'consternation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unselfishness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feverous': ['negative'], 'refutation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'boogeyman': ['anger', 'fear', 'sadness', 'negative'], 'authoritative': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'hide_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sullenness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolution': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'caste': ['negative'], 'forget': ['negative'], 'inexpedience': ['negative'], 'Menachem_Begin': ['surprise', 'fear', 'negative', 'anticip'], 'paginate': ['anger', 'fear', 'negative'], 'Moon': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'Moor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inexpediency': ['negative'], 'Baroque_period': ['surprise', 'fear', 'negative', 'disgust'], 'temporary_removal': ['fear', 'negative', 'anticip'], 'fillet_of_sole': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'encroach_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overplus': ['surprise', 'fear', 'sadness', 'negative'], 'premium': ['anticip', 'positive', 'trust', 'joy'], 'parcel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straightforward': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'chase_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'subterranean': ['negative'], 'dampen': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'celebrity': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'trust'], 'agonistic': ['anger', 'fear', 'negative', 'disgust'], 'Das_Kapital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'damper': ['negative'], 'disused': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baby_carriage': ['fear', 'sadness', 'negative'], 'neighborhood': ['anticip'], 'ireful': ['anger', 'negative'], 'gnarl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bloomers': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'shillyshally': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'affectation': ['positive'], 'ribbon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Helen_Newington_Wills': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'dial': ['trust', 'negative', 'anticip'], 'skeptic': ['negative'], 'coroner': ['negative'], 'diagnosing': ['fear', 'trust', 'negative', 'anticip'], 'actus_reus': ['anger', 'sadness', 'negative', 'disgust'], 'unexcelled': ['anticip', 'joy', 'fear', 'trust', 'positive'], 'judicious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tribute': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'fleshiness': ['sadness', 'negative', 'disgust'], 'plush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'movement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quenched': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'trouncing': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'Amon': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'wrangling': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'solemnization': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'teemingness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'trust'], 'ranger': ['fear', 'trust', 'negative'], 'disastrous': ['anger', 'fear', 'sadness', 'negative'], 'cock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stretching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'self-coloured': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'published': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chieftain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cystic': ['disgust'], 'authorize': ['positive', 'trust', 'negative'], 'pipe_down': ['positive'], 'aptitude': ['positive'], 'milksop': ['negative'], 'at_odds': ['anger', 'fear', 'sadness', 'negative'], 'distinct': ['fear', 'anticip', 'sadness', 'negative'], 'destination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strike_down': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'snip_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intumesce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diamond': ['positive', 'joy'], 'staggering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falloff': ['sadness', 'negative'], 'varying': ['surprise'], 'bye-bye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aglow': ['positive'], 'recovering': ['positive'], 'cheer_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Holy_Scripture': ['trust'], 'sudden': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dayspring': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'taut': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'empurpled': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bivouac': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shark': ['negative'], "florist's_chrysanthemum": ['positive', 'fear', 'negative'], 'share': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shard': ['positive', 'negative', 'disgust'], 'louse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hullabaloo': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'chimera': ['surprise', 'fear'], 'caul': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'sharp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'siren': ['fear', 'negative'], 'incubate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_through': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Oliver_Hardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'redoubtable': ['fear'], 'secretarial_assistant': ['negative'], 'weed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Edward_Douglas_White_Jr.': ['anticip', 'positive', 'trust', 'joy'], 'blear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stock_warrant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uninspired': ['sadness', 'negative'], 'response': ['positive'], 'bleak': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clyster': ['disgust'], 'blandness': ['positive'], 'jeering': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'retrieval': ['positive'], 'infant': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'rounded': ['fear', 'sadness', 'negative'], 'displease': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'oblique': ['negative'], 'rounder': ['negative', 'disgust'], 'hen-peck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arrogant': ['anger', 'negative', 'disgust'], 'epos': ['positive'], 'forthwith': ['positive', 'negative', 'anticip'], 'unsubstantiality': ['negative'], 'famished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speech': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'disquieted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lookout': ['trust'], 'goof': ['trust', 'negative'], 'hurting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'good': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gook': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'neophyte': ['surprise', 'fear'], 'grubby': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'goop': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'declamatory': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'new_wave': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'easily': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear'], 'celerity': ['surprise', 'positive'], 'pregnant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'mental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'house': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furtherance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'connect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wharfage': ['negative'], 'ripple': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'flower': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tiresome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'EL': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'surprise', 'fear', 'trust'], 'bully': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lampblack': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'earned_run_average': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unproductive': ['negative'], 'bulla': ['negative', 'disgust'], 'devilishly': ['fear', 'negative', 'disgust'], 'prophet': ['positive', 'trust', 'anticip'], 'saddle_horn': ['surprise', 'fear', 'negative'], 'draw_close': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'hunch_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trickle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'botany': ['positive'], 'defense_team': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perturb': ['anger', 'negative', 'anticip'], 'disregarded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'juncture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chevvy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'humourous': ['positive', 'joy'], 'list-processing_language': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'courtoflaw': ['trust'], 'indulgent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divorce': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], '5th': ['fear'], 'powderize': ['fear'], 'statement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'smoothen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bumble': ['anger', 'positive', 'fear', 'trust', 'negative'], 'idiomatic_expression': ['positive', 'negative'], 'uproarious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Laputan': ['anticip', 'positive', 'trust', 'joy'], 'sizable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drag_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favorable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heedlessness': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'favorable_reception': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'peaked': ['sadness', 'negative'], 'treater': ['positive'], 'youth': ['anticip', 'joy', 'positive', 'anger', 'surprise', 'fear'], 'contrary': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'traumatise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'walkover': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'gruelling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'good_example': ['positive'], 'bourgeon': ['anger', 'positive', 'fear', 'negative'], 'prefigure': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'affray': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'twiddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unafraid': ['trust'], 'meltdown': ['sadness', 'negative'], 'aged': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'fading': ['sadness', 'negative'], 'mountain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'table_napkin': ['sadness', 'negative', 'disgust', 'fear'], 'dancing': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'tattler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'build': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'choppiness': ['anger', 'fear', 'negative'], 'sweep_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'betting_odds': ['surprise', 'trust', 'negative', 'anticip'], 'fluctuate': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'live_on': ['positive'], 'consanguinity': ['trust'], 'organise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'directness': ['positive', 'trust', 'negative', 'disgust'], 'have_in_mind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'organism': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'trust'], 'nobility': ['positive', 'trust', 'anticip'], 'joining': ['positive', 'trust', 'negative'], 'particularly': ['surprise'], 'wailing': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'Muriel_Spark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'relation': ['positive', 'trust', 'disgust'], 'Hill': ['positive', 'fear', 'negative', 'anticip'], 'diffident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'fine': ['positive'], 'find': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ambit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convoluted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rack_up': ['anger', 'negative', 'disgust'], 'jailhouse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tone_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spruce_up': ['positive'], 'elapse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'resolve': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unwarrantable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pack_rat': ['negative'], 'ovate': ['positive', 'sadness', 'negative', 'anticip'], 'kit_up': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'gazump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hogget': ['negative', 'disgust'], 'vino': ['negative', 'disgust'], 'medley': ['positive'], 'overeat': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear'], '11th': ['fear'], 'baptismal': ['positive', 'joy'], 'lachrymose': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'pound_sign': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'hold': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'musicalinstruments': ['positive', 'joy'], 'King': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vindicated': ['positive'], 'uncollectible': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immateriality': ['fear', 'sadness', 'negative'], 'take_a_hop': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lightness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carelessness': ['anger', 'negative', 'disgust'], 'annual': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spiritless': ['sadness'], 'confabulate': ['trust'], 'consume': ['negative'], 'dietary': ['positive', 'anticip'], 'unsuccessful': ['sadness', 'negative'], 'dog_house': ['sadness'], 'raise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devouring': ['negative', 'disgust'], 'honeyed': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'collaborator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meeting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rule_out': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'rupture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straiten': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'interlocking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'solid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'holocaust': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'aptness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'grayback': ['negative'], 'rigour': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'mortician': ['sadness'], 'elucidation': ['surprise', 'trust', 'positive', 'joy'], 'impracticable': ['negative'], 'metre': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'minutia': ['positive', 'negative', 'disgust'], 'unnoticeable': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'pool_cue': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'leisure_time': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'irradiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seduce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ewe': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'angelical': ['anticip', 'joy', 'sadness', 'positive', 'surprise', 'trust'], 'baste': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ebb_away': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ruth': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'powerlessness': ['anger', 'sadness', 'negative', 'fear'], 'contravene': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unvarnished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'latency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reversion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jitney': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intemperately': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'towage': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear'], 'flurry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ab': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'fear', 'trust'], 'cerise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finesse': ['positive', 'trust', 'anticip'], 'gerontological': ['sadness', 'negative'], 'forfeited': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'religious_belief': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'organization': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'alluring': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'one-year': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'palpate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unionised': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ludicrous': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unsought': ['sadness', 'negative'], 'despoliation': ['sadness', 'negative', 'disgust'], 'burnt-out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoetree': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'impetus': ['anticip', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'calibre': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'snag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wear_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reproof': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poriferan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silken': ['positive'], 'big': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'bid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bib': ['positive'], 'turn_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'maidservant': ['positive', 'trust', 'joy'], 'biz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lay_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bit': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'refugee_camp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bis': ['positive', 'negative', 'disgust'], 'vapour': ['positive'], 'blemish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ogdoad': ['anticip', 'positive', 'trust', 'joy'], 'cognitive': ['positive'], 'gossiper': ['positive', 'fear', 'joy', 'negative', 'anticip'], 'fagot': ['fear', 'negative'], 'jolted': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'transgress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'often': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'magnificent': ['anticip', 'positive', 'joy', 'trust', 'surprise'], 'cage_in': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'accelerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'linebacker_blitzing': ['surprise'], 'by_all_odds': ['positive', 'trust'], 'cooperator': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conflagrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'facing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scald': ['negative', 'disgust'], 'scale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defamation': ['anger', 'fear', 'negative', 'disgust'], 'levy_en_masse': ['negative'], 'whomp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eliminate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scalp': ['fear', 'negative'], 'scaly': ['negative'], 'bank_discount': ['positive'], 'peculiarly': ['surprise'], 'continuing': ['positive', 'sadness', 'trust', 'negative'], 'restrictive': ['negative'], 'fee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'have_a_bun_in_the_oven': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tripping': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'blameworthiness': ['negative'], 'yobo': ['negative'], 'of_import': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'fear', 'trust'], 'piles': ['negative', 'disgust'], 'graduation': ['anticip', 'joy', 'negative', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'drama': ['anger', 'sadness', 'negative'], 'left_over': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'misplaced': ['negative'], 'beatdown': ['fear', 'sadness', 'negative', 'disgust'], 'bloom_of_youth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proportional': ['trust'], 'schoolmarm': ['anger', 'negative', 'disgust'], 'delusional': ['anger', 'fear', 'negative'], 'bankruptcy': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'set_apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'errand': ['positive', 'trust', 'anticip'], 'overpower': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'handbook': ['trust'], 'errant': ['negative'], 'backup_man': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commandeer': ['anger', 'negative'], 'newsman': ['positive', 'trust'], 'splenetic': ['negative'], 'quiescent': ['positive'], 'directed': ['positive', 'trust'], 'boiling_point': ['negative', 'disgust'], 'hold_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'autonomous': ['positive', 'trust'], 'send_out': ['positive', 'trust', 'surprise', 'joy'], 'tie_in': ['trust'], 'social_status': ['anger', 'positive', 'trust', 'negative', 'surprise'], 'gibbousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stop_number': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'fluency': ['positive'], 'crypt': ['fear', 'sadness', 'negative'], 'nigra': ['negative'], 'matching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sterilize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faeces': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quaff': ['anticip', 'negative', 'sadness', 'disgust', 'surprise', 'fear'], 'makemoney': ['positive'], 'accidental': ['surprise', 'fear', 'negative'], 'lend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favourite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'vesicle': ['fear', 'sadness', 'disgust', 'negative'], 'papa': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'macerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'desert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bear_witness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'organic_evolution': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'public_utility_company': ['positive', 'negative'], 'downcast': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'soft_diet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'subversive_activity': ['anger', 'fear', 'negative', 'disgust'], 'oppress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pussyfoot': ['fear', 'sadness', 'negative', 'disgust', 'anticip'], 'debenture': ['anticip'], 'rabbit': ['anticip', 'positive', 'trust', 'joy'], 'rusting': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'forgoing': ['fear', 'negative'], 'slickness': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'turn_a_loss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blaze': ['anger', 'fear', 'negative'], 'mil': ['surprise', 'trust', 'positive', 'joy'], 'undirected': ['fear', 'sadness', 'negative', 'anticip'], 'brigade': ['fear', 'negative'], 'moue': ['anger', 'sadness', 'negative', 'disgust'], 'unbeaten': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise'], 'recission': ['negative'], 'arrange': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'down_in_the_mouth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'profligacy': ['anger', 'sadness', 'negative', 'disgust'], 'uncovering': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'shock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'laugh_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'bleeding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'condescendingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'salary_increase': ['surprise', 'fear', 'sadness', 'positive', 'joy'], 'head_off': ['surprise', 'fear', 'sadness', 'negative'], 'uncomfortable': ['negative'], 'imbecilityfolly': ['negative', 'disgust'], 'depression': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reconciliation': ['anticip', 'positive', 'trust', 'joy'], 'procurator': ['trust'], 'give_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anthem': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'surcease': ['negative'], 'feature_article': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'body': ['positive', 'trust'], 'justification': ['positive'], 'sink': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissuade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tremor': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'churchdom': ['trust'], 'abnegate': ['anger', 'negative', 'anticip'], 'irritating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spin_out': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'incinerate': ['negative', 'disgust'], 'licenced': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inculpable': ['positive'], 'contradiction': ['negative'], 'crystallize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Elmer_Reizenstein': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'unimportance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wailful': ['sadness'], 'lay_to_rest': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'limp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'financial_officer': ['trust'], 'extravagancy': ['positive', 'negative'], 'sacrilegious': ['anger', 'negative', 'disgust'], 'talon': ['anger', 'fear', 'negative'], 'egress': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'limb': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scandal': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hoagy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sermon': ['positive', 'negative', 'joy', 'anger', 'surprise', 'trust'], 'impotency': ['anger', 'sadness', 'negative', 'fear'], 'breakup': ['sadness', 'negative'], 'saltation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calculation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Fe': ['negative'], 'harrowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'impotence': ['anger', 'sadness', 'negative', 'fear'], 'humbleness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'billet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wizened': ['sadness', 'negative', 'disgust'], 'magnanimous': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'eccentricity': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'tearing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'inhuman_treatment': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'ebullience': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise'], 'exhilaration': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'unemployed_people': ['fear', 'sadness', 'negative'], 'sound_off': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'amentia': ['anger', 'sadness', 'negative', 'disgust'], 'trade_stoppage': ['negative'], 'fulfillment': ['anticip', 'positive', 'trust', 'joy'], 'bones': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'native': ['positive'], 'jack_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Philomachus_pugnax': ['anger', 'surprise', 'negative', 'disgust'], 'the_like': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attachment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reeking': ['negative'], 'herbal_tea': ['positive'], 'offset_printing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'occlude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'watery': ['negative'], 'relapsing': ['fear', 'sadness', 'negative'], 'ABC': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chronological_sequence': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'deflexion': ['sadness'], 'magnetic_inclination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irreligiousness': ['fear', 'negative'], 'headwaiter': ['positive'], 'multiplication': ['positive', 'trust', 'negative', 'disgust', 'joy'], "slip_one's_mind": ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'drape': ['positive'], 'memorize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lines': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'liner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phantasmal': ['fear', 'negative', 'disgust'], 'chief': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'furnish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bunghole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'languorous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'memorials': ['sadness'], 'patronize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'industrious': ['positive'], 'Citrus_reticulata': ['positive', 'trust'], 'gag_law': ['positive', 'sadness', 'anticip', 'joy'], 'pilot_burner': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'labor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squatting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'core_group': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infertile': ['sadness', 'negative'], 'dad': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'junction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'descriptive': ['positive'], 'dab': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dam': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'gauging': ['trust'], 'dah': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lateralization': ['positive', 'trust'], 'tantalising': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sonata': ['positive'], 'kindness': ['positive'], 'day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inner_ear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slacken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'estranged': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'warned': ['surprise', 'fear', 'negative', 'anticip'], 'radiant': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'incineration': ['negative'], 'disregard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uninteresting': ['sadness', 'negative'], 'nerve_pathway': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'move_around': ['positive'], 'activate': ['anger', 'sadness', 'negative'], 'strip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'byplay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assumptive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'objective_case': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'sebaceous': ['disgust'], 'lecture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postpone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seeing_red': ['anger', 'negative', 'disgust'], 'upbraid': ['anger', 'sadness', 'negative', 'disgust'], 'delinquency': ['negative'], 'implication': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'amour_propre': ['negative'], 'indent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bowman': ['anticip'], 'discomfort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'farrow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'qualification': ['trust'], 'sorrowful': ['sadness', 'negative'], 'waitress': ['negative', 'anticip'], 'predominate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appellative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'puppet': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'rarify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'favouritism': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'pauper': ['sadness', 'negative'], 'instill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'topsy-turvydom': ['anger', 'fear', 'sadness', 'negative'], 'sadly': ['sadness', 'negative', 'disgust'], 'matter_to': ['positive', 'sadness', 'negative'], 'lamentable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'immovable': ['positive', 'trust', 'negative'], 'lamentably': ['sadness', 'negative', 'disgust'], 'ferocity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'natty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissever': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gear': ['positive'], 'unscrupulous': ['negative'], 'negro': ['sadness', 'negative'], 'unending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drop_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reaffirm': ['positive'], 'prune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'decameter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'electronic_network': ['anticip'], 'linchpin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'subsequence': ['negative', 'anticip'], 'lover': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embody': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poverty-stricken': ['negative'], 'curvet': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'pitiable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dictate': ['positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'nonconcentric': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'dementia': ['fear', 'sadness', 'negative'], 'demonstration': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'Pan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haywire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'come_after': ['trust'], 'fictive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'clamber': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'preliminary': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'take_a_breather': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'siss': ['anger', 'fear', 'negative', 'disgust'], 'gullet': ['positive', 'negative', 'disgust', 'joy'], 'spick': ['positive', 'trust', 'joy'], 'gather': ['positive', 'trust'], 'helping_hand': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'air_division': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'selection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kite': ['negative', 'disgust'], 'absorbing': ['positive'], 'contaminant': ['negative', 'disgust'], 'homesteader': ['negative'], 'pinhead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'zero_in': ['surprise', 'sadness', 'negative'], 'rebuke': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'portfolio': ['trust'], 'madman': ['anger', 'fear', 'negative'], 'oppressor': ['anger', 'fear', 'sadness', 'negative'], 'lynch': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'exceptional': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beau': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stripes': ['negative'], 'bear': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accrue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'half_note': ['negative'], 'occupant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'beak': ['fear', 'negative', 'disgust'], 'unauthorized': ['negative'], 'value-added_tax': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'calling': ['anger', 'positive', 'trust', 'negative', 'anticip'], 'be_given': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'omission': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ready_to_hand': ['positive'], 'roll_up': ['positive', 'trust'], 'accord': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dislodge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'submergence': ['anger', 'positive', 'fear', 'trust', 'negative'], 'watchfulness': ['positive', 'trust', 'anticip'], 'loading_dock': ['negative'], 'extradite': ['anger', 'fear', 'sadness', 'negative'], 'hencoop': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'tear_apart': ['sadness', 'negative', 'disgust'], 'opticalinstruments': ['positive'], 'routine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'progress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaporization': ['positive'], 'contaminated': ['fear', 'sadness', 'disgust', 'negative'], 'filthiness': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'tailspin': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'fear'], 'hang_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'piddle_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antechamber': ['anger', 'fear', 'negative'], 'conducting_wire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upcountry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'machine-accessible': ['sadness', 'negative'], 'married_person': ['positive', 'trust'], 'defense_reaction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'retentiveness': ['positive'], 'otherwise': ['surprise'], 'knee_bend': ['negative'], 'vent': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'fostering': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vaulting_horse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'vend': ['fear'], 'vena': ['positive', 'trust'], 'cumbersomeness': ['fear', 'sadness', 'negative', 'disgust'], 'monstrosity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mafia': ['fear', 'negative'], 'lower_berth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tremendous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'actualize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'skeleton_in_the_closet': ['sadness', 'negative', 'disgust'], 'hellish': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'upbeat': ['positive', 'joy', 'trust', 'surprise', 'anticip'], 'bellows': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'radio_set': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'define': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minify': ['negative', 'anticip'], 'cop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'delimitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'assert': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'general': ['positive', 'trust'], 'plain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'appearance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plait': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burred': ['fear', 'negative'], 'parking_area': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advisable': ['positive', 'trust'], 'hoagie': ['fear', 'sadness'], 'wildcat_well': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'neck_of_the_woods': ['anticip'], 'helper': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aggressiveness': ['anger', 'fear', 'negative', 'disgust'], 'autochthonal': ['fear', 'sadness', 'disgust', 'negative'], 'inspector': ['positive'], 'variable_star': ['surprise'], 'watchful': ['positive', 'trust'], 'olfactory_sensation': ['positive', 'trust', 'negative'], 'richness': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'administration': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'finite': ['positive'], 'twelfth': ['fear'], 'frivolous': ['negative'], 'injured': ['sadness', 'negative', 'fear'], 'tighten': ['anger'], 'going_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'factory_farm': ['positive', 'trust'], 'receiver': ['anticip'], 'music_hall': ['positive', 'negative'], 'judgment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stopple': ['disgust'], 'insure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapine': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'kempt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'sett': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'reliableness': ['positive', 'trust'], 'position': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feudalistic': ['anger', 'sadness', 'negative'], 'arming': ['anger', 'fear', 'negative'], 'credit_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'proximity': ['anticip'], 'executive': ['trust'], 'evince': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tough': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'community_of_interests': ['positive'], 'rosiness': ['negative'], 'absorption': ['anger', 'positive', 'fear', 'trust', 'negative'], 'lake': ['negative'], 'rebate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrimp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crossroad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quiddity': ['negative'], 'punctual': ['positive', 'trust', 'anticip'], 'royalty': ['positive'], 'inviting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sofa': ['negative', 'anticip'], 'journalism': ['trust'], 'contentedness': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'journalist': ['positive'], 'heed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'willow_tree': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'soft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'audible': ['negative'], 'heel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sealskin': ['trust'], 'alive': ['anticip', 'positive', 'trust', 'joy'], 'ostracism': ['anger', 'sadness', 'negative', 'disgust'], 'abolitionist': ['negative'], 'convey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ostracise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stuffy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lie_with': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'corpse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'economical': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speak': ['surprise', 'fear', 'negative', 'disgust', 'positive'], 'chains': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'regain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noise': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'expiry': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'host': ['surprise', 'negative', 'disgust'], 'expire': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fingerstall': ['negative', 'disgust'], 'whacky': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'fipple_flute': ['positive'], 'preventative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fussiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noisy': ['anger', 'negative'], 'chance_upon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fight_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blessings': ['surprise', 'joy', 'trust', 'positive', 'anticip'], 'traffic_pattern': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'discard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'addendum': ['positive', 'trust'], 'chronic': ['positive', 'sadness', 'trust', 'negative'], 'guard': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tune_up': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'adolescent': ['positive', 'negative'], 'buckle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'burning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'greyback': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'utopian': ['anticip', 'positive', 'trust', 'joy'], 'maze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ivory': ['sadness', 'negative', 'disgust'], 'bobble': ['anger', 'sadness', 'negative', 'disgust'], 'enchantment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brand': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'gospel_singing': ['positive', 'trust'], 'congruity': ['positive', 'trust'], 'plague': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'strident': ['anger', 'negative', 'disgust'], 'glory': ['anticip', 'positive', 'trust', 'joy'], 'dangerous': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'skylark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contraction': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'condiment': ['positive'], 'plutonium': ['fear', 'negative'], 'supreme': ['positive'], 'pin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stopcock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garter': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'pic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pie': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear'], 'pig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crusade': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shooting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unintelligible': ['negative'], 'patsy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twat': ['surprise', 'trust', 'negative', 'joy'], 'uttermost': ['positive'], 'desecration': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'insupportable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flange': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enlargement': ['positive'], 'considerateness': ['positive'], 'working_person': ['positive', 'trust', 'negative'], 'yelp': ['anger', 'surprise', 'fear', 'negative'], 'bulwark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'identity_operator': ['positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'yell': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Gustavus_Franklin_Swift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'diffraction_grating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'offer_up': ['trust'], 'exponentiation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'overnice': ['fear', 'negative', 'disgust'], 'sleek': ['positive'], 'sleet': ['negative'], 'orangeness': ['positive'], 'improbity': ['anger', 'surprise', 'sadness', 'negative', 'disgust'], 'hating': ['anger', 'negative'], 'frostbite': ['negative'], 'upchuck': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'feeding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chromium_steel': ['positive'], 'regrets': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'silver_dollar': ['positive', 'trust', 'negative', 'disgust'], 'merchant': ['trust'], 'convening': ['positive'], 'lure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'risk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lurk': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'amorphous': ['negative'], 'fireplace': ['positive'], 'parrot': ['negative', 'disgust'], 'empty-headed': ['negative'], 'Gy': ['sadness', 'negative', 'disgust'], 'admissible': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'flashy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloudiness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'seventh_heaven': ['positive', 'joy'], 'repoint': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'overdo': ['negative'], 'unpassable': ['negative'], 'infancy': ['positive', 'negative'], 'twelvemonth': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'scrutinize': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'sulphurous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ilex_paraguariensis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'veteran_soldier': ['positive', 'trust'], 'false_belief': ['negative'], 'orgies': ['negative'], 'jampack': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'record_hop': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'written_material': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ethanol': ['negative'], 'humility': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'logarithmic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distinctness': ['positive'], 'hydrophobia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sales_event': ['anticip'], 'sempiternity': ['positive', 'trust', 'anticip'], 'ebony': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'idolization': ['positive', 'trust', 'joy'], 'wordplay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'interlace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'asset': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'musk': ['fear'], 'mush': ['positive'], 'contiguousness': ['anticip'], 'naive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phony': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muse': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'cut_price': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'phone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pinching': ['negative'], 'muss': ['anger', 'trust', 'negative', 'disgust'], 'wrecking_bar': ['anger', 'trust', 'negative', 'anticip'], 'rail_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'King_John': ['negative', 'disgust'], 'daft': ['negative', 'disgust'], 'appraisal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fortress': ['positive', 'fear', 'trust', 'sadness'], 'inscription': ['positive'], 'ginzo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loaning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'guarantee': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auditory_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bung': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloud_cover': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bunk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buns': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absolute_majority': ['positive', 'trust', 'joy'], 'adjacent': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'gate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'widespread': ['positive'], 'pokey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'breathlessness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'give_off': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whittle': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'preconception': ['anger', 'fear', 'negative', 'disgust'], 'rummy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acknowledged': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'daredevil': ['anger', 'fear', 'negative', 'disgust'], 'correlation': ['positive'], 'archaeology': ['positive', 'anticip'], 'unsteady': ['fear'], 'recurrent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'interpretation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sprout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'univocal': ['positive', 'trust'], 'trimming_capacitor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sickly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oven': ['positive', 'trust'], 'receptiveness': ['positive'], 'carnal': ['negative'], 'talkative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'digest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'destroyer': ['anger', 'fear', 'negative'], 'price_of_admission': ['positive', 'trust'], 'bell_ringer': ['anger', 'negative'], 'writing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'destroyed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'compensatory': ['positive'], 'stifling': ['positive'], 'eelpout': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'slum_area': ['sadness', 'negative', 'disgust'], 'encyclopaedism': ['positive', 'joy'], 'stinking': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'sottish': ['negative', 'disgust'], 'explode': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'money_box': ['anger', 'positive', 'fear', 'sadness', 'negative'], 'capricious': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'muscularity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prohibit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue_angel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constipation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'celebrating': ['positive', 'joy', 'anticip'], 'dispiriting': ['sadness', 'negative'], 'clothe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accurse': ['anger', 'fear', 'sadness', 'negative'], 'driving': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'haired': ['negative', 'disgust'], 'accurst': ['anger', 'fear', 'sadness', 'negative'], 'collaborationist': ['trust'], 'resistor': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'tierce': ['positive'], 'free': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'untruth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'evil': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'enrapture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Rota': ['positive', 'trust'], 'wanted': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'fret': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Mickey': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pay_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'horseshit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jointly': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'toilet_facility': ['positive'], 'Sir_Herbert_Beerbohm_Tree': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'explicate': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'nonaddition': ['negative'], 'recite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gazelle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_a_breath': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'internal-combustion_engine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Siren': ['fear', 'negative'], 'bushwhack': ['anger', 'surprise', 'fear', 'negative'], 'snatch_up': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scissors': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excommunication': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'mercury': ['surprise', 'negative'], 'revival': ['anticip', 'positive', 'trust', 'joy'], 'pabulum': ['positive', 'trust'], 'instantaneousness': ['surprise'], 'overact': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'abridge': ['negative'], 'percentage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'duress': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'tragical': ['negative'], 'fastidiousness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vacillating': ['positive', 'trust'], 'conspicuously': ['positive'], 'comb_out': ['anger', 'fear', 'negative', 'anticip'], 'heartworm': ['disgust'], 'atmospheric_static': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'nominate': ['anger', 'sadness', 'negative', 'disgust'], 'countess': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'splenic_fever': ['fear', 'sadness', 'disgust', 'negative'], 'typewriter_ribbon': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'the_absurd': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'raw': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eternal_sleep': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unaffected': ['positive', 'negative'], 'ray': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toxic_condition': ['negative', 'disgust'], 'laugher': ['negative'], 'relapse': ['fear', 'sadness', 'negative'], 'isolated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'watch_glass': ['positive', 'negative'], 'wild_blue_yonder': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tibia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prime_quantity': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'glob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jactitate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'audition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commanding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glop': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'inexcusable': ['anger', 'sadness', 'negative', 'disgust'], 'glow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constancy': ['positive', 'fear', 'trust', 'negative', 'disgust'], 'partition': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'freeway': ['fear'], 'curio': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nascence': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pope': ['positive', 'trust'], 'queen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'William_Holman_Hunt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'queer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nascency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wile': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'launch_area': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commandment': ['positive', 'trust', 'anticip'], 'corn_whiskey': ['anger', 'negative'], 'map_out': ['surprise', 'trust', 'negative', 'positive'], 'enslave': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'scripture': ['trust'], 'axiom': ['positive', 'trust'], 'kindling': ['anger', 'fear', 'negative'], 'Bellow': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'pomposity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scandalization': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'reconstruct': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unmediated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rowing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collusion': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'idiotic': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'big_money': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'riches': ['positive', 'trust', 'joy'], 'malt_whiskey': ['surprise', 'negative'], 'talebearer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thralldom': ['fear', 'sadness', 'negative'], 'mull': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'temptation': ['negative'], 'make_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paternal': ['positive', 'negative', 'anticip'], 'startle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bestride': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'liaise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fortune_telling': ['anticip'], 'oxidation': ['negative'], 'contort': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'devout': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'put_forward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dedication': ['positive'], 'state_highway': ['fear'], 'abasement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'jelly': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'ventricular': ['disgust'], 'tattle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'tediousness': ['sadness', 'negative'], 'paries': ['sadness', 'negative', 'disgust'], 'confide': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vexer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comprehension': ['trust'], 'comical': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'rescission': ['negative'], 'bathroom': ['positive', 'trust', 'negative', 'disgust'], 'jobless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'binge': ['anger', 'negative'], "ma'am": ['positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'blower': ['negative'], 'confident': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'neoplasm': ['fear', 'sadness', 'negative'], 'musical_mode': ['positive', 'trust', 'anticip'], 'Thanksgiving': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'fleeting': ['surprise'], 'divine_service': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'bereavement': ['sadness', 'negative'], 'climb-down': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'craft': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backdown': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'smartness': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'cracker': ['anger', 'surprise', 'fear', 'negative', 'anticip'], 'inviolable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enmity': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'subjugate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cracked': ['anger', 'fear', 'negative'], 'precede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'famishment': ['fear', 'sadness', 'negative'], 'punctuality': ['positive'], 'articulatio_humeri': ['positive', 'trust'], 'find_fault': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Garrison': ['positive', 'trust'], 'cycle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hearth': ['positive'], 'incredulity': ['negative', 'disgust'], 'diverseness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Brigham_Young': ['anticip', 'positive', 'joy', 'anger', 'surprise', 'fear'], 'hearty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'detainee': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'turbidity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'rabbit_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nerve_impulse': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'mental_synthesis': ['anger', 'positive', 'sadness', 'negative', 'anticip'], 'Janus-faced': ['anger', 'sadness', 'negative', 'disgust'], 'after_part': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'upper_side': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sink_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Corse': ['sadness'], 'pitiful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'submissive': ['positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'teetotal': ['positive', 'trust'], 'rubicund': ['positive'], 'vulture': ['fear', 'negative', 'disgust'], 'plot_of_land': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bungling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incontrovertible': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], 'asshole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'advanced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trivia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "log_Z's": ['negative'], "cash_in_one's_chips": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gifted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fisticuffs': ['anger'], 'mindlessness': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'unsuspecting': ['surprise'], 'Katherine_Anne_Porter': ['positive', 'trust', 'joy'], 'Badger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bunco_game': ['negative'], 'assay-mark': ['trust'], 'mete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'accost': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'charabanc': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twist_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intellect': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hz': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jalopy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'convict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Hg': ['surprise', 'negative'], 'booking': ['positive', 'trust', 'negative', 'disgust'], 'jejune': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weasel-worded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unseasonableness': ['surprise'], 'con_game': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hobgoblin': ['fear', 'negative', 'disgust'], 'in_conclusion': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'druthers': ['positive', 'negative', 'disgust', 'anticip'], 'erotica': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'over-crowding': ['negative'], 'uniformity': ['positive'], 'wicket_door': ['positive'], 'saphead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cesspit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'steadily': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twitch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curry': ['anticip', 'positive', 'trust', 'negative', 'joy'], 'respondent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'presence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chain_reactor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'puzzle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncontrolled': ['negative'], 'finely': ['positive'], 'uncleanness': ['negative', 'disgust'], 'highschool': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'indispensable': ['positive'], 'Jewish-Orthodox': ['trust'], 'synthesis': ['surprise', 'fear', 'positive', 'sadness', 'negative'], 'abysmal': ['sadness', 'negative'], 'visitation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncle': ['negative', 'disgust'], 'outfox': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'solar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'removed': ['negative'], 'luxuriant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'viva': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'admiration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muster': ['negative'], 'take_a_shit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prowl': ['surprise', 'fear'], 'prematurely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trigonometry': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'penal': ['anger', 'fear', 'sadness', 'negative'], 'trim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'automobile_horn': ['fear', 'negative'], 'impropriety': ['anger', 'negative', 'disgust'], 'Libra_the_Balance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despotism': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'everlasting_flower': ['positive'], 'believable': ['positive', 'trust'], 'bring_forth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scrubby': ['negative'], 'upheaval': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'tit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waiting_area': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear'], 'tin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'luscious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stagnant': ['sadness', 'negative'], 'security_deposit': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'tie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vanished': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eternity': ['anticip'], 'nuance': ['anger', 'positive', 'negative'], 'phoenix': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'turnup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'get_ahead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uniformly': ['positive'], 'police_car': ['trust'], 'cable_system': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thorax': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'younger': ['positive'], 'sexual_conquest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'final_exam': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ineluctable': ['negative'], 'serious': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'premeditated': ['fear', 'negative'], 'remarkable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'difference_of_opinion': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'obviate': ['surprise', 'fear', 'sadness', 'negative'], 'snip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overreckoning': ['surprise', 'negative'], 'computation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recidivism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remarkably': ['positive'], 'abhorrent': ['anger', 'fear', 'negative', 'disgust'], 'computer_graphic': ['positive', 'joy'], 'Day': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overwrought': ['sadness', 'negative'], 'artwork': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'emption': ['positive'], 'ruthlessness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'policeman': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brother': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'mandarin_orange': ['positive', 'trust'], 'brothel': ['negative', 'disgust'], 'barroom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'quick': ['positive', 'fear', 'trust', 'sadness', 'negative'], 'red-faced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eroding': ['negative'], 'phrasing': ['positive', 'trust', 'negative', 'anticip'], 'comforting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hymn': ['anticip', 'joy', 'sadness', 'trust', 'positive'], 'stressful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'postman': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unripe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contracted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'servility': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'theist': ['anger', 'sadness', 'trust', 'negative', 'fear'], 'theism': ['negative', 'disgust'], 'fall_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'aircraft_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Aga': ['positive', 'fear', 'trust', 'negative'], 'water': ['positive', 'sadness', 'negative'], 'attainment': ['positive'], 'fluke': ['surprise', 'joy', 'trust', 'negative', 'positive'], 'crippled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hoarse': ['negative'], 'supplying': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'catnap': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'blotch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'law-abiding': ['positive', 'joy', 'surprise'], 'resonance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'potable': ['positive', 'negative'], 'pull_wires': ['anger', 'surprise', 'negative', 'anticip'], 'vendue': ['anticip'], 'vaccinum': ['positive'], 'Justice': ['anger', 'positive', 'trust', 'negative'], 'fishgig': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'expletive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'alcoholic_drink': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'voluted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thrum': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'mimicker': ['surprise', 'negative', 'positive'], 'transferrable': ['positive', 'trust', 'negative'], 'islet': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'pan_out': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wrecking': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'confounded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ravage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frothy': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'memory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dowse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'cabin_cruiser': ['trust'], 'unwarranted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dismay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'conductor': ['positive', 'trust'], 'cashier': ['trust'], 'drown': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'dismal': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'past_times': ['positive', 'trust', 'joy'], 'Apocalypse': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'tribunal': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'spaceman': ['positive'], 'modified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'radon': ['fear', 'negative'], 'flagship': ['trust'], 'streak': ['negative'], 'jeune_fille': ['positive', 'joy'], 'earphone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trump': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-possession': ['anger', 'positive', 'fear', 'negative', 'disgust'], 'downfall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vertiginous': ['negative'], 'despot': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'spoilation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'garboil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sectary': ['anger', 'fear', 'negative'], 'living-room': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wheel_spoke': ['positive', 'trust', 'negative', 'anticip'], 'inheritance': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'fossil_oil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endorsement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unappreciated': ['negative'], 'levy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taste_sensation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'clone': ['anger', 'negative'], 'Advent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heartbreaking': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'birthday': ['surprise', 'anticip', 'positive', 'joy'], 'floral': ['positive'], 'renovation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anthropophagite': ['fear', 'negative', 'disgust'], 'amuse': ['positive', 'joy'], 'send_back': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purification': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exclusive': ['positive', 'sadness', 'negative'], 'words': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'constituents': ['trust'], 'blare': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muck_up': ['sadness', 'negative', 'disgust'], 'missinglink': ['positive'], 'swank': ['surprise', 'fear', 'trust', 'negative', 'anticip'], 'choking_coil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sugarcoat': ['positive'], 'handgun': ['negative'], 'organisation': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'swearword': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'prodigality': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'rocking_horse': ['joy', 'positive'], 'swarthiness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'swindle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whirlpool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramble_on': ['anger'], 'draw_rein': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Spark': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'civilisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cancer_of_the_blood': ['anger', 'fear', 'sadness', 'negative'], 'advent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wearisome': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'self-annihilation': ['anger', 'fear', 'sadness', 'negative'], 'authenticity': ['positive', 'trust'], 'phalanx': ['fear', 'trust'], 'hysteric': ['anger', 'fear', 'negative'], 'sunrise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hysteria': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flaccid': ['sadness', 'negative'], 'set-aside': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absentminded': ['sadness', 'negative', 'fear'], 'factory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ruck': ['positive', 'trust'], 'extrapolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'collate': ['trust'], 'critical_point': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'maneuver': ['fear', 'trust'], 'President_Ford': ['positive'], 'hulk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unfriendly': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'attender': ['fear', 'trust'], 'hobble': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'notary': ['trust'], 'sophistication': ['anticip', 'positive', 'trust', 'joy'], 'accommodation': ['anticip', 'positive', 'trust', 'joy'], 'delude': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'come_up': ['positive'], 'stonecutter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'accordance_of_rights': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gusto': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sediment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motion': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'genus_Pan': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prehension': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'gusty': ['negative'], 'gruntle': ['positive'], 'suspend': ['negative'], 'surviving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symbolic': ['positive'], 'clumsy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tumbler_pigeon': ['positive', 'fear', 'trust', 'joy'], 'intone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paradiddle': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'seize_with_teeth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'earthy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'haggle': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'plastic': ['positive', 'trust'], 'molder': ['negative', 'disgust'], 'white': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'festivity': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'DoJ': ['anger', 'positive', 'trust', 'negative'], 'unobtainable': ['negative'], 'reverie': ['positive', 'trust', 'joy'], 'revue': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'season': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sound_judgment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'farce_comedy': ['fear', 'sadness', 'disgust', 'negative'], 'deceleration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'act_of_terrorism': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'self-respectful': ['positive'], 'wide': ['positive'], 'deserter': ['anger', 'negative'], 'sassing': ['surprise', 'negative'], 'at_rest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'poisoning': ['negative', 'disgust'], 'draw_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'birken': ['anger', 'fear', 'negative', 'disgust'], 'pleasurableness': ['positive'], 'generality': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pompousness': ['fear', 'negative'], 'impingement': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'episcopal': ['trust'], 'dryness': ['positive', 'trust', 'negative', 'disgust'], 'prosperity': ['positive'], 'conversion': ['anticip'], 'mental_case': ['fear', 'negative', 'disgust'], 'forcemeat': ['negative'], 'paraphrase': ['positive', 'trust', 'negative'], 'resort_area': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'tornado': ['fear'], 'boiling': ['anticip'], 'oral_communication': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'consignment': ['sadness', 'trust', 'negative'], 'neck_ruff': ['anger', 'surprise', 'negative', 'disgust'], 'multiply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forage': ['negative'], 'rascality': ['negative'], 'playing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'senior': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'quantity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slope': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'parliamentary_law': ['positive', 'fear', 'negative'], 'cloaca': ['negative', 'disgust'], 'amortisation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Samuel_Butler': ['positive', 'trust'], 'slops': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'trust'], 'hack': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motivative': ['positive'], 'featherbed': ['positive', 'trust', 'joy'], 'fulsome': ['positive'], 'obstinacy': ['negative'], 'shimmer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blue-belly': ['positive'], 'fickle': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'crystalized': ['positive'], 'wool': ['anger', 'sadness', 'negative', 'disgust'], 'dreaded': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crimper': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arguable': ['positive', 'trust', 'negative'], 'lighten': ['surprise', 'trust', 'positive', 'joy'], 'expectation': ['positive', 'anticip'], 'fixedness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Baroque': ['surprise', 'fear', 'negative', 'disgust'], 'mirthfully': ['positive', 'joy'], 'lateralisation': ['positive', 'trust'], 'impolite': ['negative', 'disgust'], 'naked': ['fear', 'sadness', 'negative'], 'unlicensed': ['negative'], 'quetch': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ignored': ['anger', 'sadness', 'negative', 'disgust'], 'come_together': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Scomber_japonicus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uneconomical': ['anger', 'sadness', 'negative', 'disgust'], 'euphony': ['anticip', 'positive', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'golf_hole': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'bluntness': ['negative'], 'undefiled': ['positive', 'trust', 'joy'], 'mortgage': ['fear', 'trust'], 'addled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'unappealing': ['anger', 'trust', 'negative', 'disgust', 'anticip'], 'arrival': ['anticip'], 'fearless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'straitlaced': ['anger', 'positive', 'trust', 'negative'], 'inseparable': ['positive', 'trust', 'joy'], 'domiciliate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'overcharge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'manufacturing_plant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'coma': ['fear', 'sadness', 'negative'], 'conservativism': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'comb': ['anger', 'fear', 'negative', 'anticip'], 'come': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'isthmus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slip_in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'psychotic_belief': ['anger', 'fear', 'sadness', 'negative'], 'superstar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fissure': ['negative'], 'ungentle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'provocation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'swaggering': ['anger', 'negative'], 'continuation': ['negative', 'anticip'], 'graveness': ['positive', 'trust', 'negative', 'disgust'], 'smooth-spoken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'white-haired': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'quinine': ['positive'], 'temporary_hookup': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bizarre': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'raring': ['negative', 'anticip'], 'mistiming': ['surprise', 'sadness', 'negative', 'anticip'], 'hobo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peaceful': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'abstract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'enraptured': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'followup': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'interrogative_sentence': ['fear'], 'infective': ['fear', 'sadness', 'disgust', 'negative'], 'remissness': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'indirect': ['trust'], 'tasteless': ['negative', 'disgust'], 'reimburse': ['positive', 'trust'], 'depository_library': ['positive'], 'final_examination': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hernia': ['negative', 'disgust'], 'exclamatory': ['positive', 'trust'], 'attentive': ['positive', 'trust'], 'research_lab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'refractory': ['negative'], 'unsatisfactory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'palliate': ['positive'], 'drive_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'telephone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dissident': ['anger', 'fear', 'negative'], 'telephony': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'artistic_production': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'contractable': ['fear', 'negative', 'disgust'], 'spell-bound': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'post-mortem_examination': ['fear', 'sadness', 'disgust', 'negative'], 'locking': ['fear', 'sadness', 'negative'], 'confidant': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'regularityofrecurrence': ['anticip'], 'Indian_file': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reminder': ['positive', 'fear', 'trust'], 'isle': ['anger', 'fear', 'trust', 'negative', 'disgust'], 'hermit': ['sadness', 'trust'], 'twosome': ['negative'], 'vocalism': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'psychiatric_hospital': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mockery': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'vocalise': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'muffled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'driven': ['surprise'], 'drivel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'canister': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'muffler': ['negative'], 'confusedness': ['anger', 'fear', 'negative'], 'prisoner_of_war': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'longing': ['sadness', 'anticip'], 'perennial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'minimize': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'illume': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'foyer': ['anger', 'fear', 'negative'], 'flakey': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'Godhead': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'soapsuds': ['negative'], 'desolate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'capturer': ['fear', 'negative'], 'unconstitutional': ['negative'], 'kilt': ['positive'], 'lavish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'violent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kill': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pastureland': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'kneeling': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'blow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'blot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gentleness': ['positive', 'negative'], 'hint': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simple_machine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'falsely': ['negative'], 'blob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'backbite': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'particle': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'sternly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intellectual_nourishment': ['positive', 'trust', 'joy'], 'sexual_relation': ['positive', 'trust', 'disgust'], 'disco_biscuit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deduct': ['negative'], 'neuralgia': ['fear', 'sadness', 'negative'], 'nitty-gritty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'divestment': ['negative'], 'perspiration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deduce': ['negative'], 'coddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'International': ['positive'], "catch_some_Z's": ['negative'], 'Paddy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slice': ['negative'], 'renounce': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unregenerate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'slick': ['positive'], 'unmatched': ['positive'], 'unhappiness': ['sadness', 'trust', 'negative', 'fear'], 'metropolis': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Book_of_Ruth': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'itching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inspect': ['positive', 'fear', 'trust', 'negative', 'anticip'], 'give_birth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voracious': ['anger', 'fear', 'sadness', 'negative'], 'arrivederci': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'valuation_account': ['positive'], 'surplusage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'baffled': ['negative'], 'chivy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'by_design': ['surprise', 'negative'], 'exquisite': ['positive', 'joy'], 'scornful': ['anger', 'negative'], 'improvize': ['surprise', 'anticip', 'positive'], 'accredit': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'John_Constable': ['trust'], 'tiddly': ['surprise', 'negative', 'anticip'], 'jade_green': ['sadness', 'trust', 'negative', 'anticip'], 'determine': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'enthronization': ['positive', 'trust', 'joy'], 'lastly': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'feudal': ['anger', 'sadness', 'negative'], 'pharmaceutics': ['positive', 'trust'], 'inadvertent': ['surprise', 'fear', 'negative'], 'backwater': ['sadness', 'negative'], 'trustor': ['positive', 'fear'], 'disposed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'peel_off': ['negative'], 'price_reduction': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expatriate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'valley': ['trust'], 'energy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gibe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vested': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'fundamentals': ['positive', 'trust'], 'tranquility': ['positive', 'trust', 'joy'], 'baronial': ['positive', 'trust'], 'betoken': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'cabinet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sleaze': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fabricate': ['anticip', 'positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'pulverization': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Twin': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lonesomeness': ['fear', 'sadness', 'negative'], 'sure-enough': ['positive', 'sadness', 'trust', 'negative'], 'tiptop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'toilet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'frighten': ['surprise', 'fear', 'sadness', 'negative'], 'contributory': ['positive', 'anticip'], 'intro': ['sadness', 'negative'], 'incorrect': ['negative'], 'abyss': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'overcloud': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'inculpation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'monstrance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear'], '5': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ramification': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'trash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stalwart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cypress': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abysm': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'championship': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'separate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'symbol': ['positive'], 'cove': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'stocky': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taciturnity': ['negative'], 'requester': ['negative'], 'stocks': ['negative'], 'luxate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hereunder': ['anticip'], 'applause': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'calls': ['trust', 'negative', 'anticip'], 'answerableness': ['positive', 'trust'], 'sportswoman': ['negative'], 'lace': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'embolism': ['fear', 'sadness', 'negative'], 'ad-lib': ['surprise', 'anticip', 'positive'], 'executing': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dry_out': ['positive', 'trust'], 'catastrophe': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'lining': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sparkling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'infirmary': ['positive', 'fear', 'trust', 'sadness'], 'hemi': ['positive', 'trust'], 'Sir_Frederick_Handley_Page': ['anger', 'fear', 'negative'], 'chameleon': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'fat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'plank_over': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'fear', 'trust'], 'cyclone': ['surprise', 'fear', 'negative'], 'coursing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fan': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'hemp': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fad': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plump_down': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'ranting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prolonged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'entourage': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'synergy': ['positive', 'trust'], 'functioning': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paralyse': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'importee': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'opaqueness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'whimper': ['fear', 'sadness'], 'anniversary': ['positive', 'joy', 'surprise'], 'gaseous_state': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'tauten': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'twenty_percent': ['fear'], 'depreciation': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'overstatement': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'magnetic_core': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hopelessness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'relaxation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'observing': ['positive', 'joy', 'surprise'], 'thrift': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'tomfool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'miniature': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gleeful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'runoff': ['surprise', 'fear', 'sadness', 'negative', 'disgust'], 'chain': ['anger', 'sadness', 'negative'], 'godless': ['anger', 'negative'], 'tightness': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'trust'], 'worked_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suddenly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fearfully': ['surprise', 'fear', 'sadness', 'negative'], 'aberrant': ['negative'], 'disenable': ['fear', 'sadness', 'negative'], 'wield': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'shite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "make_up_one's_mind": ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'even_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'last_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inborn_reflex': ['surprise'], 'unprompted': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear'], 'bulblike': ['negative'], 'compromising': ['anger', 'positive', 'sadness', 'trust', 'negative'], 'stutter': ['anger', 'positive', 'fear', 'trust', 'negative'], 'ethical_motive': ['anticip', 'positive', 'disgust', 'joy', 'anger', 'surprise', 'trust'], 'domination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outlawry': ['anger', 'fear', 'negative'], 'stick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oleaginous': ['disgust'], 'spendthrift': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise'], 'berth': ['positive'], 'plagiarism': ['fear', 'negative', 'disgust'], 'erratum': ['negative'], 'plagiarise': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'trust'], 'memorialization': ['positive', 'sadness', 'anticip', 'joy'], 'forbearance': ['positive', 'trust', 'negative', 'anticip'], 'undertide': ['anger', 'negative'], 'plagiarist': ['anger', 'negative'], 'shielder': ['positive', 'trust'], 'counselor-at-law': ['anger', 'positive', 'fear', 'trust', 'negative'], 'challenging': ['anticip', 'positive', 'trust', 'joy'], 'prompting': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'honestness': ['positive', 'trust', 'negative', 'disgust'], 'emergency_brake': ['surprise', 'fear', 'sadness', 'negative'], 'Capsicum_annuum_grossum': ['positive'], 'plectron': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spoilable': ['negative'], 'peregrine': ['anticip'], 'Hope': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'speeding': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buzzword': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shoo-in': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mould': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simplicity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'engild': ['positive'], 'empale': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reflect': ['anticip', 'positive', 'negative', 'joy', 'fear', 'trust'], 'logic_gate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'gaudiness': ['anger', 'negative'], 'distrustfulness': ['positive', 'negative', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'replete': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'penitentiary': ['anger', 'negative'], 'rending': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'misanthropic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonchalantly': ['surprise'], 'departure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'groundless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'callback': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'trust'], 'jigaboo': ['negative'], 'retaliate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'admonishment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncase': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'disabled': ['fear', 'sadness', 'negative'], 'bigoted': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'Mandarin': ['positive', 'trust'], 'conformism': ['trust'], 'unsated': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'trust'], 'March': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jollify': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'propensity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prodigy': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harmless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Opposition': ['anger', 'fear', 'negative', 'disgust'], 'self-willed': ['anger', 'sadness', 'negative'], 'return': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'in_and_of_itself': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'accumulate': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'insane_asylum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsavoriness': ['sadness', 'negative', 'disgust'], 'abacus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'surprise', 'trust'], 'Ram': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'refresh': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'black_flag': ['anger', 'fear', 'negative'], 'firmament': ['positive', 'trust', 'joy'], 'needless': ['disgust'], 'generation': ['positive', 'trust', 'negative', 'disgust', 'joy'], 'beneficent': ['trust'], 'fixture': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'inflict': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'filmdom': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'poke_at': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'loll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'congenial': ['positive'], 'craving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'forgive': ['positive'], 'clinch': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abeyance': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'surprise', 'fear', 'trust'], 'blister': ['negative', 'disgust'], 'discriminating': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'thread': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'threat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chew_out': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upper': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'relate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'churning': ['fear', 'negative'], 'Don_Marquis': ['positive'], 'fancy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plummet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wench': ['joy', 'negative', 'disgust', 'positive', 'anger', 'trust'], 'unredeemed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cigaret': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unforfeitable': ['positive'], 'science_lab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'script': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'regulation': ['trust'], 'doomsday': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'passee': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'finances': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'formalness': ['trust'], 'headache': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'treasured': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'option': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boilerplate': ['negative'], 'enterprisingness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'importunity': ['surprise', 'fear', 'anticip'], 'treasurer': ['trust'], 'spinal_fusion': ['anger', 'positive', 'fear', 'negative'], 'vindication': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'convinced': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reliever': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throttle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sinless': ['positive', 'trust'], 'organ_pipe': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'double': ['positive', 'anticip'], 'the_great_unwashed': ['disgust'], 'stall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dank': ['disgust'], 'stale': ['anger', 'negative', 'disgust'], 'endowment_fund': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'net_profit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pillaging': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Orange': ['positive'], 'vagabondage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gala': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gall': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'remodel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trip_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'buff': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'plagiarization': ['fear', 'negative', 'disgust'], 'queasiness': ['sadness', 'negative', 'anticip'], 'Coventry': ['anger', 'sadness', 'negative', 'disgust'], 'matte_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'reach': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'secondlieutenant': ['positive', 'trust'], 'splay': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'miserly': ['surprise', 'trust', 'positive', 'negative', 'anticip'], 'achievement': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bugaboo': ['anger', 'fear', 'sadness', 'negative'], 'Creation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hindrance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mental_object': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'electrical_energy': ['positive'], 'sea_dog': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fond': ['positive', 'trust', 'joy'], 'puberulent': ['positive'], 'font': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'set-apart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'workfellow': ['positive', 'trust'], 'betray': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'hip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sacking': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unconsidered': ['anger', 'sadness', 'negative', 'disgust'], 'babble': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'hang-up': ['surprise', 'negative'], 'nonaged': ['negative'], 'hie': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instinctive': ['anger', 'positive', 'fear', 'disgust'], 'banquet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ampoule': ['positive', 'joy'], 'baroque': ['surprise', 'fear', 'negative', 'disgust'], 'tourney': ['anger', 'positive', 'trust', 'negative', 'disgust'], 'insensible': ['positive', 'negative'], 'stump': ['positive'], 'dump': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'supporting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'intelligence': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'limited_review': ['surprise', 'fear', 'negative'], 'bank_check': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'absurdness': ['negative'], 'barb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dumb': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bard': ['anger', 'positive', 'fear', 'negative'], 'barf': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unsure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'bark': ['anger', 'negative'], 'ark': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'arm': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'glistening': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'carry_off': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'distinctive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drooping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'various': ['trust'], 'consecutive': ['trust', 'anticip'], 'inauguration': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'denomination': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'Harkat_ul-Ansar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'penchant': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'opposition': ['anger', 'fear', 'negative', 'disgust', 'anticip'], 'turn_a_profit': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'missionary_post': ['positive', 'trust', 'anticip'], 'riddled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fraternity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chorus_line': ['positive'], 'arbitrarily': ['surprise'], 'clashing': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'Ford_Madox_Ford': ['positive'], 'improper': ['negative'], 'apache': ['fear', 'negative'], 'begetter': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sacramental_manduction': ['positive', 'trust', 'joy'], 'Dubyuh': ['anger', 'surprise', 'fear', 'negative', 'disgust'], 'acrid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'eyewitness': ['trust'], 'overlook': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'reduction': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'watchword': ['anticip', 'positive', 'negative', 'joy', 'anger', 'fear', 'trust'], 'herb_tea': ['positive'], 'debasing': ['fear', 'sadness', 'disgust', 'negative'], 'passably': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'strikebreaker': ['negative'], 'heighten': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stolen': ['anger', 'negative'], 'civility': ['positive'], 'ill-chosen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'precursor': ['anticip', 'positive', 'negative', 'anger', 'fear', 'trust'], 'behavior': ['anger', 'surprise', 'negative', 'disgust'], 'electric-light_bulb': ['negative'], 'rip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ecstasy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rim': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'run_into': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rig': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anguish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'lengthy': ['positive', 'trust', 'joy'], 'twofold': ['positive', 'anticip'], 'minim': ['negative'], 'excruciation': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'cumulus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'widely': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'uncertainty': ['surprise', 'negative', 'anticip'], 'change_of_mind': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'trust'], 'negotiate': ['positive', 'trust'], 'organic_fertilizer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'playscript': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obit': ['positive', 'sadness', 'trust', 'negative', 'surprise'], 'mass_murder': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'shoot_a_line': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perquisite': ['positive'], 'atrociousness': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'solemnity': ['positive', 'trust', 'negative', 'disgust'], 'unconformity': ['surprise'], 'John_Rock': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'expansion_slot': ['negative', 'disgust'], 'edge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stumblebum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'starved': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'endeavour': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'galvanising': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'vigilant': ['positive', 'fear', 'trust'], 'infract': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'instruction_execution': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'tamed': ['sadness', 'negative'], 'old-time': ['positive', 'trust', 'joy'], 'Sir_Henry_Rider_Haggard': ['sadness', 'negative', 'fear'], 'theorem': ['trust'], 'bay_wreath': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "waste_one's_time": ['negative'], 'pin_down': ['negative'], 'aggregation': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'antiseptic': ['positive', 'trust'], 'glittery': ['positive', 'joy'], 'Jehovah': ['positive', 'trust'], 'cognitive_operation': ['anger', 'fear', 'negative'], 'pushcart': ['fear', 'negative'], 'incidental': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'shabu': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ignore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'urge_on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'acceptation': ['positive', 'trust'], 'specialness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'physicalism': ['negative'], 'war-ridden': ['anger', 'fear', 'negative'], 'impassioned': ['anger', 'negative', 'disgust'], 'news_show': ['anticip', 'positive', 'negative', 'anger', 'surprise', 'fear'], 'eluding': ['surprise', 'negative'], 'litter': ['positive', 'negative', 'disgust', 'joy'], 'loser': ['fear', 'sadness', 'disgust', 'negative'], 'selfishness': ['negative'], 'modernize': ['positive', 'anticip'], 'anesthetic_agent': ['sadness', 'negative'], 'indictable': ['fear', 'sadness', 'negative'], 'prow': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'prop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'trust'], 'dorsum': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ticking': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'prog': ['anticip', 'joy', 'sadness', 'positive', 'fear', 'trust'], 'prof': ['positive', 'trust'], 'prod': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'apathetic': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'achromatism': ['negative', 'disgust'], 'horse_wrangler': ['negative'], 'uncounted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'streetcar': ['fear', 'sadness', 'disgust', 'negative'], 'intense': ['positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vigorish': ['negative'], 'complementary_color': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tortuous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'completing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'senile': ['fear', 'sadness', 'negative'], 'mental_attitude': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hatred': ['anger', 'sadness', 'negative', 'disgust', 'fear'], 'credible': ['positive', 'trust'], 'tipsiness': ['negative'], 'incoherence': ['fear', 'negative'], 'military_volunteer': ['negative'], 'finalize': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'glooming': ['sadness', 'negative'], 'piteous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'incoherency': ['fear', 'negative'], 'colorize': ['sadness', 'negative', 'disgust'], 'pallid': ['sadness', 'negative', 'fear'], 'discourtesy': ['negative', 'disgust'], 'stupefaction': ['anger', 'surprise', 'fear', 'negative'], 'signified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fearfulness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perplexing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_aback': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'crank': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'auf_wiedersehen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'upright': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gallantry': ['positive'], 'commercialism': ['trust'], 'move_over': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commercialise': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'trust'], 'nut_case': ['anger', 'negative'], 'gunpoint': ['anger', 'positive', 'sadness', 'negative', 'disgust'], 'Sagittarius_the_Archer': ['anticip'], 'entailment': ['negative'], 'tentative': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'malicious': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'frig_around': ['negative'], 'Eastern_Orthodox': ['trust'], 'ornamented': ['positive'], 'caparison': ['anger', 'positive', 'fear', 'negative'], 'irk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forty_winks': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'pureness': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'deadbolt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cannister': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'move_through': ['anticip'], 'digressive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'anserine': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'unbendable': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Reformation': ['positive'], 'earth-closet': ['negative', 'disgust'], 'scroll': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'paw': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'turn_of_events': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'per_se': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'trust'], 'United_States_Treasury': ['trust'], 'fuddled': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'adjustment': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chiropteran': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'prospectively': ['anticip'], 'varlet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fenced': ['anger'], 'squeezing': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ridiculousness': ['negative'], 'blandish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'abode': ['positive', 'trust'], 'skin_doctor': ['trust'], 'nutrify': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'harlot': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'savorless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outdo': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'noted': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'defensive_structure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'curtly': ['anger', 'fear', 'anticip', 'sadness', 'negative'], 'plexus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'procession': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'narcotized': ['sadness'], 'sciatica': ['negative'], 'lusus_naturae': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fermenting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'amobarbital_sodium': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'hourly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spelunk': ['negative'], 'absquatulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'waiting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attire': ['negative', 'disgust'], 'chop_up': ['fear', 'negative', 'disgust'], 'ad_valorem_tax': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'scrapper': ['anger', 'fear', 'negative'], 'unremitting': ['positive', 'trust', 'negative'], 'flavourer': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'meritable': ['positive', 'trust', 'joy'], 'opiate': ['negative'], 'Hardy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'simpleton': ['anger', 'negative', 'disgust'], 'typic': ['positive', 'fear'], 'science_laboratory': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'stay_fresh': ['positive', 'trust'], 'declivity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'deputy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'forbid': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'confession': ['anticip', 'positive', 'negative', 'sadness', 'surprise', 'fear', 'trust'], 'scaley': ['negative'], 'scaled': ['negative'], 'intellection': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'motor': ['positive'], 'apply': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'depute': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprovoked': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cauterise': ['anger', 'negative', 'disgust'], 'black_rockweed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'off-and-on': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'weeping': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cyclopaedia': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pitter-patter': ['anger', 'negative'], 'inclined': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'briery': ['fear', 'negative'], 'remission': ['positive', 'sadness', 'trust', 'negative', 'joy'], 'cooperate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'faultless': ['positive', 'trust', 'joy'], 'penis': ['fear', 'sadness', 'disgust', 'negative'], 'benignant': ['positive', 'joy'], 'annoy': ['anger', 'fear', 'negative', 'disgust'], 'wind_up': ['anger', 'sadness', 'negative', 'fear'], 'untasted': ['negative'], 'nuclear_fusion_reaction': ['anger', 'positive', 'fear', 'negative'], 'self-worth': ['positive', 'trust'], 'feebleminded': ['negative', 'disgust'], 'column': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pig_bed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proof': ['positive', 'trust', 'anticip'], 'tat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'taw': ['fear'], 'tap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'forgivingness': ['positive'], 'earnestness': ['positive', 'fear', 'sadness'], 'tax': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rapt': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear', 'trust'], 'heaving': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'condescend': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'tab': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'securities_industry': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'serial': ['trust', 'anticip'], 'rape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'commonness': ['trust'], 'jape': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'guru': ['positive', 'trust'], 'inaugural': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fortunate': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'earth_tremor': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear'], 'duette': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'undersized': ['negative'], 'fosterage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'panic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'exemplify': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'fear', 'trust'], 'administrator': ['trust'], 'condole_with': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'smoking_carriage': ['negative'], 'perjury': ['surprise', 'fear', 'negative'], 'expatriation': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'ethnic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'bursary': ['trust'], 'skullduggery': ['anticip', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'ash_gray': ['surprise', 'negative', 'positive'], 'insect_bite': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'interrupted': ['sadness', 'negative'], 'geartrain': ['positive'], 'lady_of_pleasure': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'crawling': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'irregularity': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'irresolution': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'unjustified': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'scandalise': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dearest': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obeisance': ['positive'], 'interrogative': ['fear'], 'gunslinger': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'complicate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'inlet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'voiceless': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'choose': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'covered': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bye': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'nonindulgence': ['sadness', 'trust'], 'pending': ['fear', 'anticip'], 'crash': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'theistical': ['anger', 'sadness', 'trust', 'negative', 'fear'], 'practice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unprocurable': ['negative'], 'flout': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'attestor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Adam': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excitability': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tram': ['fear', 'sadness', 'disgust', 'negative'], 'mirthful': ['negative', 'disgust'], 'muddy_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'fiddle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'trap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tray': ['negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear'], 'counterinsurgency': ['positive', 'trust', 'joy'], 'pal_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'besufficient': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'category': ['positive', 'joy'], 'semen': ['positive', 'trust', 'negative', 'joy'], 'ejaculate': ['sadness', 'negative', 'disgust'], 'furiously': ['anger'], 'liberalisation': ['positive'], 'prospicient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'impart': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tardily': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sacrifice': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'proviso': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dictionary': ['positive', 'trust'], 'tyrannic': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'diva': ['positive', 'fear', 'negative', 'surprise'], 'peace_of_mind': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'obliteration': ['anger', 'fear', 'sadness', 'negative'], 'segregated': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'academic_session': ['anger', 'fear', 'negative', 'disgust'], 'substantiate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'public_convenience': ['positive'], 'feasible': ['negative'], 'conversation': ['positive'], 'calvary': ['fear', 'sadness', 'negative'], 'air_castle': ['positive', 'trust', 'joy'], 'bleakness': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'hitherto': ['negative'], 'probation': ['positive', 'fear', 'trust', 'sadness', 'anticip'], 'endemic': ['fear', 'sadness', 'disgust', 'negative'], 'come_away': ['negative'], 'salient': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'droop': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flourish': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'outre': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'accent': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'grantor': ['positive', 'fear'], 'motorcar': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'drool': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'doomed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'higher-up': ['positive'], 'simulate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'pressure_level': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'constituent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'institution': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Ursus_arctos_horribilis': ['fear', 'sadness', 'negative', 'disgust'], 'bismuth': ['positive', 'negative', 'disgust'], 'KO': ['negative'], 'frugal': ['positive'], 'enticement': ['negative'], 'sculpture': ['positive'], 'soot_black': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'lateness': ['negative'], 'woebegone': ['sadness', 'negative', 'disgust'], 'persecute': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'outstrip': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sorcerous': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'recuperative': ['positive', 'joy', 'trust', 'anticip'], 'afraid': ['fear', 'negative'], 'florid': ['positive'], 'oozing': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'agency': ['anticip', 'positive', 'trust', 'joy'], 'invigilate': ['positive', 'trust'], 'divert': ['positive', 'joy'], 'divers': ['anger', 'positive', 'negative', 'disgust', 'surprise'], 'gracelessness': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'greyish_brown': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'centre': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Dean_Swift': ['positive'], 'filch': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'flawlessness': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'time_period': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'courageousness': ['positive'], 'deny': ['anger', 'negative', 'anticip'], 'lordliness': ['positive', 'trust'], 'dent': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cloaked': ['surprise', 'negative', 'anticip'], 'Earth': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'inane': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'surprise', 'fear', 'trust'], 'dining_table': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ill-shapen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'purely': ['positive', 'trust'], 'chicken': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'debate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dandruff': ['negative'], 'grazing_land': ['positive', 'negative'], 'craziness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'syndicalist': ['anger', 'fear', 'negative'], 'storekeeper': ['trust'], 'procreative': ['positive', 'joy'], 'plum_tree': ['positive', 'fear', 'negative', 'anticip'], 'surefooted': ['positive', 'trust', 'joy'], 'vigor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'merchandiser': ['trust'], 'indulge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'flirting': ['anticip', 'joy', 'negative', 'positive', 'anger', 'surprise', 'trust'], 'bigmouthed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'suer': ['negative'], 'dopy': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sonsy': ['positive', 'anticip', 'joy'], 'self-evident': ['trust'], 'penetrate': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'wordy': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mouthful': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ghetto': ['fear', 'sadness', 'disgust', 'negative'], 'heretic': ['negative', 'disgust'], 'expertness': ['positive', 'trust'], 'genteel': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cleavage': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'highjack': ['anger', 'negative'], 'view': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'chin_wag': ['positive', 'negative'], 'ebb': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'unbeloved': ['negative'], 'turbulent': ['anger', 'surprise', 'fear', 'negative'], 'churchman': ['positive', 'negative', 'sadness', 'joy', 'surprise', 'trust'], 'violet': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'oddment': ['surprise'], 'liquidness': ['anger', 'joy', 'sadness', 'negative'], 'closet': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'record': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'beef_up': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'superb': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'genius': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'entrant': ['surprise', 'fear'], 'closed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'vacillant': ['anticip', 'positive', 'negative', 'sadness', 'anger', 'surprise', 'fear', 'trust'], 'masterful': ['anticip', 'positive', 'negative', 'disgust', 'joy', 'surprise', 'trust'], 'pants': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'spoil': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gusset_plate': ['trust'], 'dependance': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'declining': ['negative'], 'soapbox': ['positive'], 'profanity': ['anger', 'negative'], 'drag_through_the_mud': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'broadside': ['anger', 'negative', 'disgust', 'anticip'], 'befuddlement': ['surprise', 'fear'], 'grain': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'tousle': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'speech_rhythm': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'surprise', 'fear'], 'electric_glow': ['positive', 'trust', 'joy'], 'hyphen': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'big_H': ['anger', 'fear', 'negative'], 'worldly': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'take_heed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'fear', 'trust'], 'true_laurel': ['anger', 'fear', 'negative'], 'egotism': ['positive', 'negative', 'disgust', 'anger', 'fear', 'trust'], 'validating': ['trust'], 'on_purpose': ['surprise', 'negative'], 'thrusting': ['anger', 'trust', 'negative', 'anticip'], 'serial_publication': ['trust', 'anticip'], 'folding': ['positive', 'fear', 'anticip', 'negative', 'surprise'], 'repetition': ['surprise'], 'irrevokable': ['negative'], 'wily': ['positive', 'negative', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'wilt': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'herpesvirus': ['negative', 'disgust'], 'irate': ['anger', 'negative'], 'will': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'oneirism': ['positive', 'trust', 'joy'], 'spumy': ['anticip', 'positive', 'negative', 'joy', 'anger', 'surprise'], 'wild': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'excursive': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'perseveration': ['positive', 'fear', 'sadness', 'disgust', 'negative'], 'hobbyhorse': ['joy', 'positive'], 'stridor': ['anger', 'surprise', 'fear', 'negative'], 'far-out': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'propaedeutic': ['anticip'], 'whorl': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'whore': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'headlight': ['anticip'], 'adverse': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'merciful': ['positive'], 'fomentation': ['negative'], 'privileged': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'trust'], 'factor_in': ['positive', 'trust', 'negative', 'disgust', 'anticip'], 'unwished-for': ['sadness', 'negative'], 'premiere': ['anticip', 'positive', 'negative', 'sadness', 'joy', 'anger', 'fear', 'trust'], 'diploma': ['positive', 'trust', 'anticip'], 'projectiles': ['fear'], 'arse': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fill_up': ['trust', 'anticip'], 'overwork': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slap-up': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'sensing': ['positive'], 'eruct': ['fear', 'sadness', 'negative', 'disgust'], 'rocker': ['anticip', 'positive', 'trust', 'joy'], 'rocket': ['anger'], 'affright': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'despiteful': ['anger', 'fear', 'negative', 'disgust'], 'Greenwich_Village': ['positive', 'trust'], 'cultus': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'happiness': ['positive', 'sadness', 'joy', 'negative', 'anticip'], 'temerity': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'disturbance': ['anger', 'surprise', 'fear', 'sadness', 'negative'], 'small_town': ['positive', 'trust'], 'hunker_down': ['negative'], 'sky': ['anticip', 'positive', 'negative', 'joy', 'surprise', 'fear'], 'hall': ['anger', 'fear', 'negative'], 'adoption': ['positive', 'trust'], 'ski': ['positive', 'negative', 'sadness', 'anger', 'fear', 'trust'], 'Mediterranean_Sea': ['positive'], 'class_period': ['positive', 'trust'], 'saturation': ['positive', 'trust'], 'sick': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'visibleness': ['fear'], 'overmaster': ['positive', 'negative', 'sadness', 'anger', 'surprise', 'fear'], 'know': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'knot': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'boob': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'spin_around': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ahem': ['positive', 'negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'turn_away': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'Labour_Party': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'surprise', 'trust'], 'lengthways': ['trust'], 'full-of-the-moon': ['positive', 'negative', 'sadness', 'disgust', 'joy', 'surprise', 'fear', 'trust'], 'nigga': ['negative'], 'shabby': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sequence': ['positive', 'sadness', 'trust', 'negative', 'anticip'], 'dispossession': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'searching': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'fear', 'trust'], 'holler': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'making_water': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'empire': ['negative', 'sadness', 'disgust', 'anger', 'fear', 'trust'], 'neglecting': ['negative'], 'leaden': ['negative'], 'lead': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leak': ['sadness', 'negative'], 'lean': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leap': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], "coup_d'etat": ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'brake_shoe': ['anger', 'fear', 'sadness', 'negative'], 'glacial': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'leader': ['positive', 'trust'], 'uneffective': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'locate': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'mania': ['anger', 'fear', 'negative'], 'murderer': ['anger', 'fear', 'sadness', 'disgust', 'negative'], 'slur': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'mitt': ['trust', 'negative'], 'slut': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slum': ['sadness', 'negative', 'disgust'], 'slub': ['surprise', 'trust', 'positive', 'negative', 'joy'], 'tempered': ['positive', 'trust'], 'mite': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ignition_system': ['anger', 'fear', 'negative'], 'slug': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'slue': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throne': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'throng': ['disgust'], 'incline': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'getting': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dependence': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'surge': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'squealer': ['negative'], 'dependency': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'cakehole': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'unlikable': ['anger', 'negative', 'disgust'], 'warranty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'bugle': ['anticip'], 'argumentative': ['negative'], 'versed': ['anticip', 'joy', 'negative', 'positive', 'fear', 'trust'], 'warrants': ['trust', 'negative', 'anticip'], 'tag': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'headphone': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brush': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'brusk': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'dispossessed': ['anger', 'fear', 'sadness', 'negative'], 'brilliantly': ['anticip', 'positive', 'trust', 'surprise', 'joy'], 'poove': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'maize': ['negative', 'disgust'], 'Ball': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'effeminate': ['negative'], 'Bale': ['fear', 'negative'], 'imperviable': ['positive'], 'unsufferable': ['sadness', 'negative'], 'uncontrollable': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear'], 'chicken_feed': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'draw_in': ['anticip', 'joy', 'negative', 'sadness', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'concision': ['positive', 'trust', 'surprise'], 'funds': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'ataloss': ['negative'], 'wight': ['anger', 'fear', 'sadness', 'negative', 'disgust'], 'contradictory': ['anger', 'fear', 'sadness', 'negative'], 'bratwurst': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goose': ['negative'], 'recede': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'gelatine': ['anticip', 'positive', 'disgust', 'joy', 'surprise', 'trust'], 'windfall': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'waterlessness': ['positive', 'trust', 'negative', 'disgust'], 'meaningless': ['sadness', 'negative'], 'dearth': ['sadness', 'negative'], 'carbohydrate': ['positive'], 'hardiness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'goodness': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'attack_aircraft_carrier': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boor': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'anger', 'fear'], 'boot': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'defending_team': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'book': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'boom': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'boon': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'heat_energy': ['anticip', 'joy', 'negative', 'sadness', 'disgust', 'positive', 'anger', 'surprise', 'fear', 'trust'], 'lance': ['positive', 'fear', 'trust', 'anticip'], 'junk': ['negative'], 'guard_duty': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'fall_flat': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'sherd': ['positive', 'negative', 'disgust'], 'dissension': ['anger', 'surprise', 'sadness', 'negative', 'fear'], 'Aaron_Montgomery_Ward': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'track_down': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'rotting': ['negative', 'disgust'], 'heart-to-heart': ['anticip', 'surprise', 'trust', 'positive', 'joy'], 'orphic': ['anticip', 'positive', 'negative', 'sadness', 'disgust', 'joy', 'anger', 'surprise', 'fear', 'trust'], 'jawbone': ['fear', 'negative', 'disgust']}
    
    def __init__(self, text):
        self.text = text
        blob = TextBlob(text)
        self.words = list(blob.words)
        self.sentences = list(blob.sentences)
        build_word_affect(self)
        top_emotions(self)

    def append_text(self, text_add):
        self.text = self.text + ' ' + text_add
        blob = TextBlob(self.text)
        self.words = list(blob.words)
        self.sentences = list(blob.sentences)
        build_word_affect(self)